import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:sixam_mart/controller/user_controller.dart';
import 'package:sixam_mart/data/api/api_checker.dart';
import 'package:sixam_mart/data/model/response/wallet_model.dart';
import 'package:sixam_mart/data/repository/wallet_repo.dart';
import 'package:sixam_mart/view/base/custom_snackbar.dart';

import '../data/model/response/AllRegisteredUsersResponse.dart';
import '../data/model/response/PrimePaymentTrackResppnse.dart';
import '../data/model/response/UserIndentityResModel.dart';
import '../data/model/response/WallerTransferHistoryResponseModel.dart';
import '../data/model/response/closing_response.dart';
import '../data/model/response/response_model.dart';
import '../data/model/response/revenue_statement_response.dart';
import '../data/model/response/upi_payments_list_response.dart';
import '../data/model/response/wallet_statement_response.dart';
import '../data/model/response/wallet_withdrawal_requests_history_model.dart';
import '../data/repository/all_prime_members_repo.dart';
import '../helper/route_helper.dart';
import '../util/app_constants.dart';
import '../view/screens/checkout/widget/wallet_withdrawal_request_successfull.dart';
import 'closing_controller.dart';

class AllPrimeMembersController extends GetxController implements GetxService{
  final AllPrimeMembersRepo allPrimeMembersRepo;
  AllPrimeMembersController({@required this.allPrimeMembersRepo});

  List<AllRegisteredUsersData> _allRegisteredUsersDataList;
  List<AllRegisteredUsersData> _searchedPrimeMembersList;
  AllRegisteredUsersData _selectedPrimeToViewStatement;
  bool _isSearchMode = false;
  bool _isSearchPrimeMembersLoading = false;
  int _offset = 1;
  int _pageSize;
  double _allPrimeMembersAmt;
  bool _isLoading = false;
  String _amtGreaterThanZero = "0";
  String _searchQuery = "";

  List<AllRegisteredUsersData> get allRegisteredUsersDataList => _allRegisteredUsersDataList;
  bool get isSearchPrimeMembersLoading => _isSearchPrimeMembersLoading;
  bool get isSearchMode => _isSearchMode;
  int get offset => _offset;
  int get totalPageSize => _pageSize;
  double get allPrimeMembersAmt => _allPrimeMembersAmt;
  bool get isLoading => _isLoading;
  String get amtGreaterThanZero => _amtGreaterThanZero;
  String get searchQuery => _searchQuery;
  List<AllRegisteredUsersData> get searchedPrimeMembersList => _searchedPrimeMembersList;
  AllRegisteredUsersData get selectedPrimeToViewStatement => _selectedPrimeToViewStatement;


  void selectPrimeMemberToViewStatement(AllRegisteredUsersData item) {
    _selectedPrimeToViewStatement = item;
    update();
  }
  void searchModeDisable() {
    _isSearchMode=false;
    _offset = 1;
    update();
  }
  void setOffset(int offset) {
    _offset = offset;
    update();
  }
  void showBottomLoader() {
    _isLoading = true;
    update();
  }
  void setAmtGreaterThanZero(String value) {
    _amtGreaterThanZero = value;
    update();
  }
  void setSearch(String value) {
    _searchQuery = value;
    update();
  }

  Future<void> getRegisteredUsers(String title,bool load) async {

    if(!load){
      _allRegisteredUsersDataList = null;
    }
    _isLoading = true;

    update();

    String userType='0';
    if(title=='prime_members'.tr){
      userType='1';
    }

    String url='${AppConstants.REGISTERED_USERS_URL}?offset=$offset&limit=10&user_type=$userType&query_text=&amt_greater_than_zero=$_amtGreaterThanZero';

    if(searchQuery.isNotEmpty){
      url = url+'&query_text=$searchQuery';
    }
    Response response = await allPrimeMembersRepo.getData(url);
    _isLoading = false;
    if (response.statusCode == 200) {
      if(!load){
        _allRegisteredUsersDataList=[];
      }

      AllRegisteredUsersResponse  _res = AllRegisteredUsersResponse.fromJson(response.body);
      _pageSize = _res.totalSize;
      _allPrimeMembersAmt = _res.totalBalance;

      _allRegisteredUsersDataList.addAll(_res.data);

      update();
    } else {
      ApiChecker.checkApi(response);
    }
    update();
  }

  Future<void> searchRegisteredUsers(String title,bool load) async {

    _isSearchMode = true;
    _isSearchPrimeMembersLoading=true;

    update();

    String userType='0';
    if(title=='prime_members'.tr){
      userType='1';
    }

    String url='${AppConstants.REGISTERED_USERS_URL}?offset=$offset&limit=10&user_type=$userType&query_text=$searchQuery&amt_greater_than_zero=$_amtGreaterThanZero'
    ;

    Response response = await allPrimeMembersRepo.getData(url);
    _isSearchPrimeMembersLoading = false;
    if (response.statusCode == 200) {
      if(!load){
        _allRegisteredUsersDataList=[];
      }

      AllRegisteredUsersResponse  _res = AllRegisteredUsersResponse.fromJson(response.body);
      _pageSize = _res.totalSize;
      _allPrimeMembersAmt = _res.totalBalance;

      _allRegisteredUsersDataList.addAll(_res.data);

      update();
    } else {
      ApiChecker.checkApi(response);
    }
    update();
  }

  void resetStatementFilter() {

    _pageSize = 0;
    _offset = 1;
    _isSearchMode=false;
    _selectedPrimeToViewStatement=null;
    update();
  }

}