import 'package:sixam_mart/data/api/api_checker.dart';
import 'package:sixam_mart/data/model/response/item_model.dart';

import 'package:flutter/material.dart';
import 'package:get/get.dart';

import '../data/model/response/brand_model.dart';
import '../data/repository/brands_repo_sonu.dart';
import 'package:flutter/foundation.dart' as Foundation;

import '../util/app_constants.dart';

class BrandController extends GetxController implements GetxService {
  final BrandsRepo brandRepo;
  BrandController({@required this.brandRepo});
  
  List<Brands> _featuredBrandsList;
  List<Brands> _allBrandsList;

  bool _isLoading = false;
  int _pageSize;
  int _restPageSize;
  bool _isSearching = false;
  bool _isStore = false;
  String _searchText = '';
  int _offset = 0;

  List<Brands> get allBrandsList => _allBrandsList;
  List<Brands> get featuredBrandsList => _featuredBrandsList;

  bool get isLoading => _isLoading;
  int get pageSize => _pageSize;
  int get restPageSize => _restPageSize;
  bool get isSearching => _isSearching;
  bool get isStore => _isStore;
  String get searchText => _searchText;
  int get offset => _offset;


  List<Item> _brandItemList;
  List<Item> _searchItemList = [];
  List<bool> _interestSelectedList;

  int _subCategoryIndex = 0;
  String _type = 'all';
  String _itemResultText = '';
  List<Item> get brandItemList => _brandItemList;
  List<Item> get searchItemList => _searchItemList;
  List<bool> get interestSelectedList => _interestSelectedList;
  int get subCategoryIndex => _subCategoryIndex;
  String get type => _type;



  Future<void> getFeaturedBrandItemList(int offset, bool notify ,{int type =  AppConstants.FEATURED}) async {
    _isLoading = true;
    Response response = await brandRepo.getBrandsList( offset, type);
    _isLoading = false;
    if (response.statusCode == 200) {
      print("getFeaturedBrandItemList type$type");

      if (type ==AppConstants.FEATURED) {
        _featuredBrandsList = null;
        _featuredBrandsList = [];
        _featuredBrandsList.addAll(BrandModel.fromJson(response.body).brands);
        print("getFeaturedBrandItemList _featuredBrandsList_size = ${_featuredBrandsList.length}");
      }else{
        _allBrandsList = null;
        _allBrandsList = [];
        _allBrandsList.addAll(BrandModel.fromJson(response.body).brands);
        print("getFeaturedBrandItemList _allBrandsList_size = ${_allBrandsList.length}");
      }

    } else {
      _isLoading = false;
      ApiChecker.checkApi(response);
    }
    update();
  }
  void getBrandItemList(String brandID, int offset, String type, bool notify) async {
    _offset = offset;
    if(offset == 0) {
      if(_type == type) {
        _isSearching = false;
      }
      _type = type;
      if(notify) {
        update();
      }
      _brandItemList = null;
    }
    Response response = await brandRepo.getBrandItemList(brandID, offset);
    if (response.statusCode == 200) {
      if (offset == 0) {
        _brandItemList = [];
      }
      _brandItemList.addAll(ItemModel.fromJson(response.body).items);
      _pageSize = ItemModel.fromJson(response.body).totalSize;
      _isLoading = false;
    } else {
      ApiChecker.checkApi(response);
    }
    update();
  }

  void searchData(String query, String categoryID, String type) async {
    if(query.isNotEmpty && query != _itemResultText) {
      _searchText = query;
      _type = type;
      _searchItemList = null;
      _isSearching = true;
      update();
      
      Response response = await brandRepo.getSearchData(query, categoryID  );
      if (response.statusCode == 200) {
        if (query.isEmpty) {

          _searchItemList = [];

        } else {
          _itemResultText = query;
          _searchItemList = [];
          _searchItemList.addAll(ItemModel.fromJson(response.body).items);

        }
      } else {
        ApiChecker.checkApi(response);
      }
      update();
    }
  }

  void toggleSearch() {
    _isSearching = !_isSearching;
    _searchItemList = [];
    if(_brandItemList != null) {
      _searchItemList.addAll(_brandItemList);
    }
    update();
  }

  void showBottomLoader() {
    _isLoading = true;
    update();
  }

  Future<bool> saveInterest(List<int> interests) async {
    _isLoading = true;
    update();
    Response response = await brandRepo.saveUserInterests(interests);
    bool _isSuccess;
    if(response.statusCode == 200) {
      _isSuccess = true;
    }else {
      _isSuccess = false;
      ApiChecker.checkApi(response);
    }
    _isLoading = false;
    update();
    return _isSuccess;
  }

  void addInterestSelection(int index) {
    _interestSelectedList[index] = !_interestSelectedList[index];
    update();
  }
  
}
