import 'package:sixam_mart/controller/item_controller.dart';
import 'package:sixam_mart/controller/splash_controller.dart';
import 'package:sixam_mart/data/model/response/cart_model.dart';
import 'package:sixam_mart/data/model/response/item_model.dart';
import 'package:sixam_mart/data/repository/cart_repo.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:sixam_mart/helper/date_converter.dart';
import 'package:sixam_mart/view/base/custom_snackbar.dart';

class CartController extends GetxController implements GetxService {
  final CartRepo cartRepo;
  CartController({@required this.cartRepo});

  List<Item> _recentViewList = [];

  List<Item> get recentViewList => _recentViewList;

  List<CartModel> _cartList = [];

  List<CartModel> get cartList => _cartList;

  double _subTotal = 0;
  double _itemPrice = 0;
  double _addOns = 0;
  List<List<AddOns>> _addOnsList = [];
  List<bool> _availableList = [];

  double get subTotal => _subTotal;
  double get itemPrice => _itemPrice;
  double get addOns => _addOns;
  List<List<AddOns>> get addOnsList => _addOnsList;
  List<bool> get availableList => _availableList;
  
  
  

 //START RECENT VIEW CODE
  void getRecentViewData() {
    _recentViewList = [];
    _recentViewList.addAll(cartRepo.getRecentViewList());
  }

  void addToRecentView(Item item) {
   if(!_recentViewList.contains(item)){
     if(_recentViewList.length==10){
       _recentViewList.removeAt(9);
     }
     _recentViewList.add(item);
     cartRepo.addToRecentViewList(_recentViewList);
     update();
   }
  }

  void clearRecentViewList() {
    _recentViewList = [];
    cartRepo.addToRecentViewList(_recentViewList);
    update();
  }

  int isExistInRecentView(int itemID, String variationType, bool isUpdate, int recentIndex) {
    for(int index=0; index<_recentViewList.length; index++) {
      if(_recentViewList[index].id == itemID) {
        if((isUpdate && index == recentIndex)) {
          return -1;
        }else {
          return index;
        }
      }
    }
    return -1;
  }
  //END RECENT VIEW CODE



  double calculationCart(){
    _addOnsList = [];
    _availableList = [];
    _itemPrice = 0;
    _addOns = 0;
    cartList.forEach((cartModel) {

      List<AddOns> _addOnList = [];
      cartModel.addOnIds.forEach((addOnId) {
        for(AddOns addOns in cartModel.item.addOns) {
          if(addOns.id == addOnId.id) {
            _addOnList.add(addOns);
            break;
          }
        }
      });
      _addOnsList.add(_addOnList);

      _availableList.add(DateConverter.isAvailable(cartModel.item.availableTimeStarts, cartModel.item.availableTimeEnds));

      for(int index=0; index<_addOnList.length; index++) {
        _addOns = _addOns + (_addOnList[index].price * cartModel.addOnIds[index].quantity);
      }
      _itemPrice = _itemPrice + (cartModel.discountedPrice * cartModel.quantity);

    });
    _subTotal = _itemPrice + _addOns;

    return _subTotal;
  }

  void getCartData() {
    _cartList = [];
    _cartList.addAll(cartRepo.getCartList());
    calculationCart();
  }

  void addToCart(CartModel cartModel, int index) {
    debugPrint("AddToCartTest index = $index");
    if(index != null && index != -1) {
      debugPrint("AddToCartTest replaceRange run");
      _cartList.replaceRange(index, index+1, [cartModel]);
    }else {
      debugPrint("AddToCartTest add run");
      _cartList.add(cartModel);
    }
    Get.find<ItemController>().setExistInCart(cartModel.item, notify: true);
    cartRepo.addToCartList(_cartList);

    calculationCart();
    update();
  }

  void setQuantity(bool isIncrement, int cartIndex, int stock ,{int newSelectedQuantity}) {
    if (isIncrement) {

      if(Get.find<SplashController>().configModel.moduleConfig.module.stock && cartList[cartIndex].quantity >= stock) {
        showCustomSnackBar('out_of_stock'.tr);
      }else {
        _cartList[cartIndex].quantity = newSelectedQuantity==null? _cartList[cartIndex].quantity + 1 : _cartList[cartIndex].quantity + newSelectedQuantity;
      }
    } else {
      _cartList[cartIndex].quantity =newSelectedQuantity==null? _cartList[cartIndex].quantity - 1 : _cartList[cartIndex].quantity - newSelectedQuantity;
    }
    cartRepo.addToCartList(_cartList);

    calculationCart();

    update();
  }

  void removeFromCart(int index) {
    _cartList.removeAt(index);
    cartRepo.addToCartList(_cartList);

    if(Get.find<ItemController>().item != null) {
      Get.find<ItemController>().setExistInCart(Get.find<ItemController>().item, notify: true);
    }
    calculationCart();
    update();

  }

  void removeAddOn(int index, int addOnIndex) {
    _cartList[index].addOnIds.removeAt(addOnIndex);
    cartRepo.addToCartList(_cartList);
    calculationCart();
    update();
  }

  void clearCartList() {
    _cartList = [];
    cartRepo.addToCartList(_cartList);
    calculationCart();
    update();
  }

  int isExistInCart(int itemID, String variationType, bool isUpdate, int cartIndex) {
    for(int index=0; index<_cartList.length; index++) {
      if(_cartList[index].item.id == itemID && (_cartList[index].variation.length > 0 ? _cartList[index].variation[0].type
          == variationType : true)) {
        if((isUpdate && index == cartIndex)) {
          return -1;
        }else {
          return index;
        }
      }
    }
    return -1;
  }

  bool existAnotherStoreItem(int storeID) {
    for(CartModel cartModel in _cartList) {
      if(cartModel.item.storeId != storeID) {
        return true;
      }
    }
    return false;
  }

  void removeAllAndAddToCart(CartModel cartModel) {
    _cartList = [];
    _cartList.add(cartModel);
    Get.find<ItemController>().setExistInCart(cartModel.item, notify: true);
    cartRepo.addToCartList(_cartList);
    calculationCart();
    update();
  }

  bool isAvailable(Item item) {

    return (item.stock>0 && item.isInactive==0);
    //return DateConverter.isAvailable(item.availableTimeStarts, item.availableTimeEnds);
  }

  double getDiscount(Item item) => item.discount==null?0 : item.discount;

  String getDiscountType(Item item) => item.storeDiscount == 0 ? item.discountType : 'percentage';

  double getStartingPrice(Item item) {
    double _startingPrice = 0;
    if (item.choiceOptions!=null && item.choiceOptions.length != 0) {
      List<double> _priceList = [];
      item.variations.forEach((variation) => _priceList.add(variation.price));
      _priceList.sort((a, b) => a.compareTo(b));
      _startingPrice = _priceList[0];
    } else {
      _startingPrice = item.price;
    }
    return _startingPrice;
  }
}
