import 'package:sixam_mart/data/api/api_checker.dart';
import 'package:sixam_mart/data/model/response/category_model.dart';
import 'package:sixam_mart/data/model/response/item_model.dart';
import 'package:sixam_mart/data/model/response/store_model.dart';
import 'package:sixam_mart/data/repository/category_repo.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

import '../util/app_constants.dart';

class CategoryController extends GetxController implements GetxService {
  final CategoryRepo categoryRepo;
  CategoryController({@required this.categoryRepo});

  List<CategoryModel> _featuredCategoryList;
  List<CategoryModel> _categoryList;
  List<CategoryModel> _subCategoryList;
  List<Item> _categoryDairyItemList;
  List<Item> _categoryItemList;
  List<Store> _categoryStoreList;
  List<Item> _searchItemList = [];
  List<Store> _searchStoreList = [];
  List<bool> _interestSelectedList;
  bool _isLoading = false;
  int _pageSize;
  int _restPageSize;
  bool _isSearching = false;
  int _subCategoryIndex = 0;
  String _type = 'all';
  String _parentChild = 'parent';
  bool _isStore = false;
  String _searchText = '';
  String _storeResultText = '';
  String _itemResultText = '';
  int _offset = 1;

  List<CategoryModel> get categoryList => _categoryList;
  List<CategoryModel> get featuredCategoryList => _featuredCategoryList;
  List<CategoryModel> get subCategoryList => _subCategoryList;
  List<Item> get categoryItemList => _categoryItemList;
  List<Item> get categoryDairyItemList => _categoryDairyItemList;
  List<Store> get categoryStoreList => _categoryStoreList;
  List<Item> get searchItemList => _searchItemList;
  List<Store> get searchStoreList => _searchStoreList;
  List<bool> get interestSelectedList => _interestSelectedList;
  bool get isLoading => _isLoading;
  int get pageSize => _pageSize;
  int get restPageSize => _restPageSize;
  bool get isSearching => _isSearching;
  int get subCategoryIndex => _subCategoryIndex;
  String get type => _type;
  String get parentChild => _parentChild;
  bool get isStore => _isStore;
  String get searchText => _searchText;
  int get offset => _offset;

  Future<void> getCategoryList(bool reload) async {
    if(_categoryList == null || reload) {
      _categoryList = null;
      Response response = await categoryRepo.getCategoryList(0,AppConstants.ALL);
      if (response.statusCode == 200) {

         _categoryList = [];
         _interestSelectedList = [];
         response.body.forEach((category) {
           _categoryList.add(CategoryModel.fromJson(category));
           _interestSelectedList.add(false);
         });

      } else {
        ApiChecker.checkApi(response);
      }
      update();
    }
  }

  Future<void> getFeaturedCategoryList(bool reload) async {
    if(_featuredCategoryList == null || reload) {
      _featuredCategoryList = null;
      Response response = await categoryRepo.getCategoryList(0,AppConstants.ALL);
      if (response.statusCode == 200) {

        _featuredCategoryList = [];

        response.body.forEach((category) {
          _featuredCategoryList.add(CategoryModel.fromJson(category));

        });

      } else {
        ApiChecker.checkApi(response);
      }
      update();
    }
  }
  void getSubCategoryList(String categoryID) async {
    _subCategoryIndex = 0;
    _subCategoryList = null;
    _categoryItemList = null;
    Response response = await categoryRepo.getSubCategoryList(categoryID);
    if (response.statusCode == 200) {
      _subCategoryList= [];
      _subCategoryList.add(CategoryModel(id: int.parse(categoryID), name: 'all'.tr));
      response.body.forEach((category) => _subCategoryList.add(CategoryModel.fromJson(category)));
      getCategoryItemList(categoryID, 1, 'all', false);
    } else {
      ApiChecker.checkApi(response);
    }
  }

  void setSubCategoryIndex(int index, String categoryID) {
    _subCategoryIndex = index;
    if(_isStore) {
      getCategoryStoreList(_subCategoryIndex == 0 ? categoryID : _subCategoryList[index].id.toString(), 1, _type, true);
    }else {
      getCategoryItemList(_subCategoryIndex == 0 ? categoryID : _subCategoryList[index].id.toString(), 1, _type, true);
    }
  }

  void getCategoryItemList(String categoryID, int offset, String parentChild, bool notify) async {
    _offset = offset;
    if(offset == 1) {
      if(_type == parentChild) {
        _isSearching = false;
      }
      _type = parentChild;
      if(notify) {
        update();
      }
      _categoryItemList = null;
    }
    Response response = await categoryRepo.getCategoryItemList(categoryID, offset, parentChild);
    if (response.statusCode == 200) {
      if (offset == 1) {
        _categoryItemList = [];
      }
      _categoryItemList.addAll(ItemModel.fromJson(response.body).items);
      _pageSize = ItemModel.fromJson(response.body).totalSize;
      _isLoading = false;
    } else {
      ApiChecker.checkApi(response);
    }
    update();
  }

  void getCategoryItemList_Sonu(String categoryID, int offset, String parentChild,bool notify) async {
    if(offset == 0) {
      _categoryItemList = null;
      if(notify) {
        update();
      }
    }
    _offset=offset;
    _isLoading =true;

    Response response = await categoryRepo.getCategoryItemList(categoryID, offset, parentChild);
    if (response.statusCode == 200) {
      if (offset == 0) {
        _parentChild = parentChild;
        _categoryItemList = [];
      }
      _categoryItemList.addAll(ItemModel.fromJson(response.body).items);
      _pageSize = ItemModel.fromJson(response.body).totalSize;
      _isLoading = false;
    } else {
      ApiChecker.checkApi(response);
    }
    update();
  }

  Future<void> getCategoryDairyItemList_Sonu() async {

    Response response = await categoryRepo.getCategoryItemList('55', 0, 'child');
    if (response.statusCode == 200) {
      _categoryDairyItemList = [];
      _categoryDairyItemList.addAll(ItemModel.fromJson(response.body).items);
    } else {
      ApiChecker.checkApi(response);
    }
    update();
  }

  void getCategoryStoreList(String categoryID, int offset, String type, bool notify) async {
    _offset = offset;
    if(offset == 1) {
      if(_type == type) {
        _isSearching = false;
      }
      _type = type;
      if(notify) {
        update();
      }
      _categoryStoreList = null;
    }
    Response response = await categoryRepo.getCategoryStoreList(categoryID, offset, type);
    if (response.statusCode == 200) {
      if (offset == 1) {
        _categoryStoreList = [];
      }
      _categoryStoreList.addAll(StoreModel.fromJson(response.body).stores);
      _restPageSize = ItemModel.fromJson(response.body).totalSize;
      _isLoading = false;
    } else {
      ApiChecker.checkApi(response);
    }
    update();
  }

  void searchData(String query, String categoryID, String type) async {
    if((_isStore && query.isNotEmpty && query != _storeResultText) || (!_isStore && query.isNotEmpty && query != _itemResultText)) {
      _searchText = query;
      if (_isStore) {
        _searchStoreList = null;
      } else {
        _searchItemList = null;
      }
      _isSearching = true;
      update();

      Response response = await categoryRepo.getSearchData(query, categoryID, _isStore, parentChild);
      if (response.statusCode == 200) {
        if (query.isEmpty) {
          if (_isStore) {
            _searchStoreList = [];
          } else {
            _searchItemList = [];
          }
        } else {
          if (_isStore) {
            _storeResultText = query;
            _searchStoreList = [];
            _searchStoreList.addAll(StoreModel.fromJson(response.body).stores);
          } else {
            _itemResultText = query;
            _searchItemList = [];
            _searchItemList.addAll(ItemModel.fromJson(response.body).items);
          }
        }
      } else {
        ApiChecker.checkApi(response);
      }
      update();
    }
  }

  void toggleSearch() {
    _isSearching = !_isSearching;
    _searchItemList = [];
    if(_categoryItemList != null) {
      _searchItemList.addAll(_categoryItemList);
    }
    update();
  }

  void showBottomLoader() {
    _isLoading = true;
    update();
  }

  Future<bool> saveInterest(List<int> interests) async {
    _isLoading = true;
    update();
    Response response = await categoryRepo.saveUserInterests(interests);
    bool _isSuccess;
    if(response.statusCode == 200) {
      _isSuccess = true;
    }else {
      _isSuccess = false;
      ApiChecker.checkApi(response);
    }
    _isLoading = false;
    update();
    return _isSuccess;
  }

  void addInterestSelection(int index) {
    _interestSelectedList[index] = !_interestSelectedList[index];
    update();
  }

  void setRestaurant(bool isRestaurant) {
    _isStore = isRestaurant;
    update();
  }

  double getStartingPrice(Item item) {
    double _startingPrice = 0;
    if (item.choiceOptions!=null && item.choiceOptions.length != 0) {
      List<double> _priceList = [];
      item.variations.forEach((variation) => _priceList.add(variation.price));
      _priceList.sort((a, b) => a.compareTo(b));
      _startingPrice = _priceList[0];
    } else {
      _startingPrice = item.price;
    }
    return _startingPrice;
  }

  bool isAvailable(Item item) {

    return (item.stock>0 && item.isInactive==0);
    //return DateConverter.isAvailable(item.availableTimeStarts, item.availableTimeEnds);
  }
  double getDiscount(Item item) => item.discount==null?0 : item.discount;

  String getDiscountType(Item item) => item.storeDiscount == 0 ? item.discountType : 'percentage';
}
