import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:sixam_mart/controller/user_controller.dart';
import 'package:sixam_mart/data/api/api_checker.dart';
import 'package:sixam_mart/data/model/response/wallet_model.dart';
import 'package:sixam_mart/data/repository/wallet_repo.dart';
import 'package:sixam_mart/view/base/custom_snackbar.dart';

import '../data/model/response/AllRegisteredUsersResponse.dart';
import '../data/model/response/PrimePaymentTrackResppnse.dart';
import '../data/model/response/UserIndentityResModel.dart';
import '../data/model/response/WallerTransferHistoryResponseModel.dart';
import '../data/model/response/closing_response.dart';
import '../data/model/response/response_model.dart';
import '../data/model/response/revenue_statement_response.dart';
import '../data/model/response/upi_payments_list_response.dart';
import '../data/model/response/wallet_statement_response.dart';
import '../data/model/response/wallet_withdrawal_requests_history_model.dart';
import '../data/repository/closing_repo.dart';
import '../helper/route_helper.dart';
import '../util/app_constants.dart';
import '../view/screens/checkout/widget/wallet_withdrawal_request_successfull.dart';

class ClosingController extends GetxController implements GetxService{
  final ClosingRepo closingRepo;
  ClosingController({@required this.closingRepo});

  List<ClosingResponseData> _closingDataList;
  ClosingResponseData _closingDataItem;
  int _pageSize;
  int _offset = 1;
  bool _isLoading = false;



  int get totalPageSize => _pageSize;
  int get offset => _offset;
  bool get isLoading => _isLoading;
  List<ClosingResponseData> get closingDataList => _closingDataList;
  ClosingResponseData get closingDataItem => _closingDataItem;

  void setOffset(int offset) {
    _offset = offset;
    update();
  }



  void setCurrentItem(ClosingResponseData item) {
    _closingDataItem=item;
    update();
  }

  void resetStatementFilter() {

    _pageSize = 0;
    _offset = 1;
    _isLoading=false;
    _closingDataList=null;
    _closingDataItem=null;
    update();
  }


  Future<void> getClosingData(bool refresh) async {

    if(refresh){
      _offset=1;
    }

    if(offset==1){
      _closingDataList = null;
    }
    _isLoading = true;

    update();


    String url='${AppConstants.WALLET_CLOSING_URL}?offset=$offset&limit=50'

    ;

    Response response = await closingRepo.getData(url);
    _isLoading = false;
    if (response.statusCode == 200) {
      if(offset==1){
        _closingDataList=[];
      }

      ClosingResponse  _res = ClosingResponse.fromJson(response.body);
      _pageSize = _res.totalSize;
      _closingDataList.addAll(_res.data);

      update();
    } else {
      ApiChecker.checkApi(response);
    }
    update();
  }
  void showBottomLoader() {
    _isLoading = true;
    update();
  }
}