import 'dart:typed_data';

import 'package:shared_preferences/shared_preferences.dart';
import 'package:sixam_mart/controller/auth_controller.dart';
import 'package:sixam_mart/controller/cart_controller.dart';
import 'package:sixam_mart/controller/splash_controller.dart';
import 'package:sixam_mart/controller/wishlist_controller.dart';
import 'package:sixam_mart/data/api/api_checker.dart';
import 'package:sixam_mart/data/model/response/conversation_model.dart';
import 'package:sixam_mart/data/model/response/response_model.dart';
import 'package:sixam_mart/data/repository/user_repo.dart';
import 'package:sixam_mart/data/model/response/userinfo_model.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:image_picker/image_picker.dart';
import 'package:sixam_mart/helper/network_info.dart';
import 'package:sixam_mart/helper/route_helper.dart';
import 'package:sixam_mart/view/base/custom_snackbar.dart';

import '../data/model/body/prime_member_create_body.dart';
import '../data/model/response/client_referral_info.dart';
import '../data/model/response/order_details_model.dart';
import '../util/images.dart';
import '../view/base/confirmation_dialog.dart';
import 'item_controller.dart';

class UserController extends GetxController implements GetxService {
  final UserRepo userRepo;
  final SharedPreferences sharedPreferences;
  UserController({@required this.userRepo , @required this.sharedPreferences});

  UserInfoModel _userInfoModel;
  XFile _pickedFile;
  Uint8List _rawFile;
  bool _isLoading = false;
  bool _isCheckUserCanShareAppLoading = false;

  UserInfoModel get userInfoModel => _userInfoModel;
  XFile get pickedFile => _pickedFile;
  Uint8List get rawFile => _rawFile;
  bool get isLoading => _isLoading;
  bool get isCheckUserCanShareAppLoading => _isCheckUserCanShareAppLoading;

  ReferralInfo _referralInfo;
  ReferralInfo get referralInfo => _referralInfo;


  void primeMemberPaymentStatus(){
    try{
      print("primeMemberPaymentStatus run");

      if(_userInfoModel!=null){
        if(_userInfoModel.isFormCompleted!=null && _userInfoModel.isFormCompleted=="true" &&
            _userInfoModel.upiPaymentStatus!=null && _userInfoModel.upiPaymentStatus=="pending" &&
            _userInfoModel.upiScreenShot!=null
        ){
          Get.dialog( ConfirmationDialog(
            icon: Images.digital_payment
            ,shouldYesButtonHide: true,
            rightButtonText: '',
            leftButtonText:  'Ok',
            title:   'UPI Payment For Prime Membership is under process.' ,
            description: "We are working on your request.",
            onYesPressed: ()  {
              Get.back();
            },
          ));
        }
      }
    }catch(e){
      print("primeMemberPaymentStatus error ${e.toString()}");

    }

  }
  Future<ResponseModel> getUserInfo({bool shouldFeaturedApiCall}) async {
    _isCheckUserCanShareAppLoading=false;
    _pickedFile = null;
    _rawFile = null;
    ResponseModel _responseModel;
    Response response = await userRepo.getUserInfo();
    if (response.statusCode == 200) {
      _userInfoModel = UserInfoModel.fromJson(response.body);
      _responseModel = ResponseModel(true, 'successful');


      primeMemberPaymentStatus();
      if(shouldFeaturedApiCall!=null && shouldFeaturedApiCall==true){
        Get.find<ItemController>().getFeaturedLatestItemList();
      }

    } else {
      _responseModel = ResponseModel(false, response.statusText);
      ApiChecker.checkApi(response);
    }
    update();
    return _responseModel;
  }



  Future<ResponseModel> checkUserCanShareApp(String name, String mobile) async {
    _isCheckUserCanShareAppLoading = true;
    update();
    ResponseModel _responseModel;
    Response response = await userRepo.checkUserCanShareApp(name,mobile);

    if (response.statusCode == 200) {
      _isCheckUserCanShareAppLoading = false;
      String isShared = response.body['isShared'].toString();
      String message = response.body['message'].toString();

      if(isShared!=null && isShared=="true"){
         Get.find<UserController>().updateRefIncome(response);
        _responseModel = ResponseModel(true, 'successful');
      }else if(message!=null){
        _responseModel = ResponseModel(false, message);
      }else{
        _responseModel = ResponseModel(false, 'Not found');
      }
    } else {
      _responseModel = ResponseModel(false, response.statusText);
      ApiChecker.checkApi(response);
    }
    _isCheckUserCanShareAppLoading = false;
    update();

    return _responseModel;
  }
  Future<void> getClientSidePrimeUserInfo(String clientReferralCode) async {
    _isLoading = true;
    update();
    Response response = await userRepo.getClientSidePrimeUserInfo(clientReferralCode);

    if (response.statusCode == 200) {
       var _runningOrderModel = ClientReferralInfo.fromJson(response.body);
       _referralInfo = _runningOrderModel.referralInfo;

    } else {
      showCustomSnackBar('choose_any_prime_member_first'.tr, isError: false);

      Get.toNamed(RouteHelper.getPrimeMemberBankDetailsRoute(''));

    }
    _isLoading = false;
    update();

  }

  Future<ResponseModel> updateUserInfo(UserInfoModel updateUserModel, String token) async {
    _isLoading = true;
    update();
    ResponseModel _responseModel;
    Response response = await userRepo.updateProfile(updateUserModel, _pickedFile, token);
    _isLoading = false;
    if (response.statusCode == 200) {
      _userInfoModel = updateUserModel;
      _responseModel = ResponseModel(true, response.bodyString);
      _pickedFile = null;
      _rawFile = null;
      getUserInfo();
      print(response.bodyString);
    } else {
      _responseModel = ResponseModel(false, response.statusText);
      print(response.statusText);
    }
    update();
    return _responseModel;
  }

  Future<ResponseModel> changePassword(UserInfoModel updatedUserModel) async {
    _isLoading = true;
    update();
    ResponseModel _responseModel;
    Response response = await userRepo.changePassword(updatedUserModel);
    _isLoading = false;
    if (response.statusCode == 200) {
      String message = response.body["message"];
      _responseModel = ResponseModel(true, message);
    } else {
      _responseModel = ResponseModel(false, response.statusText);
    }
    update();
    return _responseModel;
  }

  void updateUserWithNewData(User user) {
    _userInfoModel.userInfo = user;
  }

  void pickImage() async {
    _pickedFile = await ImagePicker().pickImage(source: ImageSource.gallery);
    if(_pickedFile != null) {
      _pickedFile = await NetworkInfo.compressImage(_pickedFile);
      _rawFile = await _pickedFile.readAsBytes();
    }
    update();
  }

  void initData() {
    _pickedFile = null;
    _rawFile = null;
  }

  Future removeUser() async {
    _isLoading = true;
    update();
    Response response = await userRepo.deleteUser();
    _isLoading = false;
    if (response.statusCode == 200) {
      showCustomSnackBar('your_account_remove_successfully'.tr);
      setPrime(0);
      Get.find<AuthController>().clearSharedData();
      Get.find<CartController>().clearCartList();
      Get.find<WishListController>().removeWishes();
      Get.offAllNamed(RouteHelper.getSignInRoute(RouteHelper.splash));

    }else{
      Get.back();
      ApiChecker.checkApi(response);
    }
  }

  int getPrime() {
    return userRepo.getPrime() ?? 0;
  }
  void setFalse() {
    _isCheckUserCanShareAppLoading=false;
    update();
  }
  void updateRefIncome(Response response) {

   if(response.body['refferral_income']!=null) {
     _userInfoModel.refIncome = response.body['refferral_income'].toDouble();
   }
       if(response.body['ref_remaining']!=null) {
         _userInfoModel.refRemaining = response.body['ref_remaining'];
       }

       if(response.body['wallet_balance']!=null) {
         _userInfoModel.walletBalance = response.body['wallet_balance'].toDouble() ;
       }

       if(response.body['sponsor_income']!=null) {
         _userInfoModel.sponsorIncome = response.body['sponsor_income'].toDouble() ;
       }

       if(response.body['total_shared_links']!=null) {
         _userInfoModel.totalSharedLinks = response.body['total_shared_links'] ;
       }

    update();
  }

  setPrime(int value) {
    userRepo.savePrime(value);
  }

}