import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:sixam_mart/controller/user_controller.dart';
import 'package:sixam_mart/data/api/api_checker.dart';
import 'package:sixam_mart/data/model/response/wallet_model.dart';
import 'package:sixam_mart/data/repository/wallet_repo.dart';
import 'package:sixam_mart/view/base/custom_snackbar.dart';

import '../data/model/response/AllRegisteredUsersResponse.dart';
import '../data/model/response/PrimePaymentTrackResppnse.dart';
import '../data/model/response/UserIndentityResModel.dart';
import '../data/model/response/WallerTransferHistoryResponseModel.dart';
import '../data/model/response/closing_response.dart';
import '../data/model/response/response_model.dart';
import '../data/model/response/revenue_statement_response.dart';
import '../data/model/response/upi_payments_list_response.dart';
import '../data/model/response/wallet_statement_response.dart';
import '../data/model/response/wallet_withdrawal_requests_history_model.dart';
import '../helper/route_helper.dart';
import '../util/app_constants.dart';
import '../view/screens/checkout/widget/wallet_withdrawal_request_successfull.dart';
import 'all_prime_members_controller.dart';
import 'closing_controller.dart';

class WalletController extends GetxController implements GetxService{
  final WalletRepo walletRepo;
  WalletController({@required this.walletRepo});
  List<Transaction> _transactionList;
  List<WalletStatementData> _walletStatementData;
  List<Types> _transferTypes;

  List<ClosingResponseData> _closingDataList;
  RevenueStatementResponse _revenueStatementData;
  List<UpiPaymentsListData> _upiPaymentsList;
  Types _transferTypeDropDownValue;
  UserIndentityResModel _userIdentityModel;
  WallerTransferHistoryResponseModel _wallerTransferHistoryResponseModel;
  WalletWithdrawalRequestsHistoryModel _walletWithdrawalRequestsHistoryModel;
  // ReferralHistory _referralHistory;
  List<String> _offsetList = [];
  int _offset = 1;
  int _totalPrimeUsers = 0;
  List<String> _sortList = ['ascending'.tr, 'descending'.tr];
  DateTime _selectedToDate = DateTime.now();
  DateTime _selectedFromDate = DateTime.now();
  int _sortIndex = -1;
  String _type = "";
  String _actionDropdownValue;
  String _actionType = "";

  String _transferType = "";
  String _transactionType = "";
  String _fromDate = 'from_date'.tr;
  String _toDate = 'to_date'.tr;
  String _orderBy = "asc";
  int _pageSize;

  PrimePaymentTrackResponse _walletPaymentTrackResponse;
  bool _isLoading = false;
  bool _isSearchMode = false;
  String _searchKeyword = "";
  bool _isPrimePaymentFromWalletLoading = false;
  bool _isFilterApplied = false;
  bool _isOrderIdLoadingLoading = false;
  bool _isHistoryLoading = false;
  bool _isRefHistoryLoading = false;
  bool _canTransferWalletAmt = false;
  bool _isAmtTransferLoading = false;
  bool _isAmtWithdrawalLoading = false;
  String _searchText = '';
  DateTime get selectedFromDate => _selectedFromDate;
  DateTime get selectedToDate => _selectedToDate;
  List<Transaction> get transactionList => _transactionList;
  List<ClosingResponseData> get closingDataList => _closingDataList;
  List<WalletStatementData> get walletStatementData => _walletStatementData;
  List<Types> get transferTypesList => _transferTypes;
  RevenueStatementResponse get revenueStatementData => _revenueStatementData;
  List<UpiPaymentsListData> get upiPaymentsList => _upiPaymentsList;
  Types get transferTypeDropDownValue => _transferTypeDropDownValue;
  PrimePaymentTrackResponse get walletPaymentTrackResponse => _walletPaymentTrackResponse;
  UserIndentityResModel get userIdentityModel => _userIdentityModel;
  WallerTransferHistoryResponseModel get wallerTransferHistoryResponseModel => _wallerTransferHistoryResponseModel;
  WalletWithdrawalRequestsHistoryModel get walletWithdrawalRequestsHistoryModel => _walletWithdrawalRequestsHistoryModel;
  // ReferralHistory get referralHistory => _referralHistory;
  int get totalPageSize => _pageSize;
  bool get isLoading => _isLoading;
  bool get isPrimePaymentFromWalletLoading => _isPrimePaymentFromWalletLoading;
  bool get isFilterApplied => _isFilterApplied;
  bool get isHistoryLoading => _isHistoryLoading;
  bool get isRefHistoryLoading => _isRefHistoryLoading;
  bool get isSearchMode => _isSearchMode;
  bool get isOrderIdLoadingLoading => _isOrderIdLoadingLoading;
  bool get isAmtTransferLoading => _isAmtTransferLoading;
  bool get isAmtWithdrawalLoading => _isAmtWithdrawalLoading;
  bool get canTransferWalletAmt => _canTransferWalletAmt;
  int get offset => _offset;
  int get totalPrimeUsers => _totalPrimeUsers;
  String get type => _type;
  String get actionDropdownValue => _actionDropdownValue;
  String get actionType => _actionType;
  String get searchKeyword => _searchKeyword;
  String get transferType => _transferType;
  String get transactionType => _transactionType;
  String get fromDate => _fromDate;
  String get toDate => _toDate;
  String get orderBy => _orderBy;
  int get sortIndex => _sortIndex;
  List<String> get sortList => _sortList;
  String get searchText => _searchText;

  void updateTransferTypeDropdown(Types value) {

    _transferTypeDropDownValue=value;
    if(value!=null){
      _type=value.value;
    }else{
      _type="";
    }
    print("updateTransferTypeDropdown $_type");

    update();
  }
  void setOffset(int offset) {
    _offset = offset;
    update();
  }
  void setFilterApplied() {

      _offset=1;
      _upiPaymentsList = null;
    _isFilterApplied = true;
    update();
  }
  void setOrderBy(String orderBy) {
    _orderBy = orderBy;
    update();
  }

  void setActionType(String transactionType) {
    _actionType = transactionType;
    update();
  }

  void setTransferType(String transferType) {
    _transferType = transferType;
    update();
  }
  void setTransactionType(String transactionType) {
    _transactionType = transactionType;
    update();
  }
  void setFromDate(String fromDate, DateTime picked) {

    _fromDate = fromDate;
    _selectedFromDate = picked;
    update();
  }
  void setToDate(String toDate, DateTime picked) {
    _toDate = toDate;
    _selectedToDate = picked;
    update();
  }

  void resetStatementFilter2() {

    _pageSize = 0;
    _offset = 1;
    _isLoading=false;
    _closingDataList=null;
    update();
  }
  void resetStatementFilter() {
    _actionDropdownValue="Approve";
   _selectedToDate = DateTime.now();
    _selectedFromDate = DateTime.now();
    _pageSize = 0;
    _offset = 1;
    _sortIndex = -1;
    _type = "";
    _actionType = "";
    _searchKeyword = "";
    _transferType = "";
    _transactionType = "";
    _fromDate = 'from_date'.tr;
    _toDate = 'to_date'.tr;
    _orderBy = "asc";
    _isLoading=false;
    _isFilterApplied=false;
    _transferTypeDropDownValue=null;
    _upiPaymentsList=null;
    update();
  }
  void setSortIndex(int index) {
    _sortIndex = index;
    if(index==0){
      _orderBy = "asc";
    }else{
      _orderBy = "desc";
    }
    update();
  }
  void showBottomLoader() {
    _isLoading = true;
    update();
  }
  void updateActionDropdown(String value) {

    _actionDropdownValue=value;
    update();
  }


  Future<void> getWalletTransactionList(String offset, bool reload, bool isWallet) async {
    if(offset == '1' || reload) {
      _offsetList = [];
      _offset = 1;
      _transactionList = null;
      if(reload) {
        update();
      }

    }
    if (!_offsetList.contains(offset)) {
      _offsetList.add(offset);
      Response response;
      if(isWallet){
        response = await walletRepo.getWalletTransactionList(offset);
      }else{
        response = await walletRepo.getLoyaltyTransactionList(offset);
      }

      if (response.statusCode == 200) {
        if (offset == '1') {
          _transactionList = [];
        }
        _transactionList.addAll(WalletModel.fromJson(response.body).data);
        _pageSize = WalletModel.fromJson(response.body).totalSize;

        _isLoading = false;
        update();
      } else {
        ApiChecker.checkApi(response);
      }
    } else {
      if(isLoading) {
        _isLoading = false;
        update();
      }
    }
  }
  void searchModeDisable() {
    _isSearchMode=false;
    _searchKeyword="";
    _offset = 1;
    update();
  }
  void saveSearchKeyword(String value) {
    _searchKeyword=value;
    _isSearchMode=true;
    update();
  }
  Future<void> getWalletStatement({String preFilter}) async {
    _isLoading=true;

    if(offset==1){
      _transferTypes = null;
      _walletStatementData = null;
    }
    var report="null";
    print("preFilter $preFilter");

    if(preFilter!="NA" && preFilter!=null){
      report = "summery";
      if(preFilter=='loan'.tr || preFilter=='receipt'.tr){
        _transferType=preFilter;

        update();

        updateTransferTypeDropdown(Types(name: "Transfer",value: "transfer"));

      }

      else if(preFilter=='transfer'.tr){

        updateTransferTypeDropdown(Types(name: "Transfer",value: "transfer"));

      }
      else if(preFilter=='company_recharge'.tr){
        updateTransferTypeDropdown(Types(name: "Company Recharge",value: "company_recharge"));
      }
      else if(preFilter=='pair_income'.tr){
        updateTransferTypeDropdown(Types(name: "Team Income",value: "pair_income"));
      }

    }

    String url='${AppConstants.WALLET_STATEMENT_URL}?offset=$offset&limit=10&type=$type&transaction_type=${actionType.toLowerCase()}&transfer_type=${transferType.toLowerCase()}'
        '&from_date=${fromDate=='from_date'.tr ? "" : fromDate}'
        '&to_date=${toDate=='to_date'.tr ? "" : toDate}'
        '&order_by=$orderBy';

    if(preFilter!="NA" && preFilter!=null){

      if(preFilter=='select_prime_to_view_statement'.tr){
        url = url+'&user_id=${Get.find<AllPrimeMembersController>().selectedPrimeToViewStatement.id.toString()}';
      }else{
        url = url+'&report=$report';

        if(preFilter=='pair_income'.tr){
          url = url+'&closing_id=${Get.find<ClosingController>().closingDataItem.id.toString()}';
        }
      }

    }
    if(searchKeyword.isNotEmpty){
      url = url+'&keyword=$searchKeyword';
    }


    Response response = await walletRepo.getData(url);
    _isLoading=false;
      if (response.statusCode == 200) {

        if(offset==1){
          _transferTypes = [];
          _walletStatementData = [];
        }

        WalletStatementResponse w = WalletStatementResponse.fromJson(response.body);
        _walletStatementData.addAll(w.data);
        _transferTypes.addAll(w.types);
        _pageSize=w.totalReocrd;
        _isLoading = false;
        update();
      } else {
        ApiChecker.checkApi(response);
      }

  }
  Future<void> getRevenueStatement() async {
    _revenueStatementData = null;
    update();

    // String url='${AppConstants.WALLET_STATEMENT_URL}?offset=$offset&limit=10&type=$type&transaction_type=${transactionType.toLowerCase()}'
    //     '&from_date=${fromDate=='from_date'.tr ? "" : fromDate}'
    //     '&to_date=${toDate=='to_date'.tr ? "" : toDate}'
    //     '&order_by=$orderBy';

    Response response = await walletRepo.getData('${AppConstants.REVENUE_STATEMENT_URL}?offset=$offset&limit=10');


      if (response.statusCode == 200) {
        _revenueStatementData = RevenueStatementResponse.fromJson(response.body);

        //_pageSize = _revenueStatementData.data.totalRecords;
        _isLoading = false;
        update();
      } else {
        ApiChecker.checkApi(response);
      }

  }
  Future<void> getUpiPaymentList() async {
    if(offset==1){
      _upiPaymentsList = null;
      update();
    }


    String url='${AppConstants.UPI_PAYMENTS_LIST_URI}?offset=0&page=$offset&limit=30&status=$_actionType&type=$_transactionType'
        '&from_date=${fromDate=='from_date'.tr ? "" : fromDate}'
        '&to_date=${toDate=='to_date'.tr ? "" : toDate}';

    Response response = await walletRepo.getData(url);
    if (response.statusCode == 200) {

      if(_upiPaymentsList==null){
        _upiPaymentsList=[];
      }
      UpiPaymentsListResponse   _upiPaymentsListResponse = UpiPaymentsListResponse.fromJson(response.body);
      _pageSize=_upiPaymentsListResponse.totalSize;
      _upiPaymentsList.addAll(_upiPaymentsListResponse.content.data);
      _isLoading = false;
      update();
    } else {
      ApiChecker.checkApi(response);
    }

  }


  Future<void> getClosingData(bool refresh) async {

    if(refresh){
      _offset=1;
    }

    if(offset==1){
      _closingDataList = null;
    }
    _isLoading = true;

    update();


    String url='${AppConstants.WALLET_CLOSING_URL}?offset=$offset&limit=50'

    ;

    Response response = await walletRepo.getData(url);
    _isLoading = false;
    if (response.statusCode == 200) {
      if(offset==1){
        _closingDataList=[];
      }

      ClosingResponse  _res = ClosingResponse.fromJson(response.body);
      _pageSize = _res.totalSize;
      _closingDataList.addAll(_res.data);

      update();
    } else {
      ApiChecker.checkApi(response);
    }
    update();
  }
  Future<ResponseModel> customerIdentity(String mobile) async {

    _isLoading = true;
    _userIdentityModel=null;
    update();
    ResponseModel _responseModel;
    Response response = await walletRepo.customerIdentity(mobile);

    if (response.statusCode == 200) {
      _isLoading = false;
      _userIdentityModel = UserIndentityResModel.fromJson(response.body);
      if(_userIdentityModel!=null && _userIdentityModel.data!=null){
        _responseModel = ResponseModel(true, _userIdentityModel.message);
      }else{
        _responseModel = ResponseModel(false, _userIdentityModel.message);
      }

    } else {
      _responseModel = ResponseModel(false, 'User not found');
      ApiChecker.checkApi(response);
    }
    _isLoading = false;
    update();

    return _responseModel;
  }
  Future<ResponseModel> updateUpiPaymentStatus({String id, String remarks, String action}) async {

    _isLoading = true;
    update();
    ResponseModel _responseModel;
    Response response = await walletRepo.updateUpiPaymentStatus(id: id,remarks: remarks,action: action);

    if (response.statusCode == 200) {
      showCustomSnackBar(response.body['message'], isError: false);
      _responseModel = ResponseModel(true, response.body['message']);
    } else {
      _responseModel = ResponseModel(false, '');
      ApiChecker.checkApi(response);
    }
    _isLoading = false;
    update();

    return _responseModel;
  }
  Future<ResponseModel> primePaymentFromWallet(String orderId) async {

    _isPrimePaymentFromWalletLoading = true;
    _userIdentityModel=null;
    update();
    ResponseModel _responseModel;
    Response response = await walletRepo.primePaymentFromWalletUri(orderId);

    if (response.statusCode == 200) {
      _isPrimePaymentFromWalletLoading = false;
      //{status: true, message: Congratulation your Prime Account No.: 231130111849}
      _responseModel = ResponseModel(true, "Congratulation");
      // _userIdentityModel = UserIndentityResModel.fromJson(response.body);
      // if(_userIdentityModel!=null && _userIdentityModel.data!=null){
      //
      // }else{
      //   _responseModel = ResponseModel(false, _userIdentityModel.message);
      // }

    } else {
      _responseModel = ResponseModel(false, 'User not found');
      ApiChecker.checkApi(response);
    }
    _isPrimePaymentFromWalletLoading = false;
    update();

    return _responseModel;
  }
  Future<void> trackWalletRechargeOrder( String orderID ) async {

    _walletPaymentTrackResponse=null;
    _isLoading = true;
    update();

    Response response = await walletRepo.trackWalletOrder(orderID);
    _isLoading = false;
    if (response.statusCode == 200) {
      _walletPaymentTrackResponse = PrimePaymentTrackResponse.fromJson(response.body);
    }
    update();
  }

  Future<void> getOrderIdForWalletRecharge(String amt,String mode, Function(bool isSuccess, String message, String orderID) callback) async {

    _isOrderIdLoadingLoading = true;
    update();

    Response response = await walletRepo.getOrderIdForWalletRecharge(amt);

    print('Wallet_Recharge_Order id return response ${response.statusCode} ----------');

    _isOrderIdLoadingLoading = false;
    if (response.statusCode == 200) {


      String orderID = response.body['order_id'].toString();
        if(mode=='upi' || mode=='qrCode'){
          Get.toNamed(RouteHelper.getPrimePaymentManuallyRoute(orderID,mode,"recharge"));
      }else{
        callback(true, "", orderID);
      }


    }else {
      ApiChecker.checkApi(response);
    }

    update();
  }

  Future<void> requestToWithdrawal(String amount) async {
    _isAmtWithdrawalLoading = true;
    update();
    Response response = await walletRepo.requestToWithdrawal(amount:amount);

    if (response.statusCode == 200) {
      _isAmtWithdrawalLoading = false;
      Get.dialog(WalletWithdrawalSuccessDialog(), barrierDismissible: false);
    } else {
      ApiChecker.checkApi(response);
    }
    _isAmtWithdrawalLoading = false;
    update();

  }
  Future<ResponseModel> walletAmtTransfer(String loanDeductionPercent,String remark,String amount,String recipientId) async {
    _isAmtTransferLoading = true;
    update();
    ResponseModel _responseModel;
    Response response = await walletRepo.walletAmtTransfer(loanDeductionPercent: loanDeductionPercent,amount:amount,recipientId:recipientId,transferType: actionType.toLowerCase(),remark: remark);

    if (response.statusCode == 200) {
      _isAmtTransferLoading = false;
      _responseModel = ResponseModel(true, 'wallet_amount_transferred'.tr);
      Get.find<UserController>().getUserInfo();
      removeUserIdentity();

    } else {
      _responseModel = ResponseModel(false, response.statusText);
      ApiChecker.checkApi(response);
    }
    _isAmtTransferLoading = false;
    update();

    return _responseModel;
  }

  //parameter(order_by:desc, from_date, to_date)
  //
  // parameter(order_by:asc, from_date, to_date)
  //
  // parameter(transfer_type:credit, order_by:asc,from_date, to_date)
  //
  // parameter(transfer_type:debit ,order_by:asc, from_date, to_date)
  Future<void> walletAmtTransferHistory() async {
    _wallerTransferHistoryResponseModel=null;
    _isHistoryLoading = true;
    String url;
    ResponseModel _responseModel;
    Response response;

    //url='${AppConstants.CUSTOMER_ALL_TRANSFER_URL}?offset=$offset&limit=10';
    url='${AppConstants.CUSTOMER_ALL_TRANSFER_URL}';

    response = await walletRepo.walletAmtTransferHistory(url);

    if (response.statusCode == 200) {
      _isHistoryLoading = false;
      _wallerTransferHistoryResponseModel= WallerTransferHistoryResponseModel.fromJson(response.body);

    } else {
      ApiChecker.checkApi(response);
    }
    _isHistoryLoading = false;
    update();
  }
  Future<void> walletWithdrawalRequestHistory() async {
    _walletWithdrawalRequestsHistoryModel=null;
    _isHistoryLoading = true;
    String url;
    ResponseModel _responseModel;
    Response response;

    url='${AppConstants.WALLET_WITHDRAWAL_REQUEST_LIST_URL}';

     response = await walletRepo.walletAmtTransferHistory(url);

    if (response.statusCode == 201) {
      _isHistoryLoading = false;
      _walletWithdrawalRequestsHistoryModel= WalletWithdrawalRequestsHistoryModel.fromJson(response.body);

    } else {
      ApiChecker.checkApi(response);
    }
    _isHistoryLoading = false;
    update();


  }
  // Future<void> getReferralHistory() async {
  //   _referralHistory=null;
  //   _isRefHistoryLoading = true;
  //   String url;
  //   ResponseModel _responseModel;
  //   Response response;
  //
  //   url='${AppConstants.REFERRAL_HISTORY_URL}';
  //
  //    response = await walletRepo.getReferralHistory(url);
  //
  //   if (response.statusCode == 201) {
  //     _isRefHistoryLoading = false;
  //     _referralHistory= ReferralHistory.fromJson(response.body);
  //
  //   } else {
  //     ApiChecker.checkApi(response);
  //   }
  //   _isRefHistoryLoading = false;
  //   update();
  //
  //
  // }

  void setCanTransferWalletAmt(bool value){
    _canTransferWalletAmt=value;
    _userIdentityModel=null;
    update();
  }
  void init(){
    _isPrimePaymentFromWalletLoading = false;
    _userIdentityModel=null;
    update();
  }
  void removeUserIdentity(){
    _userIdentityModel=null;
    update();
  }
  void updateList(int index,String status){

  }
  Future<void> pointToWallet(int point, bool fromWallet) async {
    _isLoading = true;
    update();
    Response response = await walletRepo.pointToWallet(point: point);
    if (response.statusCode == 200) {
      Get.back();
      getWalletTransactionList('1', true, fromWallet);
      Get.find<UserController>().getUserInfo();
      showCustomSnackBar('converted_successfully_transfer_to_your_wallet'.tr, isError: false);
    } else {
      ApiChecker.checkApi(response);
    }
    _isLoading = false;
    update();
  }



}