import 'package:sixam_mart/controller/location_controller.dart';
import 'package:sixam_mart/controller/splash_controller.dart';
import 'package:sixam_mart/data/api/api_checker.dart';
import 'package:sixam_mart/data/model/response/item_model.dart';
import 'package:sixam_mart/data/model/response/store_model.dart';
import 'package:sixam_mart/data/repository/item_repo.dart';
import 'package:sixam_mart/data/repository/wishlist_repo.dart';
import 'package:sixam_mart/util/app_constants.dart';
import 'package:sixam_mart/view/base/custom_snackbar.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

class WishListController extends GetxController implements GetxService {
  final WishListRepo wishListRepo;
  final ItemRepo itemRepo;
  WishListController({@required this.wishListRepo, @required this.itemRepo});

  List<Item> _wishItemList = [];
  List<Store> _wishStoreList;
  List<int> _wishItemIdList = [];
  List<int> _wishStoreIdList = [];

  List<Item> get wishItemList => _wishItemList;
  List<Store> get wishStoreList => _wishStoreList;
  List<int> get wishItemIdList => _wishItemIdList;
  List<int> get wishStoreIdList => _wishStoreIdList;

  void addToWishList(Item product, Store store, bool isStore) async {
    Response response = await wishListRepo.addWishList(isStore ? store.id : product.id, isStore);
    if (response.statusCode == 200) {
      if(isStore) {
        _wishStoreIdList.add(store.id);
        _wishStoreList.add(store);
      }else {
        _wishItemList.add(product);
        _wishItemIdList.add(product.id);
      }

      showCustomSnackBar(response.body['message'], isError: false);
    } else {
      ApiChecker.checkApi(response);
    }
    update();
  }

  void removeFromWishList(int id, bool isStore) async {
    Response response = await wishListRepo.removeWishList(id, isStore);
    if (response.statusCode == 200) {
      int _idIndex = -1;
      if(isStore) {
        _idIndex = _wishStoreIdList.indexOf(id);
        _wishStoreIdList.removeAt(_idIndex);
        _wishStoreList.removeAt(_idIndex);
      }else {
        _idIndex = _wishItemIdList.indexOf(id);
        _wishItemIdList.removeAt(_idIndex);
        _wishItemList.removeAt(_idIndex);
      }

      showCustomSnackBar(response.body['message'], isError: false);
    } else {
      ApiChecker.checkApi(response);
    }
    update();
  }

  Future<void> getWishList() async {
    Response response = await wishListRepo.getWishList();
    AppConstants.printLongString('getWishList  item = ${response.body.toString()} END Item');
    try{
      if (response.statusCode == 200) {
        update();



        if(response.body['item']!=null){
          response.body['item'].forEach((item) async {
            Item _item = Item.fromJson(item);
            // if(Get.find<SplashController>().module == null){
            //   Get.find<LocationController>().getUserAddress().zoneData.forEach((zone) {
            //     zone.modules.forEach((module) {
            //       if(module.id == _item.moduleId){
            //         if(module.pivot.zoneId == _item.zoneId){
            //           _wishItemList.add(_item);
            //           _wishItemIdList.add(_item.id);
            //         }
            //       }
            //     });
            //   });
            // }
            //else{
            _wishItemList.add(_item);
            _wishItemIdList.add(_item.id);
            //}
          });
        }
        // _wishStoreList = [];
        //       _wishStoreIdList = [];
        // response.body['store'].forEach((store) async {
        //   if(Get.find<SplashController>().module == null){
        //     Get.find<LocationController>().getUserAddress().zoneData.forEach((zone) {
        //       zone.modules.forEach((module) {
        //         if(module.id == Store.fromJson(store).moduleId){
        //           if(module.pivot.zoneId == Store.fromJson(store).zoneId){
        //             _wishStoreList.add(Store.fromJson(store));
        //             _wishStoreIdList.add(Store.fromJson(store).id);
        //           }
        //         }
        //       });
        //     });
        //   }else{
        //     Store _store;
        //     try{
        //       _store = Store.fromJson(store);
        //     }catch(e){}
        //     if(_store != null && Get.find<SplashController>().module.id == _store.moduleId) {
        //       _wishStoreList.add(_store);
        //       _wishStoreIdList.add(_store.id);
        //     }
        //   }
        //
        // });
      } else {
        ApiChecker.checkApi(response);
      }
    }catch(e){
      AppConstants.printLongString('getWishList  error = ${e.toString()} END Error');
    }

    update();
  }

  void removeWishes() {
    _wishItemIdList = [];
    _wishStoreIdList = [];
  }
}
