import 'dart:convert';
import 'dart:typed_data';
import 'package:get/get_connect/http/src/request/request.dart';

import 'package:sixam_mart/data/model/response/address_model.dart';
import 'package:sixam_mart/data/model/response/error_response.dart';
import 'package:sixam_mart/data/model/response/module_model.dart';
import 'package:sixam_mart/util/app_constants.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:image_picker/image_picker.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:flutter/foundation.dart' as Foundation;
import 'package:http/http.dart' as Http;

import '../../util/html_type.dart';

class ApiClient extends GetxService {
  final String appBaseUrl;
  final SharedPreferences sharedPreferences;
  static final String noInternetMessage = 'connection_to_api_server_failed'.tr;
  final int timeoutInSeconds = 30;

  String token;
  Map<String, String> _mainHeaders;

  ApiClient({@required this.appBaseUrl, @required this.sharedPreferences}) {
    token = sharedPreferences.getString(AppConstants.TOKEN);
    if(Foundation.kDebugMode) {
      print('Token: $token');
    }
    AddressModel _addressModel;
    try {
      _addressModel = AddressModel.fromJson(jsonDecode(sharedPreferences.getString(AppConstants.USER_ADDRESS)));
    }
    catch(e) {}
    int _moduleID;
   // if(GetPlatform.isWeb && sharedPreferences.containsKey(AppConstants.MODULE_ID)) {
    if(sharedPreferences.containsKey(AppConstants.MODULE_ID)) {
      try {
        _moduleID = ModuleModel.fromJson(jsonDecode(sharedPreferences.getString(AppConstants.MODULE_ID))).id;
      }catch(e) {

      }
    }
    updateHeader(
      token,
        _addressModel == null ? null : _addressModel.zoneIds,
      sharedPreferences.getString(AppConstants.LANGUAGE_CODE),
        _moduleID, _addressModel == null ? null : _addressModel.latitude,
        _addressModel == null ? null : _addressModel.longitude
    );
  }

  void updateHeader(String token, List<int> zoneIDs, String languageCode, int moduleID, String latitude, String longitude) {
    Map<String, String> _header = {
      // 'Access-Control-Allow-Origin': '*',
      'Content-Type': 'application/json; charset=UTF-8',
      'Accept': 'application/json;',
      AppConstants.ZONE_ID: zoneIDs != null ? jsonEncode(zoneIDs) : null,
      //AppConstants.ZONE_ID: "8",
      AppConstants.LOCALIZATION_KEY: languageCode ?? AppConstants.languages[0].languageCode,
      AppConstants.LATITUDE: latitude != null ? latitude : null,
      AppConstants.LONGITUDE: longitude != null ? longitude : null,
      // AppConstants.LATITUDE: "28.53551929676534",
      // AppConstants.LONGITUDE: "77.3910229280591",
      'Authorization': 'Bearer $token'
    };
    print('-----> module id: $moduleID');
    // if(moduleID != null) {
    //   _header.addAll({AppConstants.MODULE_ID: moduleID.toString()});
    // }

      _header.addAll({AppConstants.MODULE_ID:'1'});

    _mainHeaders = _header;
  }

  Future<Response> getData(String uri, {Map<String, dynamic> query, Map<String, String> headers}) async {
    try {
      if(Foundation.kDebugMode) {
        print('====> API Call: $uri\nHeader: $_mainHeaders');
      }
      Http.Response _response = await Http.get(
        Uri.parse(appBaseUrl+uri),
        headers: headers ?? _mainHeaders,
      ).timeout(Duration(seconds: timeoutInSeconds));
      return handleResponse(_response, uri);
    } catch (e) {
      print('------------${e.toString()}');
      return Response(statusCode: 1, statusText: noInternetMessage);
    }
  }
  Future<Response> getHtmlData(String uri,HtmlType htmlType, {Map<String, dynamic> query, Map<String, String> headers}) async {
    try {
      if(Foundation.kDebugMode) {
        print('====> getHtmlData_API Call: $uri\nHeader: $_mainHeaders');
      }
      String baseUrl = appBaseUrl;
      // if(htmlType == HtmlType.PRIVACY_POLICY){
      //   baseUrl = AppConstants.BASE_URL_STORE;
      // }
      //https://Bhavyaretail.com/api/v1/privacy-policy
      if(Foundation.kDebugMode) {
        print('====> getHtmlData_API Call: ${baseUrl+uri}');
      }
      Http.Response _response = await Http.get(
        Uri.parse(baseUrl+uri),
        headers: headers ?? _mainHeaders,
      ).timeout(Duration(seconds: timeoutInSeconds));
      return handleResponse(_response, uri);
    } catch (e) {
      print('------------${e.toString()}');
      return Response(statusCode: 1, statusText: noInternetMessage);
    }
  }
  Future<Response> postData(String uri, dynamic body, {Map<String, String> headers}) async {
    try {
      if(Foundation.kDebugMode) {
        print('====> API Call: $uri\nHeader: $_mainHeaders');
        print('====> API Body: $body');
      }
      Http.Response _response = await Http.post(
        Uri.parse(appBaseUrl+uri),
        body: jsonEncode(body),
        headers: headers ?? _mainHeaders,
      ).timeout(Duration(seconds: timeoutInSeconds));
      return handleResponse(_response, uri);
    } catch (e) {
      return Response(statusCode: 1, statusText: noInternetMessage);
    }
  }

  Future<Response> postMultipartData(String uri, Map<String, String> body, List<MultipartBody> multipartBody, {Map<String, String> headers}) async {
    try {
      if(Foundation.kDebugMode) {
        print('====> API Call: $uri\nHeader: $_mainHeaders');
        print('====> API Body: $body with ${multipartBody.length} picture');
      }
      Http.MultipartRequest _request = Http.MultipartRequest('POST', Uri.parse(appBaseUrl+uri));
      _request.headers.addAll(headers ?? _mainHeaders);
      for(MultipartBody multipart in multipartBody) {
        if(multipart.file != null) {
          Uint8List _list = await multipart.file.readAsBytes();
          _request.files.add(Http.MultipartFile(
            multipart.key, multipart.file.readAsBytes().asStream(), _list.length,
            filename: '${DateTime.now().toString()}.png',
          ));
        }
      }
      _request.fields.addAll(body);
      Http.Response _response = await Http.Response.fromStream(await _request.send());
      return handleResponse(_response, uri);
    } catch (e) {
      return Response(statusCode: 1, statusText: noInternetMessage);
    }
  }

  Future<Response> putData(String uri, dynamic body, {Map<String, String> headers}) async {
    try {
      if(Foundation.kDebugMode) {
        print('====> API Call: $uri\nHeader: $_mainHeaders');
        print('====> API Body: $body');
      }
      Http.Response _response = await Http.put(
        Uri.parse(appBaseUrl+uri),
        body: jsonEncode(body),
        headers: headers ?? _mainHeaders,
      ).timeout(Duration(seconds: timeoutInSeconds));
      return handleResponse(_response, uri);
    } catch (e) {
      return Response(statusCode: 1, statusText: noInternetMessage);
    }
  }

  Future<Response> deleteData(String uri, {Map<String, String> headers}) async {
    try {
      if(Foundation.kDebugMode) {
        print('====> API Call: $uri\nHeader: $_mainHeaders');
      }
      Http.Response _response = await Http.delete(
        Uri.parse(appBaseUrl+uri),
        headers: headers ?? _mainHeaders,
      ).timeout(Duration(seconds: timeoutInSeconds));
      return handleResponse(_response, uri);
    } catch (e) {
      return Response(statusCode: 1, statusText: noInternetMessage);
    }
  }

  Response handleResponse(Http.Response response, String uri) {


    dynamic _body;
    try {
      _body = jsonDecode(response.body);
    }catch(e) {}
    Response _response = Response(
      body: _body != null ? _body : response.body, bodyString: response.body.toString(),
      request: Request(headers: response.request.headers, method: response.request.method, url: response.request.url),
      headers: response.headers, statusCode: response.statusCode, statusText: response.reasonPhrase,
    );
    if(_response.statusCode != 200 && _response.body != null && _response.body is !String) {

      if(_response.body.toString().startsWith('{errors: [{code:')) {
        print('Wallet_Recharge_Order Te  ----------');
        ErrorResponse _errorResponse = ErrorResponse.fromJson(_response.body);
        _response = Response(statusCode: _response.statusCode, body: _response.body, statusText: _errorResponse.errors[0].message);
      }else if(_response.body.toString().startsWith('{message')) {
        _response = Response(statusCode: _response.statusCode, body: _response.body, statusText: _response.body['message']);
      }
    }else if(_response.statusCode != 200 && _response.body == null) {
      _response = Response(statusCode: 0, statusText: noInternetMessage);
    }else{
      print('Wallet_Recharge_Order handleResponse ${_response.body is !String} ----------');

    }
    if(Foundation.kDebugMode) {
      print('====> API Response: [${_response.statusCode}] $uri\n${_response.body}');
      //AppConstants.printLongString('====> API Response: START statusCode: [${_response.statusCode}] uri: [$uri] \n${_response.body} END');

    }
    return _response;
  }

  // /// Print Long String
  // void printLongString(String text) {
  //   final RegExp pattern = RegExp('.{1,800}'); // 800 is the size of each chunk
  //   pattern.allMatches(text).forEach((RegExpMatch match) =>   print(match.group(0)));
  // }
}

class MultipartBody {
  String key;
  XFile file;

  MultipartBody(this.key, this.file);
}