
import 'package:sixam_mart/data/model/response/chat_model.dart';

class ConversationsModel {
  int totalSize;
  int limit;
  int offset;
  List<Conversation> conversations;

  ConversationsModel({this.totalSize, this.limit, this.offset, this.conversations});

  ConversationsModel.fromJson(Map<String, dynamic> json) {
    totalSize = json['total_size'];
    limit = json['limit'];
    offset = json['offset'];
    if (json['conversations'] != null) {
      conversations = <Conversation>[];
      json['conversations'].forEach((v) {
        conversations.add(new Conversation.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['total_size'] = this.totalSize;
    data['limit'] = this.limit;
    data['offset'] = this.offset;
    if (this.conversations != null) {
      data['conversations'] = this.conversations.map((v) => v.toJson()).toList();
    }
    return data;
  }

}

class Conversation {
  int id;
  int senderId;
  String senderType;
  int receiverId;
  String receiverType;
  int unreadMessageCount;
  int lastMessageId;
  String lastMessageTime;
  String createdAt;
  String updatedAt;
  User sender;
  User receiver;
  Message lastMessage;

  Conversation(
      {this.id,
        this.senderId,
        this.senderType,
        this.receiverId,
        this.receiverType,
        this.unreadMessageCount,
        this.lastMessageId,
        this.lastMessageTime,
        this.createdAt,
        this.updatedAt,
        this.sender,
        this.receiver,
        this.lastMessage,
      });

  Conversation.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    senderId = json['sender_id'];
    senderType = json['sender_type'];
    receiverId = json['receiver_id'];
    receiverType = json['receiver_type'];
    unreadMessageCount = json['unread_message_count'];
    lastMessageId = json['last_message_id'];
    lastMessageTime = json['last_message_time'];
    createdAt = json['created_at'];
    updatedAt = json['updated_at'];
    sender = json['sender'] != null ? new User.fromJson(json['sender']) : null;
    receiver = json['receiver'] != null ? new User.fromJson(json['receiver']) : null;
    lastMessage = json['last_message'] != null ? new Message.fromJson(json['last_message']) : null;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['id'] = this.id;
    data['sender_id'] = this.senderId;
    data['sender_type'] = this.senderType;
    data['receiver_id'] = this.receiverId;
    data['receiver_type'] = this.receiverType;
    data['unread_message_count'] = this.unreadMessageCount;
    data['last_message_id'] = this.lastMessageId;
    data['last_message_time'] = this.lastMessageTime;
    data['created_at'] = this.createdAt;
    data['updated_at'] = this.updatedAt;
    if (this.sender != null) {
      data['sender'] = this.sender.toJson();
    }
    if (this.receiver != null) {
      data['receiver'] = this.receiver.toJson();
    }
    if (this.lastMessage != null) {
      data['last_message'] = this.lastMessage.toJson();
    }
    return data;
  }
}

class User {
  int id;
  String fName;
  String lName;
  String phone;
  String email;
  String image;
  String createdAt;
  String updatedAt;
  int userId;

  User(
      {this.id,
        this.fName,
        this.lName,
        this.phone,
        this.email,
        this.image,
        this.createdAt,
        this.userId,
        this.updatedAt});

  User.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    fName = json['f_name'];
    lName = json['l_name'];
    phone = json['phone'];
    email = json['email'];
    image = json['image'];
    createdAt = json['created_at'];
    userId = json['user_id'];
    updatedAt = json['updated_at'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['id'] = this.id;
    data['f_name'] = this.fName;
    data['l_name'] = this.lName;
    data['phone'] = this.phone;
    data['email'] = this.email;
    data['image'] = this.image;
    data['created_at'] = this.createdAt;
    data['updated_at'] = this.updatedAt;
    data['user_id'] = this.userId;
    return data;
  }
}

class CompanyWalletSummery {
  CompanyWalletSummery({
    dynamic headers,
    Original original,
    dynamic exception,}){
    _headers = headers;
    _original = original;
    _exception = exception;
  }

  CompanyWalletSummery.fromJson(dynamic json) {
    _headers = json['headers'];
    _original = json['original'] != null ? Original.fromJson(json['original']) : null;
    _exception = json['exception'];
  }
  dynamic _headers;
  Original _original;
  dynamic _exception;
  CompanyWalletSummery copyWith({  dynamic headers,
    Original original,
    dynamic exception,
  }) => CompanyWalletSummery(  headers: headers ?? _headers,
    original: original ?? _original,
    exception: exception ?? _exception,
  );
  dynamic get headers => _headers;
  Original get original => _original;
  dynamic get exception => _exception;

  Map<String, dynamic> toJson() {
    final map = <String, dynamic>{};
    map['headers'] = _headers;
    if (_original != null) {
      map['original'] = _original.toJson();
    }
    map['exception'] = _exception;
    return map;
  }

}

class Original {
  Original({
    String success,
    num code,
    CompanyWalletData data,}){
    _success = success;
    _code = code;
    _data = data;
  }

  Original.fromJson(dynamic json) {
    _success = json['success'];
    _code = json['code'];
    _data = json['data'] != null ? CompanyWalletData.fromJson(json['data']) : null;
  }
  String _success;
  num _code;
  CompanyWalletData _data;
  Original copyWith({  String success,
    num code,
    CompanyWalletData data,
  }) => Original(  success: success ?? _success,
    code: code ?? _code,
    data: data ?? _data,
  );
  String get success => _success;
  num get code => _code;
  CompanyWalletData get data => _data;

  Map<String, dynamic> toJson() {
    final map = <String, dynamic>{};
    map['success'] = _success;
    map['code'] = _code;
    if (_data != null) {
      map['data'] = _data.toJson();
    }
    return map;
  }

}
class CompanyWalletData {
  CompanyWalletData({
    num walletCredits,
    num usedCredits,
    num availableCredits,
    num loanCredits,
    num paidCredits,
    num loanCount,
    num paidCount,
    num closingCount,
    num totalTeamIncome,}){
    _walletCredits = walletCredits;
    _usedCredits = usedCredits;
    _availableCredits = availableCredits;
    _loanCredits = loanCredits;
    _paidCredits = paidCredits;
    _loanCount = loanCount;
    _paidCount = paidCount;
    _closingCount = closingCount;
    _totalTeamIncome = totalTeamIncome;
  }

  CompanyWalletData.fromJson(dynamic json) {
    _walletCredits = json['wallet_credits'];
    _usedCredits = json['used_credits'];
    _availableCredits = json['available_credits'];
    _loanCredits = json['loan_credits'];
    _paidCredits = json['paid_credits'];
    _loanCount = json['loan_count'];
    _paidCount = json['paid_count'];
    _closingCount = json['closing_count'];
    _totalTeamIncome = json['total_team_income'];
  }
  num _walletCredits;
  num _usedCredits;
  num _availableCredits;
  num _loanCredits;
  num _paidCredits;
  num _loanCount;
  num _paidCount;
  num _closingCount;
  num _totalTeamIncome;
  CompanyWalletData copyWith({  num walletCredits,
    num usedCredits,
    num availableCredits,
    num loanCredits,
    num paidCredits,
    num loanCount,
    num paidCount,
    num closingCount,
    num totalTeamIncome,
  }) => CompanyWalletData(  walletCredits: walletCredits ?? _walletCredits,
    usedCredits: usedCredits ?? _usedCredits,
    availableCredits: availableCredits ?? _availableCredits,
    loanCredits: loanCredits ?? _loanCredits,
    paidCredits: paidCredits ?? _paidCredits,
    loanCount: loanCount ?? _loanCount,
    paidCount: paidCount ?? _paidCount,
    closingCount: closingCount ?? _closingCount,
    totalTeamIncome: totalTeamIncome ?? _totalTeamIncome,
  );
  num get walletCredits => _walletCredits;
  num get usedCredits => _usedCredits;
  num get availableCredits => _availableCredits;
  num get loanCredits => _loanCredits;
  num get paidCredits => _paidCredits;
  num get loanCount => _loanCount;
  num get paidCount => _paidCount;
  num get closingCount => _closingCount;
  num get totalTeamIncome => _totalTeamIncome;

  Map<String, dynamic> toJson() {
    final map = <String, dynamic>{};
    map['wallet_credits'] = _walletCredits;
    map['used_credits'] = _usedCredits;
    map['available_credits'] = _availableCredits;
    map['loan_credits'] = _loanCredits;
    map['paid_credits'] = _paidCredits;
    map['loan_count'] = _loanCount;
    map['paid_count'] = _paidCount;
    map['closing_count'] = _closingCount;
    map['total_team_income'] = _totalTeamIncome;
    return map;
  }

}