import '../../../util/app_constants.dart';

class ItemModel {
  int totalSize;
  String limit;
  int offset;
  List<Item> items;

  ItemModel({this.totalSize, this.limit, this.offset, this.items});

  ItemModel.fromJson(Map<String, dynamic> json) {
    totalSize = json['total_size'];
    limit = json['limit'].toString();
    offset = (json['offset'] != null && json['offset'].toString().trim().isNotEmpty) ? int.parse(json['offset'].toString()) : null;
    if (json['products'] != null) {
      items = [];
      json['products'].forEach((v) {
        items.add(new Item.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['total_size'] = this.totalSize;
    data['limit'] = this.limit;
    data['offset'] = this.offset;
    if (this.items != null) {
      data['products'] = this.items.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class Item {
  double storeDiscount;
  double price;
  double mrp;
  double tax;
  double discount;
  double avgRating;
  int storeId;
  int brandId;
  int zoneId;
  int id;
  int categoryId;
  int ratingCount;
  int veg;
  int moduleId;
  int stock;
  int isInactive;

  String name;
  String categoryName;
  String brandName;
  String description;
  String image;
  List<String> images;

  List<CategoryIds> categoryIds;
  List<Variation> variations;
  List<AddOns> addOns;
  List<DiscountRange> discountRange;
  List<ChoiceOptions> choiceOptions;

  String discountType;
  String availableTimeStarts;
  String availableTimeEnds;
  String storeName;

  bool scheduleOrder;

  String unitType;
  String availableDateStarts;

  Item(
      {this.id,
        this.name,
        this.categoryName,
        this.brandName,
        this.description,
        this.image,
        this.images,
        this.categoryId,
        this.categoryIds,
        this.variations,
        this.addOns,
        this.choiceOptions,
        this.discountRange,
        this.price,
        this.tax,
        this.discount,
        this.discountType,
        this.availableTimeStarts,
        this.availableTimeEnds,
        this.storeId,
        this.brandId,
        this.storeName,
        this.zoneId,
        this.storeDiscount,
        this.scheduleOrder,
        this.avgRating,
        this.ratingCount,
        this.veg,
        this.moduleId,
        this.unitType,
        this.stock,
        this.isInactive,
      });

  Item.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    //name = json['name'];
    name = json['product'];
    categoryName = json['category'];
    brandName = json['brand'];
    description = json['description'];
    image = json['image'];
    images = json['images'] != null ? json['images'].cast<String>() : [];
    categoryId = json['category_id'];
    if (json['category_ids'] != null) {
      categoryIds = [];
      json['category_ids'].forEach((v) {
        categoryIds.add(new CategoryIds.fromJson(v));
      });
    }
    if (json['variations'] != null) {
      variations = [];
      json['variations'].forEach((v) {
        variations.add(new Variation.fromJson(v));
      });
    }
    if (json['add_ons'] != null) {
      addOns = [];
      json['add_ons'].forEach((v) {
        addOns.add(new AddOns.fromJson(v));
      });
    }
    if (json['choice_options'] != null) {
      choiceOptions = [];
      json['choice_options'].forEach((v) {
        choiceOptions.add(new ChoiceOptions.fromJson(v));
      });
    }

    if (json['discount_range'] != null) {
      discountRange = [];
      json['discount_range'].forEach((v) {
        discountRange.add(new DiscountRange.fromJson(v));
      });
    }
    mrp =json['mrp'] != null ? json['mrp'].toDouble() : 0;
    price =json['price'] != null ? json['price'].toDouble() : 0;
    tax = json['tax'] != null ? json['tax'].toDouble() : 0;
    discount =json['discount'] != null ? json['discount'].toDouble() : 0;
    discountType = json['discount_type'];
    availableTimeStarts = json['available_time_starts'];
    availableTimeEnds = json['available_time_ends'];
    storeId = json['store_id']==null? 4: json['store_id'];
    brandId = json['brand_id']==null? -1: json['brand_id'];
    storeName = json['store_name'];
    zoneId = json['zone_id'];
    storeDiscount = json['store_discount'] != null ? json['store_discount'].toDouble() : 0;
    scheduleOrder = json['schedule_order']==null? false : json['schedule_order'];
    avgRating =json['avg_rating'] != null ? json['avg_rating'].toDouble() : 0;
    ratingCount = json['rating_count'];
    moduleId = json['module_id'];
    veg = json['veg'] != null ? int.parse(json['veg'].toString()) : 0;
    //stock = AppConstants.checkIntTypeKey(json['stock']);
    stock = json['stock'];
    isInactive = json['is_inactive'];
    unitType = json['unit_type'];
    availableDateStarts = json['available_date_starts'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['id'] = this.id;
    data['product'] = this.name;
    data['category'] = this.categoryName;
    data['brand'] = this.brandName;
    data['description'] = this.description;
    data['image'] = this.image;
    data['images'] = this.images;
    data['category_id'] = this.categoryId;
    if (this.categoryIds != null) {
      data['category_ids'] = this.categoryIds.map((v) => v.toJson()).toList();
    }
    if (this.variations != null) {
      data['variations'] = this.variations.map((v) => v.toJson()).toList();
    }
    if (this.addOns != null) {
      data['add_ons'] = this.addOns.map((v) => v.toJson()).toList();
    }
    if (this.choiceOptions != null) {
      data['choice_options'] =
          this.choiceOptions.map((v) => v.toJson()).toList();
    }
    if (this.discountRange != null) {
      data['discount_range'] =
          this.discountRange.map((v) => v.toJson()).toList();
    }
    data['mrp'] = this.mrp;
    data['price'] = this.price;
    data['tax'] = this.tax;
    data['discount'] = this.discount;
    data['discount_type'] = this.discountType;
    data['available_time_starts'] = this.availableTimeStarts;
    data['available_time_ends'] = this.availableTimeEnds;
    data['store_id'] = this.storeId;
    data['brand_id'] = this.brandId;
    data['store_name'] = this.storeName;
    data['zone_id'] = this.zoneId;
    data['store_discount'] = this.storeDiscount;
    data['schedule_order'] = this.scheduleOrder;
    data['avg_rating'] = this.avgRating;
    data['rating_count'] = this.ratingCount;
    data['veg'] = this.veg;
    data['module_id'] = this.moduleId;
    data['stock'] = this.stock;
    data['is_inactive'] = this.isInactive;
    data['unit_type'] = this.unitType;
    data['available_date_starts'] = this.availableDateStarts;
    return data;
  }

}

class CategoryIds {
  String id;

  CategoryIds({this.id});

  CategoryIds.fromJson(Map<String, dynamic> json) {
    id = json['id'].toString();
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['id'] = this.id;
    return data;
  }
}

class Variation {
  String type;
  double price;
  int stock;

  Variation({this.type, this.price, this.stock});

  Variation.fromJson(Map<String, dynamic> json) {
    type = json['type'];
    price = json['price']==null? 0 : json['price'].toDouble();
    stock = int.parse(json['stock'] != null ? json['stock'].toString() : '0');
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['type'] = this.type;
    data['price'] = this.price;
    data['stock'] = this.stock;
    return data;
  }
}

class AddOns {
  int id;
  String name;
  double price;

  AddOns(
      {this.id,
        this.name,
        this.price});

  AddOns.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    name = json['name'];
    price = json['price'].toDouble();
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['id'] = this.id;
    data['name'] = this.name;
    data['price'] = this.price;
    return data;
  }
}

class ChoiceOptions {
  String name;
  String title;
  List<String> options;

  ChoiceOptions({this.name, this.title, this.options});

  ChoiceOptions.fromJson(Map<String, dynamic> json) {
    name = json['name'];
    title = json['title'];
    options = json['options'].cast<String>();
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['name'] = this.name;
    data['title'] = this.title;
    data['options'] = this.options;
    return data;
  }


}

class DiscountRange {
  int qty;
  String discount;

  DiscountRange({this.qty, this.discount});

  DiscountRange.fromJson(Map<String, dynamic> json) {
    qty = json['qty'];
    discount = json['discount'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['qty'] = this.qty;
    data['discount'] = this.discount;
    return data;
  }
}