import 'package:sixam_mart/data/api/api_client.dart';
import 'package:sixam_mart/data/model/body/review_body.dart';
import 'package:sixam_mart/util/app_constants.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

import '../../controller/auth_controller.dart';
import '../../controller/user_controller.dart';
import '../model/response/userinfo_model.dart';

class ItemRepo extends GetxService {
  final ApiClient apiClient;

  ItemRepo({@required this.apiClient});

  Future<Response> getPopularItemList(String type) async {
    return await apiClient.getData(
        '${AppConstants.POPULAR_ITEM_URI}?type=$type');
  }

  Future<Response> getReviewedItemList(String type) async {
    return await apiClient.getData(
        '${AppConstants.REVIEWED_ITEM_URI}?type=$type');
  }

  Future<Response> submitReview(ReviewBody reviewBody) async {
    return await apiClient.postData(
        AppConstants.REVIEW_URI, reviewBody.toJson());
  }

  Future<Response> submitDeliveryManReview(ReviewBody reviewBody) async {
    return await apiClient.postData(
        AppConstants.DELIVER_MAN_REVIEW_URI, reviewBody.toJson());
  }

  Future<Response> getItemDetails(int itemID) async {
    return apiClient.getData('${AppConstants.ITEM_DETAILS_URI}$itemID');
  }

  Future<Response> getLatestItemList(int offset, String limit, int type) async {
    UserInfoModel _user =  Get.find<UserController>().userInfoModel;
    bool _isLoggedIn = Get.find<AuthController>().isLoggedIn();
    var isPrime="0";
    if(_isLoggedIn && _user!=null
        && _user.primeMember!=null
        && _user.primeMember==1
    ){
      isPrime="1";
    }

    return await apiClient.getData(
      '${AppConstants.LATEST_ITEM_URI}?offset=$offset&limit=$limit&type=$type&is_prime=$isPrime',);
  }
  Future<Response> getSearchData(String query, String categoryID, bool isStore, String parentChild) async {

    UserInfoModel _user =  Get.find<UserController>().userInfoModel;
    bool _isLoggedIn = Get.find<AuthController>().isLoggedIn();
    var isPrime="0";
    if(_isLoggedIn && _user!=null
        && _user.primeMember!=null
        && _user.primeMember==1
    ){
      isPrime="1";
    }


    return await apiClient.getData(
      '${AppConstants.SEARCH_URI}${isStore ? 'stores' : 'items'}/search?name=$query&category_id=$categoryID&parent_child=$parentChild&offset=1&limit=50&is_prime=$isPrime',
    );
  }
}
