
import 'package:image_compression_flutter/image_compression_flutter.dart';
import 'package:sixam_mart/controller/user_controller.dart';
import 'package:sixam_mart/data/api/api_client.dart';

import 'package:flutter/foundation.dart';
import 'package:get/get.dart';
import 'package:shared_preferences/shared_preferences.dart';

import '../../controller/auth_controller.dart';
import '../../util/app_constants.dart';
import '../model/body/prime_member_create_body.dart';

class PrimeMemberRepo {
  final ApiClient apiClient;
  final SharedPreferences sharedPreferences;
  PrimeMemberRepo({@required this.apiClient, @required this.sharedPreferences});


  Future<Response> uploadDocument(bool shouldBeUpdate,String state,
  String city,
  String pin,
  String bank_account_no,
  String bank_ifc,
  String aadhar_card,
  String pan_card,
  String nominee_name,
  String nominee_mobile,
  String nominee_relation,
  String nominee_adhar_card,
  String nominee_pan_card,
  String parent_id

      , XFile _pickedUserImageFile
      , XFile _pickedAadharImageFile
      , XFile _pickedAadharBackImageFile
      , XFile _pickedPanImageFile
      , XFile _pickedNomineeAadharImageFile
      , XFile _pickedNomineeAadharBackImageFile
      , XFile _pickedNomineePanImageFile
      ) async {

    Map<String, String> _body = Map();
    _body.addAll(<String, String>{
      'state': state,
      'city': city,
      'pin': pin,
      'bank_account_no': bank_account_no,
      'bank_ifc': bank_ifc,
      'aadhar_card': aadhar_card,
      'pan_card': pan_card,
      'nominee_name': nominee_name,
      'nominee_mobile': nominee_mobile,
      'nominee_relation': nominee_relation,
      'nominee_adhar_card': nominee_adhar_card,
      'nominee_pan_card': nominee_pan_card,
      'parent_id': parent_id,
    });
    String url = AppConstants.PRIME_DOCUMENTS_URI;
    if(shouldBeUpdate){
      url = AppConstants.UPDATE_PRIME_DOCUMENTS_URI;
    }


    return await apiClient.postMultipartData(url, _body,
        [
           MultipartBody('image', _pickedUserImageFile)
          ,MultipartBody('aadhar_card_image', _pickedAadharImageFile)
          ,MultipartBody('aadhar_card_image_back', _pickedAadharBackImageFile)
          ,MultipartBody('nominee_adhar_card_image_back', _pickedNomineeAadharBackImageFile)
          ,MultipartBody('pan_card_image', _pickedPanImageFile)
          ,MultipartBody('nominee_adhar_card_image', _pickedNomineeAadharImageFile)
          ,MultipartBody('nominee_pan_card_image', _pickedNomineePanImageFile)
        ]
    );
  }


  Future<Response> uploadUpiPaymentScreenshot(XFile _screenshot,String platform,String orderId,String remarks,String upiNumber, String type, String transactionID) async {
    Map<String, String> _body = Map();
    _body.addAll(<String, String>{
      'trn_no': transactionID,
      'platform': platform,
      'order_id': orderId,
      'upi_number': upiNumber,
      'remarks': remarks,
      'type': type,
    });


    return await apiClient.postMultipartData(AppConstants.UPI_SCREENSHOT_URI, _body,
        [

          MultipartBody('upi_screen_shot', _screenshot)
        ]
    );
  }

  Future<Response> getStateCityAndRelationData() async {
    return await apiClient.getData(AppConstants.CONFIG_2_URI);
  }

  Future<Response> getPrimeMemberDetail() async {
    return await apiClient.getData(AppConstants.PRIME_MEMBER_DETAIL);
  }

  Future<Response> getFamilyMemberList() async {
    return await apiClient.getData("${AppConstants.PRIME_FAMILY_MEMBER_URI}display");
  }

  Future<Response> familyMemberDelete(String url) async {
    return await apiClient.postData(url,null);
  }

  Future<Response> familyMemberCreateUpdate2({String mobile, String name,
    String relationship,String url}) async {
    return await apiClient.postData(url,
        {"mobile": mobile,
      "name": name,
      "relationship": relationship
      // "userid": Get.find<UserController>().userInfoModel.id.toString(),
    });
  }

  Future<Response> familyMemberCreateUpdate(String aadharCard,String mobile, String name,
  String relationship,String url, XFile aadharcardImage, XFile image) async {

    Map<String, String> _body = Map();


    _body.addAll(<String, String>{
      "aadharcard_no": aadharCard,
      "mobile": mobile,
      "name": name,
      "relationship": relationship
    });
    print("updateProfile img =  $image _body = ${_body.toString()}");
    return await apiClient.postMultipartData(url, _body, [
      MultipartBody('image', image),
      MultipartBody('aadharcard_image', aadharcardImage)
    ]);

  }

  Future<Response> getSearchData(String query) async {
    return await apiClient.getData(
      '${AppConstants.PRIME_MEMBER_SEARCH_URI}${'?name=$query'}',
    );
  }
  Future<Response> getOrderIdForPrimeMembership(String userId) async {
    return await apiClient.getData(
      '${AppConstants.PRIME_MEMBER_ORDER_ID_URI}${'?user_id=$userId'}',
    );
  }

  Future<Response> trackPrimeOrder(String orderId) async {
    return await apiClient.getData(
      '${AppConstants.PRIME_MEMBER_ORDER_STATUS_URI}${'?order_id=$orderId'}',
    );
  }
  Future<Response> getUsersPrimaryMembersList(int offset, int limit) async {
    return await apiClient.getData(
      '${AppConstants.USERS_PRIMARY_MEMBERS_URI}?offset=$offset&limit=1000',);
  }  Future<Response> getPrimaryMembersList(int offset, int limit) async {
    return await apiClient.getData(
      '${AppConstants.PRIMARY_MEMBERS_URI}?offset=$offset&limit=1000',);
  }
Future<Response> getSharedLinkList() async {
    return await apiClient.getData(AppConstants.SHARE_LINK_LIST_URL,);
  }

}
