import 'package:shared_preferences/shared_preferences.dart';
import 'package:sixam_mart/data/api/api_client.dart';
import 'package:sixam_mart/data/model/response/userinfo_model.dart';
import 'package:sixam_mart/util/app_constants.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:get/get_connect/http/src/response/response.dart';
import 'package:image_picker/image_picker.dart';

import '../model/body/prime_member_create_body.dart';

class UserRepo {
  final ApiClient apiClient;
  final SharedPreferences sharedPreferences;
  UserRepo({@required this.apiClient , @required this.sharedPreferences});

  Future<Response> getUserInfo() async {

    return await apiClient.getData(AppConstants.CUSTOMER_INFO_URI);

  }

  Future<Response> updateProfile(UserInfoModel userInfoModel, XFile data, String token) async {

    Map<String, String> _body = Map();


    _body.addAll(<String, String>{
      'f_name': userInfoModel.fName, 'l_name': userInfoModel.lName, 'email': userInfoModel.email
    });
    print("updateProfile img =  $data _body = ${_body.toString()}");
    return await apiClient.postMultipartData(AppConstants.UPDATE_PROFILE_URI, _body, [MultipartBody('image', data)]);

  }

  Future<Response> makeUserPrimeMember(PrimeMemberCreateBody body) async {
    return await apiClient.postData(AppConstants.PRIME_MEMBER_URI, body.toJson());
  }

  Future<Response> checkUserCanShareApp(String name, String mobile) async {
    return await apiClient.postData(AppConstants.CHECK_USER_CAN_SHARE_APP_URI, {'name': name, 'mobile_no': mobile});
  }

  Future<Response> getClientSidePrimeUserInfo(String clientReferralCode) async {
    return await apiClient.getData('${AppConstants.REFERRAL_CODE_DETAIL_URI}?ref_code=$clientReferralCode');
  }

  Future<Response> changePassword(UserInfoModel userInfoModel) async {
    return await apiClient.postData(AppConstants.UPDATE_PROFILE_URI, {'f_name': userInfoModel.fName, 'l_name': userInfoModel.lName,
      'email': userInfoModel.email, 'password': userInfoModel.password});
  }

  Future<Response> deleteUser() async {
    return await apiClient.deleteData(AppConstants.CUSTOMER_REMOVE);
  }

  Future<void> savePrime(int number) async {
    try {
      await sharedPreferences.setInt(AppConstants.USER_PRIME, number);
    } catch (e) {
      throw e;
    }
  }

  int getPrime() {
    return sharedPreferences.getInt(AppConstants.USER_PRIME) ?? 0;
  }



}