import 'dart:async';

import 'package:sixam_mart/controller/auth_controller.dart';
import 'package:sixam_mart/controller/cart_controller.dart';
import 'package:sixam_mart/controller/item_controller.dart';
import 'package:sixam_mart/controller/splash_controller.dart';
import 'package:sixam_mart/controller/wishlist_controller.dart';
import 'package:sixam_mart/data/model/response/cart_model.dart';
import 'package:sixam_mart/data/model/response/item_model.dart';
import 'package:sixam_mart/helper/date_converter.dart';
import 'package:sixam_mart/helper/price_converter.dart';
import 'package:sixam_mart/helper/responsive_helper.dart';
import 'package:sixam_mart/helper/route_helper.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/images.dart';
import 'package:sixam_mart/util/styles.dart';
import 'package:sixam_mart/view/base/confirmation_dialog.dart';
import 'package:sixam_mart/view/base/custom_button.dart';
import 'package:sixam_mart/view/base/custom_image.dart';
import 'package:sixam_mart/view/base/discount_tag.dart';
import 'package:sixam_mart/view/base/quantity_button.dart';
import 'package:sixam_mart/view/base/rating_bar.dart';
import 'package:sixam_mart/view/screens/checkout/checkout_screen.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

import '../screens/item/widget/details_app_bar.dart';
import 'cart_snackbar.dart';
import 'custom_snackbar.dart';

class ItemBottomSheet extends StatefulWidget {
  final Item item;
  final bool isCampaign;
  final CartModel cart;
  final int cartIndex;
  final bool inStorePage;
  final bool fromCartPage;
  ItemBottomSheet({@required this.item, this.isCampaign = false, this.cart, this.cartIndex, this.inStorePage = false, this.fromCartPage = false});

  @override
  State<ItemBottomSheet> createState() => _ItemBottomSheetState();
}

class _ItemBottomSheetState extends State<ItemBottomSheet> {
  final ScrollController scrollController = ScrollController();
  final GlobalKey<DetailsAppBarState> _key = GlobalKey();
  DiscountRange qtyDropdownValue;
  List<DiscountRange> discountRange=[];

  @override
  void initState() {
    super.initState();

    discountRange.insert(0, DiscountRange(qty: 0,discount: 'Select Qty'));
    qtyDropdownValue=discountRange[0];

    if(widget.item.discountRange!=null && widget.item.discountRange.isNotEmpty) {

      discountRange.addAll(widget.item.discountRange);
    }

    Get.find<ItemController>().initData(widget.item, widget.cart);
  }

  double getStartingPrice(Item item) {
    double _startingPrice = 0;
    if (item.choiceOptions!=null && item.choiceOptions.length != 0) {
      List<double> _priceList = [];
      item.variations.forEach((variation) => _priceList.add(variation.price));
      _priceList.sort((a, b) => a.compareTo(b));
      _startingPrice = _priceList[0];
    } else {
      _startingPrice = item.price;
    }
    return _startingPrice;
  }

  double getDiscount(Item item) => item.discount==null?0 : item.discount;

  double getUpdatedDiscount(ItemController itemController){

    //print("getUpdatedDiscountTest run");
    var discount=double.parse(discountRange[1].discount);

    for(int index=0; index<discountRange.length; index++) {

       // if (itemController.isBulkQtyAddBtnClicked && itemController.quantity>0 && itemController.quantity==discountRange[index].qty) {
        if (itemController.quantity>0 && itemController.quantity==discountRange[index].qty) {
          discount=double.parse(discountRange[index].discount);
        //  print("getUpdatedDiscountTest discount $discount");
          break;
        }


    }

    return discount;
  }

  String getDiscountType(Item item) => item.storeDiscount == 0 ? item.discountType : 'percentage';


  bool isCurrentQtyAvailable(DiscountRange singleItem){
    return singleItem.qty <= widget.item.stock;
  }
  bool isCurrentQtySelected(ItemController itemController , DiscountRange singleItem){
    return ( widget.fromCartPage ? (itemController.quantity==singleItem.qty) || (itemController.isBulkQtyAddBtnClicked && itemController.quantity>0 && itemController.quantity==singleItem.qty)
        :(widget.cart != null || itemController.cartIndex != -1 && itemController.quantity==singleItem.qty) || (itemController.isBulkQtyAddBtnClicked && itemController.quantity>0 && itemController.quantity==singleItem.qty)
    );
  }

  @override
  Widget build(BuildContext context) {
    bool _desktop = ResponsiveHelper.isDesktop(context);
    bool _isTab = ResponsiveHelper.isTab(context);
    bool _isWeb = ResponsiveHelper.isWeb();
    bool _isMobile = ResponsiveHelper.isMobile(context);
    double screenWidth = MediaQuery.of(context).size.width;
    return Container(
      width:  550,
      margin: EdgeInsets.only(top: _desktop ? 0 : 30),
      padding: EdgeInsets.only(left: Dimensions.PADDING_SIZE_DEFAULT, bottom: Dimensions.PADDING_SIZE_DEFAULT),
      decoration: BoxDecoration(
        color: Theme.of(context).cardColor,
        borderRadius: ResponsiveHelper.isMobile(context) ? BorderRadius.vertical(top: Radius.circular(Dimensions.RADIUS_EXTRA_LARGE))
            : BorderRadius.all(Radius.circular(Dimensions.RADIUS_EXTRA_LARGE)),
      ),
      child: GetBuilder<ItemController>(builder: (itemController) {

        double _startingPrice;
        double _endingPrice;
        if (widget.item.choiceOptions!=null && widget.item.choiceOptions.length != 0) {
          List<double> _priceList = [];
          widget.item.variations.forEach((variation) => _priceList.add(variation.price));
          _priceList.sort((a, b) => a.compareTo(b));
          _startingPrice = _priceList[0];
          if (_priceList[0] < _priceList[_priceList.length - 1]) {
            _endingPrice = _priceList[_priceList.length - 1];
          }
        } else {
          _startingPrice = widget.item.price;
        }

        List<String> _variationList = [];
        if(widget.item.choiceOptions!=null){
          for (int index = 0; index < widget.item.choiceOptions.length; index++) {
            _variationList.add(widget.item.choiceOptions[index].options[itemController.variationIndex[index]].replaceAll(' ', ''));
          }
        }

        String variationType = '';
        bool isFirst = true;
        _variationList.forEach((variation) {
          if (isFirst) {
            variationType = '$variationType$variation';
            isFirst = false;
          } else {
            variationType = '$variationType-$variation';
          }
        });

        double price = widget.item.price;
        Variation _variation;
        int _stock = widget.item.stock;
        if(widget.item.variations!=null) {
          for (Variation variation in widget.item.variations) {
            if (variation.type == variationType) {
              price = variation.price;
              _variation = variation;
              _stock = variation.stock;
              break;
            }
          }
        }

        double _discount = (discountRange!=null && discountRange.isNotEmpty)? getUpdatedDiscount(itemController) : (widget.isCampaign || widget.item.storeDiscount == 0) ? widget.item.discount : widget.item.storeDiscount;
        String _discountType = (discountRange!=null && discountRange.isNotEmpty)?'percentage' :(widget.isCampaign || widget.item.storeDiscount == 0) ? widget.item.discountType : 'percentage';
        double discountedPrice = PriceConverter.convertWithDiscount(price, _discount, _discountType);
        double discountedPriceMask = PriceConverter.convertWithDiscountMask(price, _discount, _discountType);
        double priceWithQuantity = discountedPrice * itemController.quantity;
        double addonsCost = 0;
        List<AddOn> _addOnIdList = [];
        List<AddOns> _addOnsList = [];

        //print("testBulkQtyDiscount =  _discount $_discount _discountType $_discountType discountedPrice $discountedPrice");

        if(widget.item.addOns!=null){
          for (int index = 0; index < widget.item.addOns.length; index++) {
            if (itemController.addOnActiveList[index]) {
              addonsCost = addonsCost + (widget.item.addOns[index].price * itemController.addOnQtyList[index]);
              _addOnIdList.add(AddOn(id: widget.item.addOns[index].id, quantity: itemController.addOnQtyList[index]));
              _addOnsList.add(widget.item.addOns[index]);
            }
          }
        }

        double priceWithAddons = priceWithQuantity + (Get.find<SplashController>().configModel.moduleConfig.module.addOn ? addonsCost : 0);
        // bool _isRestAvailable = DateConverter.isAvailable(widget.product.restaurantOpeningTime, widget.product.restaurantClosingTime);
        bool _isAvailable = DateConverter.isAvailable(widget.item.availableTimeStarts, widget.item.availableTimeEnds);

        CartModel _cartModel = CartModel(
          price, discountedPrice,discountedPriceMask,_discount, _variation != null ? [_variation] : [],
          (price - PriceConverter.convertWithDiscount(price, _discount, _discountType)),
          itemController.quantity, _addOnIdList, _addOnsList, widget.isCampaign, _stock, widget.item,
        );

        if(itemController.isBulkQtyRemoveBtnClicked){

          Timer(Duration(seconds: 1), () async {
           Get.find<CartController>().addToCart(_cartModel, widget.cartIndex != null ? widget.cartIndex : itemController.cartIndex,);

           Timer(Duration(seconds: 2), () async {

              Get.find<ItemController>().removeFromCart(widget.item);
            });
          });

        }


        return SingleChildScrollView(
          physics: NeverScrollableScrollPhysics(),
          child: Padding(
            padding: EdgeInsets.only(
              right: Dimensions.PADDING_SIZE_DEFAULT,
              top: ResponsiveHelper.isDesktop(context) ? Dimensions.PADDING_SIZE_DEFAULT : Dimensions.PADDING_SIZE_DEFAULT,
            ),
            child: Column(
                mainAxisAlignment: MainAxisAlignment.center, crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Stack(children: [

                    Column(children: [

                      Row(
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        children: [
                          SizedBox(),
                          InkWell(onTap: () => Get.back(), child: Padding(
                            padding:  EdgeInsets.only(right:_desktop? Dimensions.PADDING_SIZE_LARGE : Dimensions.PADDING_SIZE_EXTRA_SMALL),
                            child: Icon(Icons.close),
                          )),
                        ],
                      ),

                      // Text( 'Select More quantity to get More discount',
                      //   style: robotoRegular.copyWith(fontSize:
                      //   _desktop? Dimensions.fontSizeExtraLarge :Dimensions.fontSizeSmall,color:
                      //   Colors.black),),
                      //
                       SizedBox(height: 20,),

                      Row(mainAxisAlignment: MainAxisAlignment.start, children: [

                        InkWell(
                          onTap: widget.isCampaign ? null : () {
                            if(!widget.isCampaign) {
                              Get.toNamed(RouteHelper.getItemImagesRoute(widget.item));
                            }
                          },
                          child: Stack(children: [
                            ClipRRect(
                              borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
                              child: CustomImage(
                                image: '${widget.isCampaign ? Get.find<SplashController>().configModel.baseUrls.campaignImageUrl
                                    : Get.find<SplashController>().configModel.baseUrls.commonImageUrl}/${widget.item.image}',
                                width: _isMobile ? 130 : _desktop ? 210 :  140,
                                height: _isMobile ? 130 : _desktop ? 230 : 140,
                                fit: BoxFit.cover,
                              ),
                            ),
                            DiscountTag(discount: _discount, discountType: _discountType, fromTop: 20),
                          ]),
                        ),
                        SizedBox(width: 10),


                      ]),
                    ],),


                   itemController.isBulkQtyRemoveBtnClicked ? Positioned(
                     right: 0,
                     bottom: 0,
                     child: Container(
                       padding: EdgeInsets.only(bottom: 2.0,top: 2.0),
                       height:150,width: 210, color: Theme.of(context).dividerColor,

                       child: Center(child: Column(
                         children: [
                           SizedBox(height: 20,),
                           Text('Removing...',
                             style: robotoRegular.copyWith(fontSize:
                             Dimensions.fontSizeSmall,color:
                             Colors.black),),
                           SizedBox(height: 20,),
                           CircularProgressIndicator(),
                         ],
                       )),
                     ),
                   ):

                   Positioned(
                      right: 0,
                      bottom: 0,
                      child: Container(
                        padding: EdgeInsets.only(bottom: 2.0,top: 2.0),
                        height:_desktop? 200 : 150,width: _desktop? 350 : 220, color: Theme.of(context).primaryColorLight.withOpacity(0.5),

                        child: ListView.builder(
                          controller: scrollController,
                          scrollDirection: Axis.vertical,
                          itemCount: discountRange.length,
                          physics: ScrollPhysics(),
                          itemBuilder: (context, index) {
                            return Padding(
                              padding: const EdgeInsets.all(1.0),
                              child: Container(

                               // color:(itemController.quantity>0 && itemController.quantity==discountRange[index].qty)?Colors.blueGrey: Colors.black12,
                               //  color:( widget.fromCartPage ? (itemController.quantity==discountRange[index].qty) || (itemController.isBulkQtyAddBtnClicked && itemController.quantity>0 && itemController.quantity==discountRange[index].qty)
                               //      :(widget.cart != null || itemController.cartIndex != -1 && itemController.quantity==discountRange[index].qty) || (itemController.isBulkQtyAddBtnClicked && itemController.quantity>0 && itemController.quantity==discountRange[index].qty)
                               //  )
                                  color : isCurrentQtySelected(itemController,discountRange[index])
                                    ?  Theme.of(context).primaryColor : isCurrentQtyAvailable(discountRange[index]) ? index==0 ? Colors.transparent:  Colors.grey[100]  : Colors.grey[100],

                                padding: EdgeInsets.all((itemController.quantity<1 && index==0)? 0 :8.0),
                                child: (itemController.quantity<0 && index==0) ? SizedBox()

                                    :index==0 ? InkWell(
                                  onTap:(Get.find<SplashController>().configModel.moduleConfig.module.stock && _stock <= 0) ? null : (){
                                    showRemoveItemFromCartSnackBar(context);
                                    //remove all bulk selected qty by user
                                    itemController.setQuantityBySonuTyagi(false, _stock,newSelectedQuantity: 0);

                                    // Get.find<CartController>().addToCart(
                                    //   _cartModel, widget.cartIndex != null ? widget.cartIndex : itemController.cartIndex,
                                    // );

                                  },child: Text((widget.cart != null || itemController.cartIndex != -1)?
                                'Remove (${itemController.quantity.toString()}) Qty'
                                    :'Select Qty',
                                  style: robotoRegular.copyWith(fontSize:
                                  _desktop? Dimensions.fontSizeLarge: Dimensions.fontSizeSmall,color: Colors.black),),)

                                    : InkWell(onTap: (Get.find<SplashController>().configModel.moduleConfig.module.stock && _stock <= 0) ? null : (){
                                  //add bulk qty selected by user
                                  //itemController.setQuantity(false, _stock,newSelectedQuantity: discountRange[index].qty);

                                  if(isCurrentQtyAvailable(discountRange[index])){
                                    itemController.setQuantityBySonuTyagi(true, _stock,newSelectedQuantity: discountRange[index].qty);

                                  }
                                  // _key.currentState.shake();

                                },child: Row(
                                  children: [
                                    Text( '${discountRange[index].qty}',
                                      style: robotoRegular.copyWith(fontSize:
                                      _desktop? Dimensions.fontSizeLarge: Dimensions.fontSizeSmall,color:
                                      isCurrentQtySelected(itemController,discountRange[index]) ? Colors.white : isCurrentQtyAvailable(discountRange[index]) ? Colors.black : Colors.black38),),

                                    Text( ' - ${discountRange[index].discount} % extra',
                                      style: robotoRegular.copyWith(fontSize:
                                      Dimensions.fontSizeSmall,color:
                                      isCurrentQtySelected(itemController,discountRange[index]) ? Colors.white : isCurrentQtyAvailable(discountRange[index]) ? Colors.black : Colors.black38),),

                                    isCurrentQtyAvailable(discountRange[index]) ? SizedBox() : Text( '    Sold out',
                                      style: robotoRegular.copyWith(fontSize:
                                      Dimensions.fontSizeSmall,color:
                                      Colors.red),)
                                  ],
                                )),
                              ),
                            );
                          },
                        ),
                      ),
                    ),
                  ],),


               SizedBox(height: discountRange.length==1 ? _desktop ? 20 : 10 : 0,),
              discountRange.length==1 ? Container(
                width: context.width,
                decoration: BoxDecoration(
                  color: Colors.blueGrey[200],
                  // backgroundBlendMode: BlendMode.darken,
                  borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),),
                child: Padding(
                  padding: const EdgeInsets.symmetric(vertical: 10,horizontal: 7),
                  child:  Center(child: Text('out_of_stock'.tr, style: robotoRegular.copyWith(fontSize: _desktop ? Dimensions.fontSizeLarge : Dimensions.fontSizeSmall, color: Colors.blueGrey))),
                ),
              )
                  : Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [

                  Container(
                    decoration: BoxDecoration(
                      color: Colors.purple[50],
                      // backgroundBlendMode: BlendMode.darken,
                      borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),),
                    child: Padding(
                      padding: const EdgeInsets.symmetric(vertical: 4,horizontal: 7),
                      child: Row(children: [

                        Text("${'Price/pc'}:  ${PriceConverter.convertPrice(discountedPrice)}",
                            style: robotoRegular.copyWith(fontSize:
                            _desktop ? Dimensions.fontSizeLarge : Dimensions.fontSizeSmall, color: Colors.purple)),

                        // Container(
                        //   padding: EdgeInsets.only(left: 6,right: 6),
                        //   decoration: BoxDecoration(
                        //       color: Colors.purple[50],
                        //
                        //   ),
                        //   child: SizedBox(
                        //     height: 24,
                        //     child: DropdownButtonHideUnderline(child: DropdownButton<String>(
                        //       iconEnabledColor: Colors.purple,
                        //       borderRadius: BorderRadius.all(Radius.zero),
                        //       value: bestPriceDropdownValue,
                        //       items: list.map<DropdownMenuItem<String>>((String value) {
                        //         return DropdownMenuItem<String>(value: value,
                        //           child: Text('${Get.find<SplashController>().configModel.currencySymbol} $value ${"/pc"}', style: robotoMedium.copyWith(fontSize:
                        //           Dimensions.fontSizeLarge,color:
                        //           Colors.purple),),
                        //         );
                        //       }).toList(),
                        //
                        //
                        //       onChanged: (String newValue) {
                        //
                        //
                        //         setState(() {bestPriceDropdownValue = newValue;});
                        //       },
                        //     )),
                        //   ),
                        // ),


                      ],),
                    ),
                  ),
                  SizedBox(width: Dimensions.PADDING_SIZE_EXTRA_SMALL,),

                  InkWell(onTap: (){

                    itemController.setQtyListVisibility(true);



                  },child
                      : Container(
                    decoration: BoxDecoration(
                      color: ((widget.cart != null || itemController.cartIndex != -1) || (itemController.isBulkQtyAddBtnClicked && itemController.quantity>0))? Colors.purple: Colors.grey,
                      // backgroundBlendMode: BlendMode.darken,
                      borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),),
                    child: Padding(
                      padding:  EdgeInsets.symmetric(vertical: 4,horizontal: 7),
                      child: Container(
                        padding: EdgeInsets.only(left: 6,right: 6),
                        decoration: BoxDecoration(
                          color: ((widget.cart != null || itemController.cartIndex != -1) || (itemController.isBulkQtyAddBtnClicked && itemController.quantity>0))? Colors.purple : Colors.grey,

                        ),
                        child: Text(((widget.cart != null || itemController.cartIndex != -1) || (itemController.isBulkQtyAddBtnClicked && itemController.quantity>0)) ?'${itemController.quantity.toString()} Selected' :
                        '0 Selected', style: robotoRegular.copyWith(fontSize:
                        _desktop ? Dimensions.fontSizeLarge : Dimensions.fontSizeSmall,color: Colors.white,),),

                      ),
                    ),
                  )),
                ],
              ),

              SizedBox(height: Dimensions.PADDING_SIZE_LARGE),

              (widget.item.description != null && widget.item.description.isNotEmpty) ? Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Text('description'.tr, style: robotoMedium),
                  SizedBox(height: Dimensions.PADDING_SIZE_EXTRA_SMALL),
                  Text(widget.item.description, style: robotoRegular),
                  SizedBox(height: Dimensions.PADDING_SIZE_LARGE),
                ],
              ) : SizedBox(),

              // Variation
              // ListView.builder(
              //   shrinkWrap: true,
              //   itemCount: widget.item.choiceOptions.length,
              //   physics: NeverScrollableScrollPhysics(),
              //   padding: EdgeInsets.zero,
              //   itemBuilder: (context, index) {
              //     return Column(crossAxisAlignment: CrossAxisAlignment.start, children: [
              //       Text(widget.item.choiceOptions[index].title, style: robotoMedium),
              //       SizedBox(height: Dimensions.PADDING_SIZE_EXTRA_SMALL),
              //       GridView.builder(
              //         gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
              //           crossAxisCount: ResponsiveHelper.isMobile(context) ? 3 : 4,
              //           crossAxisSpacing: 20,
              //           mainAxisSpacing: 10,
              //           childAspectRatio: (1 / 0.25),
              //         ),
              //         shrinkWrap: true,
              //         physics: NeverScrollableScrollPhysics(),
              //         padding: EdgeInsets.zero,
              //         itemCount: widget.item.choiceOptions[index].options.length,
              //         itemBuilder: (context, i) {
              //           return InkWell(
              //             onTap: () {
              //               itemController.setCartVariationIndex(index, i, widget.item);
              //             },
              //             child: Container(
              //               alignment: Alignment.center,
              //               padding: EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_EXTRA_SMALL),
              //               decoration: BoxDecoration(
              //                 color:
              //                 itemController.variationIndex[index] != i ? Theme.of(context).backgroundColor : Theme.of(context).primaryColor,
              //                 borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
              //                 border:
              //                 itemController.variationIndex[index] != i ? Border.all(color: Theme.of(context).disabledColor, width: 2) : null,
              //               ),
              //               child: Text(
              //                 widget.item.choiceOptions[index].options[i].trim(),
              //                 maxLines: 1,
              //                 overflow: TextOverflow.ellipsis,
              //                 style: robotoRegular.copyWith(
              //                   color: itemController.variationIndex[index] != i ? Colors.black : Colors.white,
              //                 ),
              //               ),
              //             ),
              //           );
              //         },
              //       ),
              //       SizedBox(height: index != widget.item.choiceOptions.length - 1 ? Dimensions.PADDING_SIZE_LARGE : 0),
              //     ]);
              //   },
              // ),
              //SizedBox(height: widget.item.choiceOptions.length > 0 ? Dimensions.PADDING_SIZE_LARGE : 0),

              // Quantity
              // Row(children: [
              //   Text('quantity'.tr, style: robotoMedium),
              //   Expanded(child: SizedBox()),
              //   Row(children: [
              //     QuantityButton(
              //       onTap: () {
              //         addQty(itemController,_stock,_cartModel);
              //       },
              //       isIncrement: false,
              //     ),
              //     Text(itemController.quantity.toString(), style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeLarge)),
              //     QuantityButton(
              //       onTap: () => itemController.setQuantity(true, _stock),
              //       isIncrement: true,
              //     ),
              //   ]),
              // ]),
              SizedBox(height: Dimensions.PADDING_SIZE_LARGE),

              // Addons
              // (Get.find<SplashController>().configModel.moduleConfig.module.addOn && widget.item.addOns.length > 0) ?
              // Column(
              //   crossAxisAlignment: CrossAxisAlignment.start,
              //   children: [
              //     Text('addons'.tr, style: robotoMedium),
              //     SizedBox(height: Dimensions.PADDING_SIZE_EXTRA_SMALL),
              //     GridView.builder(
              //       gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
              //         crossAxisCount: 4,
              //         crossAxisSpacing: 20, mainAxisSpacing: 10, childAspectRatio: (1 / 1.1),
              //       ),
              //       shrinkWrap: true,
              //       physics: NeverScrollableScrollPhysics(),
              //       itemCount: widget.item.addOns.length,
              //       padding: EdgeInsets.zero,
              //       itemBuilder: (context, index) {
              //         return InkWell(
              //           onTap: () {
              //             if (!itemController.addOnActiveList[index]) {
              //               itemController.addAddOn(true, index);
              //             } else if (itemController.addOnQtyList[index] == 1) {
              //               itemController.addAddOn(false, index);
              //             }
              //           },
              //           child: Container(
              //             alignment: Alignment.center,
              //             margin: EdgeInsets.only(bottom: itemController.addOnActiveList[index] ? 2 : 20),
              //             decoration: BoxDecoration(
              //               color: itemController.addOnActiveList[index] ? Theme.of(context).primaryColor : Theme.of(context).backgroundColor,
              //               borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
              //               border: itemController.addOnActiveList[index] ? null : Border.all(color: Theme.of(context).disabledColor, width: 2),
              //               boxShadow: itemController.addOnActiveList[index]
              //                   ? [BoxShadow(color: Colors.grey[Get.isDarkMode ? 700 : 300], blurRadius: 5, spreadRadius: 1)] : null,
              //             ),
              //             child: Column(children: [
              //               Expanded(
              //                 child: Column(mainAxisAlignment: MainAxisAlignment.center, children: [
              //                   Text(widget.item.addOns[index].name,
              //                     maxLines: 2, overflow: TextOverflow.ellipsis, textAlign: TextAlign.center,
              //                     style: robotoMedium.copyWith(
              //                       color: itemController.addOnActiveList[index] ? Colors.white : Colors.black,
              //                       fontSize: Dimensions.fontSizeSmall,
              //                     ),
              //                   ),
              //                   SizedBox(height: 5),
              //                   Text(
              //                     widget.item.addOns[index].price > 0 ? PriceConverter.convertPrice(widget.item.addOns[index].price) : 'free'.tr,
              //                     maxLines: 1, overflow: TextOverflow.ellipsis,
              //                     style: robotoRegular.copyWith(
              //                       color: itemController.addOnActiveList[index] ? Colors.white : Colors.black,
              //                       fontSize: Dimensions.fontSizeExtraSmall,
              //                     ),
              //                   ),
              //                 ]),
              //               ),
              //               itemController.addOnActiveList[index] ? Container(
              //                 height: 25,
              //                 decoration: BoxDecoration(borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL), color: Theme.of(context).cardColor),
              //                 child: Row(mainAxisAlignment: MainAxisAlignment.center, children: [
              //                   Expanded(
              //                     child: InkWell(
              //                       onTap: () {
              //                         if (itemController.addOnQtyList[index] > 1) {
              //                           itemController.setAddOnQuantity(false, index);
              //                         } else {
              //                           itemController.addAddOn(false, index);
              //                         }
              //                       },
              //                       child: Center(child: Icon(Icons.remove, size: 15)),
              //                     ),
              //                   ),
              //                   Text(
              //                     itemController.addOnQtyList[index].toString(),
              //                     style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeSmall),
              //                   ),
              //                   Expanded(
              //                     child: InkWell(
              //                       onTap: () => itemController.setAddOnQuantity(true, index),
              //                       child: Center(child: Icon(Icons.add, size: 15)),
              //                     ),
              //                   ),
              //                 ]),
              //               )
              //                   : SizedBox(),
              //             ]),
              //           ),
              //         );
              //       },
              //     ),
              //     SizedBox(height: Dimensions.PADDING_SIZE_EXTRA_SMALL),
              //   ],
              // ) : SizedBox(),

              Row(children: [
                Text('${'total_amount'.tr}:', style : robotoRegular.copyWith(fontSize: _desktop ? Dimensions.fontSizeLarge : Dimensions.fontSizeSmall)),
                SizedBox(width: Dimensions.PADDING_SIZE_EXTRA_SMALL),
              //  Text(PriceConverter.convertPrice(priceWithAddons), style: robotoBold.copyWith(color: Theme.of(context).primaryColor)),
                Text(((widget.cart != null || itemController.cartIndex != -1) || (itemController.isBulkQtyAddBtnClicked && itemController.quantity>0)) ?PriceConverter.convertPrice(priceWithAddons) :
        '0.0', style: robotoRegular.copyWith(fontSize: _desktop ? Dimensions.fontSizeLarge : Dimensions.fontSizeSmall,color: Theme.of(context).primaryColor)),
              ]),
              SizedBox(height: Dimensions.PADDING_SIZE_LARGE),

              //Add to cart Button

              _isAvailable ? SizedBox() : Container(
                alignment: Alignment.center,
                padding: EdgeInsets.all(Dimensions.PADDING_SIZE_SMALL),
                margin: EdgeInsets.only(bottom: Dimensions.PADDING_SIZE_SMALL),
                decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
                  color: Theme.of(context).primaryColor.withOpacity(0.1),
                ),
                child: Column(children: [
                  Text('not_available_now'.tr, style: robotoMedium.copyWith(
                    color: Theme.of(context).primaryColor, fontSize: Dimensions.fontSizeLarge,
                  )),
                  Text(
                    '${'available_will_be'.tr} ${DateConverter.convertTimeToTime(widget.item.availableTimeStarts)} '
                        '- ${DateConverter.convertTimeToTime(widget.item.availableTimeEnds)}',
                    style: robotoRegular,
                  ),
                ]),
              ),

              (( widget.item.scheduleOrder!=null&& !widget.item.scheduleOrder) && !_isAvailable) ? SizedBox() :
              Row(children: [

                // ElevatedButton(
                //   style: ElevatedButton.styleFrom(
                //     minimumSize: Size(50, 50), backgroundColor: Theme.of(context).cardColor, shape: RoundedRectangleBorder(
                //     borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL), side: BorderSide(width: 2, color: Theme.of(context).primaryColor),
                //   ),
                //   ),
                //   onPressed: () {
                //     if(widget.inStorePage) {
                //       Get.back();
                //     }else {
                //       Get.offNamed(RouteHelper.getStoreRoute(widget.item.storeId, 'item'));
                //     }
                //   },
                //   child: Image.asset(Images.house, color: Theme.of(context).primaryColor, height: 30, width: 30),
                // ),

                SizedBox(width: Dimensions.PADDING_SIZE_SMALL),

                Expanded(child: CustomButton(
                  width: ResponsiveHelper.isDesktop(context) ? MediaQuery.of(context).size.width / 2.0 : null,
                  /*buttonText: isCampaign ? 'order_now'.tr : isExistInCart ? 'already_added_in_cart'.tr : fromCart
                        ? 'update_in_cart'.tr : 'add_to_cart'.tr,*/
                  buttonText: (Get.find<SplashController>().configModel.moduleConfig.module.stock && _stock <= 0)
                      ? 'out_of_stock'.tr : widget.isCampaign ? 'order_now'.tr
                      : (widget.cart != null || itemController.cartIndex != -1) ? 'update_in_cart'.tr : 'add_to_cart'.tr,
                  onPressed:  () {

                    if(widget.isCampaign) {
                      Get.toNamed(RouteHelper.getCheckoutRoute('campaign'), arguments: CheckoutScreen(
                        fromCart: false, cartList: [_cartModel],
                      ));
                    } else {
                      if (Get.find<CartController>().existAnotherStoreItem(_cartModel.item.storeId)) {
                        Get.dialog(ConfirmationDialog(
                          icon: Images.warning,
                          title: 'are_you_sure_to_reset'.tr,
                          description: Get.find<SplashController>().configModel.moduleConfig.module.showRestaurantText
                              ? 'if_you_continue'.tr : 'if_you_continue_without_another_store'.tr,
                          onYesPressed: () {
                            Get.back();
                            Get.find<CartController>().removeAllAndAddToCart(_cartModel);
                            showCartSnackBar(context);
                          },
                        ), barrierDismissible: false);
                      } else {

                        if((Get.find<SplashController>().configModel.moduleConfig.module.stock && _stock <= 0)){

                        }else{
                          Get.find<CartController>().addToCart(
                            _cartModel, widget.cartIndex != null ? widget.cartIndex : itemController.cartIndex,
                          );
                          showCartSnackBar(context);
                        }


                      }
                    }

                    Get.back();
                  },

                )),
              ]),
            ]),
          ),
        );
      }),
    );
  }


}

//  return SingleChildScrollView(
//
//           physics: NeverScrollableScrollPhysics(),
//           child: Padding(
//             padding: EdgeInsets.only(
//               right: Dimensions.PADDING_SIZE_DEFAULT, top: ResponsiveHelper.isDesktop(context) ? 0 : Dimensions.PADDING_SIZE_DEFAULT,
//             ),
//             child: Column(
//                 mainAxisAlignment: MainAxisAlignment.center, crossAxisAlignment: CrossAxisAlignment.start, children: [
//
//                   Stack(children: [
//                     Column(children: [
//                       SizedBox(height: 10,),
//                       Row(
//                         mainAxisAlignment: MainAxisAlignment.spaceBetween,
//                         children: [
//                           SizedBox(),
//                           InkWell(onTap: () => Get.back(), child: Padding(
//                             padding:  EdgeInsets.only(right: Dimensions.PADDING_SIZE_EXTRA_SMALL),
//                             child: Icon(Icons.close),
//                           )),
//                         ],
//                       ),
//                       SizedBox(height: 20,),
//
//                       SizedBox(height: 20,),
//                       Row(mainAxisAlignment: MainAxisAlignment.center, children: [
//
//                         InkWell(
//                           onTap: widget.isCampaign ? null : () {
//                             if(!widget.isCampaign) {
//                               Get.toNamed(RouteHelper.getItemImagesRoute(widget.item));
//                             }
//                           },
//                           child: Stack(children: [
//                             ClipRRect(
//                               borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
//                               child: CustomImage(
//                                 image: '${widget.isCampaign ? Get.find<SplashController>().configModel.baseUrls.campaignImageUrl
//                                     : Get.find<SplashController>().configModel.baseUrls.commonImageUrl}/${widget.item.image}',
//                                 width: ResponsiveHelper.isMobile(context) ? 100 : 140,
//                                 height: ResponsiveHelper.isMobile(context) ? 100 : 140,
//                                 fit: BoxFit.cover,
//                               ),
//                             ),
//                             DiscountTag(discount: _discount, discountType: _discountType, fromTop: 20),
//                           ]),
//                         ),
//                         SizedBox(width: 10),
//
//                         Expanded(
//                           child: Column(crossAxisAlignment: CrossAxisAlignment.start, children: [
//                             Text(
//                               widget.item.name??'', style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeLarge),
//                               maxLines: 2, overflow: TextOverflow.ellipsis,
//                             ),
//                             InkWell(
//                               onTap: () {
//                                 // if(widget.inStorePage) {
//                                 //   Get.back();
//                                 // }else {
//                                 //   Get.offNamed(RouteHelper.getStoreRoute(widget.item.storeId, 'item'));
//                                 // }
//                               },
//                               child: Padding(
//                                 padding: EdgeInsets.fromLTRB(0, 5, 5, 5),
//                                 child: Text(
//                                   widget.item.storeName??'',
//                                   style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall, color: Theme.of(context).primaryColor),
//                                 ),
//                               ),
//                             ),
//                             RatingBar(rating: widget.item.avgRating??0.0, size: 15, ratingCount: widget.item.ratingCount),
//                             Text(
//                               '${PriceConverter.convertPrice(_startingPrice, discount: _discount, discountType: _discountType)}'
//                                   '${_endingPrice != null ? ' - ${PriceConverter.convertPrice(_endingPrice, discount: _discount,
//                                   discountType: _discountType)}' : ''}',
//                               style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeLarge),
//                             ),
//                             price > priceWithDiscount ? Text(
//                               '${PriceConverter.convertPrice(_startingPrice)}'
//                                   '${_endingPrice != null ? ' - ${PriceConverter.convertPrice(_endingPrice)}' : ''}',
//                               style: robotoMedium.copyWith(color: Theme.of(context).disabledColor, decoration: TextDecoration.lineThrough),
//                             ) : SizedBox(),
//                           ]),
//                         ),
//
//                         // Column(mainAxisAlignment: MainAxisAlignment.spaceBetween, children: [
//                         //   ((Get.find<SplashController>().configModel.moduleConfig.module.unit && widget.item.unitType != null)
//                         //   || (Get.find<SplashController>().configModel.moduleConfig.module.vegNonVeg && Get.find<SplashController>().configModel.toggleVegNonVeg)) ? Container(
//                         //     padding: EdgeInsets.symmetric(vertical: Dimensions.PADDING_SIZE_EXTRA_SMALL, horizontal: Dimensions.PADDING_SIZE_SMALL),
//                         //     decoration: BoxDecoration(
//                         //       borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
//                         //       color: Theme.of(context).primaryColor,
//                         //     ),
//                         //     child: Text(
//                         //       Get.find<SplashController>().configModel.moduleConfig.module.unit ? widget.item.unitType ?? ''
//                         //           : widget.item.veg == 0 ? 'non_veg'.tr : 'veg'.tr,
//                         //       style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeExtraSmall, color: Colors.white),
//                         //     ),
//                         //   ) : SizedBox(),
//                         //   SizedBox(height: Get.find<SplashController>().configModel.toggleVegNonVeg ? 50 : 0),
//                         //   widget.isCampaign ? SizedBox(height: 25) : GetBuilder<WishListController>(builder: (wishList) {
//                         //     return InkWell(
//                         //       onTap: () {
//                         //         if(Get.find<AuthController>().isLoggedIn()) {
//                         //           wishList.wishItemIdList.contains(widget.item.id) ? wishList.removeFromWishList(widget.item.id, false)
//                         //               : wishList.addToWishList(widget.item, null, false);
//                         //         }else {
//                         //           showCustomSnackBar('you_are_not_logged_in'.tr);
//                         //         }
//                         //       },
//                         //       child: Icon(
//                         //         wishList.wishItemIdList.contains(widget.item.id) ? Icons.favorite : Icons.favorite_border,
//                         //         color: wishList.wishItemIdList.contains(widget.item.id) ? Theme.of(context).primaryColor
//                         //             : Theme.of(context).disabledColor,
//                         //       ),
//                         //     );
//                         //   }),
//                         // ]),
//
//                       ]),
//                     ],),
//
//
//                     Positioned(
//
//                       right: 0,
//                       bottom: 0,
//                       child: Container(
//                         padding: EdgeInsets.only(bottom: 2.0,top: 2.0),
//                         height:150,width: 220, color: Theme.of(context).dividerColor,
//
//                         child: ListView.builder(
//                           controller: scrollController,
//                           scrollDirection: Axis.vertical,
//                           itemCount: discountRange.length,
//                           physics: ScrollPhysics(),
//                           itemBuilder: (context, index) {
//                             return Padding(
//                               padding: const EdgeInsets.all(1.0),
//                               child: Container(
//                                 color: Colors.black12,
//                                 padding: EdgeInsets.all((itemController.quantity<1 && index==0)? 0 :8.0),
//                                 child: (itemController.quantity<0 && index==0)? SizedBox()
//
//                                     :index==0? InkWell(
//                                   onTap:(Get.find<SplashController>().configModel.moduleConfig.module.stock && _stock <= 0) ? null : (){
//                                     //remove all bulk selected qty by user
//                                     //itemController.setQuantityBySonuTyagi(-1);
//                                     if(itemController.quantity>1){
//                                       itemController.setQuantityBySonuTyagi(false, _stock);
//
//                                     }
//
//                                   },child: Text((widget.cart != null || itemController.cartIndex != -1)? 'Remove (${itemController.quantity.toString()}) Qty':'Select Qty', style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall,color: Colors.black),),)
//
//
//                                     : InkWell(onTap: (Get.find<SplashController>().configModel.moduleConfig.module.stock && _stock <= 0) ? null : (){
//                                   //add bulk qty selected by user
//                                   //itemController.setQuantity(false, _stock,newSelectedQuantity: discountRange[index].qty);
//
//                                   itemController.setQuantityBySonuTyagi(true, _stock,newSelectedQuantity: discountRange[index].qty);
//
//
//                                 },child: Row(
//                                   children: [
//                                     Text( '${discountRange[index].qty}',
//                                       style: robotoRegular.copyWith(fontSize:
//                                       Dimensions.fontSizeSmall,color:
//                                       Colors.black),),
//
//                                     Text( ' - ${discountRange[index].discount} % extra',
//                                       style: robotoRegular.copyWith(fontSize:
//                                       Dimensions.fontSizeSmall,color:
//                                       Colors.grey),)
//                                   ],
//                                 )),
//                               ),
//                             );
//                           },
//                         ),
//                       ),
//                     ),
//                   ],),
//
//
//
//               discountRange.length==1?Container(
//                 width: context.width,
//                 decoration: BoxDecoration(
//                   color: Colors.blueGrey[200],
//                   // backgroundBlendMode: BlendMode.darken,
//                   borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),),
//                 child: Padding(
//                   padding: const EdgeInsets.symmetric(vertical: 10,horizontal: 7),
//                   child:  Center(child: Text('out_of_stock'.tr, style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall, color: Colors.blueGrey))),
//                 ),
//               )
//                   : Row(
//                 mainAxisAlignment: MainAxisAlignment.spaceBetween,
//                 children: [
//
//                   Container(
//                     decoration: BoxDecoration(
//                       color: Colors.purple[50],
//                       // backgroundBlendMode: BlendMode.darken,
//                       borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),),
//                     child: Padding(
//                       padding: const EdgeInsets.symmetric(vertical: 4,horizontal: 7),
//                       child: Row(children: [
//
//                         Text("${'best_price'.tr}: ${PriceConverter.convertPrice(
//                           getStartingPrice(widget.item), discount: getDiscount(widget.item),
//                           discountType: getDiscountType(widget.item),
//                         )}", style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall, color: Colors.purple)),
//
//                         // Container(
//                         //   padding: EdgeInsets.only(left: 6,right: 6),
//                         //   decoration: BoxDecoration(
//                         //       color: Colors.purple[50],
//                         //
//                         //   ),
//                         //   child: SizedBox(
//                         //     height: 24,
//                         //     child: DropdownButtonHideUnderline(child: DropdownButton<String>(
//                         //       iconEnabledColor: Colors.purple,
//                         //       borderRadius: BorderRadius.all(Radius.zero),
//                         //       value: bestPriceDropdownValue,
//                         //       items: list.map<DropdownMenuItem<String>>((String value) {
//                         //         return DropdownMenuItem<String>(value: value,
//                         //           child: Text('${Get.find<SplashController>().configModel.currencySymbol} $value ${"/pc"}', style: robotoMedium.copyWith(fontSize:
//                         //           Dimensions.fontSizeLarge,color:
//                         //           Colors.purple),),
//                         //         );
//                         //       }).toList(),
//                         //
//                         //
//                         //       onChanged: (String newValue) {
//                         //
//                         //
//                         //         setState(() {bestPriceDropdownValue = newValue;});
//                         //       },
//                         //     )),
//                         //   ),
//                         // ),
//
//
//                       ],),
//                     ),
//                   ),
//                   SizedBox(width: Dimensions.PADDING_SIZE_EXTRA_SMALL,),
//
//                   InkWell(onTap: (){
//
//                     itemController.setQtyListVisibility(true);
//
//                     //_key.currentState.shake();
//                     // showCartSnackBar(context);
//
//                   },child
//                       : Container(
//                     decoration: BoxDecoration(
//                       color: Colors.purple,
//                       // backgroundBlendMode: BlendMode.darken,
//                       borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),),
//                     child: Padding(
//                       padding:  EdgeInsets.symmetric(vertical: 4,horizontal: 7),
//                       child: Container(
//                         padding: EdgeInsets.only(left: 6,right: 6),
//                         decoration: BoxDecoration(
//                           color: Colors.purple,
//
//                         ),
//                         child: Text((widget.cart != null || itemController.cartIndex != -1) ?'${itemController.quantity.toString()} Added' :
//                         'Select Qty', style: robotoRegular.copyWith(fontSize:
//                         Dimensions.fontSizeSmall,color: Colors.white,),),
//
//
//
//                       ),
//                     ),
//                   )),
//
//
//                 ],
//               ),
//
//               SizedBox(height: Dimensions.PADDING_SIZE_LARGE),
//
//               (widget.item.description != null && widget.item.description.isNotEmpty) ? Column(
//                 crossAxisAlignment: CrossAxisAlignment.start,
//                 children: [
//                   Text('description'.tr, style: robotoMedium),
//                   SizedBox(height: Dimensions.PADDING_SIZE_EXTRA_SMALL),
//                   Text(widget.item.description, style: robotoRegular),
//                   SizedBox(height: Dimensions.PADDING_SIZE_LARGE),
//                 ],
//               ) : SizedBox(),
//
//               // Variation
//               // ListView.builder(
//               //   shrinkWrap: true,
//               //   itemCount: widget.item.choiceOptions.length,
//               //   physics: NeverScrollableScrollPhysics(),
//               //   padding: EdgeInsets.zero,
//               //   itemBuilder: (context, index) {
//               //     return Column(crossAxisAlignment: CrossAxisAlignment.start, children: [
//               //       Text(widget.item.choiceOptions[index].title, style: robotoMedium),
//               //       SizedBox(height: Dimensions.PADDING_SIZE_EXTRA_SMALL),
//               //       GridView.builder(
//               //         gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
//               //           crossAxisCount: ResponsiveHelper.isMobile(context) ? 3 : 4,
//               //           crossAxisSpacing: 20,
//               //           mainAxisSpacing: 10,
//               //           childAspectRatio: (1 / 0.25),
//               //         ),
//               //         shrinkWrap: true,
//               //         physics: NeverScrollableScrollPhysics(),
//               //         padding: EdgeInsets.zero,
//               //         itemCount: widget.item.choiceOptions[index].options.length,
//               //         itemBuilder: (context, i) {
//               //           return InkWell(
//               //             onTap: () {
//               //               itemController.setCartVariationIndex(index, i, widget.item);
//               //             },
//               //             child: Container(
//               //               alignment: Alignment.center,
//               //               padding: EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_EXTRA_SMALL),
//               //               decoration: BoxDecoration(
//               //                 color:
//               //                 itemController.variationIndex[index] != i ? Theme.of(context).backgroundColor : Theme.of(context).primaryColor,
//               //                 borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
//               //                 border:
//               //                 itemController.variationIndex[index] != i ? Border.all(color: Theme.of(context).disabledColor, width: 2) : null,
//               //               ),
//               //               child: Text(
//               //                 widget.item.choiceOptions[index].options[i].trim(),
//               //                 maxLines: 1,
//               //                 overflow: TextOverflow.ellipsis,
//               //                 style: robotoRegular.copyWith(
//               //                   color: itemController.variationIndex[index] != i ? Colors.black : Colors.white,
//               //                 ),
//               //               ),
//               //             ),
//               //           );
//               //         },
//               //       ),
//               //       SizedBox(height: index != widget.item.choiceOptions.length - 1 ? Dimensions.PADDING_SIZE_LARGE : 0),
//               //     ]);
//               //   },
//               // ),
//               //SizedBox(height: widget.item.choiceOptions.length > 0 ? Dimensions.PADDING_SIZE_LARGE : 0),
//
//               // Quantity
//               // Row(children: [
//               //   Text('quantity'.tr, style: robotoMedium),
//               //   Expanded(child: SizedBox()),
//               //   Row(children: [
//               //     QuantityButton(
//               //       onTap: () {
//               //         addQty(itemController,_stock,_cartModel);
//               //       },
//               //       isIncrement: false,
//               //     ),
//               //     Text(itemController.quantity.toString(), style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeLarge)),
//               //     QuantityButton(
//               //       onTap: () => itemController.setQuantity(true, _stock),
//               //       isIncrement: true,
//               //     ),
//               //   ]),
//               // ]),
//               SizedBox(height: Dimensions.PADDING_SIZE_LARGE),
//
//               // Addons
//               // (Get.find<SplashController>().configModel.moduleConfig.module.addOn && widget.item.addOns.length > 0) ?
//               // Column(
//               //   crossAxisAlignment: CrossAxisAlignment.start,
//               //   children: [
//               //     Text('addons'.tr, style: robotoMedium),
//               //     SizedBox(height: Dimensions.PADDING_SIZE_EXTRA_SMALL),
//               //     GridView.builder(
//               //       gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
//               //         crossAxisCount: 4,
//               //         crossAxisSpacing: 20, mainAxisSpacing: 10, childAspectRatio: (1 / 1.1),
//               //       ),
//               //       shrinkWrap: true,
//               //       physics: NeverScrollableScrollPhysics(),
//               //       itemCount: widget.item.addOns.length,
//               //       padding: EdgeInsets.zero,
//               //       itemBuilder: (context, index) {
//               //         return InkWell(
//               //           onTap: () {
//               //             if (!itemController.addOnActiveList[index]) {
//               //               itemController.addAddOn(true, index);
//               //             } else if (itemController.addOnQtyList[index] == 1) {
//               //               itemController.addAddOn(false, index);
//               //             }
//               //           },
//               //           child: Container(
//               //             alignment: Alignment.center,
//               //             margin: EdgeInsets.only(bottom: itemController.addOnActiveList[index] ? 2 : 20),
//               //             decoration: BoxDecoration(
//               //               color: itemController.addOnActiveList[index] ? Theme.of(context).primaryColor : Theme.of(context).backgroundColor,
//               //               borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
//               //               border: itemController.addOnActiveList[index] ? null : Border.all(color: Theme.of(context).disabledColor, width: 2),
//               //               boxShadow: itemController.addOnActiveList[index]
//               //                   ? [BoxShadow(color: Colors.grey[Get.isDarkMode ? 700 : 300], blurRadius: 5, spreadRadius: 1)] : null,
//               //             ),
//               //             child: Column(children: [
//               //               Expanded(
//               //                 child: Column(mainAxisAlignment: MainAxisAlignment.center, children: [
//               //                   Text(widget.item.addOns[index].name,
//               //                     maxLines: 2, overflow: TextOverflow.ellipsis, textAlign: TextAlign.center,
//               //                     style: robotoMedium.copyWith(
//               //                       color: itemController.addOnActiveList[index] ? Colors.white : Colors.black,
//               //                       fontSize: Dimensions.fontSizeSmall,
//               //                     ),
//               //                   ),
//               //                   SizedBox(height: 5),
//               //                   Text(
//               //                     widget.item.addOns[index].price > 0 ? PriceConverter.convertPrice(widget.item.addOns[index].price) : 'free'.tr,
//               //                     maxLines: 1, overflow: TextOverflow.ellipsis,
//               //                     style: robotoRegular.copyWith(
//               //                       color: itemController.addOnActiveList[index] ? Colors.white : Colors.black,
//               //                       fontSize: Dimensions.fontSizeExtraSmall,
//               //                     ),
//               //                   ),
//               //                 ]),
//               //               ),
//               //               itemController.addOnActiveList[index] ? Container(
//               //                 height: 25,
//               //                 decoration: BoxDecoration(borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL), color: Theme.of(context).cardColor),
//               //                 child: Row(mainAxisAlignment: MainAxisAlignment.center, children: [
//               //                   Expanded(
//               //                     child: InkWell(
//               //                       onTap: () {
//               //                         if (itemController.addOnQtyList[index] > 1) {
//               //                           itemController.setAddOnQuantity(false, index);
//               //                         } else {
//               //                           itemController.addAddOn(false, index);
//               //                         }
//               //                       },
//               //                       child: Center(child: Icon(Icons.remove, size: 15)),
//               //                     ),
//               //                   ),
//               //                   Text(
//               //                     itemController.addOnQtyList[index].toString(),
//               //                     style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeSmall),
//               //                   ),
//               //                   Expanded(
//               //                     child: InkWell(
//               //                       onTap: () => itemController.setAddOnQuantity(true, index),
//               //                       child: Center(child: Icon(Icons.add, size: 15)),
//               //                     ),
//               //                   ),
//               //                 ]),
//               //               )
//               //                   : SizedBox(),
//               //             ]),
//               //           ),
//               //         );
//               //       },
//               //     ),
//               //     SizedBox(height: Dimensions.PADDING_SIZE_EXTRA_SMALL),
//               //   ],
//               // ) : SizedBox(),
//
//               Row(children: [
//                 Text('${'total_amount'.tr}:', style: robotoMedium),
//                 SizedBox(width: Dimensions.PADDING_SIZE_EXTRA_SMALL),
//                 Text(PriceConverter.convertPrice(priceWithAddons), style: robotoBold.copyWith(color: Theme.of(context).primaryColor)),
//               ]),
//               SizedBox(height: Dimensions.PADDING_SIZE_LARGE),
//
//               //Add to cart Button
//
//               _isAvailable ? SizedBox() : Container(
//                 alignment: Alignment.center,
//                 padding: EdgeInsets.all(Dimensions.PADDING_SIZE_SMALL),
//                 margin: EdgeInsets.only(bottom: Dimensions.PADDING_SIZE_SMALL),
//                 decoration: BoxDecoration(
//                   borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
//                   color: Theme.of(context).primaryColor.withOpacity(0.1),
//                 ),
//                 child: Column(children: [
//                   Text('not_available_now'.tr, style: robotoMedium.copyWith(
//                     color: Theme.of(context).primaryColor, fontSize: Dimensions.fontSizeLarge,
//                   )),
//                   Text(
//                     '${'available_will_be'.tr} ${DateConverter.convertTimeToTime(widget.item.availableTimeStarts)} '
//                         '- ${DateConverter.convertTimeToTime(widget.item.availableTimeEnds)}',
//                     style: robotoRegular,
//                   ),
//                 ]),
//               ),
//
//               // (( widget.item.scheduleOrder!=null&& !widget.item.scheduleOrder) && !_isAvailable) ? SizedBox() : Row(children: [
//               //   ElevatedButton(
//               //     style: ElevatedButton.styleFrom(
//               //       minimumSize: Size(50, 50), backgroundColor: Theme.of(context).cardColor, shape: RoundedRectangleBorder(
//               //       borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL), side: BorderSide(width: 2, color: Theme.of(context).primaryColor),
//               //     ),
//               //     ),
//               //     onPressed: () {
//               //       if(widget.inStorePage) {
//               //         Get.back();
//               //       }else {
//               //         Get.offNamed(RouteHelper.getStoreRoute(widget.item.storeId, 'item'));
//               //       }
//               //     },
//               //     child: Image.asset(Images.house, color: Theme.of(context).primaryColor, height: 30, width: 30),
//               //   ),
//               //   SizedBox(width: Dimensions.PADDING_SIZE_SMALL),
//               //   Expanded(child: CustomButton(
//               //     width: ResponsiveHelper.isDesktop(context) ? MediaQuery.of(context).size.width / 2.0 : null,
//               //     /*buttonText: isCampaign ? 'order_now'.tr : isExistInCart ? 'already_added_in_cart'.tr : fromCart
//               //           ? 'update_in_cart'.tr : 'add_to_cart'.tr,*/
//               //     buttonText: (Get.find<SplashController>().configModel.moduleConfig.module.stock && _stock <= 0)
//               //         ? 'out_of_stock'.tr : widget.isCampaign ? 'order_now'.tr
//               //         : (widget.cart != null || itemController.cartIndex != -1) ? 'update_in_cart'.tr : 'add_to_cart'.tr,
//               //     onPressed: (Get.find<SplashController>().configModel.moduleConfig.module.stock && _stock <= 0) ? null : () {
//               //       Get.back();
//               //       if(widget.isCampaign) {
//               //         Get.toNamed(RouteHelper.getCheckoutRoute('campaign'), arguments: CheckoutScreen(
//               //           fromCart: false, cartList: [_cartModel],
//               //         ));
//               //       }else {
//               //         if (Get.find<CartController>().existAnotherStoreItem(_cartModel.item.storeId)) {
//               //           Get.dialog(ConfirmationDialog(
//               //             icon: Images.warning,
//               //             title: 'are_you_sure_to_reset'.tr,
//               //             description: Get.find<SplashController>().configModel.moduleConfig.module.showRestaurantText
//               //                 ? 'if_you_continue'.tr : 'if_you_continue_without_another_store'.tr,
//               //             onYesPressed: () {
//               //               Get.back();
//               //               Get.find<CartController>().removeAllAndAddToCart(_cartModel);
//               //               showCartSnackBar(context);
//               //             },
//               //           ), barrierDismissible: false);
//               //         } else {
//               //           Get.find<CartController>().addToCart(
//               //             _cartModel, widget.cartIndex != null ? widget.cartIndex : itemController.cartIndex,
//               //           );
//               //           showCartSnackBar(context);
//               //         }
//               //       }
//               //     },
//               //
//               //   )),
//               // ]),
//             ]),
//           ),
//         );