import 'package:shimmer_animation/shimmer_animation.dart';
import 'package:sixam_mart/controller/splash_controller.dart';
import 'package:sixam_mart/data/model/response/item_model.dart';
import 'package:sixam_mart/data/model/response/store_model.dart';
import 'package:sixam_mart/helper/responsive_helper.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/view/base/no_data_screen.dart';
import 'package:sixam_mart/view/base/item_widget.dart';
import 'package:sixam_mart/view/base/veg_filter_widget.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:sixam_mart/view/screens/home/theme1/store_widget.dart';
import '../../controller/theme_controller.dart';
import '../../util/styles.dart';
import 'item_shimmer.dart';

class ItemsView extends StatelessWidget {
  //A
  final List<Item> items;
  final List<Store> stores;
  final bool isStore;
  final EdgeInsetsGeometry padding;
  final bool isScrollable;
  final int shimmerLength;
  final String noDataText;
  final bool isCampaign;
  final bool inStorePage;
  final String type;
  final bool isFeatured;
  final bool showTheme1Store;
  final Function(String type) onVegFilterTap;
  ItemsView({@required this.stores, @required this.items, @required this.isStore, this.isScrollable = false,
    this.shimmerLength = 20, this.padding = const EdgeInsets.all(Dimensions.PADDING_SIZE_SMALL), this.noDataText,
    this.isCampaign = false, this.inStorePage = false, this.type, this.onVegFilterTap, this.isFeatured = false, this.showTheme1Store = false});

  @override
  Widget build(BuildContext context) {

    bool _desktop = ResponsiveHelper.isDesktop(context);
    bool _isTab = ResponsiveHelper.isTab(context);
    bool _isWeb = ResponsiveHelper.isWeb();
    bool _isMobile = ResponsiveHelper.isMobile(context);
    double _width = MediaQuery.of(context).size.width;
   // print("testResponsiveHelper ItemsView _width $_width _desktop $_desktop _isTab $_isTab isWeb $_isWeb _isMobile $_isMobile");

    bool _isNull = true;
    int _length = 0;
    if(isStore) {
      _isNull = stores == null;
      if(!_isNull) {
        _length = stores.length;
      }
    }else {
      _isNull = items == null;
      if(!_isNull) {
        _length = items.length;
      }
    }
    double getDiscount(Item item) => item.discount==null?0 : item.discount;

    return Column(children: [

      type != null ? VegFilterWidget(type: type, onSelected: onVegFilterTap) : SizedBox(),

      !_isNull ? _length > 0 ? GridView.builder(
        key: UniqueKey(),
        gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
          // crossAxisCount: GetPlatform.isWeb ? 2 : 1, mainAxisSpacing:GetPlatform.isWeb ? Dimensions.PADDING_SIZE_LARGE:  Dimensions.PADDING_SIZE_DEFAULT,
          // crossAxisSpacing:GetPlatform.isWeb ? Dimensions.PADDING_SIZE_LARGE: Dimensions.PADDING_SIZE_DEFAULT, childAspectRatio: GetPlatform.isWeb ? (1/0.35) : (1/0.7),
          //
          crossAxisCount: _desktop ? Dimensions.crossAxisCount_Desktop : (_isTab && _width > 950 )? Dimensions.crossAxisCount_Tab_widthMoreThan950 : (_isTab && _width < 950 )? Dimensions.crossAxisCount_Tab_widthLessThan950  : Dimensions.crossAxisCount_Mobile
          , mainAxisSpacing: ( _desktop || _isTab )? Dimensions.PADDING_SIZE_DEFAULT:  Dimensions.PADDING_SIZE_SMALL,
          crossAxisSpacing:( _desktop || _isTab ) ? Dimensions.PADDING_SIZE_DEFAULT : Dimensions.PADDING_SIZE_SMALL
          , childAspectRatio: _desktop ? Dimensions.childAspectRatio_Desktop : (_isTab && _width > 950 ) ? Dimensions.childAspectRatio_Tab_widthMoreThan950 : (_isTab && _width < 950 ) ? Dimensions.childAspectRatio_Tab_widthLessThan950 : Dimensions.childAspectRatio_Mobile,

        ),
        physics: isScrollable ? BouncingScrollPhysics() : NeverScrollableScrollPhysics(),
        shrinkWrap: isScrollable ? false : true,
        padding: EdgeInsets.all(Dimensions.gridPadding),
        itemCount: _length,

        //
        itemBuilder: (context, index) {
          return showTheme1Store ? StoreWidget(store: stores[index],
              index: index, inStore: inStorePage)
              : ItemWidget(
            isStore: isStore,
            item: isStore ? null : items[index],
            isFeatured: isFeatured,
            store: isStore ? stores[index] : null,
            index: index,
            length: _length,
            isCampaign: isCampaign,
            inStore: inStorePage,
          );
        },
      )
          : NoDataScreen(
        text: noDataText != null ? noDataText : isStore ? Get.find<SplashController>().configModel.moduleConfig.module.showRestaurantText
            ? 'no_restaurant_available'.tr : 'no_store_available'.tr : 'no_item_available'.tr,
      ) :
      ItemViewGridShimmer(isEnabled: items==null,),

    ]);
  }
}
class ItemViewGridShimmer extends StatelessWidget {
  final bool isEnabled;
  ItemViewGridShimmer({@required this.isEnabled});

  @override
  Widget build(BuildContext context) {
    return GridView.builder(
      gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
        crossAxisCount: 1, mainAxisSpacing: Dimensions.PADDING_SIZE_SMALL,
        crossAxisSpacing: Dimensions.PADDING_SIZE_SMALL, childAspectRatio: (1/1),
      ),
      padding: EdgeInsets.all(Dimensions.PADDING_SIZE_SMALL),
      itemCount: 12,
      shrinkWrap: true, physics: NeverScrollableScrollPhysics(),
      itemBuilder: (context, index) {
        return ItemShimmer(isEnabled: isEnabled);
      },
    );
  }

}

