import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:shimmer_animation/shimmer_animation.dart';

import '../../helper/responsive_helper.dart';
import '../../util/dimensions.dart';
import '../../util/images.dart';


class ProductGridShimmer extends StatelessWidget {
  final bool isEnabled;
  ProductGridShimmer({@required this.isEnabled});

  @override
  Widget build(BuildContext context) {
    bool _desktop = ResponsiveHelper.isDesktop(context);
    bool _isTab = ResponsiveHelper.isTab(context);
    bool _isWeb = ResponsiveHelper.isWeb();
    bool _isMobile = ResponsiveHelper.isMobile(context);
    double _width = MediaQuery.of(context).size.width;
    print("testResponsiveHelper ProductGridShimmer _desktop $_desktop _isTab $_isTab isWeb $_isWeb _isMobile $_isMobile");

    return GridView.builder(
      gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
        crossAxisCount: _desktop ? Dimensions.crossAxisCount_Desktop : (_isTab && _width > 950 )? Dimensions.crossAxisCount_Tab_widthMoreThan950 : (_isTab && _width < 950 )? Dimensions.crossAxisCount_Tab_widthLessThan950  : Dimensions.crossAxisCount_Mobile
        , mainAxisSpacing: ( _desktop || _isTab )? Dimensions.PADDING_SIZE_DEFAULT:  Dimensions.PADDING_SIZE_SMALL,
        crossAxisSpacing:( _desktop || _isTab ) ? Dimensions.PADDING_SIZE_DEFAULT : Dimensions.PADDING_SIZE_SMALL
        , childAspectRatio: _desktop ? Dimensions.childAspectRatio_Desktop : (_isTab && _width > 950 ) ? Dimensions.childAspectRatio_Tab_widthMoreThan950 : (_isTab && _width < 950 ) ? Dimensions.childAspectRatio_Tab_widthLessThan950 : Dimensions.childAspectRatio_Mobile,


      ),
      padding: EdgeInsets.all(Dimensions.gridPadding),
      itemCount: 12,
      shrinkWrap: true, physics: NeverScrollableScrollPhysics(),
      itemBuilder: (context, index) {
        return Container(
          decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(Dimensions.RADIUS_DEFAULT),
            color: Theme.of(context).backgroundColor,
            boxShadow: [BoxShadow(color: Colors.grey[Get.isDarkMode ? 700 : 200], spreadRadius: 1, blurRadius: 5)],
          ),
          child: Shimmer(
            duration: Duration(seconds: 2),
            enabled: isEnabled,
            child:  Column(crossAxisAlignment: CrossAxisAlignment.center, mainAxisAlignment: MainAxisAlignment.center, children: [


              Stack(children: [
                Center(
                  child: ClipRRect(
                    borderRadius: BorderRadius.vertical(top: Radius.circular(Dimensions.RADIUS_SMALL)),
                    child: Image.asset(
                      Images.placeholder, width: 95, height: 98, fit: BoxFit.cover,
                    ),
                  ),
                ),
                Positioned(
                  right: Dimensions.PADDING_SIZE_EXTRA_SMALL,
                  child: Padding(
                    padding: EdgeInsets.symmetric(vertical:  0),
                    child: Icon(
                      Icons.favorite_border,  size:  25,
                      color: Theme.of(context).disabledColor,
                    ),
                  ),
                ),
              ]),

              Container(height: 15, width: 50, color: Colors.grey[300]),

            ]),
          ),
        );
      },
    );
  }

}