import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:shimmer_animation/shimmer_animation.dart';
import 'package:sixam_mart/controller/auth_controller.dart';
import 'package:sixam_mart/controller/search_controller.dart';
import 'package:sixam_mart/controller/user_controller.dart';
import 'package:sixam_mart/controller/wallet_controller.dart';
import 'package:sixam_mart/helper/price_converter.dart';
import 'package:sixam_mart/helper/responsive_helper.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/images.dart';
import 'package:sixam_mart/util/styles.dart';
import 'package:sixam_mart/view/base/custom_app_bar.dart';
import 'package:sixam_mart/view/base/footer_view.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_drawer.dart';
import 'package:sixam_mart/view/base/no_data_screen.dart';
import 'package:sixam_mart/view/base/not_logged_in_screen.dart';
import 'package:sixam_mart/view/base/title_widget.dart';
import 'package:sixam_mart/view/screens/wallet/widget/history_item.dart';
import 'package:sixam_mart/view/screens/wallet/widget/wallet_bottom_sheet.dart';

import '../../../data/model/response/wallet_statement_response.dart';
import '../../../util/app_constants.dart';
import '../../base/custom_button.dart';
import '../registered_users/registered_users_screen.dart';
import '../search/widget/custom_check_box.dart';

class BhavyaPointsScreen extends StatefulWidget {
  final String title;
  BhavyaPointsScreen({Key key, @required this.title}) : super(key: key);

  @override
  State<BhavyaPointsScreen> createState() => _BhavyaPointsScreenState();
}

class _BhavyaPointsScreenState extends State<BhavyaPointsScreen> {
  final ScrollController scrollController = ScrollController();
  final bool _isLoggedIn = Get.find<AuthController>().isLoggedIn();

  @override
  void initState() {
    super.initState();
    if(_isLoggedIn){
      Get.find<UserController>().getUserInfo();

      Get.find<WalletController>().resetStatementFilter();
      Get.find<WalletController>().getWalletStatement( );
      // Get.find<WalletController>().getWalletwalletStatementData('1', false, widget.fromWallet);

      scrollController?.addListener(() {
        if (scrollController.position.pixels == scrollController.position.maxScrollExtent
            && Get.find<WalletController>().walletStatementData != null
            && !Get.find<WalletController>().isLoading) {
          //int pageSize = (Get.find<WalletController>().totalPageSize / 10).ceil();

          //if (Get.find<WalletController>().offset < pageSize) {
          int pageSize = Get.find<WalletController>().totalPageSize;
          if (Get.find<WalletController>().walletStatementData.length < pageSize) {
            Get.find<WalletController>().setOffset(Get.find<WalletController>().offset + 1);
            print('end of the page');
            Get.find<WalletController>().showBottomLoader();
            Get.find<WalletController>().getWalletStatement();
          }
        }
      });
    }

  }
  @override
  void dispose() {
    super.dispose();

    scrollController?.dispose();
  }

  @override
  Widget build(BuildContext context) {

    return Scaffold(
      backgroundColor: Theme.of(context).cardColor,
      endDrawer: WebMenuDrawer(),
      appBar: CustomAppBar(title: widget.title, backButton: true),
      body: GetBuilder<UserController>(
          builder: (userController) {
            return _isLoggedIn ? userController.userInfoModel != null ? SafeArea(
              child: RefreshIndicator(
                onRefresh: () async{
                  Get.find<WalletController>().getWalletStatement();

                },
                child: SingleChildScrollView(
                  controller: scrollController,
                  padding: EdgeInsets.symmetric(horizontal: ResponsiveHelper.isDesktop(context) ? 0.0 : Dimensions.PADDING_SIZE_DEFAULT),
                  child: FooterView(
                    child: SizedBox(
                      width: Dimensions.WEB_MAX_WIDTH,
                      child: GetBuilder<WalletController>(
                          builder: (walletController) {
                            return Column(children: [

                              Column(children: [
                                SizedBox(height: 30,),

                                Row(
                                  crossAxisAlignment: CrossAxisAlignment.start,
                                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                                  children: [
                                    Padding(
                                      padding: EdgeInsets.only(top: Dimensions.PADDING_SIZE_EXTRA_LARGE),
                                      child: TitleWidget(title: 'transaction_history'.tr),
                                    ),

                                    InkWell(child: Padding(
                                      padding: const EdgeInsets.symmetric(vertical: 12,horizontal: 7),
                                      child: Container(
                                        padding: EdgeInsets.only(left: 6,right: 6),
                                        decoration: BoxDecoration(
                                          color: walletController.isFilterApplied ? Theme.of(context).primaryColor.withOpacity(0.1) : Theme.of(context).primaryColor.withOpacity(0.0),
                                          border: Border.all(color: walletController.isFilterApplied ?  Theme.of(context).primaryColor.withOpacity(0.9) : Colors.black26),
                                          borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
                                        ),
                                        child: Row(
                                          crossAxisAlignment: CrossAxisAlignment.center,
                                          mainAxisAlignment: MainAxisAlignment.center,
                                          children: [
                                            Text('Filters', style: robotoRegular.copyWith(fontSize:
                                            Dimensions.fontSizeSmall,color:  Colors.black,),),
                                            SizedBox(width: 10,),Icon(Icons.keyboard_arrow_down_rounded,size: 15,color: Colors. black,)
                                          ],
                                        ),
                                      ),
                                    ),onTap: (){
                                      Get.dialog(FilterWidget());

                                    },),
                                  ],
                                ),

                                walletController.walletStatementData != null ?

                                walletController.walletStatementData.length > 0 ?
                                GridView.builder(
                                  padding: EdgeInsets.only(top: ResponsiveHelper.isDesktop(context)? 28 : 25),
                                  key: UniqueKey(),
                                  gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
                                    crossAxisSpacing: 50,
                                    mainAxisSpacing: ResponsiveHelper.isDesktop(context) ? Dimensions.PADDING_SIZE_LARGE : 0.1,
                                    childAspectRatio: ResponsiveHelper.isDesktop(context) ? 5 : 2.45,
                                    crossAxisCount: ResponsiveHelper.isMobile(context) ? 1 : 2,
                                  ),
                                  physics:  NeverScrollableScrollPhysics(),
                                  shrinkWrap:  true,
                                  itemCount: walletController.walletStatementData.length ,
                                  itemBuilder: (context, index) {

                                    return HistoryItem(index: index, data: walletController.walletStatementData[index] );
                                  },
                                )
                                    : NoDataScreen(text: 'no_data_found'.tr)
                                    : WalletShimmer(walletController: walletController),

                                walletController.isLoading ? Center(child: Padding(
                                  padding: EdgeInsets.all(Dimensions.PADDING_SIZE_SMALL),
                                  child: CircularProgressIndicator(),
                                )) : SizedBox(),
                              ])
                            ]);
                          }
                      ),
                    ),
                  ),
                ),
              ),
            ) : Center(child: CircularProgressIndicator()) : NotLoggedInScreen();
          }
      ),
    );
  }
}

class FilterWidget extends StatelessWidget {


  Future<void> _selectFromDate(BuildContext context, WalletController walletController) async {
    final DateTime picked = await showDatePicker(
        context: context,
        initialDate: walletController.selectedFromDate,
        firstDate: DateTime(2015, 8),
        lastDate: DateTime(2050, 8));

    if (picked != null && picked != walletController.selectedFromDate) {
      walletController.setFromDate("${picked.toLocal()}".split(' ')[0],picked);

    }
  }
  Future<void> _selectToDate(BuildContext context, WalletController walletController) async {
    final DateTime picked = await showDatePicker(
        context: context,
        initialDate: walletController.selectedToDate,
        firstDate: DateTime(2015, 8),
        lastDate: DateTime(2050, 8));
    if (picked != null && picked != walletController.selectedToDate) {
      walletController.setToDate("${picked.toLocal()}".split(' ')[0],picked);

    }
  }
  @override
  Widget build(BuildContext context) {
    return Dialog(
      shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL)),
      insetPadding: EdgeInsets.all(30),
      clipBehavior: Clip.antiAliasWithSaveLayer,
      child: Container(
        width: 600,
        padding: EdgeInsets.all(Dimensions.PADDING_SIZE_SMALL),
        child: GetBuilder<WalletController>(builder: (walletController) {
          return SingleChildScrollView(
            child: Column(mainAxisSize: MainAxisSize.min, crossAxisAlignment: CrossAxisAlignment.start, children: [

              Row(mainAxisAlignment: MainAxisAlignment.spaceBetween, children: [
                InkWell(
                  onTap: () => Navigator.of(context).pop(),
                  child: Padding(
                    padding: EdgeInsets.all(Dimensions.PADDING_SIZE_EXTRA_SMALL),
                    child: Icon(Icons.close, color: Theme.of(context).disabledColor),
                  ),
                ),
                Text('filter'.tr, style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeLarge)),
                CustomButton(
                  onPressed: () {
                    walletController.resetStatementFilter();
                    walletController.getWalletStatement();
                  },
                  buttonText: 'reset'.tr, transparent: true, width: 65,
                ),
              ]),
              SizedBox(height: Dimensions.PADDING_SIZE_LARGE),

              Text('sort_by'.tr, style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeLarge)),
              SizedBox(height: Dimensions.PADDING_SIZE_SMALL),
              GridView.builder(
                itemCount: walletController.sortList.length,
                physics: NeverScrollableScrollPhysics(),
                shrinkWrap: true,
                gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
                  crossAxisCount: ResponsiveHelper.isDesktop(context) ? 3 : ResponsiveHelper.isTab(context) ? 3 : 2,
                  childAspectRatio: 3, crossAxisSpacing: 10, mainAxisSpacing: 10,
                ),
                itemBuilder: (context, index) {
                  return InkWell(
                    onTap: () {
                      walletController.setSortIndex(index);
                    },
                    child: Container(
                      alignment: Alignment.center,
                      decoration: BoxDecoration(
                        border: Border.all(color: walletController.sortIndex == index ? Colors.transparent
                            : Theme.of(context).disabledColor),
                        borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
                        color: walletController.sortIndex == index ? Theme.of(context).primaryColor
                            : Theme.of(context).disabledColor.withOpacity(0.1),
                      ),
                      child: Text(
                        walletController.sortList[index],
                        textAlign: TextAlign.center,
                        style: robotoMedium.copyWith(
                          color: walletController.sortIndex == index ? Colors.white : Theme.of(context).hintColor,
                        ),
                        maxLines: 1,
                        overflow: TextOverflow.ellipsis,
                      ),
                    ),
                  );
                },
              ),
              SizedBox(height: Dimensions.PADDING_SIZE_LARGE),

              Text('date'.tr, style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeLarge)),
              SizedBox(height: Dimensions.PADDING_SIZE_SMALL),
              Row(
                children: [
                  InkWell(
                    onTap: () {
                      _selectFromDate(context,walletController);
                    },
                    child: Container(
                      padding: EdgeInsets.fromLTRB(15, 10, 15, 10),
                      alignment: Alignment.center,
                      decoration: BoxDecoration(
                        border: Border.all(color: walletController.fromDate != 'from_date'.tr ? Colors.transparent
                            : Theme.of(context).disabledColor),
                        borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
                        color: walletController.fromDate != 'from_date'.tr ? Theme.of(context).primaryColor
                            : Theme.of(context).disabledColor.withOpacity(0.1),
                      ),
                      child: Text(
                        walletController.fromDate,
                        textAlign: TextAlign.center,
                        style: robotoMedium.copyWith(
                          color: walletController.fromDate != 'from_date'.tr ? Colors.white : Theme.of(context).hintColor,
                        ),
                        maxLines: 1,
                        overflow: TextOverflow.ellipsis,
                      ),
                    ),
                  ),

                  SizedBox(width: 15,),

                  InkWell(
                    onTap: () {
                      _selectToDate(context,walletController);

                    },
                    child: Container(
                      padding: EdgeInsets.fromLTRB(15, 10, 15, 10),
                      alignment: Alignment.center,
                      decoration: BoxDecoration(
                        border: Border.all(color: walletController.toDate != 'to_date'.tr ? Colors.transparent
                            : Theme.of(context).disabledColor),
                        borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
                        color: walletController.toDate != 'to_date'.tr ? Theme.of(context).primaryColor
                            : Theme.of(context).disabledColor.withOpacity(0.1),
                      ),

                      child: Text(
                        walletController.toDate,
                        textAlign: TextAlign.center,
                        style: robotoMedium.copyWith(
                          color: walletController.toDate != 'to_date'.tr ? Colors.white : Theme.of(context).hintColor,
                        ),
                        maxLines: 1,
                        overflow: TextOverflow.ellipsis,
                      ),
                    ),
                  ),
                ],
              ),
              SizedBox(height: Dimensions.PADDING_SIZE_LARGE),

              Text('transaction_type'.tr, style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeLarge)),

              Row(crossAxisAlignment: CrossAxisAlignment.start,mainAxisAlignment: MainAxisAlignment.start,children: [
                CustomCheckBox(
                  title:  'debit'.tr,
                  value: walletController.actionType=='debit'.tr,
                  onClick: () {
                    if(walletController.actionType=='debit'.tr){
                      walletController.setActionType("");
                    }else{
                      walletController.setActionType('debit'.tr);
                    }

                  },
                ),
                CustomCheckBox(
                  title:  'credit'.tr,
                  value: walletController.actionType=='credit'.tr,
                  onClick: () {
                    if(walletController.actionType=='credit'.tr){
                      walletController.setActionType("");
                    }else{
                      walletController.setActionType('credit'.tr);
                    }

                  },
                ),

              ],),


              SizedBox(height: Dimensions.PADDING_SIZE_SMALL),


              (walletController.transferTypesList!=null && walletController.transferTypesList.length>0) ?
              Column(
                children: [
                  Text('transfer_type'.tr,
                      style: robotoMedium.copyWith(fontSize:
                      Dimensions.fontSizeLarge)),
                  SizedBox(height: Dimensions.PADDING_SIZE_SMALL),
                ],
              )
                  : SizedBox(),
              (walletController.transferTypesList!=null && walletController.transferTypesList.length>0) ? Container(
                height: 30, alignment: Alignment.center,
                child: ListView.builder(
                  itemCount: walletController.transferTypesList.length,
                  shrinkWrap: true,
                  scrollDirection: Axis.horizontal,
                  itemBuilder: (context, index) {
                    return CustomCheckBox(
                      title:  walletController.transferTypesList[index].name,
                      value: (walletController.transferTypeDropDownValue!=null && walletController.transferTypeDropDownValue.name==walletController.transferTypesList[index].name),
                      onClick: () {
                        if(walletController.transferTypeDropDownValue!=null && walletController.transferTypeDropDownValue.name==walletController.transferTypesList[index].name){
                          walletController.updateTransferTypeDropdown(null);
                        }else{
                          walletController.updateTransferTypeDropdown(walletController.transferTypesList[index]);
                        }
                      },
                    );
                  },
                ),
              )
                  : SizedBox(),
              SizedBox(height:(walletController.transferTypesList!=null && walletController.transferTypesList.length>0) ? 30 : 0.0),

              CustomButton(
                buttonText: 'apply_filters'.tr,
                onPressed: () {
                  walletController.setFilterApplied();
                  walletController.getWalletStatement();
                  Get.back();
                },
              ),

            ]),
          );
        }),
      ),
    );
  }
}
class HistoryItem extends StatelessWidget {
  final int index;
  final WalletStatementData data;
  const HistoryItem({Key key, @required this.index, @required this.data}) : super(key: key);


  String incomeType(String key){
    String name="";
    for(Types item in Get.find<WalletController>().transferTypesList){
      if(item.value==key){
        name=item.name;
        break;
      }
    }
    return name;
  }
  @override
  Widget build(BuildContext context) {
    return Column(crossAxisAlignment: CrossAxisAlignment.start,
        children: [

          Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,children: [
            Row(
              children: [
                Text('Type: ',
                  style: robotoMedium.copyWith(color: Colors.black54,fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
                ),
                Text('${incomeType(data.incomeType.toString())}',
                  style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
                )
              ],
            ) ,

            Text(data.transactionDate
                ,style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall,color: Theme.of(context).disabledColor),
                maxLines: 1, overflow: TextOverflow.ellipsis),
          ],),

          SizedBox(height: 5.0,),

          Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,children: [
            Row(
              children: [
                (data.debit==null && data.credit!=null)?
                Row(
                  children: [
                    Text(
                      '${'credit'.tr}:',
                      style: robotoMedium.copyWith(color: Colors.black54,fontSize: 12,),
                      textAlign: TextAlign.center,
                    ),
                    SizedBox(width: 5,),
                    Text(
                      '${PriceConverter.convertPrice(double.parse(data.credit))}',
                      style: robotoMedium.copyWith(fontSize: 12,color: Colors.green),
                      textAlign: TextAlign.center,
                    ),
                  ],
                ) :
                (data.credit==null && data.debit!=null) ?
                Row(
                  children: [
                    Text(
                      '${'debit'.tr}:',
                      style: robotoMedium.copyWith(fontSize: 12,),
                      textAlign: TextAlign.center,
                    ),
                    SizedBox(width: 5,),
                    Text(
                      '${PriceConverter.convertPrice(double.parse(data.debit))}',
                      style: robotoMedium.copyWith(fontSize: 12,color: Colors.red),
                      textAlign: TextAlign.center,
                    ),
                  ],
                )
                    : SizedBox(),

              ],
            ) ,

            Row(
              children: [
                Text(
                  '${'balance'.tr}:',
                  style: robotoMedium.copyWith(fontSize: 12),
                  textAlign: TextAlign.center,
                ),
                SizedBox(width: 5,),

                Text(
                  '${data.balance}',
                  style: robotoMedium.copyWith(fontSize: 12),
                  textAlign: TextAlign.center,
                ),
              ],
            ),
          ],),
          SizedBox(height: 5.0,),

          Row(mainAxisAlignment : MainAxisAlignment.spaceBetween,children: [
            Row(
              children: [
                Text('Party: ',
                  style: robotoMedium.copyWith(color: Colors.black54,fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
                ),
                Text('${data.party.toString()}',
                  style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
                )
              ],
            ) ,

            //DateConverter.dateToDateAndTimeAm(data.createdAt)
            // Text(data.transactionDate
            //     ,style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall,color: Theme.of(context).disabledColor),
            //     maxLines: 1, overflow: TextOverflow.ellipsis),
          ],),

          SizedBox(height: 5.0,),
          data.particulars!=null? Text('${data.particulars.toString()}',
            style: robotoRegular.copyWith(color: Colors.black26,fontSize: Dimensions.fontSizeDefault), maxLines: 2, overflow: TextOverflow.ellipsis,
          ):SizedBox(),
          Padding(
            padding: const EdgeInsets.only(top: Dimensions.PADDING_SIZE_DEFAULT),
            child: Divider(color: Theme.of(context).disabledColor),
          ),
        ]);
  }
}

class WalletShimmer extends StatelessWidget {
  final WalletController walletController;
  WalletShimmer({@required this.walletController});

  @override
  Widget build(BuildContext context) {
    return GridView.builder(
      key: UniqueKey(),
      gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
        crossAxisSpacing: 50,
        mainAxisSpacing: ResponsiveHelper.isDesktop(context) ? Dimensions.PADDING_SIZE_LARGE : 0.1,
        childAspectRatio: ResponsiveHelper.isDesktop(context) ? 5 : 2.45,
        crossAxisCount: ResponsiveHelper.isMobile(context) ? 1 : 2,
      ),
      physics:  NeverScrollableScrollPhysics(),
      shrinkWrap:  true,
      itemCount: 10,
      padding: EdgeInsets.only(top: ResponsiveHelper.isDesktop(context) ? 28 : 25),
      itemBuilder: (context, index) {
        return Padding(
          padding: EdgeInsets.symmetric(vertical: Dimensions.PADDING_SIZE_SMALL),
          child: Shimmer(
            duration: Duration(seconds: 2),
            enabled: walletController.walletStatementData == null,
            child: Column(children: [
              Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Column(crossAxisAlignment: CrossAxisAlignment.start, children: [
                    Container(height: 10, width: 50, decoration: BoxDecoration(color: Colors.grey[300], borderRadius: BorderRadius.circular(2))),
                    SizedBox(height: 10),
                    Container(height: 10, width: 70, decoration: BoxDecoration(color: Colors.grey[300], borderRadius: BorderRadius.circular(2))),
                  ]),
                  Column(crossAxisAlignment: CrossAxisAlignment.end, children: [
                    Container(height: 10, width: 50, decoration: BoxDecoration(color: Colors.grey[300], borderRadius: BorderRadius.circular(2))),
                    SizedBox(height: 10),
                    Container(height: 10, width: 70, decoration: BoxDecoration(color: Colors.grey[300], borderRadius: BorderRadius.circular(2))),
                  ]),
                ],
              ),
              Padding(padding: const EdgeInsets.only(top: Dimensions.PADDING_SIZE_LARGE), child: Divider(color: Theme.of(context).disabledColor)),
            ],
            ),
          ),
        );
      },
    );
  }
}