import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:shimmer_animation/shimmer_animation.dart';
import 'package:sixam_mart/controller/auth_controller.dart';
import 'package:sixam_mart/controller/search_controller.dart';
import 'package:sixam_mart/controller/user_controller.dart';
import 'package:sixam_mart/controller/wallet_controller.dart';
import 'package:sixam_mart/helper/price_converter.dart';
import 'package:sixam_mart/helper/responsive_helper.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/images.dart';
import 'package:sixam_mart/util/styles.dart';
import 'package:sixam_mart/view/base/custom_app_bar.dart';
import 'package:sixam_mart/view/base/footer_view.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_drawer.dart';
import 'package:sixam_mart/view/base/no_data_screen.dart';
import 'package:sixam_mart/view/base/not_logged_in_screen.dart';
import 'package:sixam_mart/view/base/title_widget.dart';
import 'package:sixam_mart/view/screens/wallet/widget/history_item.dart';
import 'package:sixam_mart/view/screens/wallet/widget/wallet_bottom_sheet.dart';

import '../../../controller/closing_controller.dart';
import '../../../data/model/response/wallet_statement_response.dart';
import '../../../helper/route_helper.dart';
import '../../../util/app_constants.dart';
import '../../base/custom_button.dart';
import '../search/widget/custom_check_box.dart';

class ClosingScreen extends StatefulWidget {
  final bool fromWallet;
  final String preFilter;

  ClosingScreen({Key key, @required this.fromWallet, @required this.preFilter}) : super(key: key);

  @override
  State<ClosingScreen> createState() => _ClosingScreenState();
}

class _ClosingScreenState extends State<ClosingScreen> {
  final ScrollController scrollController = ScrollController();
  final bool _isLoggedIn = Get.find<AuthController>().isLoggedIn();

  @override
  void initState() {
    super.initState();
    if(_isLoggedIn){
      
      Get.find<ClosingController>().resetStatementFilter();
      Get.find<ClosingController>().getClosingData(false);

      scrollController?.addListener(() {
        if (scrollController.position.pixels == scrollController.position.maxScrollExtent
            && Get.find<ClosingController>().closingDataList != null
            && !Get.find<ClosingController>().isLoading) {
          //int pageSize = (Get.find<ClosingController>().totalPageSize / 10).ceil();

          //if (Get.find<ClosingController>().offset < pageSize) {
          int pageSize = Get.find<ClosingController>().totalPageSize;
          if (Get.find<ClosingController>().closingDataList.length < pageSize) {
            Get.find<ClosingController>().setOffset(Get.find<ClosingController>().offset + 1);
            print('end of the page');
            Get.find<ClosingController>().showBottomLoader();
            Get.find<ClosingController>().getClosingData(false);
          }
        }
      });
    }

  }
  @override
  void dispose() {
    super.dispose();

    scrollController?.dispose();
  }

  @override
  Widget build(BuildContext context) {

    return Scaffold(
      backgroundColor: Theme.of(context).cardColor,
      endDrawer: WebMenuDrawer(),
      appBar: CustomAppBar(title: 'closing'.tr, backButton: true),
      body: GetBuilder<UserController>(
          builder: (userController) {
            return _isLoggedIn ? userController.userInfoModel != null ? SafeArea(
              child: RefreshIndicator(
                onRefresh: () async{
                 Get.find<ClosingController>().getClosingData(true);
                },
                child: SingleChildScrollView(
                  controller: scrollController,
                  padding: EdgeInsets.symmetric(horizontal: ResponsiveHelper.isDesktop(context) ? 0.0 : Dimensions.PADDING_SIZE_DEFAULT),
                  child: FooterView(
                    child: SizedBox(
                      width: Dimensions.WEB_MAX_WIDTH,
                      child: GetBuilder<ClosingController>(
                          builder: (closingController) {
                            return Column(children: [

                              closingController.closingDataList != null ? closingController.closingDataList.length > 0 ?
                              ListView.builder(
                                shrinkWrap: true,
                                scrollDirection: Axis.vertical,
                                itemCount: closingController.closingDataList.length,
                                physics: BouncingScrollPhysics(),
                                itemBuilder: (context, index) {
                                  return InkWell(child: ClosingItem(index: index,fromWallet: widget.fromWallet,data: closingController.closingDataList[index],preFilter: widget.preFilter, ),
                                  onTap: (){
                                    closingController.setCurrentItem(closingController.closingDataList[index]);
                                    Get.toNamed(RouteHelper.getWalletRoute(true,'pair_income'.tr));
                                  },);
                                },
                              )
                                  : NoDataScreen(text: 'no_data_found'.tr)
                                  : WalletShimmer(closingController: closingController),

                              closingController.isLoading ? Center(child: Padding(
                                padding: EdgeInsets.all(Dimensions.PADDING_SIZE_SMALL),
                                child: CircularProgressIndicator(),
                              )) : SizedBox(),
                            ]);
                          }
                      ),
                    ),
                  ),
                ),
              ),
            ) : Center(child: CircularProgressIndicator()) : NotLoggedInScreen();
          }
      ),
    );
  }
}

class WalletShimmer extends StatelessWidget {
  final ClosingController closingController;
  WalletShimmer({@required this.closingController});

  @override
  Widget build(BuildContext context) {
    return GridView.builder(
      key: UniqueKey(),
      gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
        crossAxisSpacing: 50,
        mainAxisSpacing: ResponsiveHelper.isDesktop(context) ? Dimensions.PADDING_SIZE_LARGE : 0.1,
        childAspectRatio: ResponsiveHelper.isDesktop(context) ? 5 : 2.45,
        crossAxisCount: ResponsiveHelper.isMobile(context) ? 1 : 2,
      ),
      physics:  NeverScrollableScrollPhysics(),
      shrinkWrap:  true,
      itemCount: 10,
      padding: EdgeInsets.only(top: ResponsiveHelper.isDesktop(context) ? 28 : 25),
      itemBuilder: (context, index) {
        return Padding(
          padding: EdgeInsets.symmetric(vertical: Dimensions.PADDING_SIZE_SMALL),
          child: Shimmer(
            duration: Duration(seconds: 2),
            enabled: closingController.closingDataList == null,
            child: Column(children: [
              Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Column(crossAxisAlignment: CrossAxisAlignment.start, children: [
                    Container(height: 10, width: 50, decoration: BoxDecoration(color: Colors.grey[300], borderRadius: BorderRadius.circular(2))),
                    SizedBox(height: 10),
                    Container(height: 10, width: 70, decoration: BoxDecoration(color: Colors.grey[300], borderRadius: BorderRadius.circular(2))),
                  ]),
                  Column(crossAxisAlignment: CrossAxisAlignment.end, children: [
                    Container(height: 10, width: 50, decoration: BoxDecoration(color: Colors.grey[300], borderRadius: BorderRadius.circular(2))),
                    SizedBox(height: 10),
                    Container(height: 10, width: 70, decoration: BoxDecoration(color: Colors.grey[300], borderRadius: BorderRadius.circular(2))),
                  ]),
                ],
              ),
              Padding(padding: const EdgeInsets.only(top: Dimensions.PADDING_SIZE_LARGE), child: Divider(color: Theme.of(context).disabledColor)),
            ],
            ),
          ),
        );
      },
    );
  }
}//                              return
