import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:shimmer_animation/shimmer_animation.dart';
import 'package:sixam_mart/controller/auth_controller.dart';
import 'package:sixam_mart/controller/search_controller.dart';
import 'package:sixam_mart/controller/user_controller.dart';
import 'package:sixam_mart/controller/wallet_controller.dart';
import 'package:sixam_mart/helper/price_converter.dart';
import 'package:sixam_mart/helper/responsive_helper.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/images.dart';
import 'package:sixam_mart/util/styles.dart';
import 'package:sixam_mart/view/base/custom_app_bar.dart';
import 'package:sixam_mart/view/base/footer_view.dart';
import 'package:sixam_mart/view/screens/admin_screen/upi_payment_status_update_screen.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_drawer.dart';
import 'package:sixam_mart/view/base/no_data_screen.dart';
import 'package:sixam_mart/view/base/not_logged_in_screen.dart';
import 'package:sixam_mart/view/base/title_widget.dart';
import 'package:sixam_mart/view/screens/wallet/widget/history_item.dart';
import 'package:sixam_mart/view/screens/wallet/widget/wallet_bottom_sheet.dart';

import '../../../data/model/response/revenue_statement_response.dart';
import '../../../data/model/response/upi_payments_list_response.dart';
import '../../../data/model/response/wallet_statement_response.dart';
import '../../../helper/date_converter.dart';
import '../../../helper/route_helper.dart';
import '../../../util/app_constants.dart';
import '../../base/custom_button.dart';
import '../search/widget/custom_check_box.dart';

class UpiPaymentListScreen extends StatefulWidget {

  @override
  State<UpiPaymentListScreen> createState() => _UpiPaymentListScreenState();
}

class _UpiPaymentListScreenState extends State<UpiPaymentListScreen> {
  final ScrollController scrollController = ScrollController();
  final bool _isLoggedIn = Get.find<AuthController>().isLoggedIn();

  @override
  void initState() {
    super.initState();
    if(_isLoggedIn){


      Get.find<WalletController>().resetStatementFilter();
      Get.find<WalletController>().getUpiPaymentList();

      scrollController?.addListener(() {
        if (scrollController.position.pixels == scrollController.position.maxScrollExtent
            && Get.find<WalletController>().upiPaymentsList != null
            && Get.find<WalletController>().upiPaymentsList.isNotEmpty
            && !Get.find<WalletController>().isLoading) {
        //  int pageSize = (Get.find<WalletController>().totalPageSize / 10).ceil();
          int pageSize = Get.find<WalletController>().totalPageSize ;
          if (Get.find<WalletController>().upiPaymentsList.length < pageSize) {
            Get.find<WalletController>().setOffset(Get.find<WalletController>().offset + 1);
            print('end of the page');
            Get.find<WalletController>().showBottomLoader();
            Get.find<WalletController>().getUpiPaymentList();
          }
        }
      });
    }

  }
  @override
  void dispose() {
    super.dispose();
    scrollController?.dispose();
  }

  @override
  Widget build(BuildContext context) {

    return Scaffold(
      backgroundColor: Theme.of(context).cardColor,
      endDrawer: WebMenuDrawer(),
      appBar: CustomAppBar(title: 'upi_payments'.tr, backButton: true),
      body: GetBuilder<UserController>(
          builder: (userController) {
            return _isLoggedIn ? userController.userInfoModel != null ? SafeArea(
              child: RefreshIndicator(
                onRefresh: () async{
                  Get.find<WalletController>().getUpiPaymentList();
                },
                child: SingleChildScrollView(
                  controller: scrollController,
                  padding: EdgeInsets.symmetric(horizontal: ResponsiveHelper.isDesktop(context) ? 0.0 : Dimensions.PADDING_SIZE_DEFAULT),
                  child: FooterView(
                    child: SizedBox(
                      width: Dimensions.WEB_MAX_WIDTH,
                      child: GetBuilder<WalletController>(
                          builder: (walletController) {
                            return Column(children: [
                              Row(
                                crossAxisAlignment: CrossAxisAlignment.start,
                                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                                children: [
                                  Padding(
                                    padding: EdgeInsets.only(top: Dimensions.PADDING_SIZE_EXTRA_LARGE),
                                    child: TitleWidget(title: 'Records ${walletController.upiPaymentsList!=null? walletController.upiPaymentsList.length.toString():""}'),
                                  ),

                                  InkWell(child: Padding(
                                    padding: const EdgeInsets.symmetric(vertical: 12,horizontal: 7),
                                    child: Container(
                                      padding: EdgeInsets.only(left: 6,right: 6),
                                      decoration: BoxDecoration(
                                        color: walletController.isFilterApplied ? Theme.of(context).primaryColor.withOpacity(0.1) : Theme.of(context).primaryColor.withOpacity(0.0),
                                        border: Border.all(color: walletController.isFilterApplied ?  Theme.of(context).primaryColor.withOpacity(0.9) : Colors.black26),
                                        borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
                                      ),
                                      child: Row(
                                        crossAxisAlignment: CrossAxisAlignment.center,
                                        mainAxisAlignment: MainAxisAlignment.center,
                                        children: [
                                          Text('Filters', style: robotoRegular.copyWith(fontSize:
                                          Dimensions.fontSizeSmall,color:  Colors.black,),),
                                          SizedBox(width: 10,),Icon(Icons.keyboard_arrow_down_rounded,size: 15,color: Colors. black,)
                                        ],
                                      ),
                                    ),
                                  ),onTap: (){
                                    Get.dialog(FilterWidget());

                                  },),
                                ],
                              ),
                              SizedBox(height: 10,),

                              walletController.upiPaymentsList != null ? walletController.upiPaymentsList.length > 0 ?

                              ListView.builder(
                                shrinkWrap: true,
                                scrollDirection: Axis.vertical,
                                itemCount: walletController.upiPaymentsList.length,
                                physics: BouncingScrollPhysics(),
                                itemBuilder: (context, index) {
                                  return Padding(padding: EdgeInsets.only(bottom: 10),child: Container(
                                    padding: const EdgeInsets.all(8.0),
                                    decoration: AppConstants.customBoxDecoration(context),
                                    child: HistoryItem(index: index, data: walletController.upiPaymentsList[index] ),
                                  ),);
                                },
                              )
                                  : NoDataScreen(text: 'no_data_found'.tr)
                                  : WalletShimmer(walletController: walletController),

                              walletController.isLoading ? Center(child: Padding(
                                padding: EdgeInsets.all(Dimensions.PADDING_SIZE_SMALL),
                                child: CircularProgressIndicator(),
                              )) : SizedBox(),
                            ]);
                          }
                      ),
                    ),
                  ),
                ),
              ),
            ) : Center(child: CircularProgressIndicator()) : NotLoggedInScreen();
          }
      ),
    );
  }
}

class FilterWidget extends StatelessWidget {


  Future<void> _selectFromDate(BuildContext context, WalletController walletController) async {
    final DateTime picked = await showDatePicker(
        context: context,
        initialDate: walletController.selectedFromDate,
        firstDate: DateTime(2015, 8),
        lastDate: DateTime(2050, 8));

    if (picked != null && picked != walletController.selectedFromDate) {
      walletController.setFromDate("${picked.toLocal()}".split(' ')[0],picked);

    }
  }
  Future<void> _selectToDate(BuildContext context, WalletController walletController) async {
    final DateTime picked = await showDatePicker(
        context: context,
        initialDate: walletController.selectedToDate,
        firstDate: DateTime(2015, 8),
        lastDate: DateTime(2050, 8));
    if (picked != null && picked != walletController.selectedToDate) {
      walletController.setToDate("${picked.toLocal()}".split(' ')[0],picked);

    }
  }
  @override
  Widget build(BuildContext context) {
    return Dialog(
      shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL)),
      insetPadding: EdgeInsets.all(30),
      clipBehavior: Clip.antiAliasWithSaveLayer,
      child: Container(
        width: 600,
        padding: EdgeInsets.all(Dimensions.PADDING_SIZE_SMALL),
        child: GetBuilder<WalletController>(builder: (walletController) {
          return SingleChildScrollView(
            child: Column(mainAxisSize: MainAxisSize.min, crossAxisAlignment: CrossAxisAlignment.start, children: [

              Row(mainAxisAlignment: MainAxisAlignment.spaceBetween, children: [
                InkWell(
                  onTap: () => Navigator.of(context).pop(),
                  child: Padding(
                    padding: EdgeInsets.all(Dimensions.PADDING_SIZE_EXTRA_SMALL),
                    child: Icon(Icons.close, color: Theme.of(context).disabledColor),
                  ),
                ),
                Text('filter'.tr, style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeLarge)),
                CustomButton(
                  onPressed: () {
                    walletController.resetStatementFilter();
                    walletController.getUpiPaymentList();
                  },
                  buttonText: 'reset'.tr, transparent: true, width: 65,
                ),
              ]),
              SizedBox(height: Dimensions.PADDING_SIZE_LARGE),

              Text('date'.tr, style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeLarge)),
              SizedBox(height: Dimensions.PADDING_SIZE_SMALL),
              Row(
                children: [
                  InkWell(
                    onTap: () {
                      _selectFromDate(context,walletController);
                    },
                    child: Container(
                      padding: EdgeInsets.fromLTRB(15, 10, 15, 10),
                      alignment: Alignment.center,
                      decoration: BoxDecoration(
                        border: Border.all(color: walletController.fromDate != 'from_date'.tr ? Colors.transparent
                            : Theme.of(context).disabledColor),
                        borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
                        color: walletController.fromDate != 'from_date'.tr ? Theme.of(context).primaryColor
                            : Theme.of(context).disabledColor.withOpacity(0.1),
                      ),
                      child: Text(
                        walletController.fromDate,
                        textAlign: TextAlign.center,
                        style: robotoMedium.copyWith(
                          color: walletController.fromDate != 'from_date'.tr ? Colors.white : Theme.of(context).hintColor,
                        ),
                        maxLines: 1,
                        overflow: TextOverflow.ellipsis,
                      ),
                    ),
                  ),

                  SizedBox(width: 15,),

                  InkWell(
                    onTap: () {
                      _selectToDate(context,walletController);

                    },
                    child: Container(
                      padding: EdgeInsets.fromLTRB(15, 10, 15, 10),
                      alignment: Alignment.center,
                      decoration: BoxDecoration(
                        border: Border.all(color: walletController.toDate != 'to_date'.tr ? Colors.transparent
                            : Theme.of(context).disabledColor),
                        borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
                        color: walletController.toDate != 'to_date'.tr ? Theme.of(context).primaryColor
                            : Theme.of(context).disabledColor.withOpacity(0.1),
                      ),

                      child: Text(
                        walletController.toDate,
                        textAlign: TextAlign.center,
                        style: robotoMedium.copyWith(
                          color: walletController.toDate != 'to_date'.tr ? Colors.white : Theme.of(context).hintColor,
                        ),
                        maxLines: 1,
                        overflow: TextOverflow.ellipsis,
                      ),
                    ),
                  ),
                ],
              ),
              SizedBox(height: Dimensions.PADDING_SIZE_LARGE),

              Text('action'.tr, style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeLarge)),

              Row(crossAxisAlignment: CrossAxisAlignment.start,mainAxisAlignment: MainAxisAlignment.start,children: [
                CustomCheckBox(
                  title:  'approved',
                  value: walletController.actionType=='approved',
                  onClick: () {
                    if(walletController.actionType=='approved'){
                      walletController.setActionType("");
                    }else{
                      walletController.setActionType('approved');
                    }

                  },
                ),

                CustomCheckBox(
                  title:  'rejected',
                  value: walletController.actionType=='rejected',
                  onClick: () {
                    if(walletController.actionType=='rejected'){
                      walletController.setActionType("");
                    }else{
                      walletController.setActionType('rejected');
                    }

                  },
                ),

              ],),

              Row(crossAxisAlignment: CrossAxisAlignment.start,mainAxisAlignment: MainAxisAlignment.start,children: [

                CustomCheckBox(
                  title:  'pending',
                  value: walletController.actionType=='pending',
                  onClick: () {
                    if(walletController.actionType=='pending'){
                      walletController.setActionType("");
                    }else{
                      walletController.setActionType('pending');
                    }

                  },
                ),
                // CustomCheckBox(
                //   title:  'cancelled',
                //   value: walletController.transactionType=='cancelled',
                //   onClick: () {
                //     if(walletController.transactionType=='cancelled'){
                //       walletController.setTransactionType("");
                //     }else{
                //       walletController.setTransactionType('cancelled');
                //     }
                //
                //   },
                // ),


              ],),

              SizedBox(height: Dimensions.PADDING_SIZE_LARGE),

              Text('transaction_type'.tr, style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeLarge)),

              Row(crossAxisAlignment: CrossAxisAlignment.start,mainAxisAlignment: MainAxisAlignment.start,children: [
                CustomCheckBox(
                  title:  'membership',
                  value: walletController.transactionType=='membership',
                  onClick: () {
                    if(walletController.actionType=='membership'){
                      walletController.setTransactionType("");
                    }else{
                      walletController.setTransactionType('membership');
                    }

                  },
                ),

                CustomCheckBox(
                  title:  'recharge',
                  value: walletController.actionType=='recharge',
                  onClick: () {
                    if(walletController.actionType=='recharge'){
                      walletController.setTransactionType("");
                    }else{
                      walletController.setTransactionType('recharge');
                    }

                  },
                ),

              ],),

              SizedBox(height: Dimensions.PADDING_SIZE_SMALL),

              CustomButton(
                buttonText: 'apply_filters'.tr,
                onPressed: () {
                  walletController.setFilterApplied();
                  walletController.getUpiPaymentList();
                  Get.back();
                },
              ),

            ]),
          );
        }),
      ),
    );
  }
}

class WalletShimmer extends StatelessWidget {
  final WalletController walletController;
  WalletShimmer({@required this.walletController});

  @override
  Widget build(BuildContext context) {
    return GridView.builder(
      key: UniqueKey(),
      gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
        crossAxisSpacing: 50,
        mainAxisSpacing: ResponsiveHelper.isDesktop(context) ? Dimensions.PADDING_SIZE_LARGE : 0.1,
        childAspectRatio: ResponsiveHelper.isDesktop(context) ? 5 : 2.45,
        crossAxisCount: ResponsiveHelper.isMobile(context) ? 1 : 2,
      ),
      physics:  NeverScrollableScrollPhysics(),
      shrinkWrap:  true,
      itemCount: 10,
      padding: EdgeInsets.only(top: ResponsiveHelper.isDesktop(context) ? 28 : 25),
      itemBuilder: (context, index) {
        return Padding(
          padding: EdgeInsets.symmetric(vertical: Dimensions.PADDING_SIZE_SMALL),
          child: Shimmer(
            duration: Duration(seconds: 2),
            enabled: walletController.walletStatementData == null,
            child: Column(children: [
              Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Column(crossAxisAlignment: CrossAxisAlignment.start, children: [
                    Container(height: 10, width: 50, decoration: BoxDecoration(color: Colors.grey[300], borderRadius: BorderRadius.circular(2))),
                    SizedBox(height: 10),
                    Container(height: 10, width: 70, decoration: BoxDecoration(color: Colors.grey[300], borderRadius: BorderRadius.circular(2))),
                  ]),
                  Column(crossAxisAlignment: CrossAxisAlignment.end, children: [
                    Container(height: 10, width: 50, decoration: BoxDecoration(color: Colors.grey[300], borderRadius: BorderRadius.circular(2))),
                    SizedBox(height: 10),
                    Container(height: 10, width: 70, decoration: BoxDecoration(color: Colors.grey[300], borderRadius: BorderRadius.circular(2))),
                  ]),
                ],
              ),
              Padding(padding: const EdgeInsets.only(top: Dimensions.PADDING_SIZE_LARGE), child: Divider(color: Theme.of(context).disabledColor)),
            ],
            ),
          ),
        );
      },
    );
  }
}

class HistoryItem extends StatelessWidget {
  final int index;
  final UpiPaymentsListData data;
  const HistoryItem({Key key, @required this.index, @required this.data}) : super(key: key);


  @override
  Widget build(BuildContext context) {
    return Column(crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              //
              Row(children: [
                Text('${'transaction_id'.tr}: ',
                  style: robotoMedium.copyWith(color: Colors.black54,fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
                ),
                Text(data.trnNo.toString(),
                  style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
                ),
              ],),
              data.type!=null? Text(data.type.toString(),
                style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeDefault,color: data.type.toString()=="membership"?Colors.green:Colors.blue), maxLines: 1, overflow: TextOverflow.ellipsis,
              )
                  :SizedBox(),
            ],
          ),

          SizedBox(height: 5.0),
          Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,children: [
            Row(
              children: [
                Text('Order ID:',
                  style: robotoMedium.copyWith(color: Colors.black54,fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
                ),
                Text(data.orderId.toString(),
                  style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
                )
              ],
            ) ,
            Text(
                data.requestedDate==null?'':data.requestedDate
                ,style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall,color: Theme.of(context).disabledColor),
                maxLines: 1, overflow: TextOverflow.ellipsis),
          ],),

          SizedBox(height: data.upiNumber!=null? 5.0:0),

          data.upiNumber!=null? Row(
            children: [
              Text('UPI Number: ',
                style: robotoMedium.copyWith(color: Colors.black54,fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
              ),
              Text(data.upiNumber.toString(),
                style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
              ),

            ],
          )
              :SizedBox(),

          SizedBox(height: 5.0,),

          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Row(
                children: [
                  Text(
                    '${'payment_mode'.tr}:',
                    style: robotoMedium.copyWith(color: Colors.black54,fontSize: 12,),
                    textAlign: TextAlign.center,
                  ),
                  SizedBox(width: 5,),
                  Text(
                    '${data.paymentMode.toString()} | ${data.platform.toString()}',
                    style: robotoMedium.copyWith(fontSize: 12,),
                    textAlign: TextAlign.center,
                  ),
                ],
              ),
              Row(
                children: [
                  Text(
                    '${'status'.tr}:',
                    style: robotoMedium.copyWith(color: Colors.black54,fontSize: 12,),
                    textAlign: TextAlign.center,
                  ),
                  SizedBox(width: 5,),
                  Text(
                    '${data.status.toString()}',
                    style: robotoMedium.copyWith(fontSize: 12,color: (data.status!=null && data.status=='pending') ? Colors.orange : (data.status!=null && data.status=='approved')? Colors.green : (data.status!=null && data.status=='rejected')? Colors.red : Colors.black54),
                    textAlign: TextAlign.center,
                  ),
                ],
              ),
            ],
          ) ,
          SizedBox(height: 5.0,),
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              //
              Row(
                children: [
                  InkWell(child: Container(
                    padding: EdgeInsets.all(5.0),
                    color: Colors.black12,
                    child: Text(
                      'View Screenshot',
                      style: robotoMedium.copyWith(color: Colors.black87,fontSize: 12,),
                      textAlign: TextAlign.center,
                    ),
                  ),onTap: ()=>Get.toNamed(
                      RouteHelper.getUpiScreenshotImageScreenRoute(data.screenShot.toString()))
                    ,),

                ],
              ),
              InkWell(child: Container(
                padding: EdgeInsets.all(5.0),
                color: Colors.black12,
                child: Text(
                  'Action'.tr,
                  style: robotoMedium.copyWith(color:(data.status!=null && data.status=='rejected')?Colors.grey :Theme.of(context).primaryColor,fontSize: 12,),
                  textAlign: TextAlign.center,
                ),
              ),onTap: (){
                if(data.status!=null && data.status!='rejected'){
                  Get.bottomSheet(
                    UpiPaymentStatusBottomSheet(item: data,index:index),
                    backgroundColor: Colors.transparent, isScrollControlled: true,
                  );
                }

              }
                ,),

            ],
          ),
          SizedBox(height: data.remarks==null? 0.0 : 5.0,),
          data.remarks!=null? Text(data.remarks.toString(),
            style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall,color: Colors.grey), maxLines: 2, overflow: TextOverflow.ellipsis,
          )
              :SizedBox(),

        ]);
  }
}