
import 'package:sixam_mart/helper/responsive_helper.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/view/base/custom_button.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import '../../../controller/wallet_controller.dart';
import '../../../data/model/response/upi_payments_list_response.dart';
import '../../../util/app_constants.dart';
import '../../base/custom_snackbar.dart';
import '../../base/custom_text_field.dart';

class UpiPaymentStatusBottomSheet extends StatefulWidget {
  final UpiPaymentsListData item;
  final int index;

  UpiPaymentStatusBottomSheet({@required this.item,@required this.index,});

  @override
  State<UpiPaymentStatusBottomSheet> createState() => _UpiPaymentStatusBottomSheetState();
}

class _UpiPaymentStatusBottomSheetState extends State<UpiPaymentStatusBottomSheet> {
  final ScrollController scrollController = ScrollController();
  List<String> actions=[];
  final TextEditingController _remarksController = TextEditingController();
  @override
  void initState() {
    super.initState();
    actions.add('Approve');
    actions.add('Pending');
    actions.add('Reject');
    //actions.add('Cancel');
  }
  @override
  Widget build(BuildContext context) {
    bool _desktop = ResponsiveHelper.isDesktop(context);
    bool _isTab = ResponsiveHelper.isTab(context);
    bool _isWeb = ResponsiveHelper.isWeb();
    bool _isMobile = ResponsiveHelper.isMobile(context);
    double screenWidth = MediaQuery.of(context).size.width;
    return Container(
      width:  550,
      margin: EdgeInsets.only(top: _desktop ? 0 : 30),
      padding: EdgeInsets.only(left: Dimensions.PADDING_SIZE_DEFAULT, bottom: Dimensions.PADDING_SIZE_DEFAULT),
      decoration: BoxDecoration(
        color: Theme.of(context).cardColor,
        borderRadius: ResponsiveHelper.isMobile(context) ? BorderRadius.vertical(top: Radius.circular(Dimensions.RADIUS_EXTRA_LARGE))
            : BorderRadius.all(Radius.circular(Dimensions.RADIUS_EXTRA_LARGE)),
      ),
      child: GetBuilder<WalletController>(builder: (itemController) {
        return SingleChildScrollView(
          physics: NeverScrollableScrollPhysics(),
          child: Padding(
            padding: EdgeInsets.only(
              right: Dimensions.PADDING_SIZE_DEFAULT,
              top: ResponsiveHelper.isDesktop(context) ? Dimensions.PADDING_SIZE_DEFAULT : Dimensions.PADDING_SIZE_DEFAULT,
            ),
            child: Column(
                mainAxisAlignment: MainAxisAlignment.center, crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      SizedBox(),
                      InkWell(onTap: () => Get.back(), child: Padding(
                        padding:  EdgeInsets.only(right:_desktop? Dimensions.PADDING_SIZE_LARGE : Dimensions.PADDING_SIZE_EXTRA_SMALL),
                        child: Icon(Icons.close),
                      )),
                    ],
                  ),
                  DropdownButtonFormField<String>(
                    isExpanded: true,
                    decoration: AppConstants.dropDownDecoration(),
                    value: itemController.actionDropdownValue!=null?itemController.actionDropdownValue:actions[0],
                    onChanged: (String newValue) {
                      itemController.updateActionDropdown(newValue);
                    },
                    items:actions.map<DropdownMenuItem<String>>((String value) {
                      return DropdownMenuItem<String>(
                        value: value,
                        enabled:  true,
                        child: value==null ? SizedBox() : Text(value,style:TextStyle(fontSize: 15, color: Colors.black)),
                      );
                    }).toList(),
                  ),
                  SizedBox(height: 15,),
                  CustomTextField(
                    hintText: 'remark'.tr,
                    controller: _remarksController,
                    divider: false,
                    showTitle: true,
                    maxLines: 4
                    ,showBorderStyle: true,
                  ),
                  SizedBox(height: 15,),
                 itemController.isLoading? Center(child: CircularProgressIndicator(),): CustomButton(
                    width: ResponsiveHelper.isDesktop(context) ? MediaQuery.of(context).size.width / 2.0 : null,
                    buttonText: 'update'.tr,
                    onPressed:() {
                      var action='approved';

                      if(itemController.actionDropdownValue==null
                          || itemController.actionDropdownValue=='Approve'){
                        action='approved';
                      }else if(itemController.actionDropdownValue=='Pending'){
                        action='pending';
                      }else if(itemController.actionDropdownValue=='Reject'){
                        action='rejected';
                      }else if(itemController.actionDropdownValue=='Cancel'){
                        action='cancelled';
                      }

                      if(_remarksController.text.toString().isEmpty){
                        showCustomSnackBar('Please type remarks',isError: true);
                      }else{

                        itemController.updateUpiPaymentStatus(
                            id: widget.item.id.toString(),
                          action: action,
                          remarks: _remarksController.text.toString()

                        ).then((status) async {
                          if (status.isSuccess) {
                            Get.find<WalletController>().resetStatementFilter();
                            Get.find<WalletController>().getUpiPaymentList();
                             //Get.find<WalletController>().getUpiPaymentList();
                          }
                          Get.back();
                        });
                      }

                    },

                  )
                ]),
          ),
        );
      }),
    );
  }


}
