import 'package:sixam_mart/controller/cart_controller.dart';
import 'package:sixam_mart/controller/splash_controller.dart';
import 'package:sixam_mart/data/model/response/cart_model.dart';
import 'package:sixam_mart/data/model/response/item_model.dart';
import 'package:sixam_mart/helper/price_converter.dart';
import 'package:sixam_mart/helper/responsive_helper.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/styles.dart';
import 'package:sixam_mart/view/base/custom_image.dart';
import 'package:sixam_mart/view/base/item_bottom_sheet.dart';
import 'package:sixam_mart/view/base/quantity_button.dart';
import 'package:sixam_mart/view/base/rating_bar.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

import '../../../../util/app_constants.dart';
import '../../../base/cart_snackbar.dart';
import '../../../base/discount_tag.dart';
import '../../../base/mrp_and_save_view.dart';
import '../../../base/mrp_selling_diff_view.dart';

class CartItemWidget extends StatelessWidget {
  final Item itemToDeleteFromCart;
  final CartModel cart;
  final int cartIndex;
   // final List<AddOns> addOns;
  final bool isAvailable;
  final bool isStore;
  final bool isCampaign;
  CartItemWidget({this.itemToDeleteFromCart,@required this.isCampaign,@required this.isStore,@required this.cart, @required this.cartIndex, @required this.isAvailable});
  //CartItemWidget({@required this.cart, @required this.cartIndex, @required this.isAvailable, @required this.addOns});
  @override
  Widget build(BuildContext context) {
    double getStartingPrice(Item item) {
      double _startingPrice = 0;
      if (item.choiceOptions!=null && item.choiceOptions.length != 0) {
        List<double> _priceList = [];
        item.variations.forEach((variation) => _priceList.add(variation.price));
        _priceList.sort((a, b) => a.compareTo(b));
        _startingPrice = _priceList[0];
      } else {
        _startingPrice = item.price;
      }
      return _startingPrice;
    }

    double getDiscount(Item item) => item.discount==null?0 : item.discount;

    String getDiscountType(Item item) => item.storeDiscount == 0 ? item.discountType : 'percentage';

    double _discount;
    String _discountType;
    bool _isAvailable;


      _discount =(cart.item.discountRange!=null && cart.item.discountRange.isNotEmpty) ? cart.discountMask : (cart.item.storeDiscount == 0 || isCampaign) ? PriceConverter.discount(cart.item.price,cart.discountedPrice) : cart.item.storeDiscount;
     // _discount = (cart.item.storeDiscount == 0 || isCampaign) ? cart.item.discount : cart.item.storeDiscount;
      _discountType = (cart.item.discountRange!=null && cart.item.discountRange.isNotEmpty)?'percentage' : (cart.item.storeDiscount == 0 || isCampaign) ? cart.item.discountType : 'percentage';
      _isAvailable = (cart.item.stock>0 && cart.item.isInactive==0);

    String _addOnText = '';
    int _index = 0;
    List<int> _ids = [];
    List<int> _qtys = [];

    if(cart.addOnIds!=null){
      cart.addOnIds.forEach((addOn) {
        _ids.add(addOn.id);
        _qtys.add(addOn.quantity);
      });
    }
    if(cart.item.addOns!=null){
      cart.item.addOns.forEach((addOn) {
        if (_ids.contains(addOn.id)) {
          _addOnText = _addOnText + '${(_index == 0) ? '' : ',  '}${addOn.name} (${_qtys[_index]})';
          _index = _index + 1;
        }
      });
    }



    String _variationText = '';
    if(cart.variation!=null && cart.variation.length > 0) {
      List<String> _variationTypes = cart.variation[0].type.split('-');
      if(_variationTypes.length == cart.item.choiceOptions.length) {
        int _index = 0;
        cart.item.choiceOptions.forEach((choice) {
          _variationText = _variationText + '${(_index == 0) ? '' : ',  '}${choice.title} - ${_variationTypes[_index]}';
          _index = _index + 1;
        });
      }else {
        _variationText = cart.item.variations[0].type;
      }
    }

    //var saving=  AppConstants.saving(cart.item);
    var saving=  cart.discountAmount;

    return Padding(
      padding: EdgeInsets.only(bottom: Dimensions.PADDING_SIZE_DEFAULT),
      child: InkWell(
        onTap: () {
          ResponsiveHelper.isMobile(context) ? showModalBottomSheet(
            context: context,
            isScrollControlled: true,
            backgroundColor: Colors.transparent,
            builder: (con) => ItemBottomSheet(item: cart.item, cartIndex: cartIndex, cart: cart,fromCartPage: true,),
          ) : showDialog(context: context, builder: (con) => Dialog(
            child: ItemBottomSheet(item: cart.item, cartIndex: cartIndex, cart: cart,fromCartPage: true),
          ));
        },
        child: Container(
          decoration: BoxDecoration(color: Colors.red, borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL)),
          child: Stack(children: [
            Positioned(
              top: 0, bottom: 0, right: 0, left: 0,
              child: Icon(Icons.delete, color: Colors.white, size: 50),
            ),
            Dismissible(
              key: UniqueKey(),
              onDismissed: (DismissDirection direction) => Get.find<CartController>().removeFromCart(cartIndex),
              child: Container(
                padding: EdgeInsets.symmetric(vertical: Dimensions.PADDING_SIZE_EXTRA_SMALL, horizontal: Dimensions.PADDING_SIZE_SMALL),
                decoration: BoxDecoration(
                  color: Theme.of(context).cardColor,
                  borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
                  boxShadow: [BoxShadow(
                    color: Colors.grey[Get.isDarkMode ? 800 : 200],
                    blurRadius: 5, spreadRadius: 1,
                  )],
                ),
                child: Stack(children: [
                  Column(
                    children: [

                      Row(children: [
                        Stack(
                          children: [
                            ClipRRect(
                              borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
                              child: CustomImage(
                                image: '${Get.find<SplashController>().configModel.baseUrls.commonImageUrl}/${cart.item.image}',
                                height: 65, width: 70, fit: BoxFit.cover,
                              ),
                            ),
                            DiscountTag(
                              discount: _discount, discountType: _discountType,
                              inLeft: true,
                            ),

                            isAvailable ? SizedBox() : Positioned(
                              top: 0, left: 0, bottom: 0, right: 0,
                              child: Container(
                                alignment: Alignment.center,
                                decoration: BoxDecoration(borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL), color: Colors.black.withOpacity(0.6)),
                                child: Text('not_available_now_break'.tr, textAlign: TextAlign.center, style: robotoRegular.copyWith(
                                  color: Colors.white, fontSize: 8,
                                )),
                              ),
                            ),


                          ],
                        ),
                        SizedBox(width: Dimensions.PADDING_SIZE_SMALL),

                        Expanded(
                          child: Column(crossAxisAlignment: CrossAxisAlignment.start, mainAxisAlignment: MainAxisAlignment.center, children: [

                            Text(
                              cart.item.name??'',
                              style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeSmall),
                              maxLines: 2, overflow: TextOverflow.ellipsis,
                            ),

                            // RatingBar(rating: cart.item.avgRating, size: 12, ratingCount: cart.item.ratingCount),
                            SizedBox(height: 5),
                            Text(
                              PriceConverter.convertPrice(cart.discountedPrice),
                              style: robotoMedium.copyWith(color: Theme.of(context).primaryColor,fontSize: Dimensions.fontSizeSmall),
                            ),

                            SizedBox(height: getDiscount(cart.item) > 0  ? Dimensions.PADDING_SIZE_EXTRA_SMALL : 0),

                            getDiscount(cart.item) > 0  ?

                            MrpAndSaveView(mrpFontSize: 8, saveFontSize: Dimensions.fontSizeExtraSmall,
                              saving: saving, startingPrice: getStartingPrice(cart.item),)
                                : MrpSellingDiffView(mrp: cart.item.mrp,price: cart.item.price,),
                          ]),
                        ),

                        Column(mainAxisAlignment: MainAxisAlignment.center, children: [
                          ((Get.find<SplashController>().configModel.moduleConfig.module.unit && cart.item.unitType != null)
                              || (Get.find<SplashController>().configModel.moduleConfig.module.vegNonVeg && Get.find<SplashController>().configModel.toggleVegNonVeg)) ? Container(
                            padding: EdgeInsets.symmetric(vertical: Dimensions.PADDING_SIZE_EXTRA_SMALL, horizontal: Dimensions.PADDING_SIZE_SMALL),
                            decoration: BoxDecoration(
                              borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
                              color: Theme.of(context).primaryColor,
                            ),
                            child: Text(
                              Get.find<SplashController>().configModel.moduleConfig.module.unit ? cart.item.unitType ?? ''
                                  : cart.item.veg == 0 ? 'non_veg'.tr : 'veg'.tr,
                              style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeExtraSmall, color: Colors.white),
                            ),
                          ) : SizedBox(),
                          SizedBox(height: Get.find<SplashController>().configModel.toggleVegNonVeg ? Dimensions.PADDING_SIZE_EXTRA_SMALL : 0),

                          // Container(
                          //   decoration: BoxDecoration(
                          //     color: Colors.purple,
                          //     // backgroundBlendMode: BlendMode.darken,
                          //     borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),),
                          //   child: Padding(
                          //     padding:  EdgeInsets.symmetric(vertical: 4,horizontal: 7),
                          //     child: Container(
                          //       padding: EdgeInsets.only(left: 6,right: 6),
                          //       decoration: BoxDecoration(
                          //         color: Colors.purple,
                          //
                          //       ),
                          //       child: Text('${cart.quantity.toString()} Added', style: robotoRegular.copyWith(fontSize:
                          //       Dimensions.fontSizeSmall,color: Colors.white,),),
                          //
                          //     ),
                          //   ),
                          // ),
                          Row(children: [
                            QuantityButton(
                              onTap: () {
                                // if (cart.quantity > 1) {
                                //   Get.find<CartController>().setQuantity(false, cartIndex, cart.stock);
                                // }else {
                                  Get.find<CartController>().removeFromCart(cartIndex);
                                  showRemoveItemFromCartSnackBar(context);
                                //}
                              },
                              isIncrement: false,
                            ),
                            Text(cart.quantity.toString(), style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeExtraLarge)),
                            Container(
                              height: 22, width: 22,
                              margin: EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_SMALL),
                              decoration: BoxDecoration(
                                shape: BoxShape.circle,
                                border: Border.all(width: 1, color:  Theme.of(context).primaryColor ),
                                color: Theme.of(context).primaryColor ,
                              ),
                              alignment: Alignment.center,
                              child: Icon(
                                //isIncrement ? Icons.add : Icons.remove,
                                 Icons.add ,
                                size: 15,
                                color:  Theme.of(context).cardColor,
                              ),
                            )
                            // QuantityButton(
                            //   onTap: () => Get.find<CartController>().setQuantity(true, cartIndex, cart.stock),
                            //   isIncrement: true,
                            // ),
                          ]),
                        ]),

                        !ResponsiveHelper.isMobile(context) ? Padding(
                          padding: EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_SMALL),
                          child: IconButton(
                            onPressed: () {
                              Get.find<CartController>().removeFromCart(cartIndex);
                            },
                            icon: Icon(Icons.delete, color: Colors.red),
                          ),
                        ) : SizedBox(),

                      ]),

                      (Get.find<SplashController>().configModel.moduleConfig.module.addOn && _addOnText.isNotEmpty) ? Padding(
                        padding: EdgeInsets.only(top: Dimensions.PADDING_SIZE_EXTRA_SMALL),
                        child: Row(children: [
                          SizedBox(width: 80),
                          Text('${'addons'.tr}: ', style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeSmall)),
                          Flexible(child: Text(
                            _addOnText,
                            style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall, color: Theme.of(context).disabledColor),
                          )),
                        ]),
                      ) : SizedBox(),

                      // cart.item.variations.length > 0 ? Padding(
                      //   padding: EdgeInsets.only(top: Dimensions.PADDING_SIZE_EXTRA_SMALL),
                      //   child: Row(children: [
                      //     SizedBox(width: 80),
                      //     Text('${'variations'.tr}: ', style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeSmall)),
                      //     Flexible(child: Text(
                      //       _variationText,
                      //       style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall, color: Theme.of(context).disabledColor),
                      //     )),
                      //   ]),
                      // ) : SizedBox(),

                      /*addOns.length > 0 ? SizedBox(
                      height: 30,
                      child: ListView.builder(
                        scrollDirection: Axis.horizontal,
                        physics: BouncingScrollPhysics(),
                        padding: EdgeInsets.only(top: Dimensions.PADDING_SIZE_SMALL),
                        itemCount: addOns.length,
                        itemBuilder: (context, index) {
                          return Padding(
                            padding: EdgeInsets.only(right: Dimensions.PADDING_SIZE_SMALL),
                            child: Row(children: [
                              InkWell(
                                onTap: () {
                                  Get.find<CartController>().removeAddOn(cartIndex, index);
                                },
                                child: Padding(
                                  padding: EdgeInsets.symmetric(horizontal: 2),
                                  child: Icon(Icons.remove_circle, color: Theme.of(context).primaryColor, size: 18),
                                ),
                              ),
                              Text(addOns[index].name, style: robotoRegular.copyWith(fontSize: Dimensions.FONT_SIZE_EXTRA_SMALL)),
                              SizedBox(width: 2),
                              Text(
                                PriceConverter.convertPrice(addOns[index].price),
                                style: robotoMedium.copyWith(fontSize: Dimensions.FONT_SIZE_EXTRA_SMALL),
                              ),
                              SizedBox(width: 2),
                              Text(
                                '(${cart.addOnIds[index].quantity})',
                                style: robotoRegular.copyWith(fontSize: Dimensions.FONT_SIZE_EXTRA_SMALL),
                              ),
                            ]),
                          );
                        },
                      ),
                    ) : SizedBox(),*/

                    ],
                  ),
                  Container(color: Colors.grey,child: Row(children: [

                  ]),)
                ]),
              ),
            ),
          ]),
        ),
      ),
    );
  }
}
