import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:sixam_mart/controller/auth_controller.dart';
import 'package:sixam_mart/controller/splash_controller.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/images.dart';
import 'package:sixam_mart/view/base/custom_app_bar.dart';
import 'package:sixam_mart/view/base/custom_button.dart';
import 'package:sixam_mart/view/base/custom_snackbar.dart';
import 'package:sixam_mart/view/base/footer_view.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_drawer.dart';
import 'package:sixam_mart/view/base/not_logged_in_screen.dart';
import '../../../controller/prime_member_controller.dart';
import '../../../helper/route_helper.dart';
import '../../../util/app_constants.dart';
import '../../base/custom_image.dart';
import '../../base/custom_text_field.dart';
import '../bank_details/bank_details.dart';
import '../search/widget/custom_check_box.dart';
class PrimePaymentManuallyScreen extends StatefulWidget {
  final String orderId;
  final String mode;
  final String type;
  final bool fromWallet;
  PrimePaymentManuallyScreen({Key key, @required this.fromWallet, @required this.orderId, @required this.mode, @required this.type}) : super(key: key);

  @override
  State<PrimePaymentManuallyScreen> createState() => _PrimePaymentManuallyScreenState();
}

class _PrimePaymentManuallyScreenState extends State<PrimePaymentManuallyScreen> {
  bool _isLoggedIn;

  List<String> upiOptions=[];
  List<String> upiNumbers=[];
  final TextEditingController _remarksController = TextEditingController();
  final TextEditingController _transactionIdController = TextEditingController();
  @override
  void initState() {
    super.initState();

    _isLoggedIn = Get.find<AuthController>().isLoggedIn();

    for(String item in Get.find<SplashController>().configModel.upiPaymentNumber) {
      if(item!=null && item.length>5){
        upiNumbers.add(item);
      }
    }

   // upiNumbers.addAll(Get.find<SplashController>().configModel.upiPaymentNumber);


    upiOptions.add('select_platform'.tr);
    upiOptions.add('GPay');
    upiOptions.add('Paytm');
    upiOptions.add('PhonePe');
    upiOptions.add('BHIM');
    upiOptions.add('Amazon Pay');
    upiOptions.add('BHIM SBI Pay');
    upiOptions.add('Axis Pay');
    upiOptions.add('iMobile');
    upiOptions.add('MobiqKwik');
    upiOptions.add('CRED');
    upiOptions.add('Freecharge');
    upiOptions.add('Other');


  }


  @override
  Widget build(BuildContext context) {

    // bool _desktop = ResponsiveHelper.isDesktop(context);
    // bool _isTab = ResponsiveHelper.isTab(context);
    // bool _isWeb = ResponsiveHelper.isWeb();
    // bool _isMobile = ResponsiveHelper.isMobile(context);
    double screenWidth = MediaQuery.of(context).size.width;

    print("screenWidthTest  $screenWidth");
    return Scaffold(
      endDrawer: WebMenuDrawer(),
      appBar: CustomAppBar(title: widget.type=="membership"? 'prime_membership_payment'.tr: 'wallet_recharge'.tr,onBackPressed: (){
        Get.back();
      },),
      body: Center(
        child: _isLoggedIn ? SingleChildScrollView(
          child: FooterView(
            child: SizedBox(
              width: Dimensions.WEB_MAX_WIDTH,
              child: Padding(
                padding: const EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_SMALL),
                child:  GetBuilder<PrimeMemberController>(builder: (primeController) {
                  return Column( children: [

                    Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                       widget.mode=='qrCode'?

                       CustomImage(
                         image: '${Get.find<SplashController>().configModel.baseUrls.upiQrCodeImageUrl}',
                         // color: widget.isSelected ? widget.selectedColor : Colors.white30,
                         width: context.width, height: context.width*0.7,fit: BoxFit.contain,)
                  // Image.asset(Images.company_qrcode,width: context.width,
                  //        height: context.width*0.7,)
                        :  upiNumbers.length>0?
                       DropdownButtonFormField<String>(
                         isExpanded: true,
                         decoration: AppConstants.dropDownDecoration(),
                         value: primeController.upiNumberDropdownValue!=null?primeController.upiNumberDropdownValue:upiNumbers[0],
                         onChanged: (String newValue) {
                           primeController.updateUpiNumberDropdown(newValue);
                         },
                         items:upiNumbers.map<DropdownMenuItem<String>>((String value) {
                           return DropdownMenuItem<String>(
                             value: value,
                             enabled:  true,
                             child: value==null ? SizedBox() : Text(value,style:TextStyle(fontSize: 15, color: Colors.black)),
                           );
                         }).toList(),
                       )
                           :SizedBox(),
                        SizedBox(height: 15,),

                        DropdownButtonFormField<String>(
                          isExpanded: true,
                          decoration: AppConstants.dropDownDecoration(),
                          value: primeController.upiOptionDropdownValue!=null?primeController.upiOptionDropdownValue:upiOptions[0],
                          onChanged: (String newValue) {
                            primeController.updateUpiOptionDropdown(newValue);
                          },
                          items:upiOptions.map<DropdownMenuItem<String>>((String value) {
                            return DropdownMenuItem<String>(
                              value: value,
                              enabled:  true,
                              child: value==null ? SizedBox() : Text(value),
                            );
                          }).toList(),
                        ),
                        SizedBox(height: 15,),

                        Text('take_payment_screenshot_and_upload'.tr, style:TextStyle(fontSize: 15, color: Colors.black)),
                        SizedBox(height: 10,),
                        Stack(children: [

                          primeController.isUpiScreenshotImageLoading ? Container(color: Colors.grey,height: 140,width: double.infinity,child: Center(child: CircularProgressIndicator()),)

                              : ClipRRect(
                            borderRadius: BorderRadius.vertical(top: Radius.circular(Dimensions.RADIUS_SMALL)),
                            child: primeController.rawUpiScreenshotImageFile != null ?
                            Image.memory(
                              primeController.rawUpiScreenshotImageFile, height: 140, width: double.infinity, fit: BoxFit.cover,
                            )
                                : Image.asset(
                            Images.payment_screentshot, width: double.infinity, height: 140,fit: BoxFit.fill,
                  ),

                          ),

                          Positioned(
                            bottom: 10,
                            right: 10,
                            child: UploadImageWidget(onTap: () => primeController.pickUpiScreenshotImage()),
                          ),
                        ]),


                        SizedBox(height: 10,),
                        Row(
                          children: [
                            CustomCheckBox(
                              title: 'paid'.tr,
                              value: primeController.isPaymentSuccessful,
                              onClick: () => primeController.togglePayment(),
                            ),

                            CustomCheckBox(
                              title: 'failed'.tr,
                              value: primeController.isPaymentFailed,
                              onClick: () => primeController.togglePaymentFailed(),
                            ),
                          ],
                        ),
                        SizedBox(height: 15,),
                        CustomTextField(
                          hintText: 'transaction_id'.tr,
                          controller: _transactionIdController,
                          divider: false,
                          showTitle: true,
                          maxLines: 2
                          ,showBorderStyle: true,
                        ),
                        SizedBox(height: 15,),
                        CustomTextField(
                          hintText: 'remark'.tr,
                          controller: _remarksController,
                          divider: false,
                          showTitle: true,
                          maxLines: 4
                          ,showBorderStyle: true,
                        ),
                        SizedBox(height: 10,),

                        CustomButton(
                          buttonText: 'upload'.tr ,
                          onPressed: () {
                            print("upiNumberDropdownValue  = ${primeController.upiNumberDropdownValue}");

                             if( widget.mode!='qrCode' && (primeController.upiNumberDropdownValue==null)){
                              showCustomSnackBar('please_select_upi_number'.tr,isError: true);
                            }
                            else if(primeController.upiOptionDropdownValue==null || primeController.upiOptionDropdownValue=='select_platform'.tr){
                              showCustomSnackBar('please_select_platform'.tr,isError: true);
                            }else if(primeController.rawUpiScreenshotImageFile==null){
                               showCustomSnackBar('please_attach_payment_screenshot'.tr,isError: true);
                             }
                            else if(!primeController.isPaymentSuccessful){
                              showCustomSnackBar('please_check_payment_successful'.tr,isError: true);
                            }
                            else if(_transactionIdController.text.isEmpty){
                              showCustomSnackBar('please_enter_transaction_id'.tr,isError: true);
                            }else{
                              var upiNumber='';
                              if(widget.mode!='qrCode'){
                                upiNumber = primeController.upiNumberDropdownValue;
                              }
                              primeController.uploadUpiPaymentScreenshot(widget.orderId,_remarksController.text.toString(),upiNumber,widget.type,_transactionIdController.text.toString()).then((status) async {
                                if (status.isSuccess) {
                                  if(widget.type=="membership"){
                                    Get.offNamed(RouteHelper.getPrimeMembershipPaymentSuccessRoute('NA2'));

                                  }else{
                                    Get.offNamed(RouteHelper.getPrimeMembershipPaymentSuccessRoute('NA3'));

                                  }
                                }else{
                                  showCustomSnackBar(status.message,isError:true);
                                }
                              });
                            }
                          },
                          radius: Dimensions.RADIUS_SMALL, height: 50,
                        )
                      ],
                    ),

                  ]);
                }
                ),
              ),
            ),
          ),
        ) : NotLoggedInScreen(),
      ),
    );
  }
}
