import 'dart:async';

import 'package:sixam_mart/controller/order_controller.dart';
import 'package:sixam_mart/controller/splash_controller.dart';
import 'package:sixam_mart/controller/theme_controller.dart';
import 'package:sixam_mart/helper/responsive_helper.dart';
import 'package:sixam_mart/helper/route_helper.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/images.dart';
import 'package:sixam_mart/util/styles.dart';
import 'package:sixam_mart/view/base/custom_button.dart';
import 'package:sixam_mart/view/base/footer_view.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_drawer.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_bar.dart';
import 'package:sixam_mart/view/screens/checkout/widget/payment_failed_dialog.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

import '../../../../controller/prime_member_controller.dart';
import 'memership_payment_failed_dialog.dart';

class PrimeMembershipPaymentSuccessfulScreen extends StatefulWidget {
  final String orderID;
  PrimeMembershipPaymentSuccessfulScreen({@required this.orderID});

  @override
  State<PrimeMembershipPaymentSuccessfulScreen> createState() => _PrimeMembershipPaymentSuccessfulScreenState();
}

class _PrimeMembershipPaymentSuccessfulScreenState extends State<PrimeMembershipPaymentSuccessfulScreen> {

  @override
  void initState() {
    super.initState();

    if(widget.orderID!='NA' && widget.orderID!='NA2' && widget.orderID!='NA3')
    Get.find<PrimeMemberController>().trackPrimeOrder(widget.orderID.toString());
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: () async{
        await Get.offAllNamed(RouteHelper.getInitialRoute());
        return false;
      },
      child: Scaffold(
        backgroundColor: Theme.of(context).cardColor,
        appBar: ResponsiveHelper.isDesktop(context) ? WebMenuBar() : null,
        endDrawer: WebMenuDrawer(),
        body: GetBuilder<PrimeMemberController>(builder: (orderController){
          bool success = false;
          if(widget.orderID!='NA' && widget.orderID!='NA2' && widget.orderID!='NA3'){
            if(orderController != null && orderController.primePaymentTrackResponse != null
                && orderController.primePaymentTrackResponse.orderStatus != null) {
              success = orderController.primePaymentTrackResponse.orderStatus.toLowerCase()=="success";


              if (!success) {
                Future.delayed(Duration(seconds: 3), () {
                  Get.dialog(MembershipPaymentFailedDialog(orderID: widget.orderID,isFromWallet: false), barrierDismissible: false);
                });
              }
            }
          }

          //https://morioh.com/a/b075a0796dc3/a-flutter-library-to-help-you-create-animated-and-material-dialogs
          //https://iconscout.com/lottie-animations/congratulation
          return (orderController.primePaymentTrackResponse != null || widget.orderID=='NA' || widget.orderID=='NA2'|| widget.orderID=='NA3') ?

          Center(
            child: SingleChildScrollView(
              child: FooterView(child: SizedBox(width: Dimensions.WEB_MAX_WIDTH,
                  child: Column(mainAxisAlignment: MainAxisAlignment.center, children: [

                    Image.asset( success ? Images.checked : Images.warning, width: 100, height: 100),
                    SizedBox(height: Dimensions.PADDING_SIZE_LARGE),

                    Text(success ? widget.orderID=='NA3'?'wallet_recharge_successful'.tr : 'congratulations_enjoy_your_prime_benefits'.tr
                          : 'your_prime_member_request_is_failed'.tr,
                      style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeExtraLarge),
                    ),


                    (widget.orderID=='NA2' || widget.orderID=='NA3')? Padding(
                      padding: const EdgeInsets.all(8.0),
                      child: Text( widget.orderID=='NA2'? 'your_account_activation_will_be'.tr:'your_recharge_will_be'.tr,

                        style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeLarge,color: Theme.of(context).primaryColor),
                      ),
                    )
                        :SizedBox(),

                    SizedBox(height: 30),

                    Padding(
                      padding: EdgeInsets.all(Dimensions.PADDING_SIZE_SMALL),
                      child: CustomButton(buttonText: 'back_to_home'.tr, onPressed: () => Get.offAllNamed(RouteHelper.getInitialRoute())),
                    ),
                  ]))),
            ),
          )
              : Center(child: CircularProgressIndicator());
        }),
      ),
    );
  }
}
