import 'dart:async';

import 'package:sixam_mart/controller/order_controller.dart';
import 'package:sixam_mart/controller/splash_controller.dart';
import 'package:sixam_mart/controller/theme_controller.dart';
import 'package:sixam_mart/helper/responsive_helper.dart';
import 'package:sixam_mart/helper/route_helper.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/images.dart';
import 'package:sixam_mart/util/styles.dart';
import 'package:sixam_mart/view/base/custom_button.dart';
import 'package:sixam_mart/view/base/footer_view.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_drawer.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_bar.dart';
import 'package:sixam_mart/view/screens/checkout/widget/payment_failed_dialog.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

import '../../../../controller/prime_member_controller.dart';
import '../../../../controller/wallet_controller.dart';
import 'memership_payment_failed_dialog.dart';

class WalletRechargePaymentSuccessfulScreen extends StatefulWidget {
  final String orderID;
  WalletRechargePaymentSuccessfulScreen({@required this.orderID});

  @override
  State<WalletRechargePaymentSuccessfulScreen> createState() => _WalletRechargePaymentSuccessfulScreenState();
}

class _WalletRechargePaymentSuccessfulScreenState extends State<WalletRechargePaymentSuccessfulScreen> {

  @override
  void initState() {
    super.initState();

    Get.find<WalletController>().trackWalletRechargeOrder(widget.orderID.toString());

  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: () async{
        await Get.offAllNamed(RouteHelper.getInitialRoute());
        return false;
      },
      child: Scaffold(
        backgroundColor: Theme.of(context).cardColor,
        appBar: ResponsiveHelper.isDesktop(context) ? WebMenuBar() : null,
        endDrawer: WebMenuDrawer(),
        body: GetBuilder<WalletController>(builder: (orderController){
          bool success = false;

          if(orderController != null && orderController.walletPaymentTrackResponse != null
              && orderController.walletPaymentTrackResponse.orderStatus != null) {
            success = orderController.walletPaymentTrackResponse.orderStatus.toLowerCase()=="success";

            if (!success) {
              Future.delayed(Duration(seconds: 3), () {
                Get.dialog(MembershipPaymentFailedDialog(orderID: widget.orderID,isFromWallet: true), barrierDismissible: true);
              });
            }
          }

          return orderController.walletPaymentTrackResponse != null ?
          Center(
            child: SingleChildScrollView(
              child: FooterView(child: SizedBox(width: Dimensions.WEB_MAX_WIDTH,
                  child: Column(mainAxisAlignment: MainAxisAlignment.center, children: [

                    Image.asset( success ? Images.checked : Images.warning, width: 100, height: 100),
                    SizedBox(height: Dimensions.PADDING_SIZE_LARGE),

                    Center(
                      child: Text( success ? 'wallet_recharge_successful'.tr
                          : 'your_wallet_recharge_request_is_failed'.tr,
                        style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeLarge),
                      ),
                    ),

                    SizedBox(height: 30),

                    Padding(
                      padding: EdgeInsets.all(Dimensions.PADDING_SIZE_SMALL),
                      child: CustomButton(buttonText: 'back_to_home'.tr, onPressed: () => Get.offAllNamed(RouteHelper.getInitialRoute())),
                    ),
                  ]))),
            ),
          )
              : Center(child: CircularProgressIndicator());
        }),
      ),
    );
  }
}
