import 'package:sixam_mart/controller/splash_controller.dart';
import 'package:sixam_mart/helper/responsive_helper.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/view/base/custom_app_bar.dart';
import 'package:sixam_mart/view/base/custom_snackbar.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:url_launcher/url_launcher_string.dart';
import '../../../controller/auth_controller.dart';
import '../../../controller/prime_member_controller.dart';
import '../../../controller/user_controller.dart';
import '../../../data/model/response/FamilyMemberListResponseData.dart';
import '../../../data/model/response/response_model.dart';
import '../../../data/model/response/state_city_and_relation.dart';
import '../../../helper/route_helper.dart';
import '../../../util/app_constants.dart';
import '../../../util/styles.dart';
import '../../base/custom_button.dart';
import '../../base/custom_dialog.dart';
import '../../base/custom_image.dart';
import '../../base/custom_text_field.dart';
import '../../base/image_picker_widget.dart';


class AddFamilyMemberScreen extends StatefulWidget {

  final FamilyMemberData data;
  const AddFamilyMemberScreen({@required this.data});

  @override
  State<AddFamilyMemberScreen> createState() => _AddFamilyMemberScreenState();

}

class _AddFamilyMemberScreenState extends State<AddFamilyMemberScreen> {
  final FocusNode _mobileFocus = FocusNode();
  final FocusNode _aadharCardFocus = FocusNode();

  final TextEditingController _nameController = TextEditingController();
  final TextEditingController _mobileController = TextEditingController();
  final TextEditingController _aadharCardController = TextEditingController();


  bool _isLoggedIn;
  @override
  void initState() {
    super.initState();

    _isLoggedIn = Get.find<AuthController>().isLoggedIn();
    if(_isLoggedIn && Get.find<UserController>().userInfoModel == null) {
      Get.find<UserController>().getUserInfo();
    }
    Get.find<UserController>().initData();


  }


  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: CustomAppBar(title:widget.data==null? 'Add Family Member' :'Update Family Member'),

      body:  GetBuilder<PrimeMemberController>(builder: (primeController) {
        String _url = '${AppConstants.baseUrl}/public/uploads/primemebers/family_members';
        if(widget.data!=null && _nameController.text.isEmpty){
          _nameController.text = widget.data.name ?? '';
          _mobileController.text = widget.data.mobile ?? '';
          _aadharCardController.text = widget.data.aadharcardNo ?? '';
        }
        List<String> relationList = primeController.relationList;

        return Scrollbar(child: SingleChildScrollView(
          physics: BouncingScrollPhysics(),
          child: Container(
            width: context.width,
            color: Theme.of(context).cardColor,
            child: GetBuilder<PrimeMemberController>(builder: (primeMemberController) {

              return Column(children: [

                Container(
                  padding: EdgeInsets.all(8.0),
                  child: Column(crossAxisAlignment: CrossAxisAlignment.start,children: [

                    SizedBox(height: 15,),

                    ImagePickerWidget(
                      image: (widget.data==null || widget.data.image==null)? ''
                          : '$_url/${widget.data.image}',
                      height: 150,
                      onTap: () => primeController.pickUserImage(),
                      rawFile: primeController.rawUserImageFile,
                    ),

                    SizedBox(height: 15,),
                    CustomTextField(
                      hintText: 'Name',
                      controller: _nameController,
                      nextFocus: _mobileFocus,
                      inputType: TextInputType.name,
                      capitalization: TextCapitalization.words,
                      divider: false,
                      showTitle: true,
                      showBorderStyle: true,
                    ),
                    SizedBox(height: 15,),

                    CustomTextField(
                      hintText: 'Mobile',
                      controller: _mobileController,
                      focusNode: _mobileFocus,
                      inputType: TextInputType.phone,
                      nextFocus: _aadharCardFocus,
                      divider: false,
                      showTitle: true,
                      showBorderStyle: true,
                    ),


                    SizedBox(height: 15,),
                    Text('Relation', style: robotoRegular.copyWith(fontSize: 13)),


                    SizedBox(height: 10,),
                    (relationList==null || relationList.isEmpty)? SizedBox()
                        :  DropdownButtonFormField<String>(
                      decoration: AppConstants.dropDownDecoration(),
                      value: primeController.relationDropdownValue??relationList[0],
                      onChanged: (String newValue) {
                        primeController.updateRelationDropdown(newValue);
                      },
                      items:relationList.map<DropdownMenuItem<String>>((String value) {
                        return DropdownMenuItem<String>(
                          value: value,
                          child: Text(value==null?"" : value),
                        );
                      }).toList(),
                    ),


                    SizedBox(height: 15,),


                    CustomTextField(
                      hintText: 'Aadhar Card Number',
                      controller: _aadharCardController,
                      focusNode: _aadharCardFocus,
                      inputType: TextInputType.text,
                      capitalization: TextCapitalization.words,
                      divider: false,
                      showTitle: true,
                      showBorderStyle: true,
                    ),

                    SizedBox(height: 15,),
                    Text('Aadhar Card Image', style: robotoRegular.copyWith(fontSize: 13)),
                    SizedBox(height: 10,),
                    Stack(children: [
                      primeController.isAadharImageLoading ? Container(color: Colors.grey,height: 140,width: double.infinity,child: Center(child: CircularProgressIndicator()),) : ClipRRect(
                        borderRadius: BorderRadius.vertical(top: Radius.circular(Dimensions.RADIUS_SMALL)),
                        child: primeController.rawAadharImageFile != null ? Image.memory(
                          primeController.rawAadharImageFile, height: 140, width: double.infinity, fit: BoxFit.cover,
                        ) : CustomImage(
                          image: (widget.data==null || widget.data.aadharcardImage==null)? ''
                              : '$_url/${widget.data.aadharcardImage}',
                          height: 140, width: double.infinity, fit: BoxFit.cover,
                        ),
                      ),

                      Positioned(
                        bottom: 10,
                        right: 10,
                        child: UploadImageWidget(onTap: () => primeController.pickAadharImage()),
                      ),
                    ]),

                    SizedBox(height: 35,),

                    Center(
                      child: primeController.isAddFamilyLoading? CircularProgressIndicator() : ElevatedButton(
                          child: Padding(
                            padding: const EdgeInsets.all(8.0),
                            child: Text(
                                "Submit".toUpperCase(),
                                style: TextStyle(fontSize: 14)
                            ),
                          ),
                          style: ButtonStyle(
                              shape: MaterialStateProperty.all<RoundedRectangleBorder>(RoundedRectangleBorder(borderRadius: BorderRadius.circular(10.0),))
                          ),
                          onPressed: () {
                            _addUpdateFamilyMember(primeController);
                          }
                      ),
                    ),
                  ]),
                ),


                SizedBox(height: 10),


              ]);
            }),
          ),
        ));
      }),
    );
  }

  void _addUpdateFamilyMember(PrimeMemberController primeController) async {

    String _relation;
    if(primeController.relationDropdownValue!=null){
      _relation = primeController.relationDropdownValue;
    }


    String _name = _nameController.text.trim();
    String _mobile = _mobileController.text.trim();
    String _aadharCard = _aadharCardController.text.trim();



   if (_name.isEmpty) {
      showCustomSnackBar('Enter Name');
    }
    else if (_mobile.length<10) {
      showCustomSnackBar('Invalid Mobile');
    }

    else if (_relation==null ||_relation=='Select Relationship') {
      showCustomSnackBar('Select Member Relation');
    }
   else if (_aadharCard.isEmpty) {
     showCustomSnackBar('Enter Aadhar Card Number');
   }
   else if ((widget.data==null && primeController.rawAadharImageFile==null) || ((widget.data!=null && primeController.rawAadharImageFile==null && primeController.rawAadharImageFile==null)) ) {
     showCustomSnackBar('Select Aadhar Card Image');
   }

    else {

      if(widget.data==null){

        primeController.familyMemberCreateUpdate(_aadharCard,_mobile, _name,_relation,null).then((status) async {

          bool isError=true;

          if (status.isSuccess) {
            isError=false;
            Get.find<PrimeMemberController>().getFamilyMembersListData();
            Get.back();
          }
          showCustomSnackBar(status.message,isError: isError);
        });
      }else{
        primeController.familyMemberCreateUpdate(_aadharCard,_mobile, _name,_relation,widget.data.id.toString()).then((status) async {

          bool isError=true;

          if (status.isSuccess) {
            isError=false;
            Get.find<PrimeMemberController>().getFamilyMembersListData();
            Get.back();
          }
          showCustomSnackBar(status.message,isError: isError);
        });
      }

    }
  }
}





class UploadImageWidget extends StatelessWidget {
  final Function onTap;
  UploadImageWidget({ @required this.onTap});


  @override
  Widget build(BuildContext context) {
    return InkWell(onTap: onTap,child: Container(
      padding: EdgeInsets.symmetric(vertical: 2, horizontal: Dimensions.PADDING_SIZE_EXTRA_SMALL),
      decoration: BoxDecoration(
        color: Theme.of(context).cardColor.withOpacity(0.8),
        borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
      ),
      child: Icon(Icons.upload),
    ),);
  }
}

