import 'dart:async';
import 'dart:collection';
import 'dart:ui';

import 'package:share_plus/share_plus.dart';
import 'package:sixam_mart/controller/location_controller.dart';
import 'package:sixam_mart/controller/order_controller.dart';
import 'package:sixam_mart/controller/splash_controller.dart';
import 'package:sixam_mart/data/model/response/address_model.dart';
import 'package:sixam_mart/data/model/response/order_model.dart';
import 'package:sixam_mart/data/model/response/store_model.dart';
import 'package:sixam_mart/helper/responsive_helper.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/images.dart';
import 'package:sixam_mart/view/base/custom_app_bar.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:get/get.dart';
import 'package:google_maps_flutter/google_maps_flutter.dart';
import 'package:url_launcher/url_launcher_string.dart';

import '../../../controller/prime_member_controller.dart';
import '../../../controller/user_controller.dart';
import '../../../data/model/response/FamilyMemberListResponseData.dart';
import '../../../helper/date_converter.dart';
import '../../../helper/route_helper.dart';
import '../../../util/app_constants.dart';
import '../../../util/styles.dart';
import '../../base/confirmation_dialog.dart';
import '../../base/custom_image.dart';
import '../../base/custom_snackbar.dart';
import '../../base/custom_text_field.dart';


class TrackFamilyScreen extends StatefulWidget {

  @override
  State<TrackFamilyScreen> createState() => _TrackFamilyScreenState();
}

class _TrackFamilyScreenState extends State<TrackFamilyScreen> {

  bool isListSelected=true;
  double iconH=30;
  double iconH2=50;
  Completer<GoogleMapController> _controller = Completer();
  Iterable markers = [];

  Iterable _markers = Get.find<PrimeMemberController>().familyMembersList==null? []  : Iterable.generate(Get.find<PrimeMemberController>().familyMembersList.length, (index) {
    return Marker(
        markerId: MarkerId(Get.find<PrimeMemberController>().familyMembersList[index].name),
        position: LatLng(
            Get.find<PrimeMemberController>().familyMembersList[index].trackLastLocation==null? 28.984644 :
            double.parse(Get.find<PrimeMemberController>().familyMembersList[index].trackLastLocation.latitude),
          Get.find<PrimeMemberController>().familyMembersList[index].trackLastLocation==null? 77.705956 :
          double.parse(Get.find<PrimeMemberController>().familyMembersList[index].trackLastLocation.longitude),
        ),
        infoWindow: InfoWindow(title: "The Track")
    );
  });
  @override
  void initState() {
    super.initState();
    Get.find<PrimeMemberController>().getStateCityAndRelationData("Select Relation");
    Get.find<PrimeMemberController>().getFamilyMembersListData();
    Get.find<PrimeMemberController>().setGridView();
  }

  @override
  Widget build(BuildContext context) {
    var name ='${Get.find<UserController>().userInfoModel.fName} ${Get.find<UserController>().userInfoModel.lName}';
    var validUpto =Get.find<UserController>().userInfoModel.primeValidTo;
    var phone =Get.find<SplashController>().configModel.phone;
    return Scaffold(
      appBar: CustomAppBar(title: 'track'.tr),
      floatingActionButton: !isListSelected ? SizedBox(): Row(
        mainAxisAlignment: MainAxisAlignment.end,
        children: <Widget>[
          FloatingActionButton.extended(
            onPressed: () {
              goToAddFamilyMemberScreen(null);
              // _displayTextInputDialog(context);
            },
            label: const Text(''),
            icon: Image.asset(
              Images.add_family, width: iconH, height: iconH, fit: BoxFit.cover,
            ),
          ),
        ],
      ),
      body: GetBuilder<PrimeMemberController>(builder: (primeMemberController) {
        List<FamilyMemberData> familyMembersList = primeMemberController.familyMembersList;
        return Container(
          height: context.height,
          width: context.width,
          padding: EdgeInsets.only(left: 10,right: 10),
          child: SingleChildScrollView(physics: BouncingScrollPhysics(),
              child:Column(
                children: [
                  SizedBox(height: 20,),

                  Center(child: Text("Welcome $name",style:
                  robotoRegular.copyWith(fontSize: Dimensions.fontSizeExtraLarge,)),),
                  SizedBox(height: 15,),

                  Container(
                      color: Colors.grey.shade300,
                      child:Padding(
                        padding: const EdgeInsets.all(5.0),
                        child: Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,children: [
                          Image.asset(
                            Images.calander, width: iconH, height: iconH, fit: BoxFit.cover,
                          ),

                          Text('Licence(x) Upto ${validUpto??"xx-xx-xxxx"} ', style:
                          robotoRegular.copyWith(fontSize: Dimensions.fontSizeLarge,color:
                          Theme.of(context).primaryColor)),

                        ],),
                      )),

                  SizedBox(height: 10,),

                  InkWell(child: Container(
                      color: Colors.grey.shade300,
                      child:Padding(
                        padding: const EdgeInsets.all(5.0),
                        child: Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,children: [
                          Image.asset(
                            Images.call, width: iconH, height: iconH, fit: BoxFit.cover,
                          ),

                          Text('Urgent Call @  ${phone??""} ', style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeLarge,color: Theme.of(context).primaryColor)),

                        ],),
                      )),onTap: ()async {
                    if(await canLaunchUrlString('tel:$phone')) {
                      launchUrlString('tel:$phone');
                    }else {
                      showCustomSnackBar('${'can_not_launch'.tr} $phone');
                    }
                  },),

                  SizedBox(height: 10,),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.start,
                    children: [
                      SizedBox(width: 10,),

                      InkWell(child: Container(
                        color: primeMemberController.isListViewSelected? Colors.blue : Colors.blue[300],
                        padding: EdgeInsets.all(10),
                        child: Text("Map View",style:
                        robotoRegular.copyWith(fontSize: Dimensions.fontSizeExtraLarge,color:
                        Colors.white)),
                      ),onTap: (){
                        Get.toNamed(RouteHelper.getFamilyMapRoute());
                      },),
                      SizedBox(width: 10,),
                      InkWell(child: Container(
                        color: primeMemberController.isGridViewSelected? Colors.blue : Colors.blue[300],
                        padding: EdgeInsets.all(10),
                        child: Text("Card View",style:
                        robotoRegular.copyWith(fontSize: Dimensions.fontSizeExtraLarge,color:
                        Colors.white)),
                      ),onTap: ()=>primeMemberController.setGridView(),),





                    ],
                  ),

                  SizedBox(height: primeMemberController.isListViewSelected? 30 :0,),
                  primeMemberController.isListViewSelected ?
                  Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [

                      Image.asset(
                        Images.call, width: iconH2, height: iconH2, fit: BoxFit.cover,
                      ),
                      Image.asset(
                        Images.location_market, width: iconH2, height: iconH2, fit: BoxFit.cover,
                      ),

                      Image.asset(
                        Images.battery, width: iconH2, height: iconH2, fit: BoxFit.cover,
                      ),


                    ],
                  )
                      : SizedBox(),

                  SizedBox(height: 20,),
                  primeMemberController.isListViewSelected ?
                  Container(
                    padding: EdgeInsets.only(top: 10,bottom: 10,left: 5,right: 5),
                    color: Colors.green,
                    child: Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        Text('name'.tr, style: robotoRegular.copyWith(fontSize:
                        Dimensions.fontSizeExtraLarge,color: Colors.white)),

                        SizedBox(width: 10,),
                        Text("Last Update", style: robotoRegular.copyWith(fontSize:
                        Dimensions.fontSizeExtraLarge,color: Colors.white)),

                        SizedBox(width: 10,),
                        Flexible(child: Text('Address', style: robotoRegular.copyWith(fontSize:
                        Dimensions.fontSizeExtraLarge,color: Colors.white,))),


                      ],
                    ),
                  )
                      : SizedBox(),

                  // Row(
                  //   mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  //   crossAxisAlignment: CrossAxisAlignment.center,
                  //   children: [
                  //     InkWell(onTap: (){
                  //       setState(() {
                  //         isListSelected=false;
                  //       });
                  //     },child: Container(width: context.width*0.4,child: Center(child:  Text('Map', style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeExtraLarge,color: !isListSelected? Colors.black:Colors.grey)))),),
                  //
                  //     InkWell(onTap: (){
                  //       setState(() {
                  //         isListSelected=true;
                  //       });
                  //     },child: Container(width: context.width*0.4,child: Center(child:  Text('List', style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeExtraLarge,color: isListSelected? Colors.black:Colors.grey)))),),
                  //
                  //   ],),
                  // isListSelected ?



                  familyMembersList==null ? Center(child: CircularProgressIndicator(),)
                      : familyMembersList.isEmpty ? Container(
                    width: context.width,
                      height: context.height,
                      child: Center(child: Text("Please add your family member."),)) :

                  primeMemberController.isGridViewSelected ?  ListView.builder(
                    controller: ScrollController(),
                    physics: ClampingScrollPhysics(),
                    scrollDirection : Axis.vertical,
                    shrinkWrap : true,
                    padding: EdgeInsets.only(top:Dimensions.PADDING_SIZE_SMALL),
                    itemCount: familyMembersList.length,
                    itemBuilder: (context, index){
                      return Padding(
                        padding: EdgeInsets.only(bottom: 10,),
                        child:
                       // primeMemberController.isGridViewSelected ?
                        cardViewList(familyMembersList[index],index,context) ,
                            //: listView(familyMembersList[index],index,context),
                      );
                    },
                  ) :
                  GoogleMap(
                    mapType: MapType.normal,
                    initialCameraPosition: CameraPosition(target: LatLng(23.7985053,
                        90.3842538), zoom: 13),
                    onMapCreated: (GoogleMapController controller) {
                      _controller.complete(controller);
                    },
                    markers: Set.from(_markers),
                  )

                      //:Container(height: context.height,child:FamilyTrackingScreen(orderID: "100013",),),
                ],
              )),
        );
      }),
    );

  }
}

Widget cardViewList(FamilyMemberData  item, int index,BuildContext context) {

  var baseUrl='${AppConstants.baseUrl}/public/uploads/primemebers/family_members/';
  return Container(
    width: double.infinity,
    padding: const EdgeInsets.all(10),
    decoration: BoxDecoration(
      border: Border.all(color: Colors.black12),
        color: Colors.white,
        borderRadius: BorderRadius.circular(10)),
    child: Column(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [


            Row(crossAxisAlignment: CrossAxisAlignment.start,
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Row(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    ClipOval(child: CustomImage(
                      image: '$baseUrl${item.image}',
                      height: 40, width: 40, fit: BoxFit.cover,isProfile: true,
                    )),
                    SizedBox(width: 10,),
                    Column(
                      mainAxisAlignment: MainAxisAlignment.start,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        Text(' ${item.name}', style: robotoRegular.copyWith(fontSize:
                        Dimensions.fontSizeLarge,)),

                        SizedBox(height: 5,),

                        Row(
                          children: [
                            Text(' ${item.mobile}', style: robotoRegular.copyWith(fontSize:
                            Dimensions.fontSizeDefault,)),

                            SizedBox(width: 8,),

                            InkWell(child: Icon(Icons.call, color: Colors.blue, size: 20), onTap: ()
                            async {
                              if(await canLaunchUrlString('tel:${item.mobile}')) {
                                launchUrlString('tel:${item.mobile}');
                              }else {
                                showCustomSnackBar('${'can_not_launch'.tr} ${item.mobile}');
                              }
                            }),
                            SizedBox(width: 10,),
                            InkWell(child: Container(
                              height: 20, width: 20,
                              decoration: BoxDecoration(
                                shape: BoxShape.circle,
                                color: Colors.red.withOpacity(0.2),
                              ),
                              child: Image.asset(Images.whatsapp, width: 30,
                                height: 30,fit: BoxFit.fill,),
                            ), onTap: ()
                            async {
                              var whatsappUrl =
                                  "whatsapp://send?phone=${item.mobile}" ;
                              //  + "&text=${Uri.encodeComponent("hi")}";

                              if(await canLaunchUrlString(whatsappUrl)) {
                                launchUrlString(whatsappUrl);
                              }else {
                                showCustomSnackBar('${'can_not_launch'.tr} ${item.mobile}');
                              }
                            })
                          ],
                        ),

                        SizedBox(height: 5,),
                      ],
                    ),


                  ],
                ),

                Column(
                  children: [
                    InkWell(child: Container(
                      padding: EdgeInsets.fromLTRB(5, 5, 7, 7),
                      decoration: BoxDecoration(
                          border: Border.all(color: Colors.grey),
                          borderRadius: BorderRadius.circular(5)),
                      child: Text('Send Login Details', style: robotoRegular.copyWith(fontSize:
                      10,color: Colors.black)),
                    ),onTap: (){

                      var name = item.smsMessage.toString();
                      Share.share(name);

                    },),
                    SizedBox(height: 5,),
                    Text( '${item.status==0?'Inactive': 'Active'}', style:
                    robotoMedium.copyWith(fontSize
                        : Dimensions.fontSizeDefault,color: item.status==0?Colors.orange : Colors.green)),
                  ],
                ),
              ],
            ),

            SizedBox(height: 10,),
            item.trackLastLocation!=null ? Row(
              children: [
                Text('Current Location', style: robotoRegular.copyWith(fontSize:
                10,color: Colors.black)),
                SizedBox(width: 10,),

                InkWell(child: Container(
                  height: 15, width: 15,
                  decoration: BoxDecoration(
                    shape: BoxShape.circle,
                    color: Colors.blue.withOpacity(0.2),
                  ),
                  child: Image.asset(Images.location_market, width: 30,
                    height: 30,fit: BoxFit.fill,),
                ), onTap: ()
                async {}),
                SizedBox(width: 10,),

                Container(
                  padding: EdgeInsets.fromLTRB(5, 5, 7, 7),
                  decoration: BoxDecoration(
                      border: Border.all(color: Colors.green),
                      borderRadius: BorderRadius.circular(5)),

                  child: Text(DateConverter.dateTimeStringToDateTime(
                      DateConverter.isoStringToLocalString(
                          item.trackLastLocation.createdAt)), style: robotoRegular.copyWith(fontSize:
                  10,color: Colors.red)),
                )

              ],
            )
                :SizedBox(),

            SizedBox(height: 5,),
            item.trackLastLocation==null? SizedBox()
                : Text('${item.trackLastLocation.location}', style: robotoRegular.copyWith(fontSize:
            Dimensions.fontSizeSmall,color: Colors.black54)),

            SizedBox(height: 10,),
            Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Row(children: [

                  SizedBox(width: 10,),

                  Container(
                    padding: EdgeInsets.only(left: 8,right: 8,bottom: 8,top: 5),
                    decoration: BoxDecoration(
                      color: Colors.white,
                        border: Border.all(color: Colors.grey.shade200),
                        borderRadius: BorderRadius.circular(5)),
                    child: Column(
                      children: [
                        InkWell(onTap: (){
                          goToAddFamilyMemberScreen(item);
                        },
                          child: Icon(
                            Icons.edit,
                            size: 20,
                            color:  Colors.black54,
                          ),),

                        SizedBox(height: 5,),

                        Text('Edit'.tr, style: robotoRegular.copyWith(fontSize:
                        Dimensions.fontSizeDefault,)),
                      ],
                    ),
                  ),

                  SizedBox(width: 10,),
                  InkWell(child: Container(
                    padding: EdgeInsets.only(left: 8,right: 8,bottom: 8,top: 5),
                    decoration: BoxDecoration(
                        color: Colors.white,
                        border: Border.all(color: Colors.grey.shade200),
                        borderRadius: BorderRadius.circular(5)),
                    child: Column(
                      children: [
                        Icon(
                          Icons.delete_outline,
                          size: 20,
                          color:  Colors.black54,
                        ),

                        SizedBox(height: 5,),

                        Text('Delete'.tr, style: robotoRegular.copyWith(fontSize:
                        Dimensions.fontSizeDefault,)),
                      ],
                    ),
                  ),onTap: (){
                    deleteFamilyMemberPopup(item.id.toString(),item.name.toString(),index);

                  },),

                  SizedBox(width: 10,),
                  InkWell(child: Container(
                    padding: EdgeInsets.only(left: 8,right: 8,bottom: 8,top: 5),
                    decoration: BoxDecoration(
                        color: Colors.white,
                        border: Border.all(color: Colors.grey.shade200),
                        borderRadius: BorderRadius.circular(5)),
                    child: Column(
                      children: [
                        Icon(
                          Icons.location_on_outlined,
                          size: 20,
                          color:  Colors.black54,
                        ),

                        SizedBox(height: 5,),

                        Text('Location', style: robotoRegular.copyWith(fontSize:
                        Dimensions.fontSizeDefault,)),
                      ],
                    ),
                  ),onTap: (){
                    Get.toNamed(RouteHelper.getFamilyMapRoute());
                  },),

                  SizedBox(width: 20,),

                  (item.trackLastLocation!=null)?  Column(
                    children: [
                      Text('${item.trackLastLocation.batteryStatus} %', style: robotoRegular.copyWith(fontSize:
                      Dimensions.fontSizeDefault,)),

                      SizedBox(width: 8,),

                      int.parse(item.trackLastLocation.batteryStatus)>15 ?
                      Image.asset(Images.battery, width: 25,
                        height: 32,fit: BoxFit.fill,)
                          :  Image.asset(Images.battery_discharge, width: 25,
                        height: 32,fit: BoxFit.fill,),

                    ],
                  )
                      : SizedBox(),
                ],),


              ],
            ),



          ],
        ), // Adds a price to the bottom of the card
      ],
    ),
  );
}
Widget listView(FamilyMemberData  item, int index,BuildContext context) {

  return Container(
    width: context.width,
    color: Colors.grey.shade200,

    child: Padding(
      padding: const EdgeInsets.only(top: 10,bottom: 10),
      child: Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Text(item.name, style: robotoRegular.copyWith(fontSize:
          Dimensions.fontSizeDefault,)),

          SizedBox(width: 10,),
          Text("14-01-2024", style: robotoRegular.copyWith(fontSize:
          Dimensions.fontSizeDefault,color: Colors.black87)),

          SizedBox(width: 10,),
          Flexible(child: Text("Mirpur Hindu,Loni", style: robotoRegular.copyWith(fontSize:
          Dimensions.fontSizeDefault,))),


        ],
      ),
    ),
  );
}

Future<void> deleteFamilyMemberPopup(String memberId,String name,int index) async {

  Get.dialog(ConfirmationDialog(
    icon: Images.warning, title:  'are_you_sure_to_delete_member'.tr ,
    description: name,
    onYesPressed: () async {

      Get.back();
      Get.find<PrimeMemberController>().familyMemberDelete(memberId,index);

    },
  ));

}



class FamilyTrackingScreen extends StatefulWidget {

  @override
  _FamilyTrackingScreenState createState() => _FamilyTrackingScreenState();
}

class _FamilyTrackingScreenState extends State<FamilyTrackingScreen> {
  GoogleMapController _controller;
  bool _isLoading = true;
  Set<Marker> _markers = HashSet<Marker>();
  Timer _timer;

  void _loadData() async {
    await Get.find<LocationController>().getCurrentLocation(true, notify: false, defaultLatLng: LatLng(
      double.parse(Get.find<LocationController>().getUserAddress().latitude),
      double.parse(Get.find<LocationController>().getUserAddress().longitude),
    ));
  }

  void _startApiCall(){
    _timer = Timer.periodic(Duration(seconds: 10), (timer) {
    });
  }

  @override
  void initState() {
    super.initState();

    _loadData();
    _startApiCall();
  }

  @override
  void dispose() {
    super.dispose();
    _controller?.dispose();
    _timer?.cancel();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(

      body: GetBuilder<OrderController>(builder: (orderController) {
        OrderModel _track;
        if(orderController.trackModel != null) {
          _track = orderController.trackModel;

          /*if(_controller != null && GetPlatform.isWeb) {
            if(_track.deliveryAddress != null) {
              _controller.showMarkerInfoWindow(MarkerId('destination'));
            }
            if(_track.store != null) {
              _controller.showMarkerInfoWindow(MarkerId('store'));
            }
            if(_track.deliveryMan != null) {
              _controller.showMarkerInfoWindow(MarkerId('delivery_boy'));
            }
          }*/
        }

        return _track != null ? Center(child: SizedBox(width: Dimensions.WEB_MAX_WIDTH, child: Stack(children: [

          GoogleMap(
            initialCameraPosition: CameraPosition(target: LatLng(
              double.parse(_track.deliveryAddress.latitude), double.parse(_track.deliveryAddress.longitude),
            ), zoom: 16),
            minMaxZoomPreference: MinMaxZoomPreference(0, 16),
            zoomControlsEnabled: true,
            markers: _markers,
            onMapCreated: (GoogleMapController controller) {
              _controller = controller;
              _isLoading = false;
              setMarker(
                _track.store, _track.deliveryMan ?? DeliveryMan(location: ''),
                _track.orderType == 'take_away' ? Get.find<LocationController>().position.latitude == 0 ? _track.deliveryAddress : AddressModel(
                  latitude: Get.find<LocationController>().position.latitude.toString(),
                  longitude: Get.find<LocationController>().position.longitude.toString(),
                  address: Get.find<LocationController>().address,
                ) : _track.deliveryAddress,
                _track.orderType == 'take_away',
              );
            },
          ),

          _isLoading ? Center(child: CircularProgressIndicator()) : SizedBox(),

        ]))) : Center(child: CircularProgressIndicator());
      }),
    );
  }

  void setMarker(Store store, DeliveryMan deliveryMan, AddressModel addressModel, bool takeAway) async {
    try {
      Uint8List restaurantImageData = await convertAssetToUnit8List(Images.restaurant_marker, width: 100);
      Uint8List deliveryBoyImageData = await convertAssetToUnit8List(Images.delivery_man_marker, width: 100);
      Uint8List destinationImageData = await convertAssetToUnit8List(
        takeAway ? Images.my_location_marker : Images.user_marker,
        width: takeAway ? 50 : 100,
      );

      // Animate to coordinate
      LatLngBounds bounds;
      double _rotation = 0;
      if(_controller != null) {
        if (double.parse(addressModel.latitude) < double.parse(store.latitude)) {
          bounds = LatLngBounds(
            southwest: LatLng(double.parse(addressModel.latitude), double.parse(addressModel.longitude)),
            northeast: LatLng(double.parse(store.latitude), double.parse(store.longitude)),
          );
          _rotation = 0;
        }else {
          bounds = LatLngBounds(
            southwest: LatLng(double.parse(store.latitude), double.parse(store.longitude)),
            northeast: LatLng(double.parse(addressModel.latitude), double.parse(addressModel.longitude)),
          );
          _rotation = 180;
        }
      }
      LatLng centerBounds = LatLng(
        (bounds.northeast.latitude + bounds.southwest.latitude)/2,
        (bounds.northeast.longitude + bounds.southwest.longitude)/2,
      );

      _controller.moveCamera(CameraUpdate.newCameraPosition(CameraPosition(target: centerBounds, zoom: GetPlatform.isWeb ? 10 : 17)));
      if(!ResponsiveHelper.isWeb()) {
        zoomToFit(_controller, bounds, centerBounds, padding: 1.5);
      }

      // Marker
      _markers = HashSet<Marker>();
      addressModel != null ? _markers.add(Marker(
        markerId: MarkerId('destination'),
        position: LatLng(double.parse(addressModel.latitude), double.parse(addressModel.longitude)),
        infoWindow: InfoWindow(
          title: 'Destination',
          snippet: addressModel.address,
        ),
        icon: GetPlatform.isWeb ? BitmapDescriptor.defaultMarker : BitmapDescriptor.fromBytes(destinationImageData),
      )) : SizedBox();

      store != null ? _markers.add(Marker(
        markerId: MarkerId('store'),
        position: LatLng(double.parse(store.latitude), double.parse(store.longitude)),
        infoWindow: InfoWindow(
          title: Get.find<SplashController>().configModel.moduleConfig.module.showRestaurantText ? 'store'.tr : 'store'.tr,
          snippet: store.address,
        ),
        icon: GetPlatform.isWeb ? BitmapDescriptor.defaultMarker : BitmapDescriptor.fromBytes(restaurantImageData),
      )) : SizedBox();

      deliveryMan != null ? _markers.add(Marker(
        markerId: MarkerId('delivery_boy'),
        position: LatLng(double.parse(deliveryMan.lat ?? '0'), double.parse(deliveryMan.lng ?? '0')),
        infoWindow: InfoWindow(
          title: 'delivery_man'.tr,
          snippet: deliveryMan.location,
        ),
        rotation: _rotation,
        icon: GetPlatform.isWeb ? BitmapDescriptor.defaultMarker : BitmapDescriptor.fromBytes(deliveryBoyImageData),
      )) : SizedBox();
    }catch(e) {}
    setState(() {});
  }

  Future<void> zoomToFit(GoogleMapController controller, LatLngBounds bounds, LatLng centerBounds, {double padding = 0.5}) async {
    bool keepZoomingOut = true;

    while(keepZoomingOut) {
      final LatLngBounds screenBounds = await controller.getVisibleRegion();
      if(fits(bounds, screenBounds)){
        keepZoomingOut = false;
        final double zoomLevel = await controller.getZoomLevel() - padding;
        controller.moveCamera(CameraUpdate.newCameraPosition(CameraPosition(
          target: centerBounds,
          zoom: zoomLevel,
        )));
        break;
      }
      else {
        // Zooming out by 0.1 zoom level per iteration
        final double zoomLevel = await controller.getZoomLevel() - 0.1;
        controller.moveCamera(CameraUpdate.newCameraPosition(CameraPosition(
          target: centerBounds,
          zoom: zoomLevel,
        )));
      }
    }
  }

  bool fits(LatLngBounds fitBounds, LatLngBounds screenBounds) {
    final bool northEastLatitudeCheck = screenBounds.northeast.latitude >= fitBounds.northeast.latitude;
    final bool northEastLongitudeCheck = screenBounds.northeast.longitude >= fitBounds.northeast.longitude;

    final bool southWestLatitudeCheck = screenBounds.southwest.latitude <= fitBounds.southwest.latitude;
    final bool southWestLongitudeCheck = screenBounds.southwest.longitude <= fitBounds.southwest.longitude;

    return northEastLatitudeCheck && northEastLongitudeCheck && southWestLatitudeCheck && southWestLongitudeCheck;
  }

  Future<Uint8List> convertAssetToUnit8List(String imagePath, {int width = 50}) async {
    ByteData data = await rootBundle.load(imagePath);
    Codec codec = await instantiateImageCodec(data.buffer.asUint8List(), targetWidth: width);
    FrameInfo fi = await codec.getNextFrame();
    return (await fi.image.toByteData(format: ImageByteFormat.png)).buffer.asUint8List();
  }
}
void goToAddFamilyMemberScreen(FamilyMemberData data){
  Get.toNamed(RouteHelper.getAddFamilyMemberRoute(data));
}

