import 'package:sixam_mart/controller/category_controller.dart';
import 'package:sixam_mart/controller/splash_controller.dart';
import 'package:sixam_mart/helper/route_helper.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/styles.dart';
import 'package:sixam_mart/view/base/custom_image.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:shimmer_animation/shimmer_animation.dart';

import '../../../base/categories_widget.dart';

class WebCategoryViewGrid extends StatelessWidget {
  final CategoryController catController;
  WebCategoryViewGrid({@required this.catController});

  @override
  Widget build(BuildContext context) {
    return Container(
      width: context.width,
      child: Column(mainAxisAlignment: MainAxisAlignment.start,crossAxisAlignment: CrossAxisAlignment.start, children: [
        Padding(
          padding: EdgeInsets.only(top: Dimensions.PADDING_SIZE_SMALL, left: Dimensions.PADDING_SIZE_EXTRA_SMALL),
          child: Text('categories'.tr, style: robotoMedium.copyWith(fontSize: 24)),
        ),
        SizedBox(height: Dimensions.PADDING_SIZE_DEFAULT),

        catController.categoryList != null ? GridView.builder(
          gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
            crossAxisCount: 5, childAspectRatio:  (1/1.3),
            mainAxisSpacing: Dimensions.PADDING_SIZE_LARGE,
            crossAxisSpacing: Dimensions.PADDING_SIZE_LARGE,
          ),
          itemCount: catController.categoryList.length,
          shrinkWrap: true, physics: NeverScrollableScrollPhysics(),
          padding: EdgeInsets.all(Dimensions.PADDING_SIZE_LARGE),
          itemBuilder: (context, index) {

            return InkWell(
              onTap: (){
                Get.toNamed(RouteHelper.getCategoryItemRoute(catController.categoryList[index].id, catController.categoryList[index].parentId,catController.categoryList[index].name));
              },
              child: CategoriesWidget(
                isBrand: false,
                brandItem: null,
                catItem: catController.categoryList[index],
                index: index,
                length: catController.categoryList.length,
              ),
            );
            // if(index == 10) {
            //   return InkWell(
            //     onTap: () => Get.toNamed(RouteHelper.getCategoryRoute()),
            //     child: Container(
            //       padding: EdgeInsets.all(Dimensions.PADDING_SIZE_EXTRA_SMALL),
            //       color: Theme.of(context).primaryColor.withOpacity(0.1),
            //       margin: EdgeInsets.only(bottom: Dimensions.PADDING_SIZE_SMALL),
            //       child: Column(mainAxisAlignment: MainAxisAlignment.center,crossAxisAlignment: CrossAxisAlignment.center,children: [
            //         Container(
            //           height: 55, width: 55,
            //           decoration: BoxDecoration(
            //             borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
            //             color: Theme.of(context).primaryColor,
            //           ),
            //           child: Icon(Icons.arrow_downward, color: Theme.of(context).cardColor),
            //         ),
            //         SizedBox(width: Dimensions.PADDING_SIZE_SMALL),
            //
            //         Text(
            //           'view_all'.tr,
            //           style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeSmall),
            //           maxLines: 2, overflow: TextOverflow.ellipsis,
            //         ),
            //       ], ),
            //     ),
            //   );
            // }
            //
            // return InkWell(
            //   onTap: () => Get.toNamed(RouteHelper.getCategoryItemRoute(
            //     categoryController.categoryList[index].id, categoryController.categoryList[index].parentId,categoryController.categoryList[index].name
            //   )),
            //   child: Container(
            //     decoration: BoxDecoration(
            //       borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
            //       color: Theme.of(context).primaryColor.withOpacity(0.1),
            //     ),
            //
            //     margin: EdgeInsets.only(bottom: Dimensions.PADDING_SIZE_SMALL),
            //     child: Column( mainAxisAlignment: MainAxisAlignment.start,crossAxisAlignment: CrossAxisAlignment.center,children: [
            //
            //       CustomImage(
            //         image: '${Get.find<SplashController>().configModel.baseUrls.categoryImageUrl}/${categoryController.categoryList[index].image}',
            //         height: 85, width: context.width, fit: BoxFit.cover,
            //       ),
            //       SizedBox(height: Dimensions.PADDING_SIZE_DEFAULT),
            //
            //       Center(
            //         child: Expanded(child: Text(
            //           categoryController.categoryList[index].name,
            //           style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeSmall),
            //           maxLines: 2, overflow: TextOverflow.ellipsis,
            //         )),
            //       ),
            //
            //     ]),
            //   ),
            // );
          },
        ) :
        WebCategoryShimmer(categoryController: catController),

      ]),
    );
  }
}

class WebCategoryShimmer extends StatelessWidget {
  final CategoryController categoryController;
  WebCategoryShimmer({@required this.categoryController});

  @override
  Widget build(BuildContext context) {
    return ListView.builder(
      physics: NeverScrollableScrollPhysics(),
      shrinkWrap: true,
      itemCount: 5,
      itemBuilder: (context, index) {
        return Container(
          padding: EdgeInsets.all(Dimensions.PADDING_SIZE_EXTRA_SMALL),
          color: Theme.of(context).primaryColor.withOpacity(0.1),
          margin: EdgeInsets.only(bottom: Dimensions.PADDING_SIZE_SMALL),
          child: Shimmer(
            duration: Duration(seconds: 2),
            enabled: categoryController.categoryList == null,
            child: Row(children: [

              Container(
                decoration: BoxDecoration(borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL), color: Colors.grey[300]),
                height: 65, width: 70,
              ),
              SizedBox(width: Dimensions.PADDING_SIZE_SMALL),

              Container(height: 15, width: 150, color: Colors.grey[300]),

            ]),
          ),
        );
      },
    );
  }
}

