import 'package:sixam_mart/controller/category_controller.dart';
import 'package:sixam_mart/controller/splash_controller.dart';
import 'package:sixam_mart/helper/responsive_helper.dart';
import 'package:sixam_mart/helper/route_helper.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/styles.dart';
import 'package:sixam_mart/view/base/custom_app_bar.dart';
import 'package:sixam_mart/view/base/custom_image.dart';
import 'package:sixam_mart/view/base/footer_view.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_drawer.dart';
import 'package:sixam_mart/view/base/no_data_screen.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:sixam_mart/view/base/categories_shimmer.dart';

import '../../../../controller/brand_controller_sonu.dart';
import '../../../../data/model/response/brand_model.dart';
import '../../../../util/app_constants.dart';
import '../../../base/categories_widget.dart';

class AllBrandScreenSonu extends StatefulWidget {
  final String title;
  AllBrandScreenSonu({@required this.title});
  @override
  State<AllBrandScreenSonu> createState() => _AllBrandScreenSonuState();
}

class _AllBrandScreenSonuState extends State<AllBrandScreenSonu> {
  @override
  Widget build(BuildContext context) {
    bool _desktop = ResponsiveHelper.isDesktop(context);
    bool _isTab = ResponsiveHelper.isTab(context);
    bool _isWeb = ResponsiveHelper.isWeb();
    bool _isMobile = ResponsiveHelper.isMobile(context);

    double _width = MediaQuery.of(context).size.width;
    print("testResponsiveHelper AllBrandScreenSonu _desktop $_desktop _isTab $_isTab isWeb $_isWeb _isMobile $_isMobile");

    Get.find<BrandController>().getFeaturedBrandItemList(0,true,type: AppConstants.ALL);
    return Scaffold(
      appBar: CustomAppBar(title: widget.title),
      endDrawer: WebMenuDrawer(),
      body: SafeArea(child: Scrollbar(child: SingleChildScrollView(child: FooterView(child: SizedBox(
        width: _desktop? _width : Dimensions.WEB_MAX_WIDTH,
        child: GetBuilder<BrandController>(builder: (brandController) {
          List<Brands> brandList = brandController.allBrandsList;

          return brandList != null ? brandList.length > 0 ? GridView.builder(
            physics: NeverScrollableScrollPhysics(),
            shrinkWrap: true,
            gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
              crossAxisCount: _desktop ? 6 : _isTab ? 4 : 2
              , mainAxisSpacing: ( _desktop || _isTab )? Dimensions.PADDING_SIZE_LARGE:  Dimensions.PADDING_SIZE_DEFAULT,
              crossAxisSpacing:( _desktop || _isTab ) ? Dimensions.PADDING_SIZE_LARGE : Dimensions.PADDING_SIZE_DEFAULT
              , childAspectRatio: _desktop ? (1/1.4) :_isTab? (1/1.2) : (1/1.3),
            ),
            padding: EdgeInsets.all(Dimensions.PADDING_SIZE_SMALL),
            itemCount: brandList.length,
            itemBuilder: (context, index) {
              return InkWell(
                onTap: () =>Get.toNamed(RouteHelper.getBrandItemRoute(
                  brandList[index].id, brandList[index].name,
                )),
                child: CategoriesWidget(
                  isBrand: true,
                  brandItem: brandList[index],
                  catItem: null,
                  index: index,
                  length: brandList.length,
                ),
              );
            },
          )
              : NoDataScreen(text: 'no_brands_found'.tr) : CategoriesShimmer(isEnabled: brandList==null,);
        }),
      ))))),
    );
  }
}
