import 'package:sixam_mart/controller/category_controller.dart';
import 'package:sixam_mart/controller/localization_controller.dart';
import 'package:sixam_mart/controller/splash_controller.dart';
import 'package:sixam_mart/data/model/response/item_model.dart';
import 'package:sixam_mart/data/model/response/store_model.dart';
import 'package:sixam_mart/helper/responsive_helper.dart';
import 'package:sixam_mart/helper/route_helper.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/styles.dart';
import 'package:sixam_mart/view/base/cart_widget.dart';
import 'package:sixam_mart/view/base/item_view.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_drawer.dart';
import 'package:sixam_mart/view/base/veg_filter_widget.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_bar.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

import '../../../../controller/auth_controller.dart';
import '../../../../controller/cart_controller.dart';
import '../../../../controller/item_controller.dart';
import '../../../../controller/wishlist_controller.dart';
import '../../../../data/model/response/cart_model.dart';
import '../../../../data/model/response/config_model.dart';
import '../../../../data/model/response/module_model.dart';
import '../../../../helper/price_converter.dart';
import '../../../../util/app_constants.dart';
import '../../../../util/images.dart';
import '../../../base/add_item_button_widget.dart';
import '../../../base/cart_snackbar.dart';
import '../../../base/confirmation_dialog.dart';
import '../../../base/custom_image.dart';
import '../../../base/custom_snackbar.dart';
import '../../../base/discount_tag.dart';
import '../../../base/item_widget.dart';
import '../../../base/mrp_and_save_view.dart';
import '../../../base/mrp_selling_diff_view.dart';
import '../../../base/not_available_widget.dart';
import '../../../base/product_grid_shimmer.dart';
import '../../../base/rating_bar.dart';
import '../../checkout/checkout_screen.dart';
import '../../store/store_screen.dart';

class AllProductsScreenSonu extends StatefulWidget {

  final String title;
  AllProductsScreenSonu({@required this.title});

  @override
  _AllProductsScreenSonuState createState() => _AllProductsScreenSonuState();
}

class _AllProductsScreenSonuState extends State<AllProductsScreenSonu> with TickerProviderStateMixin {
  final ScrollController scrollController = ScrollController();



  @override
  void dispose() {
    // TODO: implement dispose
    super.dispose();
    scrollController.dispose();
  }

  @override
  void initState() {
    super.initState();

    Get.find<ItemController>().getLatestItemList(0,false);

    scrollController?.addListener(() {
      if (scrollController.position.pixels == scrollController.position.maxScrollExtent
          && Get.find<ItemController>().latestItemList != null
          && !Get.find<ItemController>().isLoading) {
        //int pageSize = (Get.find<ItemController>().pageSize / 10).ceil();
        int pageSize = Get.find<ItemController>().pageSize;
        if (Get.find<ItemController>().offset < pageSize) {
          print('end of the page');
          Get.find<ItemController>().showBottomLoader();
          Get.find<ItemController>().getLatestItemList(Get.find<ItemController>().offset+50
              ,true);
        }
      }
    });

  }


  double getDiscount(Item item) => item.discount==null?0 : item.discount;

  String getDiscountType(Item item) => item.storeDiscount == 0 ? item.discountType : 'percentage';
  double getStartingPrice(Item item) {
    double _startingPrice = 0;
    if (item.choiceOptions!=null && item.choiceOptions.length != 0) {
      List<double> _priceList = [];
      item.variations.forEach((variation) => _priceList.add(variation.price));
      _priceList.sort((a, b) => a.compareTo(b));
      _startingPrice = _priceList[0];
    } else {
      _startingPrice = item.price;
    }
    return _startingPrice;
  }

  @override
  Widget build(BuildContext context) {


    bool _desktop = ResponsiveHelper.isDesktop(context);
    bool _isTab = ResponsiveHelper.isTab(context);
    bool _isWeb = ResponsiveHelper.isWeb();
    bool _isMobile = ResponsiveHelper.isMobile(context);
    double _width = MediaQuery.of(context).size.width;
    print("testResponsiveHelper AllProductsScreenSonu _desktop $_desktop _isTab $_isTab isWeb $_isWeb _isMobile $_isMobile");


    BaseUrls _baseUrls = Get.find<SplashController>().configModel.baseUrls;
    return GetBuilder<ItemController>(builder: (itemController) {
      List<Item> _itemList = itemController.latestItemList;



      return Scaffold(

        appBar: ResponsiveHelper.isDesktop(context) ? WebMenuBar() : AppBar(
          title: Text(widget.title, style: robotoRegular.copyWith(
            fontSize: Dimensions.fontSizeLarge, color: Theme.of(context).textTheme.bodyText1.color,
          )),
          centerTitle: true,
          leading: IconButton(
            icon: Icon(Icons.arrow_back_ios),
            color: Theme.of(context).textTheme.bodyText1.color,
            onPressed: () {Get.back();},
          ),
          backgroundColor: Theme.of(context).cardColor,
          elevation: 0,
          actions: [
            IconButton(
              onPressed: () => itemController.toggleSearch(),
              icon: Icon(Icons.search, color: Theme.of(context).textTheme.bodyText1.color,
              ),
            ),
            IconButton(
              onPressed: () => Get.toNamed(RouteHelper.getCartRoute()),
              icon: CartWidget(color: Theme.of(context).textTheme.bodyText1.color, size: 25),
            ),
          ],
        ),
        endDrawer: WebMenuDrawer(),
        body: Center(child: SizedBox(
          width: _desktop? _width :   Dimensions.WEB_MAX_WIDTH,
          child:SingleChildScrollView(
              controller: scrollController,
              // child: Column(children: [
              //
              //   _itemList!=null? _itemList.length>0? GridView.builder(gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
              //     crossAxisCount: 1, mainAxisSpacing: Dimensions.PADDING_SIZE_SMALL,
              //     crossAxisSpacing: Dimensions.PADDING_SIZE_SMALL, childAspectRatio: (1/1),
              //   ),
              //     padding: EdgeInsets.all(Dimensions.PADDING_SIZE_SMALL),
              //     itemCount: _itemList.length,
              //     shrinkWrap: true, physics: NeverScrollableScrollPhysics(),
              //     itemBuilder: (context, index) {
              //       return Column(children: [
              //         Row(
              //           mainAxisAlignment: MainAxisAlignment.start,
              //           crossAxisAlignment: CrossAxisAlignment.start,
              //           children: [
              //           Container(
              //             height: 110,
              //             width: 110,
              //             decoration: BoxDecoration(
              //               // color: Theme.of(context).cardColor,
              //               color: Colors.pink[50],
              //               borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
              //               boxShadow: [BoxShadow(color: Colors.grey[Get.isDarkMode ? 800 : 200], blurRadius: 5, spreadRadius: 1)],
              //             ),
              //
              //             child: Column(
              //               crossAxisAlignment: CrossAxisAlignment.center,
              //               mainAxisAlignment: MainAxisAlignment.start,
              //               children: [
              //                 Padding(
              //                   padding: const EdgeInsets.only(left: 10,right: 10,top: 10,bottom: 5),
              //                   child: ClipRRect(
              //                     borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
              //                     child: CustomImage(
              //                       height: 80, width: 80, fit: BoxFit.cover,
              //                       image: '${_baseUrls.commonImageUrl}'
              //                           '/${_itemList[index].image}',
              //                     ),
              //                   ),
              //                 ),
              //                 RatingBar(rating: 3.4,
              //                     size: 9, ratingCount: 5,color: Colors.deepPurple[300],)
              //                 // RatingBar(rating: _itemList[index].avgRating??0.0,
              //                 //     size: 9, ratingCount: _itemList[index].ratingCount)
              //               ],
              //             ),
              //           ),
              //
              //           Container(
              //             padding: EdgeInsets.only(left: 5.0),
              //             child: Column(
              //               crossAxisAlignment: CrossAxisAlignment.start,
              //               children: [
              //                 Row(
              //                   children: [
              //
              //                     Container(
              //                       decoration: BoxDecoration(
              //                         color: Colors.orange[100],
              //                         // backgroundBlendMode: BlendMode.darken,
              //                         borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL)
              //                         ,),
              //                       child: Padding(
              //                         padding: const EdgeInsets.symmetric(vertical: 2,horizontal: 5),
              //                         child: Row(
              //                           mainAxisAlignment: MainAxisAlignment.start,
              //                           crossAxisAlignment: CrossAxisAlignment.start,
              //                           children: [
              //                             Icon(
              //                               Icons.ac_unit_sharp,  size: 7,
              //                               color: Colors.orange[900],
              //                             ),
              //                             SizedBox(width: 3,),
              //                             Text('OFFER',style: robotoMedium.copyWith(fontSize: 7,color: Colors.orange[900])),
              //                           ],
              //                         ),
              //                       ),
              //                     ),
              //
              //                     SizedBox(width: Dimensions.PADDING_SIZE_DEFAULT,),
              //
              //                     Container(
              //                       decoration: BoxDecoration(
              //                         color: Colors.deepPurple[200],
              //                         // backgroundBlendMode: BlendMode.darken,
              //                         borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),),
              //                       child: Padding(
              //                         padding: const EdgeInsets.symmetric(vertical: 2,horizontal: 4),
              //                         child: Row(
              //                           mainAxisAlignment: MainAxisAlignment.start,
              //                           crossAxisAlignment: CrossAxisAlignment.start,
              //                           children: [
              //                             Icon(
              //                               Icons.favorite,  size: 7,
              //                               color: Colors.deepPurple,
              //                             ),
              //                             SizedBox(width: 3,),
              //                             Text('BESTSELLER',style: robotoMedium.copyWith(fontSize: 7,color: Colors.deepPurple)),
              //                           ],
              //                         ),
              //                       ),
              //                     ),
              //                   ],
              //                 ),
              //
              //                 SizedBox(height: Dimensions.PADDING_SIZE_EXTRA_SMALL,),
              //                 Text(
              //                   _itemList[index].name ?? '',
              //                   style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeExtraSmall),
              //                   maxLines: 2, overflow: TextOverflow.ellipsis,
              //                 ),
              //                 SizedBox(height: Dimensions.PADDING_SIZE_EXTRA_SMALL,),
              //                 Text(
              //                   _itemList[index].categoryName ?? '',
              //                   style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeExtraSmall,color: Colors.grey),
              //                   maxLines: 2, overflow: TextOverflow.ellipsis,
              //                 ),
              //
              //                 SizedBox(height: Dimensions.PADDING_SIZE_EXTRA_SMALL),
              //
              //
              //               ],
              //             ),
              //           ),
              //         ],)
              //       ],);
              //     },
              //   ):SizedBox() : ProductGridShimmer(isEnabled: _itemList==null,),
              //
              //
              //   itemController.isLoading ? Center(child: Padding(
              //     padding: EdgeInsets.all(Dimensions.PADDING_SIZE_SMALL),
              //     child: CircularProgressIndicator(valueColor: AlwaysStoppedAnimation<Color>(Theme.of(context).primaryColor)),
              //   )) : SizedBox(),
              // ],)),

              child: Padding(
                padding: EdgeInsets.all(Dimensions.gridPadding),
                child: Column(children: [

                  _itemList!=null? _itemList.length>0?
                    GridView.builder(gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
                      crossAxisCount: _desktop ? Dimensions.crossAxisCount_Desktop : (_isTab && _width > 950 )? Dimensions.crossAxisCount_Tab_widthMoreThan950 : (_isTab && _width < 950 )? Dimensions.crossAxisCount_Tab_widthLessThan950  : Dimensions.crossAxisCount_Mobile
                      , mainAxisSpacing: ( _desktop || _isTab )? Dimensions.PADDING_SIZE_DEFAULT:  Dimensions.PADDING_SIZE_SMALL,
                      crossAxisSpacing:( _desktop || _isTab ) ? Dimensions.PADDING_SIZE_DEFAULT : Dimensions.PADDING_SIZE_SMALL
                      , childAspectRatio: _desktop ? Dimensions.childAspectRatio_Desktop : (_isTab && _width > 950 ) ? Dimensions.childAspectRatio_Tab_widthMoreThan950 : (_isTab && _width < 950 ) ? Dimensions.childAspectRatio_Tab_widthLessThan950 : Dimensions.childAspectRatio_Mobile,

                    ),

                    itemCount: _itemList.length,
                    shrinkWrap: true, physics: NeverScrollableScrollPhysics(),
                    itemBuilder: (context, index) {


                      return ItemWidget(
                        isStore: false,
                        item: _itemList[index],
                        isFeatured: false,
                        store:  null,
                        index: index,
                        length: _itemList.length,
                        isCampaign: false,
                        inStore: false,
                      );
                    },
                  ):
                  SizedBox()
                  : ItemViewGridShimmer(isEnabled: _itemList==null,),
                      //: ProductGridShimmer(isEnabled: _itemList==null,),


                  itemController.isLoading ? Center(child: Padding(
                    padding: EdgeInsets.all(Dimensions.PADDING_SIZE_SMALL),
                    child: CircularProgressIndicator(valueColor: AlwaysStoppedAnimation<Color>(Theme.of(context).primaryColor)),
                  )) : SizedBox(),
                ],),
              )),
        )),
      );
    });
  }
}

