import 'package:sixam_mart/controller/localization_controller.dart';
import 'package:sixam_mart/data/model/response/item_model.dart';
import 'package:sixam_mart/helper/responsive_helper.dart';
import 'package:sixam_mart/helper/route_helper.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/styles.dart';
import 'package:sixam_mart/view/base/cart_widget.dart';
import 'package:sixam_mart/view/base/item_view.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_drawer.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_bar.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import '../../../../controller/brand_controller_sonu.dart';

class BrandItemScreen extends StatefulWidget {
  final String brandID;
  final String brandName;

  BrandItemScreen({@required this.brandID, @required this.brandName});

  @override
  _BrandItemScreenState createState() => _BrandItemScreenState();
}

class _BrandItemScreenState extends State<BrandItemScreen>  {
  final ScrollController scrollController = ScrollController();

  @override
  void initState() {
    super.initState();
    Get.find<BrandController>().getBrandItemList(widget.brandID,0,'all',false);

    scrollController?.addListener(() {
      if (scrollController.position.pixels == scrollController.position.maxScrollExtent
          && Get.find<BrandController>().brandItemList != null
          && !Get.find<BrandController>().isLoading) {
        int pageSize = (Get.find<BrandController>().pageSize / 10).ceil();
        if (Get.find<BrandController>().offset < pageSize) {
          print('end of the page');
          Get.find<BrandController>().showBottomLoader();
          Get.find<BrandController>().getBrandItemList(widget.brandID,
            Get.find<BrandController>().offset+30, Get.find<BrandController>().type, false,
          );
        }
      }
    });

  }

  @override
  Widget build(BuildContext context) {
    bool _desktop = ResponsiveHelper.isDesktop(context);
    double _width = MediaQuery.of(context).size.width;
    return GetBuilder<BrandController>(builder: (brandController) {
      List<Item> _item;

      if(brandController.brandItemList != null && brandController.searchItemList != null) {
        _item = [];
        if (brandController.isSearching) {
          _item.addAll(brandController.searchItemList);
        } else {
          _item.addAll(brandController.brandItemList);
        }
      }

      return WillPopScope(
        onWillPop: () async {
          if(brandController.isSearching) {
            brandController.toggleSearch();
            return false;
          }else {
            return true;
          }
        },
        child: Scaffold(
          appBar: ResponsiveHelper.isDesktop(context) ? WebMenuBar() : AppBar(
            title: brandController.isSearching ? TextField(
              autofocus: true,
              textInputAction: TextInputAction.search,
              decoration: InputDecoration(
                hintText: 'Search...',
                border: InputBorder.none,
              ),
              style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeLarge),
              onSubmitted: (String query) => brandController.searchData(
                query,widget.brandID,
                brandController.type,
              ),
            ) : Text(widget.brandName, style: robotoRegular.copyWith(
              fontSize: Dimensions.fontSizeLarge, color: Theme.of(context).textTheme.bodyText1.color,
            )),
            centerTitle: true,
            leading: IconButton(
              icon: Icon(Icons.arrow_back_ios),
              color: Theme.of(context).textTheme.bodyText1.color,
              onPressed: () {
                if(brandController.isSearching) {
                  brandController.toggleSearch();
                }else {
                  Get.back();
                }
              },
            ),
            backgroundColor: Theme.of(context).cardColor,
            elevation: 0,
            actions: [
              IconButton(
                onPressed: () => brandController.toggleSearch(),
                icon: Icon(
                  brandController.isSearching ? Icons.close_sharp : Icons.search,
                  color: Theme.of(context).textTheme.bodyText1.color,
                ),
              ),
              IconButton(
                onPressed: () => Get.toNamed(RouteHelper.getCartRoute()),
                icon: CartWidget(color: Theme.of(context).textTheme.bodyText1.color, size: 25),
              ),
            ],
          ),
          endDrawer: WebMenuDrawer(),
          body: Center(child: SizedBox(
            width: _desktop ? _width : Dimensions.WEB_MAX_WIDTH,
            child: Column(children: [

              Expanded(child: NotificationListener(
                onNotification: (scrollNotification) {
                  if (scrollNotification is ScrollEndNotification) {
                    brandController.getBrandItemList(widget.brandID,
                      Get.find<BrandController>().offset+30, brandController.type, false,
                    );
                  }
                  return false;
                },
                child: SingleChildScrollView(
                  controller: scrollController,
                  child: ItemsView(
                    isStore: false, items: _item, stores: null, noDataText: 'no_brand_item_found'.tr,
                  ),
                ),
              )),

              brandController.isLoading ? Center(child: Padding(
                padding: EdgeInsets.all(Dimensions.PADDING_SIZE_SMALL),
                child: CircularProgressIndicator(valueColor: AlwaysStoppedAnimation<Color>(Theme.of(context).primaryColor)),
              )) : SizedBox(),

            ]),
          )),
        ),
      );
    });
  }
}


