
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:im_animations/im_animations.dart';
import 'package:sixam_mart/controller/user_controller.dart';

import '../../../../controller/auth_controller.dart';
import '../../../../controller/splash_controller.dart';
import '../../../../data/model/response/userinfo_model.dart';
import '../../../../helper/route_helper.dart';
import '../../../../util/dimensions.dart';
import '../../../../util/images.dart';
import '../../../../util/styles.dart';
import '../../../base/custom_image.dart';
import '../home_screen.dart';
import 'package:speech_to_text/speech_to_text.dart' as speechToText;
class HomeSearchView extends StatelessWidget {
  final double screenWidth;
  final SplashController splashController;
  const HomeSearchView(this.screenWidth, this.splashController);

  void goToSearchPage(String searchedData){


    if(searchedData.contains("_isHomeSearchVoice")) {
      String result = searchedData.substring(0, searchedData.indexOf('.'));
      if(result!=null && result.isNotEmpty){
        Get.find<SplashController>().setHomeSearchTrue(true);
        Get.toNamed(RouteHelper.getSearchRoute(queryText: searchedData));
      }
    }else{
      Get.find<SplashController>().setHomeSearchTrue(true);
      Get.toNamed(RouteHelper.getSearchRoute(queryText: searchedData));
    }
  }

  @override
  Widget build(BuildContext context) {


    return SliverPersistentHeader(
      pinned: true,
      delegate: SliverDelegate(child:
      Container(
        color: Colors.white,
        child: Row(
          mainAxisAlignment: MainAxisAlignment.center,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            Container(
              height: 50, width: screenWidth*0.9,
              color: Theme.of(context).bottomAppBarTheme.color,
              padding: EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_SMALL),
              child: InkWell(
                onTap: (){

                  goToSearchPage("_isHomeSearch");
                  //splashController.switchModule(1, true);

                },
                child: Container(
                  padding: EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_SMALL),
                  decoration: BoxDecoration(
                    color: Theme.of(context).colorScheme.background,
                    borderRadius: BorderRadius.circular(Dimensions.RADIUS_EXTRA_LARGE),
                    boxShadow: [BoxShadow(color: Colors.grey[Get.isDarkMode ? 800 : 200], spreadRadius: 1, blurRadius: 4)],
                  ),
                  child: Row(children: [
                    Icon(Icons.search, size: 25, color: Theme.of(context).primaryColor,),
                    SizedBox(width: Dimensions.PADDING_SIZE_EXTRA_SMALL),
                    Expanded(child: Text('search_items'.tr, style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall, color: Theme.of(context).hintColor,),)),
                    // SizedBox(
                    //   height: 30,
                    //   width: 30,
                    //   child: FloatingActionButton(
                    //     backgroundColor: Theme.of(context).primaryColor,
                    //     child: Icon(Icons.mic,size: 17,color: Colors.white),
                    //     onPressed: () {
                    //       listen();
                    //     },
                    //   ),
                    // ),
                  ]),
                ),
              ),
            ),
            InkWell(onTap: (){

              if(Get.find<AuthController>().isLoggedIn()){
                Get.offNamed(RouteHelper.getProfileRoute());
              }else{
                Get.offAllNamed(RouteHelper.getSignInRoute(RouteHelper.splash));
              }


              },
              child: Container(
              height: 50, width: screenWidth*0.1,
              color: Theme.of(context).bottomAppBarTheme.color,

                child: Container(
                decoration: BoxDecoration(
                  border: Border.all(width: 2, color: Theme.of(context).cardColor),
                  shape: BoxShape.circle,
                ),
                alignment: Alignment.centerRight,
                child: Get.find<AuthController>().isLoggedIn()? ClipOval(
                  child: CustomImage(
                    image: '${Get.find<SplashController>().configModel.baseUrls.customerImageUrl}'
                        '/${(Get.find<UserController>().userInfoModel != null && Get.find<AuthController>().isLoggedIn()) ?
                    Get.find<UserController>().userInfoModel.image ?? '' : ''}',
                    width: 35, height: 35, fit: BoxFit.fill, isProfile: true,
                  ),
                )
                  : Image.asset(Images.log_out,
                    width: 35, height: 35, color:  Theme.of(context).primaryColor),
              ),
            ),),
          ],
        ),
      )),
    );
  }
}

