import 'package:carousel_slider/carousel_slider.dart';
import 'package:sixam_mart/controller/banner_controller.dart';
import 'package:sixam_mart/controller/item_controller.dart';
import 'package:sixam_mart/controller/location_controller.dart';
import 'package:sixam_mart/controller/splash_controller.dart';
import 'package:sixam_mart/data/model/response/basic_campaign_model.dart';
import 'package:sixam_mart/data/model/response/item_model.dart';
import 'package:sixam_mart/data/model/response/module_model.dart';
import 'package:sixam_mart/data/model/response/store_model.dart';
import 'package:sixam_mart/data/model/response/zone_response_model.dart';
import 'package:sixam_mart/helper/route_helper.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/view/base/custom_image.dart';
import 'package:sixam_mart/view/base/custom_snackbar.dart';
import 'package:sixam_mart/view/screens/store/store_screen.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:shimmer_animation/shimmer_animation.dart';
import 'package:url_launcher/url_launcher_string.dart';

import '../../../../data/model/response/banner_model.dart';
import '../../../base/title_widget.dart';
import '../../../base/banner_shimmer.dart';
import '../../../base/banner_widget.dart';

class TodaysBannerViewSonu extends StatelessWidget {
  final String bannerType;
  TodaysBannerViewSonu({@required this.bannerType});

  @override
  Widget build(BuildContext context) {

    return GetBuilder<BannerController>(builder: (bannerController) {

      List<Bannr> bannerList = bannerType=='todays_offers'.tr ? bannerController.todaysBannersList : bannerController.otherBannersList;
      //List<dynamic> bannerDataList = isFeatured ? bannerController.featuredBannerDataList : bannerController.bannerDataList;

      return bannerList != null? bannerList.length>0?Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Padding(padding: EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_SMALL),
            child: TitleWidget(title: bannerType),),
          Container(
            width: MediaQuery.of(context).size.width,
            height: GetPlatform.isDesktop ? 500 : MediaQuery.of(context).size.width * 0.36,
            padding: EdgeInsets.only(top: Dimensions.PADDING_SIZE_DEFAULT),
            child: bannerList != null ? Column(
              crossAxisAlignment: CrossAxisAlignment.stretch,
              children: [
                Expanded(
                  child: CarouselSlider.builder(
                    options: CarouselOptions(
                      autoPlay: true,
                      enlargeCenterPage: true,
                      disableCenter: true,
                      viewportFraction: 0.8,
                      autoPlayInterval: Duration(seconds: 7),
                      onPageChanged: (index, reason) {
                        bannerController.setCurrentIndex(index, true);
                      },
                    ),
                    itemCount: bannerList.length == 0 ? 1 : bannerList.length,
                    itemBuilder: (context, index, _) {
                      return BannerWidget(bannerItem: bannerList[index],bannerType: bannerType,);
                    },
                  ),
                ),

                SizedBox(height: Dimensions.PADDING_SIZE_EXTRA_SMALL),
                Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: bannerList.map((bnr) {
                    int index = bannerList.indexOf(bnr);
                    return TabPageSelectorIndicator(
                      backgroundColor: index == bannerController.currentIndex ? Theme.of(context).primaryColor
                          : Theme.of(context).primaryColor.withOpacity(0.5),
                      borderColor: Theme.of(context).backgroundColor,
                      size: index == bannerController.currentIndex ? 10 : 7,
                    );
                  }).toList(),
                ),

              ],
            ) : Shimmer(
              duration: Duration(seconds: 2),
              enabled: bannerList == null,
              child: Container(margin: EdgeInsets.symmetric(horizontal: 10), decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
                color: Colors.grey[300],
              )),
            ),
          ),
        ],
      )
          :SizedBox():BannerShimmer(isEnabled: bannerList==null,context: context,) ;
    });
  }

}
