import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:sixam_mart/util/app_constants.dart';
import '../../../../controller/auth_controller.dart';
import '../../../../controller/banner_controller.dart';
import '../../../../controller/splash_controller.dart';
import '../../../../controller/user_controller.dart';
import '../../../../data/model/response/userinfo_model.dart';
import '../../../../helper/price_converter.dart';
import '../../../../helper/responsive_helper.dart';
import '../../../../helper/route_helper.dart';
import '../../../../util/dimensions.dart';
import '../../../../util/images.dart';
import '../../../../util/styles.dart';
import '../../../base/custom_button.dart';
import '../../../base/custom_snackbar.dart';
import '../../../base/custom_text_field.dart';
import '../../profile/profile_screen.dart';
import 'module_view.dart';

class UpgradeToPrimeCard extends StatelessWidget {
  final SplashController splashController;
  UpgradeToPrimeCard( this.splashController);

  Widget benefitsOfPrime(){
    return Container(
      decoration: BoxDecoration(
          gradient: const LinearGradient(
            begin: Alignment.topLeft,
            end: Alignment.bottomRight,
            colors: [ Color(0xFF846AFF),
              Color(0xFF755EE8),
              Colors.purpleAccent,
              Color(0xFF846AFF),],
            //colors: [ Colors.purpleAccent, Colors.deepPurpleAccent],
          ),
          borderRadius: BorderRadius.circular(5)),
      child: Padding(
        padding: const EdgeInsets.fromLTRB(10, 2, 10, 2),
        child: InkWell(onTap: (){
          Get.toNamed(RouteHelper.getPrimeBenefitsRoute("no"));
        },
            child: Text(
              "Benefits",
              style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeDefault,color: Colors.white),
            )),
      ),
    );
  }


  Widget whyPrime(){
    return Container(
      decoration: BoxDecoration(
          gradient: const LinearGradient(
            begin: Alignment.topLeft,
            end: Alignment.bottomRight,
            colors: [ Colors.black, Colors.black87, Colors.black54],
          ),
          borderRadius: BorderRadius.circular(5)),
      child: Padding(
        padding: const EdgeInsets.fromLTRB(10, 0, 10, 0),
        child: InkWell(onTap: (){
          Get.toNamed(RouteHelper.getHtmlRoute('upgrade-prime'));
        },
            child: Text(
              "Why Prime?",
              style: robotoRegular.copyWith(fontSize: 10,color: Colors.white),
            )),
      ),
    );
  }

  Widget remarksUI( bool isFailed, String upiPaymentStatusDesc){
    var colors1=[
      Colors.orange,
      Colors.orangeAccent,
    ];
    var colors2=[
      Colors.red,
      Colors.redAccent,
    ];
    return Container(
      decoration: BoxDecoration(
          gradient:  LinearGradient(
            begin: Alignment.topLeft,
            end: Alignment.bottomRight,
            colors: (isFailed != null && isFailed==true) ? colors2:colors1,
          ),
          borderRadius: BorderRadius.circular(5)),
      child: Padding(
        padding: const EdgeInsets.fromLTRB(10, 2, 10, 2),
        child: InkWell(onTap: (){
          Get.bottomSheet(
            UpiPaymentActionStatusBottomSheet(text: upiPaymentStatusDesc),
            backgroundColor: Colors.transparent, isScrollControlled: true,
          );
        },
            child: Text(
              "View Remarks",
              style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall,color: Colors.white),
            )),
      ),
    );

  }
  Widget mlmUI(UserInfoModel userInfoModel,BuildContext context) {

    bool _desktop = ResponsiveHelper.isDesktop(context);
    bool _isTab = ResponsiveHelper.isTab(context);
    bool _isWeb = ResponsiveHelper.isWeb();
    bool _isMobile = ResponsiveHelper.isMobile(context);
    double screenWidth = MediaQuery.of(context).size.width;

    return Container(
      padding: const EdgeInsets.only(left: 5.0,right: 5.0,bottom: 7.0),
      width: double.infinity,
      decoration: BoxDecoration(
          gradient:  LinearGradient(
            begin: Alignment.topLeft,
            end: Alignment.bottomRight,
            colors: [
              AppConstants.card_2.withOpacity(0.5),
              AppConstants.card_2.withOpacity(0.4),
            ],
          ),),
      child: Column(
        mainAxisAlignment: MainAxisAlignment.start,
        crossAxisAlignment: CrossAxisAlignment.end,
        children: [

          Row(
            crossAxisAlignment: CrossAxisAlignment.end,
            mainAxisAlignment: MainAxisAlignment.end,
            children: [


              InkWell(child: Row(
                children: [
                  Text('${'refer_and_earn'.tr}: ', style:
                  robotoRegular.copyWith(fontSize:
                  Dimensions.fontSizeSmall,color:
                  Theme.of(context).cardColor)),

                  Icon(Icons.share ,
                    color: Theme.of(context).cardColor,),
                ],
              ),onTap: (){
                Get.toNamed(RouteHelper.getReferAndEarnRoute());
              },),

              SizedBox(width:(
                  Get.find<UserController>().userInfoModel.isTeamLeader!=null &&
                  Get.find<UserController>().userInfoModel.mlmMyTeamUrl!=null &&
                  Get.find<UserController>().userInfoModel.isTeamLeader==1)? 10.0:0.0,),

              (Get.find<UserController>().userInfoModel.isTeamLeader!=null &&
                  Get.find<UserController>().userInfoModel.mlmMyTeamUrl!=null &&
                  Get.find<UserController>().userInfoModel.isTeamLeader==1)? Container(
                padding: const EdgeInsets.all(5),
                color: Colors.green,
                child: InkWell(child: Text('${'my_team'.tr}', style:
                robotoMedium.copyWith(fontSize:
                Dimensions.fontSizeLarge,color:
                Theme.of(context).cardColor)),onTap: (){
                  var mlmMyTeamUrl = Get.find<UserController>().userInfoModel.mlmMyTeamUrl;

                  if(mlmMyTeamUrl!=null){
                     Get.toNamed(RouteHelper.getMlmTreeRoute(mlmMyTeamUrl));
                    // _launchURL(mlmMyTeamUrl);
                  }
                  //_launchURL('$mlmMyTeamUrl?id=${Get.find<UserController>().userInfoModel.id.toString()}');
                }),
              )
                  :SizedBox(),

              SizedBox(width: 10.0,),
              Container(
                padding: const EdgeInsets.all(5),
                color: Theme.of(context).primaryColor,
                child: InkWell(child: Text('${'statement'.tr}', style:
                robotoMedium.copyWith(fontSize:
                Dimensions.fontSizeLarge,color:
                Theme.of(context).cardColor)),onTap: (){

                  Get.toNamed(RouteHelper.getWalletRoute(true,"NA"));

                }),
              ),

            ],
          ),
          SizedBox(height: 5.0,),
          //Get.find<SplashController>().configModel.customerWalletStatus == 1?
          (userInfoModel.walletBalance!=null) ?
          Align(child: InkWell(child: Text('${'wallet_amount'.tr} ${PriceConverter.convertPrice(userInfoModel.walletBalance)}', style:
          robotoRegular.copyWith(fontSize:
          22,)),onTap: (){
            Get.toNamed(RouteHelper.getWalletRoute(true,"NA"));
          },),alignment: Alignment.topLeft,)
              : SizedBox(),

          SizedBox(height: 10,),
          Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,children: [
            Container(
              padding: const EdgeInsets.only(left: 5,right: 5,top: 5,bottom: 5),
              decoration: BoxDecoration(
                  border: Border.all(color: Colors.blue),
                  color: Colors.blue[200]
              ),
              child: InkWell(child: Text('${'avl_Bhavya_point'.tr}: ${userInfoModel.avlBP}', style:
              robotoMedium.copyWith(fontSize:
              14,)),onTap: (){
               // Get.toNamed(RouteHelper.getBhavyaPointsRoute('avl_Bhavya_point'.tr));
              },),
            ),

            Container(
              padding: const EdgeInsets.only(left: 5,right: 5,top: 5,bottom: 5),
              decoration: BoxDecoration(
                  border: Border.all(color: Colors.red),
                  color: Colors.red[200]
              ),
              child: InkWell(child: Text('${'used_Bhavya_point'.tr}: ${userInfoModel.usedBP.toString()}', style:
              robotoMedium.copyWith(fontSize:
              14,)),onTap: (){
              //  Get.toNamed(RouteHelper.getBhavyaPointsRoute('used_Bhavya_point'.tr));
              },),
            ),

            SizedBox(),

          ],),

          SizedBox(height: 10,),

          Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,children: [
            Container(
              padding: const EdgeInsets.only(left: 5,right: 5,top: 5,bottom: 5),
              decoration: BoxDecoration(
                  border: Border.all(color: Colors.blueGrey),
                  color: Colors.green[200]
              ),
              child: InkWell(child: Text('${'recharge'.tr}', style:
              robotoMedium.copyWith(fontSize:
              14)),onTap: (){
                Get.toNamed(RouteHelper.getWalletRechargeRoute(true));
              },),
            ),

            Container(
              padding: const EdgeInsets.only(left: 5,right: 5,top: 5,bottom: 5),

              decoration: BoxDecoration(
                  border: Border.all(color: Colors.blueGrey),
                  color: Colors.green[400]
              ),
              child: InkWell(child: Text('${'transfer'.tr}', style:
              robotoMedium.copyWith(fontSize:
              14)),onTap: (){
                Get.toNamed(RouteHelper.getWalletTransferRoute());
              },),
            ),

            Container(
              padding: const EdgeInsets.only(left: 5,right: 5,top: 5,bottom: 5),

              decoration: BoxDecoration(
                  border: Border.all(color: Colors.blueGrey),
                  color: Colors.orange[400]
              ),
              child: InkWell(child: Text('${'withdrawal'.tr}', style:
              robotoMedium.copyWith(fontSize:
              14)),onTap: (){
                Get.toNamed(RouteHelper.getWalletRechargeRoute(false));
              },),
            )
          ],),

          SizedBox(height: 10,),
          Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,crossAxisAlignment: CrossAxisAlignment.start
            ,children: [
              userInfoModel.familyMembersCount!=null? Container(
                padding: const EdgeInsets.only(left: 10,right: 10,top: 5,bottom: 5),
                decoration: BoxDecoration(
                  border: Border.all(color: Colors.blueGrey),
                ),
                child: InkWell(child: Text('${'family_members'.tr}: ${userInfoModel.familyMembersCount} ', style:
                robotoMedium.copyWith(fontSize:
                Dimensions.fontSizeSmall)),onTap: (){
                  Get.toNamed(RouteHelper.getTrackFamilyMemberRoute());
                },),
              )
                  : SizedBox(),


              userInfoModel.primeMembersCount!=null?  Container(
                padding: const EdgeInsets.only(left: 10,right: 10,top: 5,bottom: 5),
                decoration: BoxDecoration(
                  border: Border.all(color: Colors.blueGrey),
                ),
                child: InkWell(child: Text('${'prime_members'.tr}: ${userInfoModel.primeMembersCount}', style:
                robotoMedium.copyWith(fontSize:
                Dimensions.fontSizeSmall)),onTap: (){
                  Get.toNamed(RouteHelper.getPrimeMemberListRoute());
                },),
              )
                  : SizedBox(),

              userInfoModel.totalSharedLinks!=null?  Container(
                padding: const EdgeInsets.only(left: 10,right: 10,top: 5,bottom: 5),
                decoration: BoxDecoration(
                  border: Border.all(color: Colors.blueGrey),
                ),
                child: InkWell(child: Text('${'shared'.tr}: ${userInfoModel.totalSharedLinks}', style:
                robotoMedium.copyWith(fontSize:
                Dimensions.fontSizeSmall)),onTap: (){
                  Get.toNamed(RouteHelper.getShareLinkListListRoute());
                },),
              )
                  : SizedBox(),

            ],),
        ],
      ),
    );
  }

  @override
  Widget build(BuildContext context) {

    UserInfoModel _user =  Get.find<UserController>().userInfoModel;

    bool _isLoggedIn = Get.find<AuthController>().isLoggedIn();

    print("UpgradeToPrimeCard _isLoggedIn $_isLoggedIn  _user = ${_user!=null} ");
    return (_isLoggedIn && _user!=null
        && _user.primeMember!=null
    ) ? Column(
      children: [
        _user.primeMember==0 ?
        Padding(
          padding: const EdgeInsets.only(left: 10 , right:  10),
          child: InkWell(
              onTap: (){
                if(_user.upiPaymentStatus!=null && _user.upiPaymentStatus=="pending"
                ){
                  showCustomSnackBar('we_are_working_on_your_request'.tr,isError: true);
                  //Get.toNamed(RouteHelper.getPrimeMemberBankDetailsRoute(''));
                }else{
                  Get.toNamed(RouteHelper.getPrimeMemberBankDetailsRoute(''));

                }

                //Get.toNamed(RouteHelper.getSelectedPrimeRoute(Get.find<AuthController>().getClientReferral().toString()));
              },
              child: Container(
                height: 80,
                decoration: BoxDecoration(
                  image: DecorationImage(
                    image: AssetImage(Images.upgrade_to_prime),
                    fit: BoxFit.fill,
                  ),
                ),
                child: Stack(children: [

                //  ( _user.isFormCompleted!=null && _user.isFormCompleted=="true" &&
                  (_user.upiPaymentStatus!=null && _user.upiPaymentStatus=="pending"
                  ) ? Container(
                    height: 80,
                    width: context.width,
                    color: Colors.black.withOpacity(0.6),
                    child: Center(child: Container(
                      color: Colors.transparent,
                      child: Padding(
                        padding: const EdgeInsets.all(8.0),
                        child: Row(
                          children: [
                            _user.upiPaymentStatusDesc!=null?  remarksUI(false,_user.upiPaymentStatusDesc)
                                : SizedBox(),
                            Padding(
                              padding: const EdgeInsets.only(left: 10),
                              child: Text("Under Processing...",
                                style: TextStyle(color: Colors.orange),),
                            ),
                          ],
                        ),
                      ),
                    ),),

                  )
                      : (_user.upiPaymentStatus!=null && _user.upiPaymentStatus=="rejected"
                  ) ? Container(
                    height: 80,
                    width: context.width,
                    color: Colors.black.withOpacity(0.75),
                    child: Center(child: Container(
                      color: Colors.transparent,
                      child: Padding(
                        padding: const EdgeInsets.all(8.0),
                        child: Row(
                          children: [

                            _user.upiPaymentStatusDesc!=null ?  remarksUI(true,_user.upiPaymentStatusDesc)
                                : SizedBox(),
                            Padding(
                              padding: const EdgeInsets.only(left: 5),
                              child: Text("Payment Rejected",
                                style: TextStyle(color: Colors.red),),
                            ),

                          ],
                        ),
                      ),
                    ),),

                  )
                      : SizedBox(),

                  Stack(children: [
                    Positioned(
                      right: Dimensions.PADDING_SIZE_EXTRA_SMALL,
                      top: Dimensions.PADDING_SIZE_EXTRA_SMALL,
                      child: whyPrime(),
                    ),
                    Positioned(
                      right: Dimensions.PADDING_SIZE_EXTRA_SMALL,
                      bottom: Dimensions.PADDING_SIZE_EXTRA_SMALL,
                      child: Column(
                        children: [
                          Padding(
                            padding: const EdgeInsets.only(right: 5),
                            child: Text(
                              'avail_exciting_offers'.tr,
                              textAlign: TextAlign.center,

                              style: robotoMedium.copyWith(fontSize:
                              Dimensions.fontSizeExtraSmall,color: Colors.white), overflow: TextOverflow.ellipsis,
                            ),
                          ),
                          SizedBox(height: 10,),
                          benefitsOfPrime(),
                        ],
                      ),
                    ),
                  ])
                ],),
              )),
        )
            : _user.primeMember==1 ?

        // Padding(
        //   padding: const EdgeInsets.only(left: 10 , right:  10),
        //   child: InkWell(
        //       onTap: (){
        //         //Get.toNamed(RouteHelper.getProfileRoute());
        //       },
        //       child: Container(
        //         height: 80,
        //         decoration: BoxDecoration(
        //           image: DecorationImage(
        //             image: AssetImage(Images.prime_banner),
        //             fit: BoxFit.fill,
        //           ),
        //         ),
        //         child: Stack(children: [
        //
        //           Positioned(
        //             right: Dimensions.PADDING_SIZE_EXTRA_SMALL,
        //             top: Dimensions.PADDING_SIZE_EXTRA_SMALL,
        //             child: whyPrime(),
        //           ),
        //
        //           Positioned(
        //             right: Dimensions.PADDING_SIZE_EXTRA_SMALL,
        //             bottom: Dimensions.PADDING_SIZE_EXTRA_SMALL,
        //             child: Column(
        //               children: [
        //                 Padding(
        //                   padding: const EdgeInsets.only(right: 5),
        //                   child: Text(
        //                     'unlock_prime_benefits'.tr,
        //                     textAlign: TextAlign.center,
        //
        //                     style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeExtraSmall,color: AppConstants.share_color), overflow: TextOverflow.ellipsis,
        //                   ),
        //                 ),
        //                 SizedBox(height: 10,),
        //                 Row(
        //                   mainAxisAlignment: MainAxisAlignment.spaceBetween,
        //                   children: [
        //                     InkWell(child: Row( children: [
        //                       Padding(
        //                         padding: const EdgeInsets.only(right: 5),
        //                         child: Icon(Icons.share, color: AppConstants.share_color,size: 15),
        //                       ) ,
        //                       // Text('SHARE', textAlign: TextAlign.center, style: robotoBold.copyWith(
        //                       //   color: AppConstants.share_color,
        //                       //   fontSize: Dimensions.fontSizeSmall,
        //                       // )),
        //                     ]),
        //                       onTap: (){
        //                         Get.toNamed(RouteHelper.getReferAndEarnRoute());
        //                       },),
        //
        //                     Padding(
        //                       padding: const EdgeInsets.only(left: 10),
        //                       child: benefitsOfPrime(),
        //                     ),
        //                   ],
        //                 ),
        //               ],
        //             ),
        //           ),
        //         ]),
        //       )),
        // )
        FlipCardScreen(_user)
            : SizedBox(),

        GetBuilder<BannerController>(builder: (bannerController) {
          return PrimeBenefitsBannerView(_user);
        }),

        SizedBox(height: _user.primeMember==1 ? 5.0 : 0.0,),
        _user.primeMember==1 ? mlmUI(_user,context)
            : SizedBox(),
      ],
    )
        :  GetBuilder<BannerController>(builder: (bannerController) {
      return PrimeBenefitsBannerView(_user);
    });
  }

}

class UpiPaymentActionStatusBottomSheet extends StatefulWidget {
  final String text;


  UpiPaymentActionStatusBottomSheet({@required this.text,});

  @override
  State<UpiPaymentActionStatusBottomSheet> createState() => _UpiPaymentActionStatusBottomSheetState();
}

class _UpiPaymentActionStatusBottomSheetState extends State<UpiPaymentActionStatusBottomSheet> {
  final TextEditingController _remarksController = TextEditingController();
  @override
  void initState() {
    super.initState();
    _remarksController.text=widget.text;
  }
  @override
  Widget build(BuildContext context) {
    bool _desktop = ResponsiveHelper.isDesktop(context);
    bool _isTab = ResponsiveHelper.isTab(context);
    bool _isWeb = ResponsiveHelper.isWeb();
    bool _isMobile = ResponsiveHelper.isMobile(context);
    double screenWidth = MediaQuery.of(context).size.width;
    return Container(
      width:  550,
      margin: EdgeInsets.only(top: _desktop ? 0 : 30),
      padding: EdgeInsets.only(left: Dimensions.PADDING_SIZE_DEFAULT, bottom: Dimensions.PADDING_SIZE_DEFAULT),
      decoration: BoxDecoration(
        color: Theme.of(context).cardColor,
        borderRadius: ResponsiveHelper.isMobile(context) ? BorderRadius.vertical(top: Radius.circular(Dimensions.RADIUS_EXTRA_LARGE))
            : BorderRadius.all(Radius.circular(Dimensions.RADIUS_EXTRA_LARGE)),
      ),
      child: SingleChildScrollView(
        physics: NeverScrollableScrollPhysics(),
        child: Padding(
          padding: EdgeInsets.only(
            right: Dimensions.PADDING_SIZE_DEFAULT,
            top: ResponsiveHelper.isDesktop(context) ? Dimensions.PADDING_SIZE_DEFAULT : Dimensions.PADDING_SIZE_DEFAULT,
          ),
          child: Column(
              mainAxisAlignment: MainAxisAlignment.center, crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    SizedBox(),
                    InkWell(onTap: () => Get.back(), child: Padding(
                      padding:  EdgeInsets.only(right:_desktop? Dimensions.PADDING_SIZE_LARGE : Dimensions.PADDING_SIZE_EXTRA_SMALL),
                      child: Icon(Icons.close),
                    )),
                  ],
                ),

                CustomTextField(
                  controller: _remarksController,
                  divider: false,
                  showTitle: false,
                  isEnabled: false
                  ,showBorderStyle: true,
                ),
                SizedBox(height: 15,),
              ]),
        ),
      ),
    );
  }


}
