import 'package:flutter_html/flutter_html.dart';
import 'package:sixam_mart/controller/splash_controller.dart';
import 'package:sixam_mart/data/model/response/notification_model.dart';
import 'package:sixam_mart/util/app_constants.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/styles.dart';
import 'package:sixam_mart/view/base/custom_image.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:universal_html/html.dart' as html;
class NotificationDialog extends StatelessWidget {
  final NotificationModel notificationModel;
  NotificationDialog({@required this.notificationModel});

  @override
  Widget build(BuildContext context) {
    return Dialog(
      shape: RoundedRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(Dimensions.RADIUS_SMALL))),
      insetPadding: EdgeInsets.all(30),
      clipBehavior: Clip.antiAliasWithSaveLayer,
      child:  SizedBox(
        // width: 600,
        child: SingleChildScrollView(
          child: (notificationModel.data.imgPlacement==null || (notificationModel.data.imgPlacement==AppConstants.imgPlacement_top || notificationModel.data.imgPlacement==AppConstants.imgPlacement_before_header)) ?
          Column(
            mainAxisSize: MainAxisSize.min,
            children: [

              Align(
                alignment: Alignment.centerRight,
                child: IconButton(
                  icon: Icon(Icons.close),
                  onPressed: () => Navigator.of(context).pop(),
                ),
              ),

              (notificationModel.data.image != null && notificationModel.data.image.isNotEmpty) ? Container(
                width: MediaQuery.of(context).size.width,
                margin: EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_LARGE),
                decoration: BoxDecoration(borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL), color: Theme.of(context).primaryColor.withOpacity(0.20)),
                child: ClipRRect(
                  borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
                  child: CustomImage(
                    isNotification: true,
                    image: '${ notificationModel.data.imgPlacement==null?  Get.find<SplashController>().configModel.baseUrls.notificationImageUrl : Get.find<SplashController>().configModel.baseUrls.notificationImageUrl2}/${notificationModel.data.image}',
                    width: MediaQuery.of(context).size.width, fit: BoxFit.contain,
                  ),
                ),
              ) : SizedBox(),
              SizedBox(height: (notificationModel.data.image != null && notificationModel.data.image.isNotEmpty)
                  ? Dimensions.PADDING_SIZE_LARGE : 0),

              Padding(
                padding: EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_LARGE),
                child: (notificationModel.data.title!=null && notificationModel.data.title.startsWith('<'))  ? Html(
                  data: notificationModel.data.title ?? '', shrinkWrap: true,
                  onLinkTap: (String url, RenderContext context, Map<String, String> attributes, element) {
                    if(url.startsWith('www.')) {
                      url = 'https://' + url;
                    }
                    print('Redirect to url: $url');
                    html.window.open(url, "_blank");
                  },
                )
                    : Text(
                  notificationModel.data.title,
                  textAlign: TextAlign.center,
                  style: robotoMedium.copyWith(
                    color: Theme.of(context).primaryColor,
                    fontSize: Dimensions.fontSizeLarge,
                  ),
                ),
              ),

              Padding(
                padding: EdgeInsets.fromLTRB(20, 10, 20, 20),
                child: (notificationModel.data.description!=null && notificationModel.data.description.startsWith('<'))  ? Html(
                  data: notificationModel.data.description ?? '', shrinkWrap: true,
                  onLinkTap: (String url, RenderContext context, Map<String, String> attributes, element) {
                    if(url.startsWith('www.')) {
                      url = 'https://' + url;
                    }
                    print('Redirect to url: $url');
                    html.window.open(url, "_blank");
                  },
                )
                    : Text(
                  notificationModel.data.description,
                  textAlign: TextAlign.start,
                  style: robotoRegular.copyWith(
                    color: Theme.of(context).disabledColor,
                  ),
                ),
              ),

            ],
          )
          :

          Column(
            mainAxisSize: MainAxisSize.min,
            children: [

              Align(
                alignment: Alignment.centerRight,
                child: IconButton(
                  icon: Icon(Icons.close),
                  onPressed: () => Navigator.of(context).pop(),
                ),
              ),


              Padding(
                padding: EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_LARGE),
                child: (notificationModel.data.title!=null && notificationModel.data.title.startsWith('<'))  ? Html(
                  data: notificationModel.data.title ?? '', shrinkWrap: true,
                  onLinkTap: (String url, RenderContext context, Map<String, String> attributes, element) {
                    if(url.startsWith('www.')) {
                      url = 'https://' + url;
                    }
                    print('Redirect to url: $url');
                    html.window.open(url, "_blank");
                  },
                )
                    : Text(
                  notificationModel.data.title,
                  textAlign: TextAlign.center,
                  style: robotoMedium.copyWith(
                    color: Theme.of(context).primaryColor,
                    fontSize: Dimensions.fontSizeLarge,
                  ),
                ),
              ),

              (notificationModel.data.image != null && notificationModel.data.image.isNotEmpty && (notificationModel.data.imgPlacement==AppConstants.imgPlacement_after_header || notificationModel.data.imgPlacement==AppConstants.imgPlacement_before_body_text)) ? Container(
                width: MediaQuery.of(context).size.width,
                margin: EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_LARGE),
                decoration: BoxDecoration(borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL), color: Theme.of(context).primaryColor.withOpacity(0.20)),
                child: ClipRRect(
                  borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
                  child: CustomImage(
                    isNotification: true,
                    image: '${Get.find<SplashController>().configModel.baseUrls.notificationImageUrl2}/${notificationModel.data.image}',
                    width: MediaQuery.of(context).size.width, fit: BoxFit.contain,
                  ),
                ),
              ) : SizedBox(),
              SizedBox(height: (notificationModel.data.image != null && notificationModel.data.image.isNotEmpty && (notificationModel.data.imgPlacement==AppConstants.imgPlacement_after_header || notificationModel.data.imgPlacement==AppConstants.imgPlacement_before_body_text))
                  ? Dimensions.PADDING_SIZE_LARGE : 0),

              Padding(
                padding: EdgeInsets.fromLTRB(20, 10, 20, 20),
                child: (notificationModel.data.description!=null && notificationModel.data.description.startsWith('<'))  ? Html(
                  data: notificationModel.data.description ?? '', shrinkWrap: true,
                  onLinkTap: (String url, RenderContext context, Map<String, String> attributes, element) {
                    if(url.startsWith('www.')) {
                      url = 'https://' + url;
                    }
                    print('Redirect to url: $url');
                    html.window.open(url, "_blank");
                  },
                )
                    : Text(
                  notificationModel.data.description,
                  textAlign: TextAlign.start,
                  style: robotoRegular.copyWith(
                    color: Theme.of(context).disabledColor,
                  ),
                ),
              ),

              (notificationModel.data.image != null && notificationModel.data.image.isNotEmpty && (notificationModel.data.imgPlacement==AppConstants.imgPlacement_after_body_text || notificationModel.data.imgPlacement==AppConstants.imgPlacement_bottom)) ? Container(
                width: MediaQuery.of(context).size.width,
                margin: EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_LARGE),
                decoration: BoxDecoration(borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL), color: Theme.of(context).primaryColor.withOpacity(0.20)),
                child: ClipRRect(
                  borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
                  child: CustomImage(
                    isNotification: true,
                    image: '${Get.find<SplashController>().configModel.baseUrls.notificationImageUrl2}/${notificationModel.data.image}',
                    width: MediaQuery.of(context).size.width, fit: BoxFit.contain,
                  ),
                ),
              ) : SizedBox(),

            ],
          ),
        ),
      ),
    );
  }
}
