import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:shimmer_animation/shimmer_animation.dart';

import '../../../../helper/price_converter.dart';
import '../../../../helper/responsive_helper.dart';
import '../../../../util/dimensions.dart';
import '../../../../util/styles.dart';
import '../../../base/footer_view.dart';
import '../../../base/title_widget.dart';

class OrderDetailsShimmer extends StatelessWidget {
  final bool isEnabled;
  OrderDetailsShimmer({@required this.isEnabled});

  @override
  Widget build(BuildContext context) {
    return Shimmer(
      duration: Duration(seconds: 1),
      enabled: isEnabled,
      child: Column(mainAxisAlignment: MainAxisAlignment.start, children: [
        Expanded(child: Scrollbar(child: SingleChildScrollView(
          physics: BouncingScrollPhysics(),
          padding: ResponsiveHelper.isDesktop(context) ? EdgeInsets.zero : EdgeInsets.all(Dimensions.PADDING_SIZE_SMALL),
          child: FooterView(child: SizedBox(width: Dimensions.WEB_MAX_WIDTH, child: Column(crossAxisAlignment: CrossAxisAlignment.start,
              children: [

                Row(children: [
                  Text('order_id'.tr, style: robotoRegular),
                  SizedBox(width: Dimensions.PADDING_SIZE_EXTRA_SMALL),
                  Container(
                    height: 15, width: 50,
                    color: Colors.grey[200],
                  ),
                  SizedBox(width: Dimensions.PADDING_SIZE_EXTRA_SMALL),
                  Expanded(child: SizedBox()),
                  Icon(Icons.watch_later, size: 17),
                  SizedBox(width: Dimensions.PADDING_SIZE_EXTRA_SMALL),
                  Container(
                    padding: const EdgeInsets.symmetric(horizontal: 10),
                    height: 15, width: 50,
                    color: Colors.grey[200],
                  ),
                ]),
                SizedBox(height: Dimensions.PADDING_SIZE_SMALL),


              Row(children: [
                Text('${'delivery_verification_code'.tr}:', style: robotoRegular),
                SizedBox(width: Dimensions.PADDING_SIZE_EXTRA_SMALL),
                Container(
                  height: 15, width: 50,
                  color: Colors.grey[200],
                ),
              ]),

                  SizedBox(height: 10),

                Row(children: [
                  Container(
                    height: 15, width: 50,
                    color: Colors.grey[200],
                  ),
                  Expanded(child: SizedBox()),
                  Container(
                    padding: EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_SMALL, vertical: Dimensions.PADDING_SIZE_EXTRA_SMALL),
                    decoration: BoxDecoration(
                      color: Theme.of(context).primaryColor, borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
                    ),
                    child: Container(
                      height: 15, width: 90,
                      color: Colors.grey[200],
                    ),
                  ),
                ]),
                Divider(height: Dimensions.PADDING_SIZE_LARGE),

                Padding(
                  padding: EdgeInsets.symmetric(vertical: Dimensions.PADDING_SIZE_EXTRA_SMALL),
                  child: Row(children: [
                    Text('${'item'.tr}:', style: robotoRegular),
                    SizedBox(width: Dimensions.PADDING_SIZE_EXTRA_SMALL),
                    Container(height: 15, width: 15, color: Colors.grey[200],),
                    Expanded(child: SizedBox()),
                    Container(height: 7, width: 7, decoration: BoxDecoration(
                      color:  Colors.grey[200],
                      shape: BoxShape.circle,
                    )),
                    SizedBox(width: Dimensions.PADDING_SIZE_EXTRA_SMALL),
                    Container(
                      height: 10, width: 70,
                      color: Colors.grey[200],
                    ),
                  ]),
                ),
                Divider(height: Dimensions.PADDING_SIZE_LARGE),
                SizedBox(height: Dimensions.PADDING_SIZE_SMALL),

                Text('${'store_details'.tr}:', style: robotoRegular),
                SizedBox(height: Dimensions.PADDING_SIZE_LARGE ),

                Row(crossAxisAlignment: CrossAxisAlignment.start,mainAxisAlignment: MainAxisAlignment.spaceBetween, children: [
                  Row(
                    children: [
                      Container(height: 50, width: 50, decoration: BoxDecoration(
                        color:  Colors.grey[200],
                        shape: BoxShape.circle,
                      )),
                      Padding(
                        padding: const EdgeInsets.all(8.0),
                        child: Container(
                          height: 10, width: 70,
                          color: Colors.grey[200],
                        ),
                      ),
                    ],
                  ),

                  TextButton.icon(
                    onPressed: ()  {},
                    icon: Icon(Icons.chat_bubble_outline, color: Theme.of(context).primaryColor, size: 20),
                    label: Text(
                      'chat'.tr,
                      style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall, color: Theme.of(context).primaryColor),
                    ),
                  ),
                ]),

                 SizedBox(height: Dimensions.PADDING_SIZE_LARGE ),
                 Column(crossAxisAlignment: CrossAxisAlignment.start, children: [
                  Row(mainAxisAlignment: MainAxisAlignment.spaceBetween, children: [
                    Text('item_price'.tr, style: robotoRegular),
                    Container(
                      height: 10, width: 70,
                      color: Colors.grey[200],
                    ),
                  ]),
                  SizedBox(height: 10),


                  Row(mainAxisAlignment: MainAxisAlignment.spaceBetween, children: [
                    Text('discount'.tr, style: robotoRegular),
                    Container(
                      height: 10, width: 70,
                      color: Colors.grey[200],
                    ),
                  ]),
                  SizedBox(height: 10),


                  Row(mainAxisAlignment: MainAxisAlignment.spaceBetween, children: [
                    Text('delivery_fee'.tr, style: robotoRegular),
                    Container(
                      height: 10, width: 70,
                      color: Colors.grey[200],
                    ),
                  ]),
                ]),

                Padding(
                  padding: EdgeInsets.symmetric(vertical: Dimensions.PADDING_SIZE_SMALL),
                  child: Divider(thickness: 1, color: Theme.of(context).hintColor.withOpacity(0.5)),
                ),

                Row(mainAxisAlignment: MainAxisAlignment.spaceBetween, children: [
                  Text('total_amount'.tr, style: robotoMedium.copyWith(
                    fontSize: Dimensions.fontSizeLarge, color: Theme.of(context).primaryColor,
                  )),
                  Container(
                    height: 10, width: 70,
                    color: Colors.grey[200],
                  ),
                ]),

              ]))),
        ))),

        Padding(
          padding: const EdgeInsets.all(8.0),
          child: SizedBox(
            width: Dimensions.WEB_MAX_WIDTH,
            child: Row(
              mainAxisAlignment: MainAxisAlignment.center,
                children: [
              Container(
                height: 50, width: 130,
                color: Colors.grey[200],
              ),
                  SizedBox(width: 50,),
              Container(
                height: 50, width: 130,
                color: Colors.grey[200],
              ),
            ]),
          ),
        ),
      ]),
    );
  }

}

