import 'dart:io';

import 'package:phone_number/phone_number.dart';
import 'package:sixam_mart/view/base/custom_app_bar.dart';
import 'package:sixam_mart/view/base/footer_view.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_drawer.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:url_launcher/url_launcher.dart';

import '../../../controller/auth_controller.dart';
import '../../../controller/splash_controller.dart';
import '../../../controller/user_controller.dart';
import '../../../data/model/body/prime_member_create_body.dart';
import '../../../helper/route_helper.dart';
import '../../../util/app_constants.dart';
import '../../../util/dimensions.dart';
import '../../../util/images.dart';
import '../../../util/styles.dart';
import '../../base/custom_button.dart';
import '../../base/custom_dialog.dart';
import '../../base/custom_image.dart';
import '../../base/custom_snackbar.dart';
import '../../base/my_text_field.dart';
import '../order/widget/order_details_shimmer.dart';
import 'package:url_launcher/url_launcher.dart' as UrlLauncher;


class SelectedPrimeScreen extends StatefulWidget {

  final String clientReferral;
  final String id;
  SelectedPrimeScreen({@required this.clientReferral,@required this.id});

  @override
  State<SelectedPrimeScreen> createState() => _SelectedPrimeScreenState();
}

class _SelectedPrimeScreenState extends State<SelectedPrimeScreen> {


  @override
  void initState() {
    super.initState();

    Get.find<UserController>().getClientSidePrimeUserInfo(widget.clientReferral);

  }



  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: CustomAppBar(title: 'prime'.tr),
      endDrawer: WebMenuDrawer(),
      body: Scrollbar(child: SingleChildScrollView(
        physics: BouncingScrollPhysics(),
        child: FooterView(child: Container(
          width: context.width,
          height: context.height,
          color: Theme.of(context).backgroundColor,
          child: Padding(
            padding: const EdgeInsets.all(10.0),
            child: GetBuilder<UserController>(builder: (userController) {

              return userController.referralInfo != null ?
              Column(crossAxisAlignment: CrossAxisAlignment.start,children: [
                Container(
                  padding: const EdgeInsets.only(left: 10,right: 10,top: 5),
                  decoration: BoxDecoration(
                    color: Colors.white,
                    borderRadius: BorderRadius.circular(Dimensions.RADIUS_LARGE),
                    boxShadow: [BoxShadow(color: Theme.of(context).primaryColor, spreadRadius: 1.5, blurRadius: 2)],
                  ),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Row(
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        children: [
                          Container(
                            decoration: BoxDecoration(
                              border: Border.all(width: 2, color: userController.referralInfo.image != null ? Theme.of(context).primaryColor :Colors.transparent),
                              shape: BoxShape.circle,
                            ),
                            alignment: Alignment.center,
                            child: ClipOval(child: CustomImage(
                              image: '${Get.find<SplashController>().configModel.baseUrls.customerImageUrl}'
                                  '/${userController.referralInfo.image != null  ? userController.referralInfo.image : ''}',
                              height: 90, width: 90, fit: BoxFit.fill,isProfile: true,
                            )),
                          ),
                          Container(
                            alignment: Alignment.topRight,
                            width: 100,
                            padding: EdgeInsets.all(5),
                            child: InkWell(child: Text('change'.tr,style: TextStyle(fontSize: 15, color: Theme.of(context).primaryColor) ),
                              onTap: (){
                                Get.toNamed(RouteHelper.getPrimeMemberBankDetailsRoute(''));

                              },),
                          )
                        ],
                      ),

                      SizedBox(height: 5,),

                      Row(
                        children: [
                          Text("Name", style:TextStyle(fontSize: 15, color: Colors.black)),
                          SizedBox(width: 5,),
                          Text(':', style:TextStyle(fontSize: 15, color: Colors.black)),
                          SizedBox(width: 10,),
                          Text(
                            userController.referralInfo.name == null ? "NA" : userController.referralInfo.name,
                            style: TextStyle(fontSize: 15.0),
                          ),
                        ],
                      ),
                      SizedBox(height: 5,),

                      Row(
                        children: [
                          Text("Prime Member Since", style:TextStyle(fontSize: 15, color: Colors.black)),
                          SizedBox(width: 5,),
                          Text(':', style:TextStyle(fontSize: 15, color: Colors.black)),
                          SizedBox(width: 10,),
                          Text(
                            userController.referralInfo.primeSince == null ? "NA" : userController.referralInfo.primeSince,
                            style: TextStyle(fontSize: 15.0),
                          ),
                        ],
                      ),
                      SizedBox(height: 5,),

                      Row(
                        children: [
                          Text("Total Prime", style:TextStyle(fontSize: 15, color: Colors.black)),
                          SizedBox(width: 5,),
                          Text(':', style:TextStyle(fontSize: 15, color: Colors.black)),
                          SizedBox(width: 10,),
                          Text(
                            userController.referralInfo.underTotalPrime.toString() == null ? "0" : userController.referralInfo.underTotalPrime.toString(),
                            style: TextStyle(fontSize: 15.0),
                          ),
                        ],
                      ),
                      SizedBox(height: 5,),


                      Row(
                        children: [
                          Text("Mobile", style:TextStyle(fontSize: 15, color: Colors.black)),
                          SizedBox(width: 5,),
                          Text(':', style:TextStyle(fontSize: 15, color: Colors.black)),
                          SizedBox(width: 10,),
                          InkWell(child: Text(
                            userController.referralInfo.phone == null ? "NA" : userController.referralInfo.phone,
                            style: TextStyle(fontSize: 15.0),
                          ) , onTap: () async {
                            try{
                              if(userController.referralInfo.phone != null && userController.referralInfo.phone.isNotEmpty) {
                                final call = Uri.parse('tel:${userController.referralInfo.phone}');
                                if (await canLaunchUrl(call)) {
                                  launchUrl(call);
                                }
                                else {
                                  throw 'Could not launch $call';
                                }
                              }
                            }catch(e){
                            }
                          },),
                        ],
                      ),
                      SizedBox(height: 5,),
                    ],
                  ),
                ),

                SizedBox(height: 100.0),
                Center(child: Text('payment_for_prime_member'.tr, style:TextStyle(fontSize: 15, color: Colors.black))),
                SizedBox(height: 20,),
                Container(
                  width: Dimensions.WEB_MAX_WIDTH,
                  padding: EdgeInsets.all(5),
                  child: CustomButton(buttonText: 'next'.tr, onPressed: () {


                  }),
                )

              ]) :
              Center(child: CircularProgressIndicator());
              //OrderDetailsShimmer(isEnabled: userController.orderDetails==null,);
            }),
          ),
        )),)),
    );
  }

}

