
import 'dart:async';
import 'dart:math';

import 'package:flutter/services.dart';
import 'package:im_animations/im_animations.dart';
import 'package:shimmer_animation/shimmer_animation.dart';
import 'package:sixam_mart/controller/auth_controller.dart';
import 'package:sixam_mart/controller/cart_controller.dart';
import 'package:sixam_mart/controller/item_controller.dart';
import 'package:sixam_mart/controller/search_controller.dart';
import 'package:sixam_mart/controller/splash_controller.dart';
import 'package:sixam_mart/helper/responsive_helper.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/styles.dart';
import 'package:sixam_mart/view/base/custom_button.dart';
import 'package:sixam_mart/view/base/custom_image.dart';
import 'package:sixam_mart/view/base/footer_view.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_drawer.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_bar.dart';
import 'package:sixam_mart/view/screens/search/widget/filter_widget.dart';
import 'package:sixam_mart/view/screens/search/widget/search_field.dart';
import 'package:sixam_mart/view/screens/search/widget/search_result_widget.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:sixam_mart/view/screens/store/widget/bottom_cart_widget.dart';
import 'package:speech_to_text/speech_recognition_error.dart';
import 'package:speech_to_text/speech_to_text.dart' as speechToText;
import 'package:speech_to_text/speech_to_text.dart';

import '../../../controller/chat_controller.dart';
import '../../../controller/prime_member_controller.dart';
import '../../../util/app_constants.dart';
import '../../../util/images.dart';
import '../../base/custom_app_bar.dart';
import '../../base/custom_snackbar.dart';
import '../../base/custom_text_field.dart';
import '../../base/no_data_screen.dart';
import '../admin_screen/upi_payment_resquest_screen.dart';

class PrimeSearchScreen extends StatefulWidget {

  @override
  _PrimeSearchScreenState createState() => _PrimeSearchScreenState();
}

class _PrimeSearchScreenState extends State<PrimeSearchScreen> {
  bool _canSearch = true;
  bool _isLoggedIn;
  bool _logEvents = false;
  String lastError = '';
  String lastStatus = '';
  String _currentLocaleId = '';
  List<LocaleName> _localeNames = [];
  final TextEditingController _pauseForController =
  TextEditingController(text: '3');
  final TextEditingController _listenForController =
  TextEditingController(text: '30');
  double level = 0.0;
  double minSoundLevel = 50000;
  double maxSoundLevel = -50000;
  Timer timeHandle;
  final TextEditingController _inputMessageController = TextEditingController();


  @override
  void dispose() {
    timeHandle?.cancel();
    super.dispose();
  }

  @override
  void initState() {
    super.initState();


    _isLoggedIn = Get.find<AuthController>().isLoggedIn();
   // _searchController.addListener(textListener);
  }


  textListener(String searchedData) {

    if (searchedData != null && searchedData.isNotEmpty &&
        searchedData.length > 1) {
      if (timeHandle != null) {
        timeHandle.cancel();
      }
      timeHandle = Timer(Duration(milliseconds: 1200), () {
        _actionSearch(searchedData);
      });
    }
  }


  @override
  Widget build(BuildContext context) {
    bool _desktop = ResponsiveHelper.isDesktop(context);
    bool _isTab = ResponsiveHelper.isTab(context);
    bool _isWeb = ResponsiveHelper.isWeb();
    bool _isMobile = ResponsiveHelper.isMobile(context);
    double _width = MediaQuery
        .of(context)
        .size
        .width;
    print(
        "testResponsiveHelper SearchScreen _width $_width _desktop $_desktop _isTab $_isTab isWeb $_isWeb _isMobile $_isMobile");

    return WillPopScope(
      onWillPop: () async {
        Get.find<PrimeMemberController>().setSearchMode();
        return true;
      },
      child: Scaffold(
          appBar: CustomAppBar(title:'search_prime'.tr),

          endDrawer: WebMenuDrawer(),
          body: SafeArea(child: Padding(
            padding: ResponsiveHelper.isDesktop(context)
                ? EdgeInsets.zero
                : EdgeInsets.symmetric(vertical: Dimensions.PADDING_SIZE_SMALL),
            child: GetBuilder<PrimeMemberController>(builder: (searchController) {

              return Column(children: [

                Padding(
                  padding: const EdgeInsets.all(8.0),
                  child: Row(children: [

                    SizedBox(width: Dimensions.PADDING_SIZE_DEFAULT),

                    Expanded(
                      child: TextField(
                        inputFormatters: [LengthLimitingTextInputFormatter(Dimensions.MESSAGE_INPUT_LENGTH)],
                        controller: _inputMessageController,
                        textCapitalization: TextCapitalization.sentences,
                        style: robotoRegular,
                        keyboardType: TextInputType.multiline,
                        maxLines: null,
                        decoration: InputDecoration(
                          border: InputBorder.none,
                          hintText: 'type_here'.tr,
                          hintStyle: robotoRegular.copyWith(color: Theme.of(context).hintColor, fontSize: Dimensions.fontSizeLarge),
                        ),
                        onSubmitted: (String newText) {
                          if(newText.trim().isNotEmpty && !Get.find<PrimeMemberController>().isSendButtonActive) {
                            Get.find<PrimeMemberController>().toggleSendButtonActivity();
                          }else if(newText.isEmpty && Get.find<PrimeMemberController>().isSendButtonActive) {
                            Get.find<PrimeMemberController>().toggleSendButtonActivity();
                          }
                        },
                        onChanged: (String newText) {
                          if(newText.trim().isNotEmpty && !Get.find<PrimeMemberController>().isSendButtonActive) {
                            Get.find<PrimeMemberController>().toggleSendButtonActivity();
                          }else if(newText.isEmpty && Get.find<PrimeMemberController>().isSendButtonActive) {
                            Get.find<PrimeMemberController>().toggleSendButtonActivity();
                          }
                        },
                      ),
                    ),

                    GetBuilder<PrimeMemberController>(builder: (chatController) {
                      return chatController.isLoading ? Padding(
                        padding: EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_DEFAULT),
                        child: SizedBox(height: 25, width: 25, child: CircularProgressIndicator()),
                      )
                          : InkWell(
                        onTap: () async {
                          //Get.find<PrimeMemberController>().getSearchData(queryText);
                          if(chatController.isSendButtonActive) {

                            chatController.getSearchData(
                                 _inputMessageController.text.toString()
                            );

                            //_inputMessageController.clear();

                          }
                          else {
                            showCustomSnackBar('write_something'.tr);
                          }
                        },
                        child: Padding(
                          padding: EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_DEFAULT),
                          child: Container(
                            padding: const EdgeInsets.only(left: 10,right: 10,top: 2,bottom: 2),
                            decoration: BoxDecoration(
                                border: Border.all(color: Colors.white),
                                color: Theme.of(context).primaryColor
                            ),
                            child: Text('Find', style:
                            robotoMedium.copyWith(fontSize:
                            18,color: Colors.white)),
                          ),
                        ),
                      );
                    }
                    ),

                  ]),
                ),

                Expanded(child:
                 SearchResultWidget()),

              ]);
            }),
          )),

          bottomNavigationBar: GetBuilder<CartController>(
              builder: (cartController) {
                return cartController.cartList.length > 0 &&
                    !ResponsiveHelper.isDesktop(context)
                    ? BottomCartWidget()
                    : SizedBox();
              })
      ),
    );
  }

  void _actionSearch(String queryText) {
    if (queryText.isNotEmpty) {
      Get.find<PrimeMemberController>().getSearchData(queryText);
    }
  }
}

class SearchResultWidget extends StatefulWidget {

  @override
  _SearchResultWidgetState createState() => _SearchResultWidgetState();
}

class _SearchResultWidgetState extends State<SearchResultWidget> with TickerProviderStateMixin {
  TabController _tabController;
  final ScrollController scrollController = ScrollController();

  @override
  void initState() {
    super.initState();

    _tabController = TabController(length: 2, initialIndex: 0, vsync: this);
  }

  @override
  Widget build(BuildContext context) {
    bool _desktop = ResponsiveHelper.isDesktop(context);
    bool _isTab = ResponsiveHelper.isTab(context);
    bool _isWeb = ResponsiveHelper.isWeb();
    bool _isMobile = ResponsiveHelper.isMobile(context);
    double _width = MediaQuery.of(context).size.width;
    print("testResponsiveHelper SearchResultWidget _width $_width _desktop $_desktop _isTab $_isTab isWeb $_isWeb _isMobile $_isMobile");

    return GetBuilder<PrimeMemberController>(
        builder: (userController) {
          return SafeArea(
            child: SingleChildScrollView(
              controller: scrollController,
              padding: EdgeInsets.symmetric(horizontal: ResponsiveHelper.isDesktop(context) ? 0.0 : Dimensions.PADDING_SIZE_DEFAULT),
              child: FooterView(
                child: SizedBox(
                  width: Dimensions.WEB_MAX_WIDTH,
                  child: GetBuilder<PrimeMemberController>(

                      builder: (primeController) {
                        return Column(children: [
                          SizedBox(height: 10,),

                          primeController.searchedPrimeMembersList != null ? primeController.searchedPrimeMembersList.length > 0 ?
                          ListView.builder(
                            shrinkWrap: true,
                            scrollDirection: Axis.vertical,
                            itemCount: primeController.searchedPrimeMembersList.length,
                            physics: BouncingScrollPhysics(),
                            itemBuilder: (context, index) {
                              return Padding(
                                padding: const EdgeInsets.only(top: 8,bottom: 8,left: 5 , right: 5),
                                child:  InkWell(
                                  onTap: () {
                                    primeController.setGoingToSearch(true);
                                    primeController.updateReferenceDropdown(primeController.searchedPrimeMembersList[index]);
                                    Get.back();
                                  },
                                  child: Container(
                                    decoration: BoxDecoration(
                                      color: Colors.grey.shade200,

                                      borderRadius: BorderRadius.circular(Dimensions.RADIUS_LARGE),
                                    ),
                                    child: Row(
                                      children: [
                                        Padding(
                                          padding: const EdgeInsets.only(right: 10,left: 10),
                                          child: Container(
                                            decoration: BoxDecoration(
                                              border: Border.all(width: 2, color: Theme.of(context).cardColor),
                                              shape: BoxShape.circle,
                                            ),
                                            alignment: Alignment.topLeft,
                                            child: ClipOval(child: CustomImage(
                                              image: '${Get.find<SplashController>().configModel.baseUrls.customerImageUrl}'
                                                  '/${primeController.searchedPrimeMembersList[index].image != null  ? primeController.searchedPrimeMembersList[index].image : ''}',
                                              height: 40, width: 40, fit: BoxFit.cover,isProfile: true,
                                            )),
                                          ),
                                        ),
                                        Column(
                                          crossAxisAlignment: CrossAxisAlignment.start,
                                          children: [
                                            SizedBox(height: 5,),
                                            Text(
                                              '${ primeController.searchedPrimeMembersList[index].fName} ${ primeController.searchedPrimeMembersList[index].lName} ',
                                              style: TextStyle(fontSize: 18.0),
                                            ),
                                            SizedBox(height: 5,),
                                            Text(
                                              '${primeController.searchedPrimeMembersList[index].primeAccountNo} ',
                                              style: TextStyle(fontSize: 15.0),
                                            ),

                                            SizedBox(height: 5,),
                                            Text(
                                              primeController.searchedPrimeMembersList[index].phone,
                                              style: TextStyle(fontSize: 15.0),
                                            ),
                                            SizedBox(height: 5,),
                                            Text(
                                              primeController.searchedPrimeMembersList[index].refCode==null? '' : primeController.searchedPrimeMembersList[index].refCode,
                                              style: TextStyle(fontSize: 15.0),
                                            ),

                                            SizedBox(height: 10,),

                                          ]
                                          ,)
                                      ],
                                    ),
                                  ),
                                ),
                              );
                            },
                          )
                              : NoDataScreen(text: 'no_data_found'.tr)
                              : SizedBox(),

                        ]);
                      }
                  ),
                ),
              ),
            ),
          );
        }
    );
  }
}


