
import 'package:flip_card/flip_card.dart';
import 'package:sixam_mart/controller/auth_controller.dart';
import 'package:sixam_mart/controller/splash_controller.dart';
import 'package:sixam_mart/controller/user_controller.dart';
import 'package:sixam_mart/data/model/response/userinfo_model.dart';
import 'package:sixam_mart/helper/price_converter.dart';
import 'package:sixam_mart/helper/responsive_helper.dart';
import 'package:sixam_mart/helper/route_helper.dart';
import 'package:sixam_mart/util/app_constants.dart';
import 'package:qr_flutter/qr_flutter.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/images.dart';
import 'package:sixam_mart/util/styles.dart';
import 'package:sixam_mart/view/base/confirmation_dialog.dart';
import 'package:sixam_mart/view/base/custom_image.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_drawer.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_bar.dart';
import 'package:sixam_mart/view/screens/profile/widget/profile_bg_widget.dart';
import 'package:sixam_mart/view/screens/profile/widget/profile_button.dart';
import 'package:sixam_mart/view/screens/profile/widget/profile_card.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:url_launcher/url_launcher_string.dart';
import '../../base/custom_button.dart';
import '../../base/custom_snackbar.dart';
import '../support/widget/support_button.dart';

class ProfileScreen extends StatefulWidget {

  final String isBackButton;

  ProfileScreen({@required this.isBackButton});

  @override
  State<ProfileScreen> createState() => _ProfileScreenState();
}

class _ProfileScreenState extends State<ProfileScreen> {
  bool _isLoggedIn = Get.find<AuthController>().isLoggedIn();

  @override
  void initState() {
    super.initState();

    //if(_isLoggedIn && Get.find<UserController>().userInfoModel == null) {
    if(_isLoggedIn ) {
      Get.find<UserController>().getUserInfo();
    }
  }
  //

  @override
  Widget build(BuildContext context) {
    final bool _showWalletCard = Get.find<SplashController>().configModel.customerWalletStatus == 1
        || Get.find<SplashController>().configModel.loyaltyPointStatus == 1;

    return Scaffold(
      appBar: ResponsiveHelper.isDesktop(context) ? WebMenuBar() : null,
      endDrawer: WebMenuDrawer(),
      backgroundColor: Theme.of(context).cardColor,
      body: GetBuilder<UserController>(builder: (userController) {
        return (_isLoggedIn && userController.userInfoModel == null) ? Center(child: CircularProgressIndicator())
            : ProfileBgWidget(
          backButton: widget.isBackButton == 'true' ? true : false,
          circularImage: Container(
            decoration: BoxDecoration(
              border: Border.all(width: 2, color: Theme.of(context).cardColor),
              shape: BoxShape.circle,
            ),
            alignment: Alignment.center,
            child: ClipOval(child: CustomImage(
              image: '${Get.find<SplashController>().configModel.baseUrls.customerImageUrl}'
                  '/${(userController.userInfoModel != null && _isLoggedIn) ? userController.userInfoModel.image : ''}',
              height: 100, width: 100, fit: BoxFit.cover,isProfile: true,
            )),
          ),
          mainWidget: SingleChildScrollView(physics: BouncingScrollPhysics(),
              child: Column(
                  mainAxisSize: MainAxisSize.max,
                  children: [

                    Text(
                      _isLoggedIn ? '${userController.userInfoModel.fName} ${userController.userInfoModel.lName}' : 'guest'.tr,
                      style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeLarge),
                    ),
                    SizedBox(height: 30),

                    ( _isLoggedIn && userController.userInfoModel.primeMember!=null && userController.userInfoModel.primeMember==1) ?
                    FlipCardScreen(userController.userInfoModel) : SizedBox(),

                    _isLoggedIn ? Row(children: [
                      ProfileCard( title : 'since_joining'.tr, data: '${userController.userInfoModel.memberSinceDays} ${'days'.tr}'),
                      SizedBox( width: Dimensions.PADDING_SIZE_SMALL),
                      ProfileCard( title : 'total_order'.tr, data: userController.userInfoModel.orderCount.toString()),
                    ]) :
                    SizedBox(),

                    SizedBox( height:( _isLoggedIn &&
                        userController.userInfoModel.refIncome!=null
                        && userController.userInfoModel.sponsorIncome!=null) ? Dimensions.PADDING_SIZE_SMALL:0.0),

                    _isLoggedIn? Row(children: [
                      userController.userInfoModel.refIncome!=null ?
                      ProfileCard( title : 'referral_income'.tr,
                          data: PriceConverter.convertPrice(userController.userInfoModel.refIncome)) :SizedBox(),
                      SizedBox( width:userController.userInfoModel.refIncome!=null ? Dimensions.PADDING_SIZE_SMALL:0.0),
                      userController.userInfoModel.sponsorIncome!=null ? ProfileCard( title : 'sponsor_income'.tr,
                          data: PriceConverter.convertPrice(userController.userInfoModel.sponsorIncome)) : SizedBox(),
                    ]):
                    SizedBox(),



                    SizedBox( height: _showWalletCard ? Dimensions.PADDING_SIZE_SMALL : 0),
                    ( _showWalletCard && _isLoggedIn ) ? Row( children: [
                      Get.find<SplashController>().configModel.customerWalletStatus == 1 ?
                      ProfileCard(
                        title: 'wallet_amount'.tr,
                        data: PriceConverter.convertPrice(userController.userInfoModel.walletBalance),
                      ) : SizedBox.shrink(),


                      SizedBox( width: Dimensions.PADDING_SIZE_SMALL ),
                      ProfileCard(
                        title : 'recharge_your_wallet'.tr,
                        data : 'recharge'.tr,
                      ),


                      // SizedBox( width: Get.find<SplashController>().configModel.customerWalletStatus == 1
                      //     && Get.find<SplashController>().configModel.loyaltyPointStatus == 1 ? Dimensions.PADDING_SIZE_SMALL : 0.0),
                      // Get.find<SplashController>().configModel.loyaltyPointStatus == 1 ? ProfileCard(
                      //   title : 'loyalty_points'.tr,
                      //   data : userController.userInfoModel.loyaltyPoint != null ? userController.userInfoModel.loyaltyPoint.toString() : '0',
                      // ) : SizedBox.shrink(),
                    ] )
                        : SizedBox(),

                    ( _isLoggedIn && userController.userInfoModel.appSharable!=null
                        && userController.userInfoModel.appSharable=="true" ) ?
                    Padding(
                      padding: const EdgeInsets.all(20.0),
                      child:
                      CustomButton(buttonText: 'refer_and_earn'.tr,icon: Icons.share, onPressed: () {
                        Get.toNamed(RouteHelper.getReferAndEarnRoute());
                      })
                    )
                        :SizedBox(),

                    // ProfileButton(icon: Icons.dark_mode, title: 'dark_mode'.tr, isButtonActive: Get.isDarkMode, onTap: () {
                    //   Get.find<ThemeController>().toggleTheme();
                    // }),
                    SizedBox(height: _isLoggedIn ? Dimensions.PADDING_SIZE_SMALL : 0),

                    _isLoggedIn ? GetBuilder<AuthController>(builder: (authController) {
                      return ProfileButton(
                        icon: Icons.notifications, title: 'notification'.tr,
                        isButtonActive: authController.notification, onTap: () {
                        authController.setNotificationActive(!authController.notification);
                      },
                      );
                    }) : SizedBox(),

                    SizedBox(height: _isLoggedIn ? Dimensions.PADDING_SIZE_SMALL : 0),
                    _isLoggedIn? ProfileButton(icon: Icons.edit, title: 'edit_profile'.tr,
                        onTap: () {
                      Get.toNamed(RouteHelper.getUpdateProfileRoute());
                    }): SizedBox(),

                    SizedBox(height: _isLoggedIn ? Dimensions.PADDING_SIZE_SMALL : 0),

                    // _isLoggedIn? ProfileButton(icon: Icons.trending_down, title: 'view_tree'.tr,
                    //     onTap: () {
                    //       Get.toNamed(RouteHelper.getMlmTreeRoute(
                    //                   "", Get.find<UserController>().userInfoModel.id
                    //               ));
                    // }): SizedBox(),

                    SizedBox(height: _isLoggedIn ? Dimensions.PADDING_SIZE_SMALL : 0),
                    _isLoggedIn? ProfileButton(icon: Icons.edit, title: 'edit_documents'.tr, onTap: () {
                      Get.toNamed(RouteHelper.getPrimeMemberBankDetailsRoute(''));
                    //  Get.toNamed(RouteHelper.getPrimeMemberBankDetailsRoute('profile'));
                    }): SizedBox(),

                    SizedBox(height: _isLoggedIn ? Dimensions.PADDING_SIZE_SMALL : 0),
                    _isLoggedIn? ProfileButton(icon: Icons.pages, title: 'statement'.tr, onTap: () {
                      Get.toNamed(RouteHelper.getWalletRoute(true,"NA"));
                    //  Get.toNamed(RouteHelper.getPrimeMemberBankDetailsRoute('profile'));
                    }): SizedBox(),

                    SizedBox(height: _isLoggedIn ? Dimensions.PADDING_SIZE_SMALL : 0),
                    _isLoggedIn ? ProfileButton(icon: Icons.shopping_bag, title: 'my_orders'.tr, onTap: () {
                      Get.toNamed(RouteHelper.getOrderRoute());
                    }) : SizedBox(),

                    SizedBox(height: _isLoggedIn ? Dimensions.PADDING_SIZE_SMALL : 0),
                    _isLoggedIn ? ProfileButton(icon: Icons.lock, title: 'change_password'.tr, onTap: () {
                      Get.toNamed(RouteHelper.getResetPasswordRoute('', '', 'password-change'));
                    }) : SizedBox(),



                    // ProfileButton(icon: Icons.discount_outlined, title: 'coupon'.tr, onTap: () {
                    //   Get.toNamed(RouteHelper.getCouponRoute());
                    // }),

                    SizedBox(height: Dimensions.PADDING_SIZE_SMALL),
                    ProfileButton(icon: Icons.my_location, title: 'my_address'.tr, onTap: () {
                      Get.toNamed(RouteHelper.getAddressRoute());
                    }) ,


                    // SizedBox(height:Dimensions.PADDING_SIZE_SMALL),
                    // ProfileButton(icon: Icons.language_outlined, title: 'language'.tr, onTap: () {
                    //   Get.toNamed(RouteHelper.getLanguageRoute('menu'));
                    // }),

                    // SizedBox(height: _isLoggedIn ? Dimensions.PADDING_SIZE_SMALL : 0),
                    // _isLoggedIn ? ProfileButton(icon2: Images.bank, title: 'bank_details'.tr, onTap: () {
                    //   Get.toNamed(RouteHelper.getBankDetailsRoute());
                    // }): SizedBox(),


                    // SizedBox(height: _isLoggedIn ? Dimensions.PADDING_SIZE_SMALL : 0),
                    // _isLoggedIn ?  ProfileButton(icon2: Images.earning, title: 'my_earnings'.tr, onTap: () {
                    //   Get.toNamed(RouteHelper.getMyEarningsRoute());
                    // }): SizedBox(),

                    // SizedBox(height: _isLoggedIn ? Dimensions.PADDING_SIZE_SMALL : 0),
                    // _isLoggedIn ?   ProfileButton(icon: Icons.book, title: 'my_passbook'.tr, onTap: () {
                    //   Get.toNamed(RouteHelper.getMyPassbookRoute());
                    // }): SizedBox(),


                    SizedBox(height: _isLoggedIn ? Dimensions.PADDING_SIZE_LARGE : Dimensions.PADDING_SIZE_LARGE),

                    // _isLoggedIn ? ProfileButton(
                    //   icon: Icons.delete, title: 'delete_account'.tr,
                    //   onTap: () {
                    //     Get.dialog(ConfirmationDialog(icon: Images.support,
                    //       title: 'are_you_sure_to_delete_account'.tr,
                    //       description: 'it_will_remove_your_all_information'.tr, isLogOut: true,
                    //       onYesPressed: () => userController.removeUser(),
                    //     ), useSafeArea: false);
                    //   },
                    // ) :
                    // SizedBox(),

                    SizedBox(height: _isLoggedIn ? Dimensions.PADDING_SIZE_LARGE : 0),

                    Row(mainAxisAlignment: MainAxisAlignment.center, children: [
                      Text('${'version'.tr}:', style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeExtraSmall)),
                      SizedBox(width: Dimensions.PADDING_SIZE_EXTRA_SMALL),
                      Text("2023-2024", style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeExtraSmall)),
                      //Text(AppConstants.APP_VERSION.toString(), style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeExtraSmall)),
                    ]),

                  ])),
        );
      }),
    );
  }
}


class FlipCardScreen extends StatelessWidget {
  final UserInfoModel userInfoModel;
  FlipCardScreen(this.userInfoModel);


  Widget adminOnlyUI(UserInfoModel userInfoModel,BuildContext context) {

    bool _desktop = ResponsiveHelper.isDesktop(context);
    bool _isTab = ResponsiveHelper.isTab(context);
    bool _isWeb = ResponsiveHelper.isWeb();
    bool _isMobile = ResponsiveHelper.isMobile(context);
    double screenWidth = MediaQuery.of(context).size.width;

    return Container(

      width: double.infinity,
      decoration: BoxDecoration(
        gradient:  LinearGradient(
          begin: Alignment.topLeft,
          end: Alignment.bottomRight,
          colors: [
            Colors.black,
            Colors.black,
            Colors.black.withOpacity(0.8),
          ],
        ),),
      child: Column(
        mainAxisAlignment: MainAxisAlignment.start,
        crossAxisAlignment: CrossAxisAlignment.end,
        children: [
          ( userInfoModel.companyWalletSummery==null &&
              userInfoModel.companyWalletSummery.original.data!=null) ? SizedBox()
              :
              Container(
                padding: const EdgeInsets.only(left: 5.0,right: 5.0,bottom: 7.0),
               color: Colors.white,
                child: Column(
                  children: [
                    SizedBox(height: 10,),
                    Align(child: Text('${'company_credit'.tr} ', style:
                    robotoRegular.copyWith(fontSize:
                    22,color: Colors.black))
                      ,alignment : Alignment.topLeft,),

                    SizedBox(height: 10.0,),
                    Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: [
                    Container(
                      padding: const EdgeInsets.only(left: 15,right: 15,top: 5,bottom: 5),

                      child: InkWell(child: Column(
                        children: [
                          Row(
                            children: [
                              Text('${'wallet_credits'.tr}', style:
                              robotoMedium.copyWith(fontSize:
                              14,color: Colors.black.withOpacity(0.6))),

                              SizedBox(width: 3,),
                              Icon(
                                Icons.open_in_new,
                                size: 10,
                                color: Theme.of(context).primaryColor,
                              )
                            ],
                          ),

                          SizedBox(height: 3.0,),

                          Text(PriceConverter.convertPrice(double.parse(
                              userInfoModel.companyWalletSummery.original.data.walletCredits.toString()
                          )), style:
                          robotoMedium.copyWith(fontSize:
                          11,color: Colors.black.withOpacity(1.0))),
                        ],
                      ),onTap: (){
                        Get.toNamed(RouteHelper.getWalletRoute(true,'company_recharge'.tr));
                      },),
                    ),
                    Container(
                      padding: const EdgeInsets.only(left: 15,right: 15,top: 5,bottom: 5),

                      child: InkWell(child: Column(
                        children: [
                          Row(
                            children: [
                              Text('${'used_credits'.tr}', style:
                              robotoMedium.copyWith(fontSize:
                              14,color: Colors.black.withOpacity(0.6))),

                              SizedBox(width: 3,),
                              Icon(
                                Icons.open_in_new,
                                size: 10,
                                color: Theme.of(context).primaryColor,
                              )
                            ],
                          ),


                          SizedBox(height: 3.0,),
                          Text(PriceConverter.convertPrice(double.parse(
                              userInfoModel.companyWalletSummery.original.data.usedCredits.toString()
                          )), style:
                          robotoMedium.copyWith(fontSize:
                          11,color: Colors.black.withOpacity(1.0))),

                        ],
                      ),onTap: (){
                        Get.toNamed(RouteHelper.getWalletRoute(true,'transfer'.tr));
                        },),
                    ),
                    Container(
                      padding: const EdgeInsets.only(left: 15,right: 15,top: 5,bottom: 5),

                      child: InkWell(child: Column(
                        children: [
                          Row(
                            children: [
                              Text('${'available_credits'.tr}', style:
                              robotoMedium.copyWith(fontSize:
                              14,color: Colors.black.withOpacity(0.6))),

                              SizedBox(width: 3,),
                              Icon(
                                Icons.open_in_new,
                                size: 10,
                                color: Theme.of(context).primaryColor,
                              )
                            ],
                          ),


                          SizedBox(height: 3.0,),
                          Text(PriceConverter.convertPrice(double.parse(
                              userInfoModel.companyWalletSummery.original.data.availableCredits.toString()
                          )), style:
                          robotoMedium.copyWith(fontSize:
                          11,color: Colors.green)),

                        ],
                      ),onTap: (){
                        //Get.toNamed(RouteHelper.getRegisteredUsersRoute('customers'.tr));
                      },),
                    ),
              ],),

                    SizedBox(height: 5,),

                    Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: [
                        Container(
                          padding: const EdgeInsets.only(left: 15,right: 15,top: 5,bottom: 5),

                          child: InkWell(child: Column(
                            children: [
                              Row(
                                children: [
                                  Text('${'loan_credits'.tr}', style:
                                  robotoMedium.copyWith(fontSize:
                                  14,color: Colors.black.withOpacity(0.6))),

                                  Text('(${userInfoModel.companyWalletSummery.original.data.loanCount})', style:
                                  robotoMedium.copyWith(fontSize:
                                  11,color: Colors.red)),

                                  SizedBox(width: 3,),
                                  Icon(
                                    Icons.open_in_new,
                                    size: 10,
                                    color: Theme.of(context).primaryColor,
                                  )
                                ],
                              ),


                              SizedBox(height: 3.0,),

                              Text(PriceConverter.convertPrice(double.parse(
                                  userInfoModel.companyWalletSummery.original.data.loanCredits.toString()
                              )), style:
                              robotoMedium.copyWith(fontSize:
                              11,color: Colors.black.withOpacity(1.0))),

                            ],
                          ),onTap: (){
                            Get.toNamed(RouteHelper.getWalletRoute(true,'loan'.tr));

                          },),
                        ),
                        Container(
                          padding: const EdgeInsets.only(left: 15,right: 15,top: 5,bottom: 5),

                          child: InkWell(child: Column(
                            children: [
                              Row(
                                children: [
                                  Text('${'paid_credits'.tr}', style:
                                  robotoMedium.copyWith(fontSize:
                                  14,color: Colors.black.withOpacity(0.6))),

                                  Text('(${userInfoModel.companyWalletSummery.original.data.paidCount})', style:
                                  robotoMedium.copyWith(fontSize:
                                  11,color: Colors.green)),


                                  SizedBox(width: 3,),
                                  Icon(
                                    Icons.open_in_new,
                                    size: 10,
                                    color: Theme.of(context).primaryColor,
                                  )
                                ],
                              ),



                              SizedBox(height: 3.0,),

                              Text(PriceConverter.convertPrice(double.parse(
                                  userInfoModel.companyWalletSummery.original.data.paidCredits.toString()
                              )), style:
                              robotoMedium.copyWith(fontSize:
                              13,color: Colors.black.withOpacity(1.0))),

                            ],
                          ),onTap: (){
                            Get.toNamed(RouteHelper.getWalletRoute(true,'receipt'.tr));                          },),
                        ),
                        Container(
                          padding: const EdgeInsets.only(left: 15,right: 15,top: 5,bottom: 5),

                          child: InkWell(child: Column(
                            children: [
                              Row(
                                children: [
                                  Text('${'closing'.tr}', style:
                                  robotoMedium.copyWith(fontSize:
                                  14,color: Colors.black.withOpacity(0.6))),

                                  Text('(${userInfoModel.companyWalletSummery.original.data.closingCount})', style:
                                  robotoMedium.copyWith(fontSize:
                                  11,color: Colors.black)),


                                  SizedBox(width: 3,),
                                  Icon(
                                    Icons.open_in_new,
                                    size: 10,
                                    color: Theme.of(context).primaryColor,
                                  )
                                ],
                              ),


                              SizedBox(height: 3.0,),

                              Text(PriceConverter.convertPrice(double.parse(
                                  userInfoModel.companyWalletSummery.original.data.totalTeamIncome.toString()
                              )), style:
                              robotoMedium.copyWith(fontSize:
                              13,color: Colors.black.withOpacity(1.0))),
                            ],
                          ),onTap: (){
                           // Get.toNamed(RouteHelper.getWalletRoute(true,'pair_income'.tr));
                          Get.toNamed(RouteHelper.getClosingRoute(true,'pair_income'.tr));
                          },),
                        ),
                      ],),
                  ],
                ),

              ),




          Container(
            padding: const EdgeInsets.only(left: 5.0,right: 5.0,bottom: 7.0),

            child: Column(children: [
            SizedBox(height: 10,),
            (userInfoModel.walletBalance!=null) ?
            Align(child: Text('${'company_account'.tr} ', style:
            robotoRegular.copyWith(fontSize:
            22,color: Colors.white.withOpacity(0.8)))
              ,alignment : Alignment.topLeft,)
                : SizedBox(),

            SizedBox(height: 10,),
            Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,children: [
              Container(
                padding: const EdgeInsets.only(left: 15,right: 15,top: 5,bottom: 5),
                decoration: BoxDecoration(
                    border: Border.all(color: Colors.white),
                    color: Colors.black12
                ),
                child: InkWell(child: Column(
                  children: [
                    Text('${'revenue'.tr}', style:
                    robotoMedium.copyWith(fontSize:
                    14,color: Colors.white.withOpacity(0.6))),

                    SizedBox(height: 3.0,),

                    Text('${userInfoModel.revenue}', style:
                    robotoMedium.copyWith(fontSize:
                    13,color: Colors.white.withOpacity(1.0))),
                  ],
                ),onTap: (){
                  Get.toNamed(RouteHelper.getRevenueRoute());
                },),
              ),
              Container(
                padding: const EdgeInsets.only(left: 15,right: 15,top: 5,bottom: 5),
                decoration: BoxDecoration(
                    border: Border.all(color: Colors.white),
                    color: Colors.black12
                ),
                child: InkWell(child: Column(
                  children: [
                    Text('${'prime_members'.tr}', style:
                    robotoMedium.copyWith(fontSize:
                    14,color: Colors.white.withOpacity(0.6))),

                    SizedBox(height: 3.0,),

                    Text('${userInfoModel.primeCount}', style:
                    robotoMedium.copyWith(fontSize:
                    13,color: Colors.white.withOpacity(1.0))),
                  ],
                ),onTap: (){
                  Get.toNamed(RouteHelper.getRegisteredUsersRoute('prime_members'.tr));
                },),
              ),
              Container(
                padding: const EdgeInsets.only(left: 15,right: 15,top: 5,bottom: 5),
                decoration: BoxDecoration(
                    border: Border.all(color: Colors.white),
                    color: Colors.black12
                ),
                child: InkWell(child: Column(
                  children: [
                    Text('${'customers'.tr}', style:
                    robotoMedium.copyWith(fontSize:
                    14,color: Colors.white.withOpacity(0.6))),

                    SizedBox(height: 3.0,),

                    Text('${userInfoModel.customerCount}', style:
                    robotoMedium.copyWith(fontSize:
                    13,color: Colors.white.withOpacity(1.0))),
                  ],
                ),onTap: (){
                  Get.toNamed(RouteHelper.getRegisteredUsersRoute('customers'.tr));
                },),
              ),
            ],),

            SizedBox(height: 10,),


            Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,crossAxisAlignment: CrossAxisAlignment.start
              ,children: [
                Container(
                  padding: const EdgeInsets.only(left: 10,right: 10,top: 5,bottom: 5),
                  decoration: BoxDecoration(
                    border: Border.all(color: Colors.blueGrey),
                  ),
                  child: InkWell(child: Text('${'left'.tr}: ${userInfoModel.familyMembersCount} ', style:
                  robotoMedium.copyWith(fontSize:
                  Dimensions.fontSizeSmall,color: Colors.white.withOpacity(1.0))),onTap: (){

                  },),
                ),

                Container(
                  padding: const EdgeInsets.only(left: 10,right: 10,top: 5,bottom: 5),
                  decoration: BoxDecoration(
                    border: Border.all(color: Colors.blueGrey),
                  ),
                  child: InkWell(child: Text('${'right'.tr}: ${userInfoModel.familyMembersCount} ', style:
                  robotoMedium.copyWith(fontSize:
                  Dimensions.fontSizeSmall,color: Colors.white.withOpacity(1.0))),onTap: (){},),
                ),

                Container(
                  padding: const EdgeInsets.only(left: 10,right: 10,top: 5,bottom: 5),
                  decoration: BoxDecoration(
                    border: Border.all(color: Colors.blueGrey),
                  ),
                  child: InkWell(child: Text('${'pairs'.tr}: ${userInfoModel.familyMembersCount} ', style:
                  robotoMedium.copyWith(fontSize:
                  Dimensions.fontSizeSmall,color: Colors.white.withOpacity(1.0))),onTap: (){

                  },),
                ),
                Container(
                  padding: const EdgeInsets.only(left: 10,right: 10,top: 5,bottom: 5),
                  decoration: BoxDecoration(
                    border: Border.all(color: Colors.blueGrey),
                  ),
                  child: InkWell(child: Text('${'upi_payments'.tr}', style:
                  robotoMedium.copyWith(fontSize:
                  Dimensions.fontSizeSmall,color: Colors.white.withOpacity(1.0))),onTap: (){
                    Get.toNamed(RouteHelper.getUpiPaymentsRoute());
                  },),
                ),

              ],),

            SizedBox(height: 10,),
          ],),)
        ],
      ),
    );
  }


  @override
  Widget build(BuildContext context) {
    var name ='${userInfoModel.fName} ${userInfoModel.lName}';
    bool _isLoggedIn = Get.find<AuthController>().isLoggedIn();
    return Container(
      padding: EdgeInsets.all(10.0),
      width: context.width,child:
    Column(
      children: [
        FlipCard(
          direction: FlipDirection.HORIZONTAL,
          side: CardSide.FRONT,
          speed: 1000,
          onFlipDone: (status) {
            print(status);
          },
          front: Container(
            width: double.infinity,
            padding: const EdgeInsets.all(15),

            decoration: BoxDecoration(
              color: Colors.white,
              borderRadius: BorderRadius.circular(20),
              border: Border.all(
                width: 0.9,
                color: Colors.black,
              ),
            ),

            child: Stack(
                children: [
                  Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    mainAxisAlignment: MainAxisAlignment.start,
                    children: [
                      Row(
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        children: [
                          Image.asset(
                            Images.logo_2,
                            width: 120,
                            fit: BoxFit.fill,
                          ),
                          Image.asset(
                            Images.prime_text_img,
                            height: 40,
                            width: 100,
                            fit: BoxFit.fill,
                          ),

                        ],
                      ),

                      SizedBox(height: 5,),
                      Padding(
                        padding: const EdgeInsets.only(left: 5),
                        child: Column(crossAxisAlignment: CrossAxisAlignment.start,children: [

                          Row(
                            children: [
                              Column(mainAxisAlignment: MainAxisAlignment.start,crossAxisAlignment: CrossAxisAlignment.start,
                                children: [
                                  Text(userInfoModel.primeMemberAccount??"NA", style: ocrWhite.copyWith(fontSize:
                            Dimensions.fontSizeLarge,color: Colors.black)),
                                  SizedBox(height: 5,),
                                  Text(name??"", style: ocrWhite.copyWith(fontSize:
                                  Dimensions.fontSizeLarge,color: Colors.black))
                                ],
                              ), // Adds a title to the card
                              const Spacer(),
                              Card(
                                shape: RoundedRectangleBorder(
                                  borderRadius: BorderRadius.circular(10),
                                ),
                                clipBehavior: Clip.hardEdge,
                                child: CustomImage(
                                  image: '${Get.find<SplashController>().configModel.baseUrls.customerImageUrl}'
                                      '/${(userInfoModel != null && _isLoggedIn) ? Get.find<UserController>().userInfoModel.image : ''}',
                                  height: 100, width: 100, fit: BoxFit.fill, isProfile: true,
                                ),
                              ),
                              // Adds a stack of two circular containers to the right of the title
                            ],
                          ),


                          SizedBox(height: 5,),

                          Row(
                            crossAxisAlignment: CrossAxisAlignment.start,
                            children: [
                              Column(
                                children : [
                                  Text('Valid From', style: ocrWhite.copyWith(fontSize: Dimensions.fontSizeDefault,color: Colors.grey)),
                                  SizedBox(height: 2.5,),
                                  Text(userInfoModel.primeValidFrom??"xx-xx-xxxx", style: ocrWhite.copyWith(fontSize: Dimensions.fontSizeLarge,color: Colors.black)),
                                ],
                              ),

                              SizedBox(width: 15,),

                              Column(
                                children: [
                                  Text('Valid To', style: ocrWhite.copyWith(fontSize: Dimensions.fontSizeDefault,color: Colors.grey)),
                                  SizedBox(height: 2.5,),
                                  Text(userInfoModel.primeValidTo??"xx-xx-xxxx", style: ocrWhite.copyWith(fontSize: Dimensions.fontSizeLarge,color: Colors.black)),
                                ],
                              ),

                              // SizedBox(width: 15,),
                              // InkWell(child: Container(
                              //   padding: EdgeInsets.fromLTRB(10, 2, 10, 2),
                              //   decoration: BoxDecoration(
                              //       border: Border.all(color: Colors.grey,width: 0.5),
                              //       borderRadius: BorderRadius.circular(5)),
                              //   child: Text('Invoice', style: robotoRegular.copyWith(fontSize:
                              //   15,color: Colors.white)),
                              // ),onTap: (){
                              //   Get.toNamed(RouteHelper.getPrimeInvoiceRoute());
                              // },),
                            ],
                          ),
                        ],),
                      )
                    ],
                  ),

                  Positioned(right: 1,bottom: 1,child:

                  RotatedBox(
                      quarterTurns: 2,
                      child: Image.asset(
                        Images.rotate,
                        height: 30,
                        width: 30,
                        fit: BoxFit.fitWidth,
                      )
                  )),

                ]),

          ),
          back: Container(
            width: double.infinity,
            padding: const EdgeInsets.all(15),

            decoration: BoxDecoration(
              color: Colors.white,
              borderRadius: BorderRadius.circular(20),
              border: Border.all(
                width: 0.9,
                color: Colors.black,
              ),
            ),

            child: Stack(children: [
              Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                mainAxisAlignment: MainAxisAlignment.start,
                children: [
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Image.asset(
                        Images.logo_2,
                        width: 120,
                        fit: BoxFit.fill,
                      ),
                      Image.asset(
                        Images.prime_text_img,
                        height: 40,
                        width: 100,
                        fit: BoxFit.fill,
                      ),

                    ],
                  ),

                  Container(

                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [

                        Column(mainAxisAlignment: MainAxisAlignment.start,
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: [
                            SizedBox(height: 10,),
                          Row(
                            children: [
                              Text('Contact: ', style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeDefault,color: Colors.grey)),
                              Text(Get.find<SplashController>().configModel.phone??"", style: ocrWhite.copyWith(fontSize: Dimensions.fontSizeDefault,color: Colors.black)),
                            ],
                          ),
                            SizedBox(height: 10,),
                            Row(
                              children: [
                                Text('Pan: ', style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeDefault,color: Colors.grey)),
                                Text(userInfoModel.primePan?? "xxxxxxxxxx", style: ocrWhite.copyWith(fontSize: Dimensions.fontSizeDefault,color: Colors.black)),
                              ],
                            ),

                            SizedBox(height: 10,),
                            Row(
                              children: [
                                Text('Aadhar: ', style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeDefault,color: Colors.grey)),
                                Text(userInfoModel.primeAadhar??"xxxx xxxx xxxx", style: ocrWhite.copyWith(fontSize: Dimensions.fontSizeDefault,color: Colors.black)),


                              ],
                            ),

                            SizedBox(height: 10,),
                            // Row(
                            //   crossAxisAlignment: CrossAxisAlignment.start,
                            //   children: [
                            //     Text('Address: ', style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeDefault,color: Colors.grey)),
                            //     SizedBox(width: 100,child: Expanded(child: Text(Get.find<SplashController>().configModel.address??"",
                            //         style: ocrWhite.copyWith(fontSize: Dimensions.fontSizeDefault,color:
                            //         Colors.white)),),),
                            //
                            //
                            //   ],
                            // ),
                            // Row(
                            //
                            //   children: [
                            //     Text('Address: ', style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeDefault,color: Colors.grey)),
                            //     Expanded(child: Text(Get.find<SplashController>().configModel.address??"", style: ocrWhite.copyWith(fontSize: Dimensions.fontSizeDefault,color: Colors.white))),
                            //   ],
                            // ),

                        ],),
                        QrImage(
                          data: userInfoModel.primeMemberAccount??"NA",
                          version: QrVersions.auto,
                          size: 120.0,
                        ),
                      ],
                    ),
                  ),

                  Row(
                    children: [
                      Text('Address: ', style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeDefault,color: Colors.grey)),
                      Expanded(child: Text(Get.find<SplashController>().configModel.address??"", style: ocrWhite.copyWith(fontSize: Dimensions.fontSizeDefault,color: Colors.black))),


                    ],
                  ),

                ],
              ),


              Positioned(right: 1,bottom: 1,child: Image.asset(
                Images.rotate,
                height: 30,
                width: 30,
                fit: BoxFit.fitWidth,
              ),
              ),
            ]),

          ),

        ),

        SizedBox(height:(userInfoModel.isCompany=="true") ? 10.0:0.0 ,),

        (userInfoModel.isCompany=="true") ? adminOnlyUI(userInfoModel,context) : SizedBox()
      ],
    ),
    );
  }
}
