import 'dart:io';

import 'package:country_code_picker/country_code.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:get/get.dart';
import 'package:dotted_border/dotted_border.dart';
import 'package:phone_number/phone_number.dart';
import 'package:share_plus/share_plus.dart';
import 'package:sixam_mart/controller/auth_controller.dart';
import 'package:sixam_mart/controller/splash_controller.dart';
import 'package:sixam_mart/controller/user_controller.dart';
import 'package:sixam_mart/helper/price_converter.dart';
import 'package:sixam_mart/helper/responsive_helper.dart';
import 'package:sixam_mart/util/app_constants.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/images.dart';
import 'package:sixam_mart/util/styles.dart';
import 'package:sixam_mart/view/base/custom_app_bar.dart';
import 'package:sixam_mart/view/base/custom_button.dart';
import 'package:sixam_mart/view/base/custom_snackbar.dart';
import 'package:sixam_mart/view/base/footer_view.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_drawer.dart';
import 'package:sixam_mart/view/base/not_logged_in_screen.dart';

import '../../base/custom_text_field.dart';
import '../profile/widget/profile_card.dart';

class ReferAndEarnScreen extends StatefulWidget {
  const ReferAndEarnScreen({Key key}) : super(key: key);

  @override
  State<ReferAndEarnScreen> createState() => _ReferAndEarnScreenState();
}

class _ReferAndEarnScreenState extends State<ReferAndEarnScreen> {
  bool _isLoggedIn;
  final FocusNode _mobileFocus = FocusNode();
  final TextEditingController _nameController = TextEditingController();
  final TextEditingController _mobileController = TextEditingController();
  String _countryDialCode;
  @override
  void initState() {
    super.initState();
    _countryDialCode = CountryCode.fromCountryCode(Get.find<SplashController>().configModel.country).dialCode;

    _isLoggedIn = Get.find<AuthController>().isLoggedIn();

    if(_isLoggedIn && Get.find<UserController>().userInfoModel == null) {
      Get.find<UserController>().getUserInfo();

    }
  }

  int remainingReferral(){
    var remaingRef =0;
    try{
      if(Get.find<SplashController>().configModel.refShareLimit!=null
      &&  Get.find<UserController>().userInfoModel.refRemaining!=null
      ){
        if(Get.find<SplashController>().configModel.refShareLimit > Get.find<UserController>().userInfoModel.refRemaining){
          remaingRef=Get.find<UserController>().userInfoModel.refRemaining;
        }else{
          remaingRef = 0;
        }

      }
    }catch(e){remaingRef =0;}

    return Get.find<UserController>().userInfoModel.refRemaining;
  }

  @override
  Widget build(BuildContext context) {
    bool _desktop = ResponsiveHelper.isDesktop(context);
    bool _isTab = ResponsiveHelper.isTab(context);
    bool _isWeb = ResponsiveHelper.isWeb();
    bool _isMobile = ResponsiveHelper.isMobile(context);
    double screenWidth = MediaQuery.of(context).size.width;

    print("screenWidthTest  $screenWidth");
    return Scaffold(
      endDrawer: WebMenuDrawer(),
      appBar: CustomAppBar(title: 'refer_and_earn'.tr),
      body: Center(
        child: _isLoggedIn ? SingleChildScrollView(
          child: FooterView(
            child: SizedBox(
              width: Dimensions.WEB_MAX_WIDTH,
              child: Padding(
                padding: const EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_LARGE),
                child: GetBuilder<UserController>(builder: (userController) {
                    return Column( children: [

                      SizedBox(height: Dimensions.PADDING_SIZE_LARGE),
                      Text('earn_money_on_every_referral'.tr, style: robotoRegular.copyWith(color: Theme.of(context).primaryColor, fontSize: Dimensions.fontSizeSmall)),
                      SizedBox(height: Dimensions.PADDING_SIZE_EXTRA_SMALL),

                      Text(
                        'one_referral'.tr + '= ' + PriceConverter.convertPrice(Get.find<SplashController>().configModel != null
                            ? Get.find<SplashController>().configModel.refEarningExchangeRate.toDouble() : 0.0),
                        style: robotoBold.copyWith(fontSize: Dimensions.fontSizeDefault),
                      ),

                      SizedBox( height:(userController.userInfoModel.refIncome!=null || userController.userInfoModel.sponsorIncome!=null) ? Dimensions.PADDING_SIZE_SMALL:0.0),

                      Row(children: [
                        userController.userInfoModel.refIncome!=null ?
                        ProfileCard( title : 'referral_income'.tr,
                            data: PriceConverter.convertPrice(userController.userInfoModel.refIncome)) :SizedBox(),

                        // SizedBox( width : userController.userInfoModel.refIncome!=null ? Dimensions.PADDING_SIZE_SMALL:0.0),
                        // userController.userInfoModel.refRemaining!=null ?
                        // ProfileCard( title : 'ref_remaining'.tr,
                        // data: '${remainingReferral()}') : SizedBox(),
                      ]),


                      SizedBox( height:(userController.userInfoModel.refIncome!=null || userController.userInfoModel.sponsorIncome!=null) ? Dimensions.PADDING_SIZE_SMALL:0.0),

                      Center(
                        child: Row(mainAxisSize: MainAxisSize.min, children: [
                          Column(children: [

                            Image.asset(Images.refer_image, width: ResponsiveHelper.isDesktop(context) ? 200 : 100,
                                height: ResponsiveHelper.isDesktop(context) ? 250 : 150, fit: BoxFit.contain),
                            SizedBox(width: 120,
                                child: Text('refer_your_code_to_your_friend'.tr , style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall), textAlign: TextAlign.center),
                            ),
                          ]),
                          SizedBox(width: ResponsiveHelper.isDesktop(context) ? 150 : 50),

                          Column(children: [
                            Image.asset(Images.earn_money, width: ResponsiveHelper.isDesktop(context) ? 200 : 100,
                                height: ResponsiveHelper.isDesktop(context) ? 250 : 150, fit: BoxFit.contain),
                            SizedBox(width: 120, child: Text(
                                'get'.tr + ' ${PriceConverter.convertPrice(Get.find<SplashController>().configModel != null ? Get.find<SplashController>().configModel.refEarningExchangeRate.toDouble() : 0.0)} ' +
                                    'instantly'.tr , style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall), textAlign: TextAlign.center),
                            ),
                          ]),
                        ]),
                      ),
                      SizedBox(height: Dimensions.PADDING_SIZE_EXTRA_LARGE),

                      Column(crossAxisAlignment: CrossAxisAlignment.start, children: [

                        Text('your_referral_code'.tr, style: robotoRegular.copyWith(color: Theme.of(context).disabledColor, fontSize: Dimensions.fontSizeDefault)),
                        SizedBox(height: Dimensions.PADDING_SIZE_SMALL),

                        DottedBorder(
                          color: Theme.of(context).primaryColor,
                          strokeWidth: 1,
                          strokeCap: StrokeCap.butt,
                          dashPattern: [8, 5],
                          padding: EdgeInsets.all(0),
                          borderType: BorderType.RRect,
                          radius: Radius.circular(Dimensions.RADIUS_SMALL),
                          child: Container(
                            padding: EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_LARGE),
                            height: 50, decoration: BoxDecoration(color: Theme.of(context).primaryColor.withOpacity(0.1), borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL)),
                            child: (userController.userInfoModel != null) ? Row(children: [
                              Expanded(
                                child: Text(
                                  '${userController.userInfoModel != null ? userController.userInfoModel.refCode ?? '' : ''}',
                                  style: robotoBlack.copyWith(color: Theme.of(context).primaryColor, fontSize: Dimensions.fontSizeExtraLarge),
                                ),
                              ),
                              InkWell(
                                onTap: () {
                                  // if(userController.userInfoModel.refCode.isNotEmpty){
                                  //   Clipboard.setData(ClipboardData(text: '${userController.userInfoModel != null ? userController.userInfoModel.refCode : ''}'));
                                  //   showCustomSnackBar('referral_code_copied'.tr, isError: false);
                                  // }
                                },
                                child: Text(''.tr, style: robotoMedium),
                                //child: Text('tap_to_copy'.tr, style: robotoMedium),
                              ),
                            ])
                                : CircularProgressIndicator(),
                          ),
                        ),
                      ]),
                      SizedBox(height: Dimensions.PADDING_SIZE_LARGE),
                      DottedBorder(
                        color: Theme.of(context).primaryColor,
                        strokeWidth: 1,
                        strokeCap: StrokeCap.butt,
                        dashPattern: [8, 5],
                        padding: EdgeInsets.all(0),
                        borderType: BorderType.RRect,
                        radius: Radius.circular(Dimensions.RADIUS_SMALL),
                        child: CustomTextField(
                          hintText: 'name'.tr,
                          controller: _nameController,
                          nextFocus: _mobileFocus,
                          inputType: TextInputType.text,
                          divider: false,
                        ),
                      ),
                      SizedBox(height: Dimensions.PADDING_SIZE_LARGE),
                      DottedBorder(
                        color: Theme.of(context).primaryColor,
                        strokeWidth: 1,
                        strokeCap: StrokeCap.butt,
                        dashPattern: [8, 5],
                        padding: EdgeInsets.all(0),
                        borderType: BorderType.RRect,
                        radius: Radius.circular(Dimensions.RADIUS_SMALL),
                        child: CustomTextField(
                          hintText: 'mobile'.tr,
                          controller: _mobileController,
                          focusNode: _mobileFocus,
                          isNumber: true,
                          inputType: TextInputType.number,
                          divider: false,
                        ),
                      ),


                      SizedBox(height: Dimensions.PADDING_SIZE_LARGE),
                      !userController.isCheckUserCanShareAppLoading ?
                      CustomButton(buttonText: 'share'.tr,icon: Icons.share, onPressed: ()
                      async {

                       // if(userController.userInfoModel.refRemaining!=null && userController.userInfoModel.refRemaining>0){

                          var name = _nameController.text.toString();
                          var mobile = _mobileController.text.toString();
                          bool _isValid = GetPlatform.isWeb ? true : false;
                          String _numberWithCountryCode = _countryDialCode + mobile;
                          if(!GetPlatform.isWeb) {
                            try {
                              PhoneNumber phoneNumber = await PhoneNumberUtil().parse(mobile);
                              _numberWithCountryCode = '+' + phoneNumber.countryCode + phoneNumber.nationalNumber;
                              _isValid = true;
                            } catch (e) {
                            }
                          }
                          if(name.isEmpty){
                            showCustomSnackBar('enter_name'.tr,isError: true);
                          }else if (mobile.isEmpty) {
                            showCustomSnackBar('enter_phone_number'.tr,isError: true);
                          }else if (mobile.length!=10) {
                            showCustomSnackBar('invalid_phone_number2'.tr,isError: true);
                          }
                          // else if (!_isValid) {
                          //   showCustomSnackBar(_numberWithCountryCode);
                          // }
                          else{
                            userController.checkUserCanShareApp(name, mobile).then((status) async {
                              if (status.isSuccess) {

                                var appLink='';
                                if (Platform.isAndroid) {
                                  appLink = 'https://play.google.com/store/apps/details?id=com.saveandshop.save_and_shop';
                                } else if (Platform.isIOS) {
                                  appLink = 'Ios app link';
                                }
                                String earnAmt = PriceConverter.convertPrice(Get.find<SplashController>().configModel != null
                                    ? Get.find<SplashController>().configModel.refEarningExchangeRate.toDouble() : 0.0);
                                String appName = AppConstants.APP_NAME;
                                String profile="";
                                if(userController.userInfoModel.image!=null){
                                  print("userInfoModelPro Run_P");
                                  profile = '\n Profile: ${Get.find<SplashController>().configModel.baseUrls.customerImageUrl}/${userController.userInfoModel.image}';
                                }

                                //Share.share('Install $appName from $appLink ${'this_is_my_refer_code'.tr}: ${userController.userInfoModel.refCode}');
                                Share.share(' Hi  \n My name is: ${userController.userInfoModel.fName + " " + userController.userInfoModel.lName} $profile \n\nInstall $appName from $appLink \n\n ${'this_is_my_refer_code'.tr}: ${userController.userInfoModel.refCode} earn $earnAmt after signup into the app. ');
                              }else {
                                showCustomSnackBar(status.message);
                              }
                            });
                          }
                        // }
                        //
                        // else{
                        //   showCustomSnackBar('share_limit_exceeded'.tr, isError: true);
                        // }


                      }):
                      Center(child: CircularProgressIndicator(),),
                    //  CustomButton(buttonText: 'share'.tr,icon: Icons.share, onPressed: () => AppConstants.onButtonTap(ShareTo.share_system,"")),

                    ]);
                  }
                ),
              ),
            ),
          ),
        ) : NotLoggedInScreen(),
      ),
    );
  }
}
