import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:shimmer_animation/shimmer_animation.dart';
import 'package:sixam_mart/controller/auth_controller.dart';
import 'package:sixam_mart/controller/user_controller.dart';
import 'package:sixam_mart/controller/wallet_controller.dart';
import 'package:sixam_mart/helper/price_converter.dart';
import 'package:sixam_mart/helper/responsive_helper.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/images.dart';
import 'package:sixam_mart/util/styles.dart';
import 'package:sixam_mart/view/base/custom_app_bar.dart';
import 'package:sixam_mart/view/base/footer_view.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_drawer.dart';
import 'package:sixam_mart/view/base/no_data_screen.dart';
import 'package:sixam_mart/view/base/not_logged_in_screen.dart';
import 'package:sixam_mart/view/base/title_widget.dart';
import 'package:sixam_mart/view/screens/wallet/widget/history_item.dart';
import 'package:sixam_mart/view/screens/wallet/widget/wallet_bottom_sheet.dart';

import '../../../controller/prime_member_controller.dart';
import '../../../helper/date_converter.dart';
import '../../../util/app_constants.dart';

class ShareLinkListScreen extends StatefulWidget {

  @override
  State<ShareLinkListScreen> createState() => _ShareLinkListScreenState();
}

class _ShareLinkListScreenState extends State<ShareLinkListScreen> {
  final ScrollController scrollController = ScrollController();
  final bool _isLoggedIn = Get.find<AuthController>().isLoggedIn();

  @override
  void initState() {
    super.initState();
    if(_isLoggedIn){
      Get.find<PrimeMemberController>().getSharedLinkList();

    }

  }
  @override
  void dispose() {
    super.dispose();

    scrollController?.dispose();
  }

  @override
  Widget build(BuildContext context) {

    return Scaffold(
      backgroundColor: Theme.of(context).cardColor,
      endDrawer: WebMenuDrawer(),
      appBar: CustomAppBar(title:  'shared_list'.tr , backButton: true),
      body: GetBuilder<UserController>(
          builder: (userController) {
            return _isLoggedIn ? userController.userInfoModel != null ? SafeArea(
              child: RefreshIndicator(
                onRefresh: () async{
                  Get.find<PrimeMemberController>().getSharedLinkList();

                },
                child: SingleChildScrollView(
                  controller: scrollController,
                  padding: EdgeInsets.symmetric(horizontal: ResponsiveHelper.isDesktop(context) ? 0.0 : Dimensions.PADDING_SIZE_DEFAULT),
                  child: FooterView(
                    child: SizedBox(
                      width: Dimensions.WEB_MAX_WIDTH,
                      child: GetBuilder<PrimeMemberController>(
                          builder: (primeMemberController) {
                            return Column(children: [

                              primeMemberController.sharedLinkDetails != null ?

                              primeMemberController.sharedLinkDetails.length > 0 ?
                              // GridView.builder(
                              //   key: UniqueKey(),
                              //   gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
                              //     crossAxisSpacing: 50,
                              //     mainAxisSpacing: ResponsiveHelper.isDesktop(context) ? Dimensions.PADDING_SIZE_LARGE : 0.1,
                              //     childAspectRatio: ResponsiveHelper.isDesktop(context) ? 5 : 4.45,
                              //     crossAxisCount: ResponsiveHelper.isMobile(context) ? 1 : 2,
                              //   ),
                              //   physics:  NeverScrollableScrollPhysics(),
                              //   shrinkWrap:  true,
                              //   itemCount: primeMemberController.sharedLinkDetails.length ,
                              //   padding: EdgeInsets.only(top: ResponsiveHelper.isDesktop(context) ? 28 : 25),
                              //   itemBuilder: (context, index) {
                              //     return Column(crossAxisAlignment: CrossAxisAlignment.start,
                              //         children: [
                              //
                              //           Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,children: [
                              //             Row(
                              //               children: [
                              //                 Text(
                              //                   '${'name'.tr}:',
                              //                   style: robotoMedium.copyWith(color: Colors.black54,fontSize: 12,),
                              //                   textAlign: TextAlign.center,
                              //                 ),
                              //                 SizedBox(width: 5,),
                              //                 Text(
                              //                   '${primeMemberController.sharedLinkDetails[index].name}',
                              //                   style: robotoMedium.copyWith(fontSize: 12,),
                              //                   textAlign: TextAlign.center,
                              //                 ),
                              //               ],
                              //             ) ,
                              //
                              //             Row(
                              //               children: [
                              //                 Text(
                              //                   '${'status'.tr}:',
                              //                   style: robotoMedium.copyWith(color: Colors.black54,fontSize: 12,),
                              //                   textAlign: TextAlign.center,
                              //                 ),
                              //                 SizedBox(width: 5,),
                              //                 Text(
                              //                   '${primeMemberController.sharedLinkDetails[index].status}',
                              //                   style: robotoMedium.copyWith(fontSize: 12,),
                              //                   textAlign: TextAlign.center,
                              //                 ),
                              //               ],
                              //             ),
                              //           ],),
                              //           SizedBox(height: 5.0,),
                              //           Row(mainAxisAlignment : MainAxisAlignment.spaceBetween,children: [
                              //             Row(
                              //               children: [
                              //                 Text('${'phone'.tr}: ',
                              //                   style: robotoMedium.copyWith(color: Colors.black54,fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
                              //                 ),
                              //                 Text('${primeMemberController.sharedLinkDetails[index].mobileNo}',
                              //                   style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
                              //                 )
                              //               ],
                              //             ) ,
                              //
                              //             Text(DateConverter.dateToDateAndTimeAm(
                              //                 primeMemberController.sharedLinkDetails[index].createdAt)
                              //                 ,style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall,color: Theme.of(context).disabledColor),
                              //                 maxLines: 1, overflow: TextOverflow.ellipsis),
                              //           ],),
                              //
                              //           Padding(
                              //             padding: const EdgeInsets.only(top: Dimensions.PADDING_SIZE_DEFAULT),
                              //             child: Divider(color: Theme.of(context).disabledColor),
                              //           ),
                              //         ]);
                              //   },
                              // )
                              ListView.builder(
                                shrinkWrap: true,
                                scrollDirection: Axis.vertical,
                                itemCount: primeMemberController.sharedLinkDetails.length,
                                physics: BouncingScrollPhysics(),
                                itemBuilder: (context, index) {
                                  return Padding(padding: EdgeInsets.only(bottom: 10),child: Container(
                                    padding: const EdgeInsets.all(8.0),
                                    decoration: AppConstants.customBoxDecoration(context),
                                    child: Padding(
                                      padding: const EdgeInsets.all(8.0),
                                      child: Column(crossAxisAlignment: CrossAxisAlignment.start,
                                          children: [

                                            Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,children: [
                                              Row(
                                                children: [
                                                  Text(
                                                    '${'name'.tr}:',
                                                    style: robotoMedium.copyWith(color: Colors.black54,fontSize: 12,),
                                                    textAlign: TextAlign.center,
                                                  ),
                                                  SizedBox(width: 5,),
                                                  Text(
                                                    '${primeMemberController.sharedLinkDetails[index].name}',
                                                    style: robotoMedium.copyWith(fontSize: 12,),
                                                    textAlign: TextAlign.center,
                                                  ),
                                                ],
                                              ) ,

                                              Row(
                                                children: [
                                                  Text(
                                                    '${'status'.tr}:',
                                                    style: robotoMedium.copyWith(color: Colors.black54,fontSize: 12,),
                                                    textAlign: TextAlign.center,
                                                  ),
                                                  SizedBox(width: 5,),
                                                  Text(
                                                    '${primeMemberController.sharedLinkDetails[index].status}',
                                                    style: robotoMedium.copyWith(fontSize: 12,),
                                                    textAlign: TextAlign.center,
                                                  ),
                                                ],
                                              ),
                                            ],),
                                            SizedBox(height: 5.0,),
                                            Row(mainAxisAlignment : MainAxisAlignment.spaceBetween,children: [
                                              Row(
                                                children: [
                                                  Text('${'phone'.tr}: ',
                                                    style: robotoMedium.copyWith(color: Colors.black54,fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
                                                  ),
                                                  Text('${primeMemberController.sharedLinkDetails[index].mobileNo}',
                                                    style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
                                                  )
                                                ],
                                              ) ,

                                              Text(DateConverter.dateToDateAndTimeAm(
                                                  primeMemberController.sharedLinkDetails[index].createdAt)
                                                  ,style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall,color: Theme.of(context).disabledColor),
                                                  maxLines: 1, overflow: TextOverflow.ellipsis),
                                            ],),

                                          ]),
                                    ),
                                  ),);
                                },
                              )
                                  : NoDataScreen(text: 'no_data_found'.tr)
                                  : ShareLinkListShimmer(primeMemberController: primeMemberController),

                              primeMemberController.isLoading ? Center(child: Padding(
                                padding: EdgeInsets.all(Dimensions.PADDING_SIZE_SMALL),
                                child: CircularProgressIndicator(),
                              )) : SizedBox(),
                            ]);
                          }
                      ),
                    ),
                  ),
                ),
              ),
            ) : Center(child: CircularProgressIndicator()) : NotLoggedInScreen();
          }
      ),
    );
  }
}
class ShareLinkListShimmer extends StatelessWidget {
  final PrimeMemberController primeMemberController;
  ShareLinkListShimmer({@required this.primeMemberController});

  @override
  Widget build(BuildContext context) {
    return GridView.builder(
      key: UniqueKey(),
      gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
        crossAxisSpacing: 50,
        mainAxisSpacing: ResponsiveHelper.isDesktop(context) ? Dimensions.PADDING_SIZE_LARGE : 0.1,
        childAspectRatio: ResponsiveHelper.isDesktop(context) ? 5 : 2.45,
        crossAxisCount: ResponsiveHelper.isMobile(context) ? 1 : 2,
      ),
      physics:  NeverScrollableScrollPhysics(),
      shrinkWrap:  true,
      itemCount: 10,
      padding: EdgeInsets.only(top: ResponsiveHelper.isDesktop(context) ? 28 : 25),
      itemBuilder: (context, index) {
        return Padding(
          padding: EdgeInsets.symmetric(vertical: Dimensions.PADDING_SIZE_SMALL),
          child: Shimmer(
            duration: Duration(seconds: 2),
            enabled: primeMemberController.sharedLinkDetails == null,
            child: Column(children: [
              Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Column(crossAxisAlignment: CrossAxisAlignment.start, children: [
                    Container(height: 10, width: 50, decoration: BoxDecoration(color: Colors.grey[300], borderRadius: BorderRadius.circular(2))),
                    SizedBox(height: 10),
                    Container(height: 10, width: 70, decoration: BoxDecoration(color: Colors.grey[300], borderRadius: BorderRadius.circular(2))),
                  ]),
                  Column(crossAxisAlignment: CrossAxisAlignment.end, children: [
                    Container(height: 10, width: 50, decoration: BoxDecoration(color: Colors.grey[300], borderRadius: BorderRadius.circular(2))),
                    SizedBox(height: 10),
                    Container(height: 10, width: 70, decoration: BoxDecoration(color: Colors.grey[300], borderRadius: BorderRadius.circular(2))),
                  ]),
                ],
              ),
              Padding(padding: const EdgeInsets.only(top: Dimensions.PADDING_SIZE_LARGE), child: Divider(color: Theme.of(context).disabledColor)),
            ],
            ),
          ),
        );
      },
    );
  }
}