import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:get/get.dart';
import 'package:shimmer_animation/shimmer_animation.dart';
import 'package:sixam_mart/controller/auth_controller.dart';
import 'package:sixam_mart/controller/user_controller.dart';
import 'package:sixam_mart/controller/wallet_controller.dart';
import 'package:sixam_mart/helper/responsive_helper.dart';
import 'package:sixam_mart/util/app_constants.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/view/base/custom_app_bar.dart';
import 'package:sixam_mart/view/base/footer_view.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_drawer.dart';
import 'package:sixam_mart/view/base/no_data_screen.dart';
import 'package:sixam_mart/view/base/not_logged_in_screen.dart';
import 'package:url_launcher/url_launcher_string.dart';
import '../../../controller/all_prime_members_controller.dart';
import '../../../controller/prime_member_controller.dart';
import '../../../controller/splash_controller.dart';
import '../../../data/model/response/AllRegisteredUsersResponse.dart';
import '../../../helper/price_converter.dart';
import '../../../helper/route_helper.dart';
import '../../../util/images.dart';
import '../../../util/styles.dart';
import '../../base/custom_image.dart';
import '../../base/custom_snackbar.dart';
import '../search/widget/custom_check_box.dart';

class RegisteredUsersScreen extends StatefulWidget {
  final String title;

  RegisteredUsersScreen({Key key, @required this.title}) : super(key: key);

  @override
  State<RegisteredUsersScreen> createState() => _RegisteredUsersScreenState();
}

class _RegisteredUsersScreenState extends State<RegisteredUsersScreen> {
  final ScrollController scrollController = ScrollController();
  final bool _isLoggedIn = Get.find<AuthController>().isLoggedIn();
  final TextEditingController _inputMessageController = TextEditingController();

  @override
  void initState() {
    super.initState();
    if(_isLoggedIn){


      Get.find<WalletController>().resetStatementFilter();
      Get.find<AllPrimeMembersController>().setAmtGreaterThanZero('1');
      Get.find<AllPrimeMembersController>().getRegisteredUsers(widget.title,false);

      scrollController?.addListener(() {
        print('scrollController_runTest olp');
        if (scrollController.position.pixels == scrollController.position.maxScrollExtent
            && Get.find<AllPrimeMembersController>().allRegisteredUsersDataList != null
            && !Get.find<AllPrimeMembersController>().isLoading) {
          int pageSize = Get.find<AllPrimeMembersController>().totalPageSize;
          if (Get.find<AllPrimeMembersController>().allRegisteredUsersDataList.length < pageSize) {
            Get.find<AllPrimeMembersController>().setOffset(Get.find<WalletController>().offset + 1);
            print('end of the page');
            Get.find<AllPrimeMembersController>().showBottomLoader();
            Get.find<AllPrimeMembersController>().getRegisteredUsers(widget.title,true);
          }
        }
      });
    }

  }
  @override
  void dispose() {
    super.dispose();
    scrollController?.dispose();
  }

  @override
  Widget build(BuildContext context) {

    return Scaffold(
      backgroundColor: Theme.of(context).cardColor,
      endDrawer: WebMenuDrawer(),
      appBar: CustomAppBar(title: widget.title, backButton: true),
      body: GetBuilder<UserController>(
          builder: (userController) {
            return _isLoggedIn ? userController.userInfoModel != null ? SafeArea(
              child: RefreshIndicator(
                onRefresh: () async{
                  Get.find<AllPrimeMembersController>().getRegisteredUsers(widget.title,false);
                },
                child: Stack(children: [

                  SingleChildScrollView(
                    controller: scrollController,
                    padding: EdgeInsets.symmetric(horizontal: ResponsiveHelper.isDesktop(context) ? 0.0 : Dimensions.PADDING_SIZE_DEFAULT),
                    child: FooterView(
                      child: SizedBox(
                        width: Dimensions.WEB_MAX_WIDTH,
                        child: GetBuilder<AllPrimeMembersController>(
                            builder: (walletController) {
                              return Column(children: [
                                Row(

                                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                                  crossAxisAlignment: CrossAxisAlignment.center,
                                  children: [
                                    Text("Users ${walletController.totalPageSize}"),

                                    Text(
                                      walletController.allPrimeMembersAmt==null ? "0.0" : PriceConverter.convertPrice(walletController.allPrimeMembersAmt),
                                      style: robotoBold.copyWith(fontSize: Dimensions.fontSizeSmall, color: Colors.green),
                                    ),

                                    Row(
                                      mainAxisAlignment: MainAxisAlignment.start,
                                      children: [
                                        Text("Amt > 0"),
                                        CustomCheckBox(
                                          title:  '',
                                          value: walletController.amtGreaterThanZero=='1',
                                          onClick: () {
                                            if(walletController.amtGreaterThanZero=='1'){
                                              walletController.setAmtGreaterThanZero("0");
                                            }else{
                                              walletController.setAmtGreaterThanZero('1');
                                            }
                                            Get.find<AllPrimeMembersController>().getRegisteredUsers(widget.title,false);
                                          },
                                        ),
                                      ],
                                    ),

                                  ],
                                ),

                                SizedBox(height: 5,),
                                Row(

                                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                                  crossAxisAlignment: CrossAxisAlignment.center,
                                  children: [
                                    SizedBox(),

                                    Get.find<AllPrimeMembersController>().isSearchMode ?
                                    InkWell(child: Text('clear_search'.tr),onTap: (){
                                      _inputMessageController.text="";
                                      Get.find<AllPrimeMembersController>().setSearch("");
                                      Get.find<AllPrimeMembersController>().searchModeDisable();
                                      Get.find<AllPrimeMembersController>().getRegisteredUsers(widget.title,false);

                                    },)
                                    : SizedBox(),

                                  ],
                                ),
                                SizedBox(height: Get.find<AllPrimeMembersController>().isSearchMode? 10 : 5,),

                                Column(children: [

                                  Container(
                                    decoration: BoxDecoration(
                                      color: Theme.of(context).colorScheme.background,
                                      borderRadius: BorderRadius.circular(Dimensions.RADIUS_EXTRA_LARGE),
                                      boxShadow: [BoxShadow(color: Colors.grey[Get.isDarkMode ? 800 : 200], spreadRadius: 1, blurRadius: 4)],
                                    ),
                                    child: Padding(
                                      padding: const EdgeInsets.all(0.0),
                                      child: Row(children: [

                                        SizedBox(width: Dimensions.PADDING_SIZE_DEFAULT),

                                        Expanded(
                                          child: TextField(
                                            inputFormatters: [LengthLimitingTextInputFormatter(Dimensions.MESSAGE_INPUT_LENGTH)],
                                            controller: _inputMessageController,
                                            textCapitalization: TextCapitalization.sentences,
                                            style: robotoRegular,
                                            keyboardType: TextInputType.multiline,
                                            maxLines: null,
                                            decoration: InputDecoration(
                                              border: InputBorder.none,
                                              hintText: widget.title=='customers'.tr ? 'Search by Name | Mobile' : 'Search by Name | ID | Mobile',
                                              hintStyle: robotoRegular.copyWith(color: Theme.of(context).hintColor, fontSize: Dimensions.fontSizeLarge),
                                            ),
                                          ),
                                        ),

                                        GetBuilder<AllPrimeMembersController>(builder: (chatController) {
                                          return chatController.isSearchPrimeMembersLoading ? Padding(
                                            padding: EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_DEFAULT),
                                            child: SizedBox(height: 25, width: 25, child: CircularProgressIndicator()),
                                          ) : InkWell(
                                            onTap: () async {

                                              if(_inputMessageController.text.isNotEmpty) {

                                                chatController.setSearch(_inputMessageController.text.toString().trim());
                                                chatController.searchRegisteredUsers(widget.title,false);

                                              }
                                              else {
                                                showCustomSnackBar('write_something'.tr);
                                              }
                                            },
                                            child: Padding(
                                              padding: EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_DEFAULT),
                                              child: Icon(Icons.search, size: 25, color:
                                              Theme.of(context).primaryColor,),
                                            ),
                                          );
                                        }
                                        ),

                                      ]),
                                    ),
                                  ),

                                  // Expanded(child:
                                  // SearchResultWidget()),

                                ]),
                                // Container(
                                //   width: context.width,
                                //   color: Colors.white,
                                //   child: Container(
                                //     height: 35,
                                //     color: Theme.of(context).bottomAppBarTheme.color,
                                //     padding: EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_SMALL),
                                //     child: InkWell(
                                //       onTap: (){
                                //
                                //       },
                                //       child: Row(
                                //         mainAxisAlignment: MainAxisAlignment.center,
                                //         crossAxisAlignment: CrossAxisAlignment.end,
                                //         children: [
                                //           Container(
                                //             height: 35,
                                //             width: context.width*0.7,
                                //             padding: EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_SMALL),
                                //             decoration: BoxDecoration(
                                //               color: Theme.of(context).colorScheme.background,
                                //               borderRadius: BorderRadius.circular(Dimensions.RADIUS_EXTRA_LARGE),
                                //               boxShadow: [BoxShadow(color: Colors.grey[Get.isDarkMode ? 800 : 200], spreadRadius: 1, blurRadius: 4)],
                                //             ),
                                //             child: Row(
                                //               mainAxisAlignment: MainAxisAlignment.center,
                                //                 children: [
                                //
                                //               Row(
                                //                 mainAxisAlignment: MainAxisAlignment.center,
                                //                 children: [
                                //
                                //                  Text("Search by Name | ID | Mobile",style: TextStyle(color: Colors.black38)),
                                //                 ],
                                //               ),
                                //
                                //
                                //
                                //             ]),
                                //           ),
                                //
                                //           SizedBox(width: 10,),
                                //
                                //           Icon(Icons.search, size: 25, color:
                                //           Theme.of(context).primaryColor,),
                                //         ],
                                //       ),
                                //     ),
                                //   ),
                                // ),
                                SizedBox(height: 15,),

                                walletController.allRegisteredUsersDataList != null ? walletController.allRegisteredUsersDataList.length > 0 ?
                                ListView.builder(
                                  shrinkWrap: true,
                                  scrollDirection: Axis.vertical,
                                  itemCount: walletController.allRegisteredUsersDataList.length,
                                  physics: BouncingScrollPhysics(),
                                  itemBuilder: (context, index) {
                                    return InkWell(
                                      onTap: () {

                                      },
                                      child: Padding(
                                        padding: const EdgeInsets.only(top: 10.0),
                                        child: Container(
                                          decoration: AppConstants.customBoxDecoration(context),
                                          child: Row(
                                            children: [
                                              Padding(
                                                padding: const EdgeInsets.only(right: 5,left: 5),
                                                child: Container(
                                                  decoration: BoxDecoration(
                                                    border: Border.all(width: 2, color: Theme.of(context).cardColor),
                                                    shape: BoxShape.circle,
                                                  ),
                                                  alignment: Alignment.topLeft,
                                                  child: ClipOval(child: CustomImage(
                                                    image: '${Get.find<SplashController>().configModel.baseUrls.customerImageUrl}'
                                                        '/${walletController.allRegisteredUsersDataList[index].image != null  ? walletController.allRegisteredUsersDataList[index].image : ''}',
                                                    height: 40, width: 40, fit: BoxFit.cover,isProfile: true,
                                                  )),
                                                ),
                                              ),
                                              Expanded(child: Column(
                                                crossAxisAlignment: CrossAxisAlignment.start,
                                                mainAxisAlignment: MainAxisAlignment.start,
                                                children: [
                                                  SizedBox(height: 5,),

                                                  Container(
                                                    width: context.width*0.7,

                                                    child: Row(
                                                      mainAxisAlignment: MainAxisAlignment.spaceBetween,

                                                      children: [
                                                        Text(
                                                          '${ walletController.allRegisteredUsersDataList[index].primeMemberDetail==null?'':walletController.allRegisteredUsersDataList[index].primeMemberDetail.primeAccountNo} ',
                                                          style: TextStyle(fontSize: 15.0),
                                                        ),


                                                      ],
                                                    ),
                                                  ),
                                                  SizedBox(height: 5,),
                                                  Text(
                                                    '${ walletController.allRegisteredUsersDataList[index].fName} ${ walletController.allRegisteredUsersDataList[index].lName}',
                                                    style: TextStyle(fontSize: 15.0),
                                                  ),
                                                  SizedBox(height: 5,),
                                                  Container(
                                                    width: context.width*0.7,
                                                    child: Row(mainAxisAlignment: MainAxisAlignment.start,
                                                      children: [
                                                        Text(
                                                          walletController.allRegisteredUsersDataList[index].phone,
                                                          style: TextStyle(fontSize: 15.0),
                                                        ),
                                                        SizedBox(width: 10,),
                                                        InkWell(child: Container(
                                                          height: 30, width: 30,
                                                          decoration: BoxDecoration(
                                                            shape: BoxShape.circle,
                                                            color: Colors.blue.withOpacity(0.2),
                                                          ),
                                                          child: Icon(Icons.call, color: Colors.blue, size: 20),
                                                        ),
                                                            onTap: () async {
                                                              if(await canLaunchUrlString('tel:${walletController.allRegisteredUsersDataList[index].phone}')) {
                                                                launchUrlString('tel:${walletController.allRegisteredUsersDataList[index].phone}');
                                                              }else {
                                                                showCustomSnackBar('${'can_not_launch'.tr} ${Get.find<SplashController>().configModel.phone}');
                                                              }
                                                            })
                                                        ,SizedBox(width: 10,),

                                                        InkWell(child: Container(
                                                          height: 30, width: 30,
                                                          decoration: BoxDecoration(
                                                            shape: BoxShape.circle,
                                                            color: Colors.red.withOpacity(0.2),
                                                          ),
                                                          child: Image.asset(Images.whatsapp, width: 30,
                                                            height: 30,fit: BoxFit.fill,),
                                                        ), onTap: ()
                                                        async {
                                                          var whatsappUrl =
                                                              "whatsapp://send?phone=${walletController.allRegisteredUsersDataList[index].phone}" ;
                                                          //  + "&text=${Uri.encodeComponent("hi")}";

                                                          if(await canLaunchUrlString(whatsappUrl)) {
                                                            launchUrlString(whatsappUrl);
                                                          }else {
                                                            showCustomSnackBar('${'can_not_launch'.tr} ${Get.find<SplashController>().configModel.phone}');
                                                          }
                                                        }),
                                                      ],
                                                    ),
                                                  ),


                                                  SizedBox(height: 5,),
                                                  Row(
                                                    children: [
                                                      Text(
                                                        walletController.allRegisteredUsersDataList[index].email,
                                                        style: TextStyle(fontSize: 12.0),
                                                      ),
                                                      SizedBox(width: 10,),
                                                      InkWell(child: Container(
                                                        height: 30, width: 30,
                                                        decoration: BoxDecoration(
                                                          shape: BoxShape.circle,
                                                          color: Colors.red.withOpacity(0.2),
                                                        ),
                                                        child: Icon(Icons.mail_outline, color: Colors.red, size: 20),
                                                      ), onTap: ()
                                                      async {
                                                        final Uri emailLaunchUri = Uri(
                                                          scheme: 'mailto',
                                                          path: walletController.allRegisteredUsersDataList[index].email,
                                                        );
                                                        launchUrlString(emailLaunchUri.toString());
                                                      }),
                                                    ],
                                                  ),
                                                  SizedBox(height: 8,),
                                                  Container(
                                                    width: context.width*0.7,
                                                    child: Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,
                                                      children: [
                                                        SizedBox(),
                                                        Row(
                                                          children: [
                                                            walletController.allRegisteredUsersDataList[index].walletAmount==null? Text(
                                                              ' ${PriceConverter.convertPrice(double.parse('0.0'))}',
                                                              style: robotoBold.copyWith(fontSize: Dimensions.fontSizeLarge, color: Colors.green),
                                                            )
                                                                : Text(
                                                              '${PriceConverter.convertPrice(double.parse( walletController.allRegisteredUsersDataList[index].walletAmount.balance))}',
                                                              style: robotoBold.copyWith(fontSize: Dimensions.fontSizeLarge, color: Colors.green),
                                                            ),
                                                            SizedBox(width: 10,),
                                                            InkWell(child: Container(
                                                              decoration: BoxDecoration(
                                                                color: Colors.grey[200],
                                                                borderRadius: BorderRadius.circular(Dimensions.RADIUS_LARGE),
                                                                boxShadow: [BoxShadow(color: Colors.white, spreadRadius: 1, blurRadius: 2)],
                                                              ),

                                                              padding: EdgeInsets.fromLTRB(10.0, 5.0, 10.0, 5.0),
                                                              child: Text(
                                                                'statement'.tr,
                                                                style: TextStyle(fontSize: 12.0,color: Colors.black),
                                                              ),
                                                            ),onTap: (){
                                                              walletController.selectPrimeMemberToViewStatement(walletController.allRegisteredUsersDataList[index]);
                                                              Get.toNamed(RouteHelper.getWalletRoute(false,'select_prime_to_view_statement'.tr));
                                                            },),
                                                          ],
                                                        ),
                                                      ],
                                                    ),
                                                  ),
                                                  SizedBox(height: 10,),

                                                ]
                                                ,))
                                            ],
                                          ),
                                        ),
                                      ),
                                    );
                                  },
                                )
                                    : NoDataScreen(text: 'no_data_found'.tr)
                                    : WalletShimmer(walletController: walletController),

                                walletController.isLoading ? Center(child: Padding(
                                  padding: EdgeInsets.all(Dimensions.PADDING_SIZE_SMALL),
                                  child: CircularProgressIndicator(),
                                )) : SizedBox(),
                              ]);
                            }
                        ),
                      ),
                    ),
                  ),

                ],),
              ),
            ) : Center(child: CircularProgressIndicator()) : NotLoggedInScreen();
          }
      ),
    );
  }
}

// class FilterWidget extends StatelessWidget {
//
//
//   Future<void> _selectFromDate(BuildContext context, WalletController walletController) async {
//     final DateTime picked = await showDatePicker(
//         context: context,
//         initialDate: walletController.selectedFromDate,
//         firstDate: DateTime(2015, 8),
//         lastDate: DateTime(2050, 8));
//
//     if (picked != null && picked != walletController.selectedFromDate) {
//       walletController.setFromDate("${picked.toLocal()}".split(' ')[0],picked);
//
//     }
//   }
//   Future<void> _selectToDate(BuildContext context, WalletController walletController) async {
//     final DateTime picked = await showDatePicker(
//         context: context,
//         initialDate: walletController.selectedToDate,
//         firstDate: DateTime(2015, 8),
//         lastDate: DateTime(2050, 8));
//     if (picked != null && picked != walletController.selectedToDate) {
//       walletController.setToDate("${picked.toLocal()}".split(' ')[0],picked);
//
//     }
//   }
//   @override
//   Widget build(BuildContext context) {
//     return Dialog(
//       shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL)),
//       insetPadding: EdgeInsets.all(30),
//       clipBehavior: Clip.antiAliasWithSaveLayer,
//       child: Container(
//         width: 600,
//         padding: EdgeInsets.all(Dimensions.PADDING_SIZE_SMALL),
//         child: GetBuilder<WalletController>(builder: (walletController) {
//           return SingleChildScrollView(
//             child: Column(mainAxisSize: MainAxisSize.min, crossAxisAlignment: CrossAxisAlignment.start, children: [
//
//               Row(mainAxisAlignment: MainAxisAlignment.spaceBetween, children: [
//                 InkWell(
//                   onTap: () => Navigator.of(context).pop(),
//                   child: Padding(
//                     padding: EdgeInsets.all(Dimensions.PADDING_SIZE_EXTRA_SMALL),
//                     child: Icon(Icons.close, color: Theme.of(context).disabledColor),
//                   ),
//                 ),
//                 Text('filter'.tr, style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeLarge)),
//                 CustomButton(
//                   onPressed: () {
//                     walletController.resetStatementFilter();
//                     walletController.getRegisteredUsers(widget.title);
//                   },
//                   buttonText: 'reset'.tr, transparent: true, width: 65,
//                 ),
//               ]),
//               SizedBox(height: Dimensions.PADDING_SIZE_LARGE),
//
//               Text('sort_by'.tr, style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeLarge)),
//               SizedBox(height: Dimensions.PADDING_SIZE_SMALL),
//               GridView.builder(
//                 itemCount: walletController.sortList.length,
//                 physics: NeverScrollableScrollPhysics(),
//                 shrinkWrap: true,
//                 gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
//                   crossAxisCount: ResponsiveHelper.isDesktop(context) ? 3 : ResponsiveHelper.isTab(context) ? 3 : 2,
//                   childAspectRatio: 3, crossAxisSpacing: 10, mainAxisSpacing: 10,
//                 ),
//                 itemBuilder: (context, index) {
//                   return InkWell(
//                     onTap: () {
//                       walletController.setSortIndex(index);
//                     },
//                     child: Container(
//                       alignment: Alignment.center,
//                       decoration: BoxDecoration(
//                         border: Border.all(color: walletController.sortIndex == index ? Colors.transparent
//                             : Theme.of(context).disabledColor),
//                         borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
//                         color: walletController.sortIndex == index ? Theme.of(context).primaryColor
//                             : Theme.of(context).disabledColor.withOpacity(0.1),
//                       ),
//                       child: Text(
//                         walletController.sortList[index],
//                         textAlign: TextAlign.center,
//                         style: robotoMedium.copyWith(
//                           color: walletController.sortIndex == index ? Colors.white : Theme.of(context).hintColor,
//                         ),
//                         maxLines: 1,
//                         overflow: TextOverflow.ellipsis,
//                       ),
//                     ),
//                   );
//                 },
//               ),
//               SizedBox(height: Dimensions.PADDING_SIZE_LARGE),
//
//               Text('date'.tr, style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeLarge)),
//               SizedBox(height: Dimensions.PADDING_SIZE_SMALL),
//               Row(
//                 children: [
//                   InkWell(
//                     onTap: () {
//                       _selectFromDate(context,walletController);
//                     },
//                     child: Container(
//                       padding: EdgeInsets.fromLTRB(15, 10, 15, 10),
//                       alignment: Alignment.center,
//                       decoration: BoxDecoration(
//                         border: Border.all(color: walletController.fromDate != 'from_date'.tr ? Colors.transparent
//                             : Theme.of(context).disabledColor),
//                         borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
//                         color: walletController.fromDate != 'from_date'.tr ? Theme.of(context).primaryColor
//                             : Theme.of(context).disabledColor.withOpacity(0.1),
//                       ),
//                       child: Text(
//                         walletController.fromDate,
//                         textAlign: TextAlign.center,
//                         style: robotoMedium.copyWith(
//                           color: walletController.fromDate != 'from_date'.tr ? Colors.white : Theme.of(context).hintColor,
//                         ),
//                         maxLines: 1,
//                         overflow: TextOverflow.ellipsis,
//                       ),
//                     ),
//                   ),
//
//                   SizedBox(width: 15,),
//
//                   InkWell(
//                     onTap: () {
//                       _selectToDate(context,walletController);
//
//                     },
//                     child: Container(
//                       padding: EdgeInsets.fromLTRB(15, 10, 15, 10),
//                       alignment: Alignment.center,
//                       decoration: BoxDecoration(
//                         border: Border.all(color: walletController.toDate != 'to_date'.tr ? Colors.transparent
//                             : Theme.of(context).disabledColor),
//                         borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
//                         color: walletController.toDate != 'to_date'.tr ? Theme.of(context).primaryColor
//                             : Theme.of(context).disabledColor.withOpacity(0.1),
//                       ),
//
//                       child: Text(
//                         walletController.toDate,
//                         textAlign: TextAlign.center,
//                         style: robotoMedium.copyWith(
//                           color: walletController.toDate != 'to_date'.tr ? Colors.white : Theme.of(context).hintColor,
//                         ),
//                         maxLines: 1,
//                         overflow: TextOverflow.ellipsis,
//                       ),
//                     ),
//                   ),
//                 ],
//               ),
//               SizedBox(height: Dimensions.PADDING_SIZE_LARGE),
//
//               Text('transaction_type'.tr, style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeLarge)),
//
//               Row(crossAxisAlignment: CrossAxisAlignment.start,mainAxisAlignment: MainAxisAlignment.start,children: [
//                 CustomCheckBox(
//                   title:  'debit'.tr,
//                   value: walletController.transactionType=='debit'.tr,
//                   onClick: () {
//                     if(walletController.transactionType=='debit'.tr){
//                       walletController.setTransactionType("");
//                     }else{
//                       walletController.setTransactionType('debit'.tr);
//                     }
//
//                   },
//                 ),
//                 CustomCheckBox(
//                   title:  'credit'.tr,
//                   value: walletController.transactionType=='credit'.tr,
//                   onClick: () {
//                     if(walletController.transactionType=='credit'.tr){
//                       walletController.setTransactionType("");
//                     }else{
//                       walletController.setTransactionType('credit'.tr);
//                     }
//
//                   },
//                 ),
//
//               ],),
//
//
//               SizedBox(height: Dimensions.PADDING_SIZE_SMALL),
//
//
//               (walletController.transferTypesList!=null && walletController.transferTypesList.length>0) ?
//               Column(
//                 children: [
//                   Text('transfer_type'.tr,
//                       style: robotoMedium.copyWith(fontSize:
//                       Dimensions.fontSizeLarge)),
//                   SizedBox(height: Dimensions.PADDING_SIZE_SMALL),
//                 ],
//               )
//                   : SizedBox(),
//               (walletController.transferTypesList!=null && walletController.transferTypesList.length>0) ? Container(
//                 height: 30, alignment: Alignment.center,
//                 child: ListView.builder(
//                   itemCount: walletController.transferTypesList.length,
//                   shrinkWrap: true,
//                   scrollDirection: Axis.horizontal,
//                   itemBuilder: (context, index) {
//                     return CustomCheckBox(
//                       title:  walletController.transferTypesList[index].name,
//                       value: (walletController.transferTypeDropDownValue!=null && walletController.transferTypeDropDownValue.name==walletController.transferTypesList[index].name),
//                       onClick: () {
//                         if(walletController.transferTypeDropDownValue!=null && walletController.transferTypeDropDownValue.name==walletController.transferTypesList[index].name){
//                           walletController.updateTransferTypeDropdown(null);
//                         }else{
//                           walletController.updateTransferTypeDropdown(walletController.transferTypesList[index]);
//                         }
//                       },
//                     );
//                   },
//                 ),
//               )
//                   : SizedBox(),
//               SizedBox(height:(walletController.transferTypesList!=null && walletController.transferTypesList.length>0) ? 30 : 0.0),
//
//               CustomButton(
//                 buttonText: 'apply_filters'.tr,
//                 onPressed: () {
//                   walletController.setFilterApplied();
//                   walletController.getRegisteredUsers(widget.title);
//                   Get.back();
//                 },
//               ),
//
//             ]),
//           );
//         }),
//       ),
//     );
//   }
// }

class WalletShimmer extends StatelessWidget {
  final AllPrimeMembersController walletController;
  WalletShimmer({@required this.walletController});

  @override
  Widget build(BuildContext context) {
    return GridView.builder(
      key: UniqueKey(),
      gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
        crossAxisSpacing: 50,
        mainAxisSpacing: ResponsiveHelper.isDesktop(context) ? Dimensions.PADDING_SIZE_LARGE : 0.1,
        childAspectRatio: ResponsiveHelper.isDesktop(context) ? 5 : 2.45,
        crossAxisCount: ResponsiveHelper.isMobile(context) ? 1 : 2,
      ),
      physics:  NeverScrollableScrollPhysics(),
      shrinkWrap:  true,
      itemCount: 10,
      padding: EdgeInsets.only(top: ResponsiveHelper.isDesktop(context) ? 28 : 25),
      itemBuilder: (context, index) {
        return Padding(
          padding: EdgeInsets.symmetric(vertical: Dimensions.PADDING_SIZE_SMALL),
          child: Shimmer(
            duration: Duration(seconds: 2),
            enabled: walletController.allRegisteredUsersDataList == null,
            child: Column(children: [
              Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Column(crossAxisAlignment: CrossAxisAlignment.start, children: [
                    Container(height: 10, width: 50, decoration: BoxDecoration(color: Colors.grey[300], borderRadius: BorderRadius.circular(2))),
                    SizedBox(height: 10),
                    Container(height: 10, width: 70, decoration: BoxDecoration(color: Colors.grey[300], borderRadius: BorderRadius.circular(2))),
                  ]),
                  Column(crossAxisAlignment: CrossAxisAlignment.end, children: [
                    Container(height: 10, width: 50, decoration: BoxDecoration(color: Colors.grey[300], borderRadius: BorderRadius.circular(2))),
                    SizedBox(height: 10),
                    Container(height: 10, width: 70, decoration: BoxDecoration(color: Colors.grey[300], borderRadius: BorderRadius.circular(2))),
                  ]),
                ],
              ),
              Padding(padding: const EdgeInsets.only(top: Dimensions.PADDING_SIZE_LARGE), child: Divider(color: Theme.of(context).disabledColor)),
            ],
            ),
          ),
        );
      },
    );
  }
}

class ItemUi extends StatelessWidget {
  final int index;
  final AllRegisteredUsersData data;
  const ItemUi({Key key, @required this.index, @required this.data}) : super(key: key);


  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: BoxDecoration(
        color: Theme.of(context).primaryColor,
        borderRadius: BorderRadius.circular(Dimensions.RADIUS_LARGE),
        boxShadow: [BoxShadow(color: Colors.grey[Get.isDarkMode ? 800 : 200], spreadRadius: 1, blurRadius: 5)],
      ),
      child: Row(
        children: [
          Padding(
            padding: const EdgeInsets.only(right: 10,left: 10),
            child: Container(
              decoration: BoxDecoration(
                border: Border.all(width: 2, color: Theme.of(context).cardColor),
                shape: BoxShape.circle,
              ),
              alignment: Alignment.topLeft,
              child: ClipOval(child: CustomImage(
                image: '${Get.find<SplashController>().configModel.baseUrls.customerImageUrl}'
                    '/${data.image != null  ? data.image : ''}',
                height: 40, width: 40, fit: BoxFit.cover,isProfile: true,
              )),
            ),
          ),
          Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              SizedBox(height: 10,),
              Text(
                ' ${ data.primeMemberDetail==null?'': data.primeMemberDetail.primeAccountNo} ${ data.fName} ${ data.lName}',
                style: TextStyle(fontSize: 15.0),
              ),
              SizedBox(height: 10,),
              Row(
                children: [
                  Text('${'phone'.tr}: ', style:TextStyle(fontSize: 15, color: Colors.black)),
                  SizedBox(width: 5,),

                  Text(
                    data.phone,
                    style: TextStyle(fontSize: 15.0),
                  ),
                ],
              ),
              SizedBox(height: 10,),
              Row(
                children: [
                  Text('${'email'.tr}: ', style:TextStyle(fontSize: 15, color: Colors.black)),
                  SizedBox(width: 5,),

                  Text(
                    data.email,
                    style: TextStyle(fontSize: 15.0),
                  ),
                ],
              ),


            ]
            ,)
        ],
      ),
    );
  }
}