
import 'dart:async';
import 'dart:math';

import 'package:im_animations/im_animations.dart';
import 'package:sixam_mart/controller/auth_controller.dart';
import 'package:sixam_mart/controller/cart_controller.dart';
import 'package:sixam_mart/controller/item_controller.dart';
import 'package:sixam_mart/controller/search_controller.dart';
import 'package:sixam_mart/controller/splash_controller.dart';
import 'package:sixam_mart/helper/responsive_helper.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/styles.dart';
import 'package:sixam_mart/view/base/custom_button.dart';
import 'package:sixam_mart/view/base/custom_image.dart';
import 'package:sixam_mart/view/base/footer_view.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_drawer.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_bar.dart';
import 'package:sixam_mart/view/screens/search/widget/filter_widget.dart';
import 'package:sixam_mart/view/screens/search/widget/search_field.dart';
import 'package:sixam_mart/view/screens/search/widget/search_result_widget.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:sixam_mart/view/screens/store/widget/bottom_cart_widget.dart';
import 'package:speech_to_text/speech_recognition_error.dart';
import 'package:speech_to_text/speech_to_text.dart' as speechToText;
import 'package:speech_to_text/speech_to_text.dart';

import '../../../util/app_constants.dart';

class SearchScreen extends StatefulWidget {
  String queryText;
  SearchScreen({@required this.queryText});

  @override
  _SearchScreenState createState() => _SearchScreenState();
}

class _SearchScreenState extends State<SearchScreen> {
  bool _canSearch = true;
  final TextEditingController _searchController = TextEditingController();
  bool _isLoggedIn;
  bool _logEvents = false;
  String lastError = '';
  String lastStatus = '';
  String _currentLocaleId = '';
  List<LocaleName> _localeNames = [];
  final TextEditingController _pauseForController =
  TextEditingController(text: '3');
  final TextEditingController _listenForController =
  TextEditingController(text: '30');
  double level = 0.0;
  double minSoundLevel = 50000;
  double maxSoundLevel = -50000;
  bool shouldCall = true;
  speechToText.SpeechToText speech;
  bool isListen = false;
  double confidence = 1.0;
  Timer timeHandle;


  @override
  void dispose() {
    // Clean up the controller when the widget is removed from the widget tree.
    // This also removes the _printLatestValue listener.
    _searchController.dispose();
    timeHandle?.cancel();
    super.dispose();
  }

  @override
  void initState() {
    super.initState();

    speech = speechToText.SpeechToText();
    _isLoggedIn = Get.find<AuthController>().isLoggedIn();
   // _searchController.addListener(textListener);

    if(_isLoggedIn) {
      Get.find<SearchController>().getSuggestedItems();
    }
    Get.find<SearchController>().setSearchingFalse();
    Get.find<SearchController>().getHistoryList();

    if(widget.queryText.isNotEmpty && widget.queryText=="_isHomeSearch") {

      widget.queryText='';
    }

    else if(widget.queryText.isNotEmpty &&  widget.queryText.contains("_isHomeSearchVoice")) {
      // user click on mic to search items with voice at home screen
      String result = widget.queryText.substring(0, widget.queryText.indexOf('.'));
      if(result!=null && result.isNotEmpty){
        _actionSearch(true, result, false);
      }
      widget.queryText='';
    }
    else {
      if(widget.queryText.isNotEmpty) {

        _actionSearch(true, widget.queryText, true);
      }
    }

  }

  // _onChangeHandler(value ) {
  //   const duration = Duration(milliseconds:800); // set the duration that you want call search() after that.
  //   if (searchOnStoppedTyping != null) {
  //     setState(() => searchOnStoppedTyping.cancel()); // clear timer
  //   }
  //   setState(() => searchOnStoppedTyping = new Timer(duration, () => _actionSearch(true, value, false)));
  // }

  textListener()  {
    var searchedData = _searchController.text.trim();
    _searchController.value = _searchController.value.copyWith(
      text: searchedData,
      selection: TextSelection(baseOffset: searchedData.length, extentOffset: searchedData.length),
      composing: TextRange.empty,
    );
    if(searchedData!=null && searchedData.isNotEmpty && searchedData.length>1){

      if (timeHandle != null) {
        timeHandle.cancel();
      }
      timeHandle = Timer(Duration(milliseconds: 1200), () {
        _actionSearch(true, searchedData, false);
      });

    }

  }
  void _logEvent(String eventDescription) {
    if (_logEvents) {
      var eventTime = DateTime.now().toIso8601String();
      print('$eventTime $eventDescription');
    }
  }
  void errorListener(SpeechRecognitionError error) {
    _logEvent(
        'Received error status: $error, listening: ${speech.isListening}');
    setState(() {
      lastError = '${error.errorMsg} - ${error.permanent}';
    });
  }
  void statusListener(String status) {
    _logEvent(
        'Received listener status: $status, listening: ${speech.isListening}');
    setState(() {
      lastStatus = '$status';
    });
  }




  void listen(SearchController searchController) async {
    try{
      // final pauseFor = int.tryParse(_pauseForController.text);
      // final listenFor = int.tryParse(_listenForController.text);
      if (!isListen) {
        bool avail = await speech.initialize(
          onError: errorListener,
          onStatus: statusListener,
          debugLogging: _logEvents,
        );
        if (avail) {
          setState(() {
            isListen = true;
          });
          // Get the list of languages installed on the supporting platform so they
          // can be displayed in the UI for selection by the user.
          _localeNames = await speech.locales();
          var systemLocale = await speech.systemLocale();
          _currentLocaleId = systemLocale?.localeId ?? '';
          if (!mounted) return;

          // Note that `listenFor` is the maximum, not the minimun, on some
          // systems recognition will be stopped before this value is reached.
          // Similarly `pauseFor` is a maximum not a minimum and may be ignored
          // on some devices.
          speech.listen(
              onResult: (value) {
            setState(() {
              // if (value.hasConfidenceRating && value.confidence > 0) {
              //   confidence = value.confidence;
              // }
              var searchedData = value.recognizedWords.trim();
              searchController.setSearchText(searchedData);
              _actionSearch(true, searchedData, false);

              setState(() {
                isListen = false;
              });

              setState(() {});
            });
          }
          );

          // speech.listen(
          //   onResult: (value){ resultListener(value,searchController);},
          //   listenFor: Duration(seconds: listenFor ?? 30),
          //   pauseFor: Duration(seconds: pauseFor ?? 3),
          //   partialResults: true,
          //   localeId: _currentLocaleId,
          //   onSoundLevelChange: soundLevelListener,
          //   cancelOnError: true,
          //   listenMode: ListenMode.confirmation,
          //   onDevice: _onDevice,
          // );
        }
      } else {
        setState(() {
          isListen = false;
        });
        speech.stop();
      }
    }catch(e){
      setState(() {
        lastError = 'Speech recognition failed: ${e.toString()}';
        isListen = false;
      });
    }
  }


  @override
  Widget build(BuildContext context) {
    bool _desktop = ResponsiveHelper.isDesktop(context);
    bool _isTab = ResponsiveHelper.isTab(context);
    bool _isWeb = ResponsiveHelper.isWeb();
    bool _isMobile = ResponsiveHelper.isMobile(context);
    double _width = MediaQuery.of(context).size.width;
    print("testResponsiveHelper SearchScreen _width $_width _desktop $_desktop _isTab $_isTab isWeb $_isWeb _isMobile $_isMobile");

    return WillPopScope(
      onWillPop: () async {
        if(Get.find<SearchController>().isSearchMode) {
          return true;
        }else {
          Get.find<SearchController>().setSearchMode(true);
          return false;
        }
      },
      child: Scaffold(
          appBar: ResponsiveHelper.isDesktop(context) ? WebMenuBar() : null,
          endDrawer: WebMenuDrawer(),
          body: SafeArea(child: Padding(
            padding: ResponsiveHelper.isDesktop(context) ? EdgeInsets.zero : EdgeInsets.symmetric(vertical: Dimensions.PADDING_SIZE_SMALL),
            child: GetBuilder<SearchController>(builder: (searchController) {

              _searchController.text = searchController.searchText;

              _searchController.selection = TextSelection.collapsed(offset: _searchController.text.length);

              return Column(children: [

                widget.queryText.isNotEmpty ? SizedBox() : Center(child: SizedBox(width: Dimensions.WEB_MAX_WIDTH,
                    child: Row(children: [
                      SizedBox(width: Dimensions.PADDING_SIZE_SMALL),
                      Expanded(child:
              // TextField(
              //
              // onChanged: (String value) async {
              //
              //   print("onChanged_Search ${value.toString()}");
              // },
              // )
              TextField(

              textInputAction: TextInputAction.search,
                decoration: InputDecoration(


                  hintText: 'search_items'.tr,
                  hintStyle: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall, color: Theme.of(context).disabledColor),
                  border: OutlineInputBorder(borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL), borderSide: BorderSide.none),
                  filled: true,
                  fillColor:  Theme.of(context).cardColor,
                  isDense: true,
                ),
              autofocus: true,
              onSubmitted: (text){
                print("action_on_Search onSubmitted ${text.toString()}");
                if(text!=null)
                _actionSearch(true, text.trim(), false);
              },
                onEditingComplete: (){

                },
                onChanged: (String value) async {

                  print("action_on_Search onChanged ${value.toString()}");
                  if(value!=null)

                  _actionSearch(true, value.trim(), false);
                },
              )


                      // SearchField(
                      //   controller: _searchController,
                      //   hint:  Get.find<SplashController>().configModel.moduleConfig.module.showRestaurantText
                      //       ? 'search_items'.tr : 'search_item_or_store'.tr,
                      //
                      //   //suffixIcon: !searchController.isSearchMode ? Icons.filter_list : Icons.search,
                      //   //iconPressed: () => _actionSearch(false, _searchController.text.trim(), false),
                      //   suffixIcon:  Icons.search,
                      //   iconPressed: () => _actionSearch(true, _searchController.text.trim(), false),
                      //   onSubmit: (text) => _actionSearch(true, _searchController.text.trim(), false),
                      //
                      // )

                      ),



                      //searchController.isSearchMode ?
                      SizedBox(
                        height: 30,
                        width: 30,
                        child: isListen ? HeartBeat(
                          child: FloatingActionButton(
                            backgroundColor: Theme.of(context).primaryColor,
                            child: Icon(Icons.mic,size: 17,color: Colors.white),
                            onPressed: () {
                              listen(searchController);
                            },
                          ),)
                            : FloatingActionButton(
                          backgroundColor: Theme.of(context).primaryColor,
                          child: Icon(Icons.mic_off,size: 17,color: Colors.white),
                          onPressed: () {
                            listen(searchController);
                          },
                        ),
                      ),
                          // : SizedBox(),

                      //  SizedBox(
                      //   height: 30,
                      //   width: 30,
                      //   child: FloatingActionButton(
                      //     backgroundColor: Theme.of(context).primaryColor,
                      //     child: Icon(Icons.mic_off,size: 17,color: Colors.white),
                      //     onPressed: () {
                      //       Get.toNamed(RouteHelper.getSpeachToTextRoute());
                      //     },
                      //   ),
                      // ),

                      CustomButton(
                        onPressed: (){
                          print("action_on_Search cancel btn isSearchMode ${Get.find<SearchController>().isSearchMode}");

                          Get.find<SearchController>().isSearchMode ? Get.back() : Get.find<SearchController>().setSearchMode(true);
                        },
                        buttonText: 'cancel'.tr,
                        transparent: true,
                        width: 80,
                      ),
                    ]))),

                Expanded(child: searchController.isSearchMode ?
                SingleChildScrollView(
                  physics: BouncingScrollPhysics(),
                  padding: ResponsiveHelper.isDesktop(context) ? EdgeInsets.zero : EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_SMALL),
                  child: FooterView(
                    child: SizedBox(width: Dimensions.WEB_MAX_WIDTH, child: Column(crossAxisAlignment: CrossAxisAlignment.start, children: [

                      searchController.historyList.length > 0 ? Row(mainAxisAlignment: MainAxisAlignment.spaceBetween, children: [
                        Text('history'.tr, style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeLarge)),
                        InkWell(
                          onTap: () => searchController.clearSearchAddress(),
                          child: Padding(
                            padding: EdgeInsets.symmetric(vertical: Dimensions.PADDING_SIZE_SMALL, horizontal: 4),
                            child: Text('clear_all'.tr, style: robotoRegular.copyWith(
                              fontSize: Dimensions.fontSizeSmall, color: Theme.of(context).disabledColor,
                            )),
                          ),
                        ),
                      ]) : SizedBox(),

                      ListView.builder(
                        itemCount: searchController.historyList.length,
                        physics: NeverScrollableScrollPhysics(),
                        shrinkWrap: true,
                        itemBuilder: (context, index) {
                          return Column(children: [
                            Row(children: [
                              Expanded(
                                //_actionSearch(true, value.trim(), false);
                                child: InkWell(
                                 // onTap: () => searchController.searchDataSonu(searchController.historyList[index], false),
                                  onTap: () => _actionSearch(true, searchController.historyList[index], false),
                                  child: Padding(
                                    padding: EdgeInsets.symmetric(vertical: Dimensions.PADDING_SIZE_EXTRA_SMALL),
                                    child: Text(
                                      searchController.historyList[index],
                                      style: robotoRegular.copyWith(color: Theme.of(context).disabledColor),
                                      maxLines: 1, overflow: TextOverflow.ellipsis,
                                    ),
                                  ),
                                ),
                              ),
                              InkWell(
                                onTap: () => searchController.removeHistory(index),
                                child: Padding(
                                  padding: EdgeInsets.symmetric(vertical: Dimensions.PADDING_SIZE_EXTRA_SMALL),
                                  child: Icon(Icons.close, color: Theme.of(context).disabledColor, size: 20),
                                ),
                              )
                            ]),
                            index != searchController.historyList.length-1 ? Divider() : SizedBox(),
                          ]);
                        },
                      ),
                      SizedBox(height: Dimensions.PADDING_SIZE_LARGE),

                      (_isLoggedIn && searchController.suggestedItemList != null) ? Text(
                        'suggestions'.tr, style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeLarge),
                      ) : SizedBox(),
                      SizedBox(height: Dimensions.PADDING_SIZE_SMALL),
                      (_isLoggedIn && searchController.suggestedItemList != null) ? searchController.suggestedItemList.length > 0 ?  GridView.builder(
                        gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(

                          crossAxisCount: ResponsiveHelper.isMobile(context) ? 2 : 4, childAspectRatio: (1/ 0.4),
                          mainAxisSpacing: Dimensions.PADDING_SIZE_SMALL, crossAxisSpacing: Dimensions.PADDING_SIZE_SMALL,


                        ),
                        physics: NeverScrollableScrollPhysics(),
                        shrinkWrap: true,
                        itemCount: searchController.suggestedItemList.length,
                        itemBuilder: (context, index) {
                          return InkWell(
                            onTap: () {
                              Get.find<ItemController>().navigateToItemPage(searchController.suggestedItemList[index], context);
                            },
                            child: Container(
                              decoration: BoxDecoration(
                                color: Theme.of(context).cardColor,
                                borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
                              ),
                              child: Row(children: [
                                SizedBox(width: Dimensions.PADDING_SIZE_SMALL),
                                ClipRRect(
                                  borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
                                  child: CustomImage(
                                    image: '${Get.find<SplashController>().configModel.baseUrls.itemImageUrl}'
                                        '/${searchController.suggestedItemList[index].image}',
                                    width: 45, height: 45, fit: BoxFit.cover,
                                  ),
                                ),
                                SizedBox(width: Dimensions.PADDING_SIZE_SMALL),
                                Expanded(child: Text(
                                  searchController.suggestedItemList[index].name,
                                  style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeSmall),
                                  maxLines: 2, overflow: TextOverflow.ellipsis,
                                )),
                              ]),
                            ),
                          );
                        },
                      )
                          : Padding(padding: EdgeInsets.only(top: 10), child: Text('no_suggestions_available'.tr)) : SizedBox(),
                    ])),
                  ),
                )
                    : SearchResultWidget(searchText: _searchController.text.trim())),

              ]);
            }),
          )),

          bottomNavigationBar: GetBuilder<CartController>(builder: (cartController) {
            return cartController.cartList.length > 0 && !ResponsiveHelper.isDesktop(context) ? BottomCartWidget() : SizedBox();
          })
      ),
    );
  }

  void _actionSearch(bool isSubmit, String queryText, bool fromHome) {
    if(Get.find<SearchController>().isSearchMode || isSubmit) {
      if(queryText.isNotEmpty) {

        Get.find<SearchController>().setSearchTextOnChanged(queryText);

        Get.find<SearchController>().searchDataSonu(queryText, fromHome);

      }

    }else {
      List<double> _prices = [];
      if(!Get.find<SearchController>().isStore) {
        Get.find<SearchController>().allItemList.forEach((product) => _prices.add(product.price));
        _prices.sort();
      }
      double _maxValue = _prices.length > 0 ? _prices[_prices.length-1] : 1000;
      Get.dialog(FilterWidget(maxValue: _maxValue, isStore: Get.find<SearchController>().isStore));
    }
  }
}


