import 'package:sixam_mart/controller/search_controller.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/styles.dart';
import 'package:sixam_mart/view/screens/search/widget/filter_widget.dart';
import 'package:sixam_mart/view/screens/search/widget/item_view.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

import '../../../../helper/responsive_helper.dart';

class SearchResultWidget extends StatefulWidget {
  final String searchText;
  SearchResultWidget({@required this.searchText});

  @override
  _SearchResultWidgetState createState() => _SearchResultWidgetState();
}

class _SearchResultWidgetState extends State<SearchResultWidget> with TickerProviderStateMixin {
  TabController _tabController;

  @override
  void initState() {
    super.initState();

    _tabController = TabController(length: 2, initialIndex: 0, vsync: this);
  }

  @override
  Widget build(BuildContext context) {
    bool _desktop = ResponsiveHelper.isDesktop(context);
    bool _isTab = ResponsiveHelper.isTab(context);
    bool _isWeb = ResponsiveHelper.isWeb();
    bool _isMobile = ResponsiveHelper.isMobile(context);
    double _width = MediaQuery.of(context).size.width;
    print("testResponsiveHelper SearchResultWidget _width $_width _desktop $_desktop _isTab $_isTab isWeb $_isWeb _isMobile $_isMobile");

    return Column(crossAxisAlignment: CrossAxisAlignment.start, children: [

      GetBuilder<SearchController>(builder: (searchController) {
        bool _isNull = true;
        int _length = 0;
        if(searchController.isStore) {
          _isNull = searchController.searchStoreList == null;
          if(!_isNull) {
            _length = searchController.searchStoreList.length;
          }
        }else {
          _isNull = searchController.searchItemList == null;
          if(!_isNull) {
            _length = searchController.searchItemList.length;
          }
        }
        return _isNull ? SizedBox() : Center(child: SizedBox(width: _desktop? _width :  Dimensions.WEB_MAX_WIDTH, child: Padding(
          padding: EdgeInsets.all(Dimensions.PADDING_SIZE_SMALL),
          child: Row(children: [
            Text(
              _length.toString(),
              style: robotoBold.copyWith(color: Theme.of(context).primaryColor, fontSize: Dimensions.fontSizeSmall),
            ),
            SizedBox(width: Dimensions.PADDING_SIZE_EXTRA_SMALL),
            Expanded(child: Text(
              'results_found'.tr,
              style: robotoRegular.copyWith(color: Theme.of(context).disabledColor, fontSize: Dimensions.fontSizeSmall),
            )),
            widget.searchText.isNotEmpty ? InkWell(
              onTap: () {
                List<double> _prices = [];
                if(!Get.find<SearchController>().isStore) {
                  Get.find<SearchController>().allItemList.forEach((product) => _prices.add(product.price));
                  _prices.sort();
                }
                double _maxValue = _prices.length > 0 ? _prices[_prices.length-1] : 1000;
                Get.dialog(FilterWidget(maxValue: _maxValue, isStore: Get.find<SearchController>().isStore));
              },
              child: Icon(Icons.filter_list),
            )
                : SizedBox(),
          ]),
        )));
      }),

      Expanded(child: NotificationListener(
        onNotification: (scrollNotification) {
          if (scrollNotification is ScrollEndNotification) {
            Get.find<SearchController>().setStore(_tabController.index == 1);
            Get.find<SearchController>().searchDataSonu(widget.searchText, false);
          }
          return false;
        },
        // child: GetBuilder<SearchController>(builder: (searchController) {
        //   return SingleChildScrollView(
        //     child: FooterView(
        //       child: SizedBox(width: Dimensions.WEB_MAX_WIDTH, child:  GridView.builder(gridDelegate:
        //       SliverGridDelegateWithFixedCrossAxisCount(
        //         crossAxisCount: _desktop ? 4 : (_isTab && _width > 950 )? 3 : (_isTab && _width < 950 )? 2 : 1
        //         , mainAxisSpacing: ( _desktop || _isTab )? Dimensions.PADDING_SIZE_DEFAULT:  Dimensions.PADDING_SIZE_SMALL,
        //         crossAxisSpacing:( _desktop || _isTab ) ? Dimensions.PADDING_SIZE_DEFAULT : Dimensions.PADDING_SIZE_SMALL
        //         , childAspectRatio: _desktop ? (1/1) : (_isTab && _width > 950 )? (1/1) : (_isTab && _width < 950 )? (1/0.8) : (1/0.7),
        //
        //       ),
        //         padding: EdgeInsets.all(Dimensions.PADDING_SIZE_DEFAULT),
        //         itemCount: searchController.searchItemList.length,
        //         shrinkWrap: true, physics: NeverScrollableScrollPhysics(),
        //         itemBuilder: (context, index) {
        //           return ItemsView(
        //             isStore: false, items: searchController.searchItemList,
        //             stores: searchController.searchStoreList,
        //           );
        //         },
        //       ),),
        //     ),
        //   );
        // }),
        child: TabBarView(
          controller: _tabController,
          children: [
            ItemView(isItem: false),
            SizedBox()
          ],
        ),
      )),

    ]);
  }
}
