import 'dart:async';
import 'package:connectivity/connectivity.dart';
import 'package:flutter_native_splash/flutter_native_splash.dart';
import 'package:lottie/lottie.dart';
import 'package:sixam_mart/controller/auth_controller.dart';
import 'package:sixam_mart/controller/cart_controller.dart';
import 'package:sixam_mart/controller/location_controller.dart';
import 'package:sixam_mart/controller/splash_controller.dart';
import 'package:sixam_mart/controller/wishlist_controller.dart';
import 'package:sixam_mart/data/model/body/notification_body.dart';
import 'package:sixam_mart/helper/route_helper.dart';
import 'package:sixam_mart/util/app_constants.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/images.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

import '../../../controller/brand_controller_sonu.dart';
import '../../../controller/localization_controller.dart';
import '../../../util/styles.dart';
import 'package:flutter/foundation.dart' as Foundation;

class SplashScreen extends StatefulWidget {
  final NotificationBody body;
  SplashScreen({@required this.body});

  @override
  _SplashScreenState createState() => _SplashScreenState();
}

class _SplashScreenState extends State<SplashScreen> with
    TickerProviderStateMixin  {
  bool animate = false;
  GlobalKey<ScaffoldState> _globalKey = GlobalKey();
  StreamSubscription<ConnectivityResult> _onConnectivityChanged;
  AnimationController _controller;
  @override
  void initState() {
    super.initState();
   // startAnimation();
    FlutterNativeSplash.remove();
    print('checkRoot: splash RUN init');

    bool _firstTime = true;
    _onConnectivityChanged = Connectivity().onConnectivityChanged.listen((ConnectivityResult result) {
      if(!_firstTime) {
        bool isNotConnected = result != ConnectivityResult.wifi && result != ConnectivityResult.mobile;
        isNotConnected ? SizedBox() : ScaffoldMessenger.of(context).hideCurrentSnackBar();
        ScaffoldMessenger.of(context).showSnackBar(SnackBar(
          backgroundColor: isNotConnected ? Colors.red : Colors.green,
          duration: Duration(seconds: isNotConnected ? 6000 : 3),
          content: Text(
            isNotConnected ? 'no_connection'.tr : 'connected'.tr,
            textAlign: TextAlign.center,
          ),
        ));
        if(!isNotConnected) {
          _route();
        }
      }
      _firstTime = false;
    });

    Get.find<CartController>().getCartData();
    //Get.find<CartController>().getRecentViewData();
   _route();

  }

  @override
  void dispose() {
    super.dispose();

    _onConnectivityChanged.cancel();
  }

  void _route() {

    print('checkRoot: splash RUN _route');
    Get.find<SplashController>().getConfigData().then((isSuccess) {
      if(isSuccess) {
        Timer(Duration(seconds: 1), () async {
          int _minimumVersion = 0;
          if(GetPlatform.isAndroid) {
            _minimumVersion = Get.find<SplashController>().configModel.appMinimumVersionAndroid;
          }
          else if(GetPlatform.isIOS) {
            _minimumVersion = Get.find<SplashController>().configModel.appMinimumVersionIos;
          }
          if(AppConstants.APP_VERSION < _minimumVersion || Get.find<SplashController>().configModel.maintenanceMode) {
            Get.offNamed(RouteHelper.getUpdateRoute(AppConstants.APP_VERSION < _minimumVersion));
          }else {
            if(widget.body != null) {
              if (widget.body.notificationType == NotificationType.order) {
                Get.offNamed(RouteHelper.getOrderDetailsRoute(widget.body.orderId, fromNotification: true));
              }else if(widget.body.notificationType == NotificationType.general){
                Get.offNamed(RouteHelper.getNotificationRoute(fromNotification: true));
              }else {
                Get.offNamed(RouteHelper.getChatRoute(notificationBody: widget.body, conversationID: widget.body.conversationId, fromNotification: true));
              }
            }
            else {
              if (Get.find<AuthController>().isLoggedIn()) {
                Get.find<AuthController>().updateToken();
                //await Get.find<WishListController>().getWishList();
                if (Get.find<LocationController>().getUserAddress() != null) {
                  print('checkRoot: getInitialRoute RUN');
                  Get.offNamed(RouteHelper.getInitialRoute());
                } else {
                  print('checkRoot: getAccessLocationRoute RUN');
                  Get.offNamed(RouteHelper.getAccessLocationRoute('splash'));
                }
              }
              else {

                if (Get.find<SplashController>().showIntro()) {
                  // if(AppConstants.languages.length > 1) {
                  //   print('checkRoot: getAccessLocationRoute RUN');
                  //   Get.offNamed(RouteHelper.getLanguageRoute('splash'));
                  // }else {
                  //   Get.offNamed(RouteHelper.getOnBoardingRoute());
                  // }

                  // REMOVE BELOW LINE OF CODE AND UNCOMMENT TOP LINES OF CODE WHEN LANGUAGE IS MULTIPLE INTO THE APP
                  // FOR THE NOW WE ARE SETTING ENGLISH LANGUAGE BY DEFAULT
                  if(AppConstants.languages.length > 1) {
                    Get.find<LocalizationController>().setLanguage(Locale('en', 'US',));
                  }
                  Get.offNamed(RouteHelper.getOnBoardingRoute());
                } else {
                  // after finishing the intro user will go to home page as guest. before as now user was going to login/signup page from
                  // here and on login/sign page there is guest button which perform same action as here
                  print('checkRoot: getAccessLocationRoute RUN B');
                  Get.offNamed(RouteHelper.getInitialRoute());

                  // if we uncomment the below line then user
                  // will go to login/signup page after intro
                  // and on login/signup page
                  // user can login or signup or click on guest button

                  // Get.offNamed(RouteHelper.getSignInRoute(RouteHelper.splash));
                }
              }
            }
          }
        });
      }
    });
  }

  @override
  Widget build(BuildContext context) {

    Get.find<SplashController>().initSharedData();

    if(Get.find<LocationController>().getUserAddress() != null && Get.find<LocationController>().getUserAddress().zoneIds == null) {
      Get.find<AuthController>().clearSharedAddress();
    }
    double screenHeight = MediaQuery.of(context).size.height;
    double screenWidth = MediaQuery.of(context).size.width;
    return Scaffold(
      key: _globalKey,
      body: GetBuilder<SplashController>(builder: (splashController) {
        return Center(
          child: Padding(
            padding: const EdgeInsets.only(left: 20,right: 20),
            child: Image.asset(Images.logo, width: double.infinity,
              fit: BoxFit.fill,),
          ),
        );
      }),
    );
  }



  Future startAnimation() async{
    await Future.delayed(Duration(milliseconds: 500));
    setState(() {
      animate =true;
    });
  }
}









//
//
// class Test extends StatefulWidget {
//   const Test({Key? key}) : super(key: key);
//
//   @override
//   State<Test> createState() => _TestState();
// }
//
// class _TestState extends State<Test> {
//   @override
//   Widget build(BuildContext context) {
//     return Container(
//           height: double.infinity,
//           width: double.infinity,
//           child: Column(
//               children: <Widget>[
//                 Container(
//                   height: screenHeight * 0.4,
//                   color: Colors.black,
//                   child: Stack(
//                     children: [
//
//                       Column(
//                         crossAxisAlignment: CrossAxisAlignment.center,
//                         children: [
//                           Image.asset(Images.logo,width: 300,height: 150,),
//                           SizedBox(height: 20,),
//                           Row(
//                             mainAxisAlignment: MainAxisAlignment.center,
//                             children: [
//                               Container(height: 2,width: 25,color: AppConstants.white,),
//                               SizedBox(width: 7,),
//                               Text(AppConstants.CHOICE_OF_INDIA, style: TextStyle(color: AppConstants.blue_theme,fontSize: 15)),
//                               SizedBox(width: 7,),
//                               Container(height: 2,width: 25,color: AppConstants.white,),
//                             ],
//                           ),
//                         ],
//                       ),
//
//                     ],
//                   ),
//                 ),
//
//                 Container(
//                   height: screenHeight * 0.6,
//                   color: Colors.black,
//                   width: double.infinity,
//                   child: Column(children: [
//                     Text(AppConstants.OUR_PRODUCTS, style: TextStyle(color: AppConstants.white,fontSize: 15,decoration: TextDecoration.underline,)),
//                     SizedBox(height: 20,),
//
//                     Container(
//                       height: 80,
//                       width: screenWidth*0.92,
//
//                       child: Center(
//                         child: Stack(
//                           children: [
//                             AnimatedPositioned(
//                                 top: animate? 0 : -60,
//                                 duration: const Duration(milliseconds: 750),
//                                 child: Container(
//                                   width: screenWidth,
//                                   child: Card(
//                                     color: AppConstants.blue_theme,
//                                     child: Padding(
//                                       padding: const EdgeInsets.all(5.0),
//                                       child: Row(children: [
//                                         Container(
//                                             decoration: BoxDecoration(
//                                               borderRadius: BorderRadius.circular(Dimensions.WEB_MAX_WIDTH),
//                                               border: Border.all(width: 1, color: AppConstants.category_item_circle),
//                                             ),
//                                             child: Padding(
//                                               padding: const EdgeInsets.all(10.0),
//                                               child: ClipRRect(
//                                                 borderRadius: BorderRadius.circular(12),
//                                                 child: Image.asset(Images.user,width: 35,height: 35,),
//                                               ),
//                                             )
//                                         ),
//                                         SizedBox(width: 20,),
//                                         Text(AppConstants.SPLASH_TEXT_1, style: TextStyle(color: AppConstants.white,fontSize: 15))
//                                       ]),
//                                     ),
//                                   ),
//                                 )),
//                           ],
//                         ),
//                       ),
//                     ),
//                     Container(
//                       height: 80,
//                       width: screenWidth*0.92,
//
//                       child: Center(
//                         child: Stack(
//                           children: [
//                             AnimatedPositioned(
//                                 top: animate? 0 : -60,
//                                 duration: const Duration(milliseconds: 750),
//                                 child: Container(
//                                   width: screenWidth,
//                                   child: Card(
//                                     color: AppConstants.blue_theme,
//                                     child: Padding(
//                                       padding: const EdgeInsets.all(5.0),
//                                       child: Row(children: [
//                                         Container(
//                                             decoration: BoxDecoration(
//                                               borderRadius: BorderRadius.circular(Dimensions.WEB_MAX_WIDTH),
//                                               border: Border.all(width: 1, color: AppConstants.category_item_circle),
//                                             ),
//                                             child: Padding(
//                                               padding: const EdgeInsets.all(10.0),
//                                               child: ClipRRect(
//                                                 borderRadius: BorderRadius.circular(12),
//                                                 child: Image.asset(Images.linkedin,width: 35,height: 35,),
//                                               ),
//                                             )
//                                         ),
//                                         SizedBox(width: 20,),
//                                         Text(AppConstants.SPLASH_TEXT_2, style: TextStyle(color: AppConstants.white,fontSize: 15))
//                                       ]),
//                                     ),
//                                   ),
//                                 )),
//                           ],
//                         ),
//                       ),
//                     ),
//                     Container(
//                       height: 80,
//                       width: screenWidth*0.92,
//
//                       child: Center(
//                         child: Stack(
//                           children: [
//                             AnimatedPositioned(
//                                 top: animate? 0 : -60,
//                                 duration: const Duration(milliseconds: 750),
//                                 child: Container(
//                                   width: screenWidth,
//                                   child: Card(
//                                     color: AppConstants.blue_theme,
//                                     child: Padding(
//                                       padding: const EdgeInsets.all(5.0),
//                                       child: Row(children: [
//                                         Container(
//                                             decoration: BoxDecoration(
//                                               borderRadius: BorderRadius.circular(Dimensions.WEB_MAX_WIDTH),
//                                               border: Border.all(width: 1, color: AppConstants.category_item_circle),
//                                             ),
//                                             child: Padding(
//                                               padding: const EdgeInsets.all(10.0),
//                                               child: ClipRRect(
//                                                 borderRadius: BorderRadius.circular(12),
//                                                 child: Image.asset(Images.linkedin,width: 35,height: 35,),
//                                               ),
//                                             )
//                                         ),
//                                         SizedBox(width: 20,),
//                                         Text(AppConstants.SPLASH_TEXT_3, style: TextStyle(color: AppConstants.white,fontSize: 15))
//                                       ]),
//                                     ),
//                                   ),
//                                 )),
//                           ],
//                         ),
//                       ),
//                     ),
//                     Container(
//                       height: 80,
//                       width: screenWidth*0.92,
//
//                       child: Center(
//                         child: Stack(
//                           children: [
//                             AnimatedPositioned(
//                                 top: animate? 0 : -60,
//                                 duration: const Duration(milliseconds: 750),
//                                 child: Container(
//                                   width: screenWidth,
//                                   child: Card(
//                                     color: AppConstants.blue_theme,
//                                     child: Padding(
//                                       padding: const EdgeInsets.all(5.0),
//                                       child: Row(children: [
//                                         Container(
//                                             decoration: BoxDecoration(
//                                               borderRadius: BorderRadius.circular(Dimensions.WEB_MAX_WIDTH),
//                                               border: Border.all(width: 1, color: AppConstants.category_item_circle),
//                                             ),
//                                             child: Padding(
//                                               padding: const EdgeInsets.all(10.0),
//                                               child: ClipRRect(
//                                                 borderRadius: BorderRadius.circular(12),
//                                                 child: Image.asset(Images.linkedin,width: 35,height: 35,),
//                                               ),
//                                             )
//                                         ),
//                                         SizedBox(width: 20,),
//                                         Text(AppConstants.SPLASH_TEXT_4, style: TextStyle(color: AppConstants.white,fontSize: 15))
//                                       ]),
//                                     ),
//                                   ),
//                                 )),
//                           ],
//                         ),
//                       ),
//                     ),
//                     Container(
//                       height: 80,
//                       width: screenWidth*0.92,
//
//                       child: Center(
//                         child: Stack(
//                           children: [
//                             AnimatedPositioned(
//                                 top: animate? 0 : -60,
//                                 duration: const Duration(milliseconds: 750),
//                                 child: Container(
//                                   width: screenWidth,
//                                   child: Card(
//                                     color: AppConstants.blue_theme,
//                                     child: Padding(
//                                       padding: const EdgeInsets.all(5.0),
//                                       child: Row(children: [
//                                         Container(
//                                             decoration: BoxDecoration(
//                                               borderRadius: BorderRadius.circular(Dimensions.WEB_MAX_WIDTH),
//                                               border: Border.all(width: 1, color: AppConstants.category_item_circle),
//                                             ),
//                                             child: Padding(
//                                               padding: const EdgeInsets.all(10.0),
//                                               child: ClipRRect(
//                                                 borderRadius: BorderRadius.circular(12),
//                                                 child: Image.asset(Images.linkedin,width: 35,height: 35,),
//                                               ),
//                                             )
//                                         ),
//                                         SizedBox(width: 20,),
//                                         Text(AppConstants.SPLASH_TEXT_5, style: TextStyle(color: AppConstants.white,fontSize: 15))
//                                       ]),
//                                     ),
//                                   ),
//                                 )),
//                           ],
//                         ),
//                       ),
//                     ),
//
//                   ]),
//                 ),
//               ]
//           ),
//         );
//
//
// // return Container(
// //           height: double.infinity,
// //           width: double.infinity,
// //           color: Colors.black,
// //           child: Column(
// //             crossAxisAlignment: CrossAxisAlignment.center,
// //             mainAxisAlignment: MainAxisAlignment.center,
// //             children: [
// //               Padding(
// //                 padding: const EdgeInsets.only(left: 100,right: 100),
// //                 child: Image.asset(Images.logo,height: 100,fit: BoxFit.cover),
// //               ),
// //               SizedBox(height: 30,),
// //               Row(
// //                 mainAxisAlignment: MainAxisAlignment.center,
// //                 children: [
// //                   Container(height: 2,width: 25,color: AppConstants.white,),
// //                   SizedBox(width: 7,),
// //                   Text(AppConstants.CHOICE_OF_INDIA, style: TextStyle(color: AppConstants.blue_theme,fontSize: 12)),
// //                   SizedBox(width: 7,),
// //                   Container(height: 2,width: 25,color: AppConstants.white,),
// //                 ],
// //               ),
// //             ],),
// //         );
//
//
//
//
//
//
// //
// //
// // return Container(
// // height: double.infinity,
// // width: double.infinity,
// // color: Colors.black,
// // child: Stack(
// // children: [
// //
// // AnimatedPositioned(
// // duration: const Duration(milliseconds: 750),
// // top: animate? 70 : -60,
// // left: 40,
// // child: Column(
// // crossAxisAlignment: CrossAxisAlignment.start,
// // children: [
// // Text(AppConstants.APP_NAME, style: robotoMedium.copyWith(fontSize: 22)),
// // SizedBox(height: 10,),
// // Text(AppConstants.SPLASH_TEXT_1, style: robotoMedium.copyWith(fontSize: 24, fontStyle: FontStyle.italic)),
// // Text(AppConstants.SPLASH_TEXT_2, style: robotoMedium.copyWith(fontSize: 24, fontStyle: FontStyle.italic)),
// //
// // ],
// // )),
// //
// //
// // AnimatedPositioned(
// // top: animate? 200 : -60,
// // left: 40,
// // duration: const Duration(milliseconds: 750),
// // child: Column(
// // crossAxisAlignment: CrossAxisAlignment.start,
// // children: [
// // Image.asset(Images.logo,width: 300),
// // SizedBox(height: 20,),
// // Text(AppConstants.SPLASH_TEXT_3, style: robotoMedium.copyWith(fontSize: 15, fontStyle: FontStyle.italic)),
// //
// // ],
// // )),
// // AnimatedPositioned(
// // bottom: animate? 60 : -50,
// // left: 40,
// // duration: const Duration(milliseconds: 750),
// // child: Image.asset(Images.parcel,width: 180,height: 220,))
// //
// // ],
// // ),
// // );
//
//
//
//
//
//
//
//
// //Center(
// //           child: splashController.hasConnection ? Column(
// //             mainAxisSize: MainAxisSize.min,
// //             children: [
// //               Image.asset(Images.image, width: 200),
// //               SizedBox(height: Dimensions.PADDING_SIZE_SMALL),
// //               // Text(AppConstants.APP_NAME, style: robotoMedium.copyWith(fontSize: 25)),
// //             ],
// //           ) : NoInternetScreen(child: SplashScreen(body: widget.body)),
// //         )
//   }
// }
