import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:dotted_border/dotted_border.dart';
import 'package:sixam_mart/controller/auth_controller.dart';
import 'package:sixam_mart/controller/splash_controller.dart';
import 'package:sixam_mart/controller/user_controller.dart';
import 'package:sixam_mart/helper/price_converter.dart';
import 'package:sixam_mart/helper/responsive_helper.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/images.dart';
import 'package:sixam_mart/util/styles.dart';
import 'package:sixam_mart/view/base/custom_app_bar.dart';
import 'package:sixam_mart/view/base/custom_button.dart';
import 'package:sixam_mart/view/base/custom_snackbar.dart';
import 'package:sixam_mart/view/base/footer_view.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_drawer.dart';
import 'package:sixam_mart/view/base/not_logged_in_screen.dart';
import '../../../controller/wallet_controller.dart';
import '../../../helper/route_helper.dart';
import '../../base/custom_text_field.dart';
class PrimePaymentFromWalletScreen extends StatefulWidget {
  final String orderId;
  final bool fromWallet;
  PrimePaymentFromWalletScreen({Key key, @required this.fromWallet, @required this.orderId}) : super(key: key);

  @override
  State<PrimePaymentFromWalletScreen> createState() => _PrimePaymentFromWalletScreenState();
}

class _PrimePaymentFromWalletScreenState extends State<PrimePaymentFromWalletScreen> {
  bool _isLoggedIn;
  final FocusNode _amtFocus = FocusNode();
  final TextEditingController _amtController = TextEditingController();
  @override
  void initState() {
    super.initState();

    _isLoggedIn = Get.find<AuthController>().isLoggedIn();
    Get.find<WalletController>().init();

    if(_isLoggedIn && Get.find<UserController>().userInfoModel == null) {
      Get.find<UserController>().getUserInfo();

    }

    _amtController.text=Get.find<SplashController>().configModel.primeMembershipAmount.toString();
  }


  @override
  Widget build(BuildContext context) {
    bool _desktop = ResponsiveHelper.isDesktop(context);
    bool _isTab = ResponsiveHelper.isTab(context);
    bool _isWeb = ResponsiveHelper.isWeb();
    bool _isMobile = ResponsiveHelper.isMobile(context);
    double screenWidth = MediaQuery.of(context).size.width;

    print("screenWidthTest  $screenWidth");
    return Scaffold(
      endDrawer: WebMenuDrawer(),
      appBar: CustomAppBar(title: 'prime_membership_payment'.tr,onBackPressed: (){
        Get.back();
      },),
      body: Center(
        child: _isLoggedIn ? SingleChildScrollView(
          child: FooterView(
            child: SizedBox(
              width: Dimensions.WEB_MAX_WIDTH,
              child: Padding(
                padding: const EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_LARGE),
                child: GetBuilder<UserController>(builder: (userController) {
                  return GetBuilder<WalletController>(builder: (walletController) {
                    return Column( children: [
                      Stack(
                        children: [
                          Container(
                            padding: widget.fromWallet ? EdgeInsets.all(Dimensions.PADDING_SIZE_EXTRA_LARGE)
                                : EdgeInsets.only(top: 40, left: Dimensions.PADDING_SIZE_EXTRA_LARGE, right: Dimensions.PADDING_SIZE_EXTRA_LARGE),
                            decoration: BoxDecoration(
                              borderRadius: BorderRadius.circular(Dimensions.RADIUS_DEFAULT),
                              color: widget.fromWallet ? Theme.of(context).primaryColor : Theme.of(context).cardColor,
                            ),
                            child:  Row(mainAxisAlignment: widget.fromWallet ? MainAxisAlignment.start : MainAxisAlignment.center, children: [

                              Image.asset( widget.fromWallet ? Images.wallet : Images.loyal , height: 60, width: 60, color: widget.fromWallet ? Theme.of(context).cardColor : null),
                              SizedBox(width: Dimensions.PADDING_SIZE_EXTRA_LARGE),

                              widget.fromWallet ? Column(crossAxisAlignment: CrossAxisAlignment.start, mainAxisSize: MainAxisSize.min,
                                  children: [
                                    Text('wallet_amount'.tr,style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall, color: Theme.of(context).cardColor)),
                                    SizedBox(height: Dimensions.PADDING_SIZE_SMALL),

                                    Text(
                                      PriceConverter.convertPrice(userController.userInfoModel.walletBalance),
                                      style: robotoBold.copyWith(fontSize: Dimensions.fontSizeOverLarge, color: Theme.of(context).cardColor),
                                    ),
                                  ])
                                  : Column(crossAxisAlignment: CrossAxisAlignment.center, mainAxisAlignment: MainAxisAlignment.end, children: [

                                Text(
                                  userController.userInfoModel.loyaltyPoint == null ? '0' : userController.userInfoModel.loyaltyPoint.toString(),
                                  style: robotoBold.copyWith(fontSize: Dimensions.fontSizeOverLarge, color: Theme.of(context).textTheme.bodyText1.color),
                                ),
                                Text(
                                  'history'.tr + ' !',
                                  style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall, color: Theme.of(context).textTheme.bodyText1.color),
                                ),
                                SizedBox(height: Dimensions.PADDING_SIZE_SMALL),
                              ])
                            ]),
                          ),

                          Positioned(
                            top: 10,right: 10,
                            child: InkWell(
                              onTap: (){
                                Get.toNamed(RouteHelper.getWalletTransferHistoryRoute());
                              },
                              child: Row(
                                children: [
                                  Text(
                                    'history'.tr , style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall,
                                      color: widget.fromWallet ? Theme.of(context).cardColor : Theme.of(context).textTheme.bodyText1.color),
                                  ),
                                  Icon(Icons.keyboard_arrow_down_outlined,size: 16, color: widget.fromWallet ? Theme.of(context).cardColor
                                      : Theme.of(context).textTheme.bodyText1.color)
                                ],
                              ),
                            ),
                          )
                        ],
                      ) ,

                       Column(children: [
                         SizedBox(height: Dimensions.PADDING_SIZE_EXTRA_LARGE),
                         Row(
                           children: [
                             Text('Payment  ', style: robotoBlack.copyWith(fontSize: 20)),
                             Text('${Get.find<SplashController>().configModel.currencySymbol} ${Get.find<SplashController>().configModel.primeMembershipAmount.toString()}', style: robotoBlack.copyWith(fontSize: 20,color: Colors.purple)),
                           ],
                         ),
                        SizedBox(height: Dimensions.PADDING_SIZE_EXTRA_LARGE),
                        DottedBorder(
                          color: Theme.of(context).primaryColor,
                          strokeWidth: 1,
                          strokeCap: StrokeCap.butt,
                          dashPattern: [8, 5],
                          padding: EdgeInsets.all(0),
                          borderType: BorderType.RRect,
                          radius: Radius.circular(Dimensions.RADIUS_SMALL),
                          child: CustomTextField(
                            controller: _amtController,
                            isEnabled: false,
                            isNumber: true,
                            divider: false,
                          ),
                        ),

                        SizedBox(height: Dimensions.PADDING_SIZE_LARGE),


                        !walletController.isPrimePaymentFromWalletLoading ?
                        CustomButton(buttonText: 'make_payment'.tr, onPressed: ()
                        async {
                          if(_amtController.text.toString().isNotEmpty){
                            var walletBalance=userController.userInfoModel.walletBalance.toDouble();
                            var membershipPrice=Get.find<SplashController>().configModel.primeMembershipAmount;

                            if(walletBalance>=membershipPrice){
                              walletController.primePaymentFromWallet(widget.orderId).then((status) async {
                                if (status.isSuccess) {
                                  Get.offNamed(RouteHelper.getPrimeMembershipPaymentSuccessRoute('NA'));

                                }else{
                                  showCustomSnackBar(status.message,isError:true);
                                }
                              });
                            }else{
                              showCustomSnackBar('insufficient wallet balance',isError:true);
                            }
                          }



                        }):
                        Center(child: CircularProgressIndicator(),),

                        SizedBox(height: Dimensions.PADDING_SIZE_LARGE),
                      ],),

                      SizedBox(height: ( walletController.userIdentityModel!=null && walletController.userIdentityModel.data!=null)? Dimensions.PADDING_SIZE_LARGE:0.0),

                    ]);
                  }
                  );
                }
                ),
              ),
            ),
          ),
        ) : NotLoggedInScreen(),
      ),
    );
  }
}
