import 'dart:io';

import 'package:country_code_picker/country_code.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:dotted_border/dotted_border.dart';
import 'package:phone_number/phone_number.dart';
import 'package:share_plus/share_plus.dart';
import 'package:sixam_mart/controller/auth_controller.dart';
import 'package:sixam_mart/controller/splash_controller.dart';
import 'package:sixam_mart/controller/user_controller.dart';
import 'package:sixam_mart/helper/price_converter.dart';
import 'package:sixam_mart/helper/responsive_helper.dart';
import 'package:sixam_mart/util/app_constants.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/images.dart';
import 'package:sixam_mart/util/styles.dart';
import 'package:sixam_mart/view/base/custom_app_bar.dart';
import 'package:sixam_mart/view/base/custom_button.dart';
import 'package:sixam_mart/view/base/custom_snackbar.dart';
import 'package:sixam_mart/view/base/footer_view.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_drawer.dart';
import 'package:sixam_mart/view/base/not_logged_in_screen.dart';
import 'package:sixam_mart/view/screens/wallet/widget/wallet_bottom_sheet.dart';

import '../../../controller/prime_member_controller.dart';
import '../../../controller/wallet_controller.dart';
import '../../../helper/route_helper.dart';
import '../../base/custom_image.dart';
import '../../base/custom_text_field.dart';
import '../checkout/widget/payment_button.dart';
import '../home/home_screen.dart';
import '../profile/widget/profile_card.dart';
import 'package:universal_html/html.dart' as html;
class WalletRechargeScreen extends StatefulWidget {
  final bool fromRecharge;
  WalletRechargeScreen({Key key, @required this.fromRecharge}) : super(key: key);

  @override
  State<WalletRechargeScreen> createState() => _WalletRechargeScreenState();
}

class _WalletRechargeScreenState extends State<WalletRechargeScreen> {
  bool _isLoggedIn;
  final TextEditingController _rechargeAmtController = TextEditingController();
  final TextEditingController _walletTransferStatus = TextEditingController();

  @override
  void initState() {
    super.initState();

    _isLoggedIn = Get.find<AuthController>().isLoggedIn();

    if(_isLoggedIn && Get.find<UserController>().userInfoModel == null) {
      Get.find<UserController>().getUserInfo();
    }
    Get.find<WalletController>().setCanTransferWalletAmt(false);
    Get.find<PrimeMemberController>().initData();
    Get.find<PrimeMemberController>().paymentMethodSelected('');
  }

  void _callback(bool isSuccess, String message, String orderID) async {
    if(isSuccess) {

      HomeScreen.loadData(true);

      if(GetPlatform.isWeb) {
        Get.back();
        String hostname = html.window.location.hostname;
        String protocol = html.window.location.protocol;
        String selectedUrl = '${AppConstants.baseUrl}/recharge-payment?order_id=$orderID&&customer_id=${Get.find<UserController>()
            .userInfoModel.id}&&callback=$protocol//$hostname${RouteHelper.walletRechargePaymentSuccess}?id=$orderID&status=';
        html.window.open(selectedUrl,"_self");
      }
      else{
        Get.offNamed(RouteHelper.getWalletRechargePaymentRoute(
            orderID, Get.find<UserController>().userInfoModel.id
        ));
      }
    }else {
      showCustomSnackBar(message);
    }
  }
  Widget paymentMethodUI(WalletController walletController){

    PrimeMemberController primeController = Get.find<PrimeMemberController>();
    return  Container(

      child: Column(crossAxisAlignment: CrossAxisAlignment.start,children: [
        SizedBox(height: 15,),

        widget.fromRecharge? Column(children: [
          SizedBox(height: 5,),
          Container(

            width: double.infinity,

            child: Padding(
              padding: const EdgeInsets.all(0.0),
              child: Column(crossAxisAlignment: CrossAxisAlignment.start,children: [

                SizedBox(height: 10,),
                Text('choose_payment_method'.tr,style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeExtraLarge, color: Theme.of(context).primaryColor)),


                SizedBox(height: 10,),
                (Get.find<SplashController>().configModel.digitalPayment ) ? PaymentButton(
                  icon: Images.digital_payment,
                  title: 'digital_payment'.tr,
                  subtitle: 'make_payment_using'.tr,
                  isSelected: primeController.isDigitalSelected,
                  onTap: () => primeController.paymentMethodSelected(AppConstants.payment_method_digital),
                ) : SizedBox(),

                SizedBox(height: 10,),
                (Get.find<SplashController>().configModel.isUpiPayment ) ? PaymentButton(
                  icon: Images.upi_payment,
                  title: 'UPI Mobile',
                  subtitle: 'Share screenshot after payment complete',
                  isSelected: primeController.isUpiSelected,
                  subtitle2: (Get.find<SplashController>().configModel.upiCashbackAmount!=null && Get.find<SplashController>().configModel.upiCashbackAmount>0)
                      ?'${Get.find<SplashController>().configModel.currencySymbol} ${Get.find<SplashController>().configModel.upiCashbackAmount} ${'cashback'.tr}'
                      : '',
                  onTap: () {
                    primeController.paymentMethodSelected(AppConstants.payment_method_upi);
                  },
                )
                : SizedBox(),
                SizedBox(height: 10,),

                (Get.find<SplashController>().configModel.isQrPayment ) ?  PaymentButton(
                  icon: Images.qr_payment,
                  title: 'qr_code'.tr,
                  subtitle: 'Share screenshot after payment complete',
                  isSelected: primeController.isQrSelected,
                  subtitle2: (Get.find<SplashController>().configModel.qrcodeCashbackAmount!=null && Get.find<SplashController>().configModel.qrcodeCashbackAmount>0)
                      ?'${Get.find<SplashController>().configModel.currencySymbol} ${Get.find<SplashController>().configModel.qrcodeCashbackAmount} ${'cashback'.tr}'
                      : '',
                  onTap: () {
                    primeController.paymentMethodSelected(AppConstants.payment_method_qrCode);
                  },
                )
                    : SizedBox()


              ]),
            ),
          ),
        ],)
            :SizedBox(),

        ((widget.fromRecharge && walletController.isOrderIdLoadingLoading) || walletController.isAmtWithdrawalLoading)
            ?Center(child: CircularProgressIndicator(),) : CustomButton(
          buttonText: widget.fromRecharge? 'recharge_now'.tr : 'withdrawal_now'.tr,
          onPressed: () {
            var amt = _rechargeAmtController.text.toString();
            if(amt.isEmpty){
              showCustomSnackBar('please_enter_amount'.tr,isError: true);
            }
            else{
              if(widget.fromRecharge){

                if(primeController.isDigitalSelected || primeController.isUpiSelected || primeController.isQrSelected){
                  if(primeController.isUpiSelected || primeController.isQrSelected){

                    Get.find<PrimeMemberController>().reset();
                    if(primeController.isUpiSelected){
                      walletController.getOrderIdForWalletRecharge(amt,'upi',_callback);

                    }else{
                      walletController.getOrderIdForWalletRecharge(amt,'qrCode',_callback);

                    }
                  }
                  else{

                    walletController.getOrderIdForWalletRecharge(amt,'gateway',_callback);

                  }
                }else{
                  showCustomSnackBar('please_select_recharge_method'.tr,isError: true);
                }


              }else{
                walletController.requestToWithdrawal(amt);
              }
            }


          },
          radius: Dimensions.RADIUS_SMALL, height: 50,
        )
            ,


        SizedBox(height: 15,),
      ],),
    );
  }

  @override
  Widget build(BuildContext context) {
    bool _desktop = ResponsiveHelper.isDesktop(context);
    bool _isTab = ResponsiveHelper.isTab(context);
    bool _isWeb = ResponsiveHelper.isWeb();
    bool _isMobile = ResponsiveHelper.isMobile(context);
    double screenWidth = MediaQuery.of(context).size.width;

    print("screenWidthTest  $screenWidth");
    return Scaffold(
      endDrawer: WebMenuDrawer(),
      appBar: CustomAppBar(title: widget.fromRecharge ? 'wallet_recharge'.tr : 'wallet_withdrawal'.tr,onBackPressed: (){

        Get.offAllNamed(RouteHelper.getInitialRoute());

      },),
      body: Center(
        child: _isLoggedIn ? GetBuilder<PrimeMemberController>(builder: (primeController) {
          return  SingleChildScrollView(
            child: FooterView(
              child: SizedBox(
                width: Dimensions.WEB_MAX_WIDTH,
                child: Padding(
                  padding: const EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_LARGE),
                  child: GetBuilder<UserController>(builder: (userController) {
                    return GetBuilder<WalletController>(builder: (walletController) {
                      return (Get.find<SplashController>().configModel.digitalPayment || Get.find<SplashController>().configModel.isUpiPayment || Get.find<SplashController>().configModel.isQrPayment )? Column( children: [


                        Stack(
                          children: [
                            Container(
                              padding:  EdgeInsets.all(Dimensions.PADDING_SIZE_EXTRA_LARGE),
                              decoration: BoxDecoration(
                                borderRadius: BorderRadius.circular(Dimensions.RADIUS_DEFAULT),
                                color:Theme.of(context).primaryColor,
                              ),
                              child:  Row(mainAxisAlignment: MainAxisAlignment.start ,
                                  children: [

                                    Image.asset( widget.fromRecharge ? Images.wallet : Images.loyal , height: 60, width: 60, color: widget.fromRecharge ? Theme.of(context).cardColor : null),
                                    SizedBox(width: Dimensions.PADDING_SIZE_EXTRA_LARGE),
                                    Column(crossAxisAlignment: CrossAxisAlignment.start, mainAxisSize: MainAxisSize.min,
                                        children: [
                                          Text('wallet_amount'.tr,style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall, color: Theme.of(context).cardColor)),
                                          SizedBox(height: Dimensions.PADDING_SIZE_SMALL),

                                          Text(
                                            PriceConverter.convertPrice(userController.userInfoModel.walletBalance),
                                            style: robotoBold.copyWith(fontSize: Dimensions.fontSizeOverLarge, color: Theme.of(context).cardColor),
                                          ),
                                        ])

                                  ]),
                            ),

                            Positioned(

                              top: 10,right: 10,
                              child: InkWell(
                                onTap: (){
                                  widget.fromRecharge ? Get.toNamed(RouteHelper.getWalletTransferHistoryRoute())
                                      : Get.toNamed(RouteHelper.getWalletWithdrawalHistoryRoute());
                                },
                                child: Row(
                                  children: [
                                    Text(
                                      widget.fromRecharge ?  'history'.tr  : 'history'.tr, style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeLarge,
                                        color: Theme.of(context).cardColor ),
                                    ),
                                    Icon(Icons.keyboard_arrow_down_outlined,size: 16, color: Theme.of(context).cardColor
                                    )
                                  ],
                                ),
                              ),
                            )
                          ],
                        ) ,

                        Column(children: [
                          SizedBox(height: Dimensions.PADDING_SIZE_LARGE),
                          DottedBorder(
                            color: Theme.of(context).primaryColor,
                            strokeWidth: 1,
                            strokeCap: StrokeCap.butt,
                            dashPattern: [8, 5],
                            padding: EdgeInsets.all(0),
                            borderType: BorderType.RRect,
                            radius: Radius.circular(Dimensions.RADIUS_SMALL),
                            child: CustomTextField(
                              hintText: 'enter_amount'.tr,
                              controller: _rechargeAmtController,
                              isNumber: false,
                              inputType: TextInputType.number,
                              divider: false,

                              // onChanged: (text) {
                              //
                              //   if(!widget.fromRecharge){
                              //     if(_rechargeAmtController.text.isNotEmpty
                              //         && userController.userInfoModel.walletBalance!=null
                              //         && userController.userInfoModel.walletBalance>0
                              //         && (double.parse(_rechargeAmtController.text.trim().toString()))<=userController.userInfoModel.walletBalance
                              //     ){
                              //       _walletTransferStatus.text="You Can Withdrawal";
                              //       walletController.setCanTransferWalletAmt(true);
                              //     }else{
                              //       _walletTransferStatus.text='insufficient_fund'.tr;
                              //       walletController.setCanTransferWalletAmt(false);
                              //     }
                              //   }
                              // },
                            ),
                          ),
                          paymentMethodUI(walletController),
                          SizedBox(height: Dimensions.PADDING_SIZE_EXTRA_LARGE),

                          //  (walletController.canTransferWalletAmt==null)?SizedBox()
                          //      :   Padding(
                          //    padding:  EdgeInsets.only(left: 5,top: 2,right: 5),
                          //    child:  Container(
                          //        padding:  EdgeInsets.all(5),
                          //        width: context.width,
                          //        color: walletController.canTransferWalletAmt? Colors.green.withOpacity(0.2) : Colors.transparent,
                          //        child: Text(_walletTransferStatus.text.toString(),
                          //            style: robotoMedium.copyWith(fontSize: 14,  color: walletController.canTransferWalletAmt? Colors.green : Colors.red))),
                          //  ),

                          // !walletController.isLoading ?
                          // CustomButton(buttonText: widget.fromRecharge? 'recharge_now'.tr : 'withdrawal_now'.tr, onPressed: ()
                          // async {
                          //   var amt = _rechargeAmtController.text.toString();
                          //   if(amt.isEmpty){
                          //     showCustomSnackBar('please_enter_amount'.tr,isError: true);
                          //   }
                          //
                          //   else{
                          //     if(widget.fromRecharge){
                          //       walletController.getOrderIdForWalletRecharge(amt,_callback);
                          //
                          //     }else{
                          //       walletController.requestToWithdrawal(amt);
                          //     }
                          //   }
                          //
                          // }):
                          // Center(child: CircularProgressIndicator(),),

                          SizedBox(height: Dimensions.PADDING_SIZE_LARGE),
                        ],),

                        SizedBox(height: (walletController.userIdentityModel!=null && walletController.userIdentityModel.data!=null)? Dimensions.PADDING_SIZE_LARGE:0.0),

                      ])
                      : Center(child: Text('Payment methods not available at this time',style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeExtraLarge, color: Theme.of(context).primaryColor)),);
                    }
                    );
                  }
                  ),
                ),
              ),
            ),
          );
        })

            : NotLoggedInScreen(),
      ),
    );
  }
}

