import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:get/get.dart';
import 'package:shimmer_animation/shimmer_animation.dart';
import 'package:sixam_mart/controller/all_prime_members_controller.dart';
import 'package:sixam_mart/controller/auth_controller.dart';
import 'package:sixam_mart/controller/search_controller.dart';
import 'package:sixam_mart/controller/user_controller.dart';
import 'package:sixam_mart/controller/wallet_controller.dart';
import 'package:sixam_mart/helper/price_converter.dart';
import 'package:sixam_mart/helper/responsive_helper.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/images.dart';
import 'package:sixam_mart/util/styles.dart';
import 'package:sixam_mart/view/base/custom_app_bar.dart';
import 'package:sixam_mart/view/base/footer_view.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_drawer.dart';
import 'package:sixam_mart/view/base/no_data_screen.dart';
import 'package:sixam_mart/view/base/not_logged_in_screen.dart';
import 'package:sixam_mart/view/base/title_widget.dart';
import 'package:sixam_mart/view/screens/wallet/widget/history_item.dart';
import 'package:sixam_mart/view/screens/wallet/widget/wallet_bottom_sheet.dart';

import '../../../controller/closing_controller.dart';
import '../../../data/model/response/wallet_statement_response.dart';
import '../../../util/app_constants.dart';
import '../../base/custom_button.dart';
import '../../base/custom_snackbar.dart';
import '../search/widget/custom_check_box.dart';

class WalletScreen extends StatefulWidget {
  final bool fromWallet;
  final String preFilter;

  WalletScreen({Key key, @required this.fromWallet, @required this.preFilter}) : super(key: key);

  @override
  State<WalletScreen> createState() => _WalletScreenState();
}

class _WalletScreenState extends State<WalletScreen> {
  final ScrollController scrollController = ScrollController();
  final bool _isLoggedIn = Get.find<AuthController>().isLoggedIn();
  final TextEditingController _inputMessageController = TextEditingController();

  @override
  void initState() {
    super.initState();
    if(_isLoggedIn){
      Get.find<UserController>().getUserInfo();
      
      Get.find<WalletController>().resetStatementFilter();
      Get.find<WalletController>().getWalletStatement(preFilter: widget.preFilter);
      //Get.find<WalletController>().getWalletwalletStatementData('1', false, widget.fromWallet);
      
      scrollController?.addListener(() {
        if (scrollController.position.pixels == scrollController.position.maxScrollExtent
            && Get.find<WalletController>().walletStatementData != null
            && !Get.find<WalletController>().isLoading) {
          //int pageSize = (Get.find<WalletController>().totalPageSize / 10).ceil();
          //if (Get.find<WalletController>().offset < pageSize) {
          int pageSize = Get.find<WalletController>().totalPageSize;
          if (Get.find<WalletController>().walletStatementData.length < pageSize) {
            Get.find<WalletController>().setOffset(Get.find<WalletController>().offset + 1);
            print('end of the page');
            Get.find<WalletController>().showBottomLoader();
            Get.find<WalletController>().getWalletStatement(preFilter: widget.preFilter);
          }
        }
      });
    }

  }
  @override
  void dispose() {
    super.dispose();

    scrollController?.dispose();
  }

  @override
  Widget build(BuildContext context) {

    return Scaffold(
      backgroundColor: Theme.of(context).cardColor,
      endDrawer: WebMenuDrawer(),
      appBar: (widget.preFilter=="NA" || widget.preFilter==null) ? CustomAppBar(title: widget.fromWallet ? 'wallet'.tr : 'loyalty_points'.tr, backButton: true)
      : CustomAppBar(title:
      widget.preFilter=='company_recharge'.tr ? 'wallet_credit_2'.tr
          : widget.preFilter=='transfer'.tr ? 'used_credits_2'.tr
          : widget.preFilter=='loan'.tr ? 'loan_credits_2'.tr
          : widget.preFilter=='receipt'.tr ? 'paid_credits_2'.tr
          : widget.preFilter=='select_prime_to_view_statement'.tr ? 'statement'.tr
          : widget.preFilter

          , backButton: true),
      body: GetBuilder<UserController>(
          builder: (userController) {
            return _isLoggedIn ? userController.userInfoModel != null ? SafeArea(
              child: RefreshIndicator(
                onRefresh: () async{
                  Get.find<WalletController>().getWalletStatement();
                },
                child: SingleChildScrollView(
                  controller: scrollController,
                  padding: EdgeInsets.symmetric(horizontal: ResponsiveHelper.isDesktop(context) ? 0.0 : Dimensions.PADDING_SIZE_DEFAULT),
                  child: FooterView(
                    child: SizedBox(
                      width: Dimensions.WEB_MAX_WIDTH,
                      child: GetBuilder<WalletController>(
                          builder: (walletController) {
                            return Column(children: [

                              (widget.preFilter=="NA" || widget.preFilter==null) ?
                              Stack(
                                children: [
                                  Container(
                                    padding: widget.fromWallet ? EdgeInsets.all(Dimensions.PADDING_SIZE_EXTRA_LARGE)
                                        : EdgeInsets.only(top: 40, left: Dimensions.PADDING_SIZE_EXTRA_LARGE, right: Dimensions.PADDING_SIZE_EXTRA_LARGE),
                                    decoration: BoxDecoration(
                                      borderRadius: BorderRadius.circular(Dimensions.RADIUS_DEFAULT),
                                      color: widget.fromWallet ? Theme.of(context).primaryColor : Theme.of(context).cardColor,
                                    ),
                                    child:  Row(mainAxisAlignment: widget.fromWallet ? MainAxisAlignment.start : MainAxisAlignment.center, children: [

                                      Image.asset( widget.fromWallet ? Images.wallet : Images.loyal , height: 60, width: 60, color: widget.fromWallet ? Theme.of(context).cardColor : null),
                                      SizedBox(width: Dimensions.PADDING_SIZE_EXTRA_LARGE),

                                      widget.fromWallet ? Column(crossAxisAlignment: CrossAxisAlignment.start, mainAxisSize: MainAxisSize.min,
                                          children: [
                                            Text('wallet_amount'.tr,style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall, color: Theme.of(context).cardColor)),
                                            SizedBox(height: Dimensions.PADDING_SIZE_SMALL),

                                            Text(
                                              PriceConverter.convertPrice(userController.userInfoModel.walletBalance),
                                              style: robotoBold.copyWith(fontSize: Dimensions.fontSizeOverLarge, color: Theme.of(context).cardColor),
                                            ),
                                          ])
                                          : Column(crossAxisAlignment: CrossAxisAlignment.center, mainAxisAlignment: MainAxisAlignment.end, children: [

                                            Text(
                                              userController.userInfoModel.loyaltyPoint == null ? '0' : userController.userInfoModel.loyaltyPoint.toString(),
                                              style: robotoBold.copyWith(fontSize: Dimensions.fontSizeOverLarge, color: Theme.of(context).textTheme.bodyText1.color),
                                            ),
                                            Text(
                                              'loyalty_points'.tr + ' !',
                                              style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall, color: Theme.of(context).textTheme.bodyText1.color),
                                            ),
                                            SizedBox(height: Dimensions.PADDING_SIZE_SMALL),
                                      ])
                                    ]),
                                  ),

                                  widget.fromWallet ? SizedBox.shrink() : Positioned(
                                    top: 10,right: 10,
                                    child: InkWell(
                                      onTap: (){
                                        ResponsiveHelper.isMobile(context) ? Get.bottomSheet(
                                            WalletBottomSheet(fromWallet: widget.fromWallet)
                                        ) : Get.dialog(
                                          Dialog(child: WalletBottomSheet(fromWallet: widget.fromWallet)),
                                        );
                                      },
                                      child: Row(
                                        children: [
                                          Text(
                                            'convert_to_currency'.tr , style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall,
                                              color: widget.fromWallet ? Theme.of(context).cardColor : Theme.of(context).textTheme.bodyText1.color),
                                          ),
                                          Icon(Icons.keyboard_arrow_down_outlined,size: 16, color: widget.fromWallet ? Theme.of(context).cardColor
                                              : Theme.of(context).textTheme.bodyText1.color)
                                        ],
                                      ),
                                    ),
                                  )
                                ],
                              )
                                  : widget.preFilter=='select_prime_to_view_statement'.tr ? SizedBox() :
                              Container(
                                width: context.width,
                                padding: EdgeInsets.only(top: 10, left: Dimensions.PADDING_SIZE_EXTRA_LARGE, right: Dimensions.PADDING_SIZE_EXTRA_LARGE,bottom: 10),
                                decoration: BoxDecoration(
                                  borderRadius: BorderRadius.circular(Dimensions.RADIUS_DEFAULT),
                                  color: Colors.green,
                                ),
                                child:  Column(crossAxisAlignment: CrossAxisAlignment.center, mainAxisSize: MainAxisSize.min,
                                    children: [
                                      widget.preFilter=='pair_income'.tr ? SizedBox() :
                                      Text(
                                          widget.preFilter=='loan'.tr ?  'loan_summary'.tr
                                              : widget.preFilter=='receipt'.tr ? 'receipt_summary'.tr
                                              : widget.preFilter=='transfer'.tr ? 'transfer_summary'.tr
                                              :  'Credit Summary'.tr
                                          ,style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeExtraExtraLarge2, color: Colors.black)),
                                      SizedBox(height: widget.preFilter=='pair_income'.tr ?0.0 :  Dimensions.PADDING_SIZE_SMALL),

                                      Text(
                                        PriceConverter.convertPrice(double.parse(
                                            widget.preFilter=='company_recharge'.tr ? Get.find<UserController>().userInfoModel.companyWalletSummery.original.data.walletCredits.toString()
                                                : widget.preFilter=='transfer'.tr ? Get.find<UserController>().userInfoModel.companyWalletSummery.original.data.usedCredits.toString()
                                                : widget.preFilter=='loan'.tr ? Get.find<UserController>().userInfoModel.companyWalletSummery.original.data.loanCredits.toString()
                                                : widget.preFilter=='receipt'.tr ? Get.find<UserController>().userInfoModel.companyWalletSummery.original.data.paidCredits.toString()
                                                : widget.preFilter=='pair_income'.tr ? Get.find<ClosingController>().closingDataItem.payment.toString()
                                                : "0.0"
                                        )),
                                        style: robotoBold.copyWith(fontSize: Dimensions.fontSizeOverLarge, color: Theme.of(context).cardColor),
                                      ),
                                    ]),
                              ),


                              Column(children: [
                                SizedBox(height: 30,),

                                widget.preFilter=="NA" ? Row(
                                  crossAxisAlignment: CrossAxisAlignment.start,
                                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                                  children: [
                                    Padding(
                                      padding: EdgeInsets.only(top: Dimensions.PADDING_SIZE_EXTRA_LARGE),
                                      child: TitleWidget(title: 'transaction_history'.tr),
                                    ),

                                    InkWell(child: Padding(
                                      padding: const EdgeInsets.symmetric(vertical: 12,horizontal: 7),
                                      child: Container(
                                        padding: EdgeInsets.only(left: 6,right: 6),
                                        decoration: BoxDecoration(
                                          color: walletController.isFilterApplied ? Theme.of(context).primaryColor.withOpacity(0.1) : Theme.of(context).primaryColor.withOpacity(0.0),
                                          border: Border.all(color: walletController.isFilterApplied ?  Theme.of(context).primaryColor.withOpacity(0.9) : Colors.black26),
                                          borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
                                        ),
                                        child: Row(
                                          crossAxisAlignment: CrossAxisAlignment.center,
                                          mainAxisAlignment: MainAxisAlignment.center,
                                          children: [
                                            Text('Filters', style: robotoRegular.copyWith(fontSize:
                                            Dimensions.fontSizeSmall,color:  Colors.black,),),
                                            SizedBox(width: 10,),Icon(Icons.keyboard_arrow_down_rounded,size: 15,color: Colors. black,)
                                          ],
                                        ),
                                      ),
                                    ),onTap: (){
                                      Get.dialog(FilterWidget());

                                    },),
                                  ],
                                )
                                    : ( widget.preFilter=='company_recharge'.tr || widget.preFilter=='select_prime_to_view_statement'.tr ) ? SizedBox()
                                    :  Column(
                                      children: [
                                        Row(

                                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                                  crossAxisAlignment: CrossAxisAlignment.center,
                                  children: [
                                        SizedBox(),

                                        Get.find<WalletController>().isSearchMode ? InkWell(child: Text('clear_search'.tr),onTap: (){
                                          _inputMessageController.text="";
                                          Get.find<WalletController>().searchModeDisable();

                                          Get.find<WalletController>().getWalletStatement(preFilter: widget.preFilter);

                                        },)
                                            : SizedBox(),

                                  ],
                                ),
                                        SizedBox(height: Get.find<WalletController>().isSearchMode ? 5 : 0,),

                                        Container(
                                          decoration: BoxDecoration(
                                            color: Theme.of(context).colorScheme.background,
                                            borderRadius: BorderRadius.circular(Dimensions.RADIUS_EXTRA_LARGE),
                                            boxShadow: [BoxShadow(color: Colors.grey[Get.isDarkMode ? 800 : 200], spreadRadius: 1, blurRadius: 4)],
                                          ),
                                          child: Padding(
                                            padding: const EdgeInsets.all(0.0),
                                            child: Row(children: [

                                              SizedBox(width: Dimensions.PADDING_SIZE_DEFAULT),

                                              Expanded(
                                                child: TextField(
                                                  inputFormatters: [LengthLimitingTextInputFormatter(Dimensions.MESSAGE_INPUT_LENGTH)],
                                                  controller: _inputMessageController,
                                                  textCapitalization: TextCapitalization.sentences,
                                                  style: robotoRegular,
                                                  keyboardType: TextInputType.multiline,
                                                  maxLines: null,
                                                  decoration: InputDecoration(
                                                    border: InputBorder.none,
                                                    hintText: 'Search by Prime|Sponsor Name,ID',
                                                    hintStyle: robotoRegular.copyWith(color: Theme.of(context).hintColor, fontSize: Dimensions.fontSizeLarge),
                                                  ),
                                                ),
                                              ),
                                              SizedBox(width: Dimensions.PADDING_SIZE_DEFAULT),
                                              GetBuilder<WalletController>(builder: (chatController) {
                                                return InkWell(
                                                  onTap: () async {

                                                    if(_inputMessageController.text.isNotEmpty) {
                                                      Get.find<WalletController>().saveSearchKeyword(_inputMessageController.text.toString());
                                                      Get.find<WalletController>().getWalletStatement(preFilter: widget.preFilter);

                                                    }
                                                    else {
                                                      showCustomSnackBar('write_something'.tr);
                                                    }
                                                  },
                                                  child: (Get.find<WalletController>().isSearchMode && Get.find<WalletController>().isLoading) ? Padding(
                                                    padding: EdgeInsets.all(10),
                                                    child: SizedBox(height: 25,width: 25,child: CircularProgressIndicator(),),
                                                  )
                                                      : Padding(
                                                    padding: EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_DEFAULT),
                                                    child: Icon(Icons.search, size: 25, color: Theme.of(context).primaryColor,),
                                                  ),
                                                );
                                              }
                                              ),

                                            ]),
                                          ),
                                        ),
                                      ],
                                    ),

                                SizedBox(height: 10,),
                               
                                walletController.walletStatementData != null ?

                                walletController.walletStatementData.length > 0 ?
                                ListView.builder(
                                  shrinkWrap: true,
                                  scrollDirection: Axis.vertical,
                                  itemCount: walletController.walletStatementData.length,
                                  physics: BouncingScrollPhysics(),
                                  itemBuilder: (context, index) {
                                    return Padding(padding: EdgeInsets.only(bottom: 10),child: Container(
                                      padding: const EdgeInsets.all(8.0),
                                      decoration: AppConstants.customBoxDecoration(context),
                                      child: ( widget.preFilter=="NA" || widget.preFilter=='select_prime_to_view_statement'.tr)?
                                      WalletHistoryItem(index: index,fromWallet: widget.fromWallet, data: walletController.walletStatementData[index] )
                                          : widget.preFilter=='pair_income'.tr?
                                      ClosingDetailsItem(index: index,fromWallet: widget.fromWallet, data: walletController.walletStatementData[index],preFilter: widget.preFilter, )
                                          : LoanHistoryItem(index: index,fromWallet: widget.fromWallet, data: walletController.walletStatementData[index],preFilter: widget.preFilter, ),
                                    ),);
                                  },
                                )

                                    : NoDataScreen(text: 'no_data_found'.tr)
                                    : WalletShimmer(walletController: walletController),

                                walletController.isLoading ? Center(child: Padding(
                                  padding: EdgeInsets.all(Dimensions.PADDING_SIZE_SMALL),
                                  child: CircularProgressIndicator(),
                                )) : SizedBox(),
                              ])
                            ]);
                          }
                      ),
                    ),
                  ),
                ),
              ),
            ) : Center(child: CircularProgressIndicator()) : NotLoggedInScreen();
          }
      ),
    );
  }
}

class FilterWidget extends StatelessWidget {


  Future<void> _selectFromDate(BuildContext context, WalletController walletController) async {
    final DateTime picked = await showDatePicker(
        context: context,
        initialDate: walletController.selectedFromDate,
        firstDate: DateTime(2015, 8),
        lastDate: DateTime(2050, 8));

    if (picked != null && picked != walletController.selectedFromDate) {
      walletController.setFromDate("${picked.toLocal()}".split(' ')[0],picked);

    }
  }
  Future<void> _selectToDate(BuildContext context, WalletController walletController) async {
    final DateTime picked = await showDatePicker(
        context: context,
        initialDate: walletController.selectedToDate,
        firstDate: DateTime(2015, 8),
        lastDate: DateTime(2050, 8));
    if (picked != null && picked != walletController.selectedToDate) {
      walletController.setToDate("${picked.toLocal()}".split(' ')[0],picked);

    }
  }
  @override
  Widget build(BuildContext context) {
    return Dialog(
      shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL)),
      insetPadding: EdgeInsets.all(30),
      clipBehavior: Clip.antiAliasWithSaveLayer,
      child: Container(
        width: 600,
        padding: EdgeInsets.all(Dimensions.PADDING_SIZE_SMALL),
        child: GetBuilder<WalletController>(builder: (walletController) {
          return SingleChildScrollView(
            child: Column(mainAxisSize: MainAxisSize.min, crossAxisAlignment: CrossAxisAlignment.start, children: [

              Row(mainAxisAlignment: MainAxisAlignment.spaceBetween, children: [
                InkWell(
                  onTap: () => Navigator.of(context).pop(),
                  child: Padding(
                    padding: EdgeInsets.all(Dimensions.PADDING_SIZE_EXTRA_SMALL),
                    child: Icon(Icons.close, color: Theme.of(context).disabledColor),
                  ),
                ),
                Text('filter'.tr, style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeLarge)),
                CustomButton(
                  onPressed: () {
                    walletController.resetStatementFilter();
                    walletController.getWalletStatement();
                  },
                  buttonText: 'reset'.tr, transparent: true, width: 65,
                ),
              ]),
              SizedBox(height: Dimensions.PADDING_SIZE_LARGE),

              Text('sort_by'.tr, style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeLarge)),
              SizedBox(height: Dimensions.PADDING_SIZE_SMALL),
              GridView.builder(
                itemCount: walletController.sortList.length,
                physics: NeverScrollableScrollPhysics(),
                shrinkWrap: true,
                gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
                  crossAxisCount: ResponsiveHelper.isDesktop(context) ? 3 : ResponsiveHelper.isTab(context) ? 3 : 2,
                  childAspectRatio: 3, crossAxisSpacing: 10, mainAxisSpacing: 10,
                ),
                itemBuilder: (context, index) {
                  return InkWell(
                    onTap: () {
                      walletController.setSortIndex(index);
                    },
                    child: Container(
                      alignment: Alignment.center,
                      decoration: BoxDecoration(
                        border: Border.all(color: walletController.sortIndex == index ? Colors.transparent
                            : Theme.of(context).disabledColor),
                        borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
                        color: walletController.sortIndex == index ? Theme.of(context).primaryColor
                            : Theme.of(context).disabledColor.withOpacity(0.1),
                      ),
                      child: Text(
                        walletController.sortList[index],
                        textAlign: TextAlign.center,
                        style: robotoMedium.copyWith(
                          color: walletController.sortIndex == index ? Colors.white : Theme.of(context).hintColor,
                        ),
                        maxLines: 1,
                        overflow: TextOverflow.ellipsis,
                      ),
                    ),
                  );
                },
              ),
              SizedBox(height: Dimensions.PADDING_SIZE_LARGE),

              Text('date'.tr, style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeLarge)),
              SizedBox(height: Dimensions.PADDING_SIZE_SMALL),
              Row(
                children: [
                  InkWell(
                    onTap: () {
                      _selectFromDate(context,walletController);
                    },
                    child: Container(
                      padding: EdgeInsets.fromLTRB(15, 10, 15, 10),
                      alignment: Alignment.center,
                      decoration: BoxDecoration(
                        border: Border.all(color: walletController.fromDate != 'from_date'.tr ? Colors.transparent
                            : Theme.of(context).disabledColor),
                        borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
                        color: walletController.fromDate != 'from_date'.tr ? Theme.of(context).primaryColor
                            : Theme.of(context).disabledColor.withOpacity(0.1),
                      ),
                      child: Text(
                        walletController.fromDate,
                        textAlign: TextAlign.center,
                        style: robotoMedium.copyWith(
                      color: walletController.fromDate != 'from_date'.tr ? Colors.white : Theme.of(context).hintColor,
                    ),
                        maxLines: 1,
                        overflow: TextOverflow.ellipsis,
                      ),
                    ),
                  ),

                  SizedBox(width: 15,),

                  InkWell(
                    onTap: () {
                      _selectToDate(context,walletController);

                    },
                    child: Container(
                      padding: EdgeInsets.fromLTRB(15, 10, 15, 10),
                      alignment: Alignment.center,
                      decoration: BoxDecoration(
                        border: Border.all(color: walletController.toDate != 'to_date'.tr ? Colors.transparent
                            : Theme.of(context).disabledColor),
                        borderRadius: BorderRadius.circular(Dimensions.RADIUS_SMALL),
                        color: walletController.toDate != 'to_date'.tr ? Theme.of(context).primaryColor
                            : Theme.of(context).disabledColor.withOpacity(0.1),
                      ),

                      child: Text(
                        walletController.toDate,
                        textAlign: TextAlign.center,
                        style: robotoMedium.copyWith(
                          color: walletController.toDate != 'to_date'.tr ? Colors.white : Theme.of(context).hintColor,
                        ),
                        maxLines: 1,
                        overflow: TextOverflow.ellipsis,
                      ),
                    ),
                  ),
                ],
              ),
              SizedBox(height: Dimensions.PADDING_SIZE_LARGE),

              Text('transaction_type'.tr, style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeLarge)),

              Row(crossAxisAlignment: CrossAxisAlignment.start,mainAxisAlignment: MainAxisAlignment.start,children: [
                CustomCheckBox(
                  title:  'debit'.tr,
                  value: walletController.actionType=='debit'.tr,
                  onClick: () {
                    if(walletController.actionType=='debit'.tr){
                      walletController.setActionType("");
                    }else{
                      walletController.setActionType('debit'.tr);
                    }

                  },
                ),
                CustomCheckBox(
                  title:  'credit'.tr,
                  value: walletController.actionType=='credit'.tr,
                  onClick: () {
                    if(walletController.actionType=='credit'.tr){
                      walletController.setActionType("");
                    }else{
                      walletController.setActionType('credit'.tr);
                    }

                  },
                ),

              ],),
              SizedBox(height:Get.find<UserController>().userInfoModel.isCompany=="true" ?  Dimensions.PADDING_SIZE_LARGE : 0.0),

              Get.find<UserController>().userInfoModel.isCompany=="true" ?  Text('transfer_type'.tr, style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeLarge)) : SizedBox(),

              Get.find<UserController>().userInfoModel.isCompany=="true" ?   Row(crossAxisAlignment: CrossAxisAlignment.start,mainAxisAlignment: MainAxisAlignment.start,children: [
                CustomCheckBox(
                  title:  'loan'.tr,
                  value: walletController.transferType=='loan'.tr,
                  onClick: () {
                    if(walletController.transferType=='loan'.tr){
                      walletController.setTransferType("");
                    }else{
                      walletController.setTransferType('loan'.tr);
                    }

                  },
                ),
                CustomCheckBox(
                  title:  'receipt'.tr,
                  value: walletController.transferType=='receipt'.tr,
                  onClick: () {
                    if(walletController.transferType=='receipt'.tr){
                      walletController.setTransferType("");
                    }else{
                      walletController.setTransferType('receipt'.tr);
                    }

                  },
                ),

              ],)
                  : SizedBox(),


              SizedBox(height: Dimensions.PADDING_SIZE_SMALL),


              (walletController.transferTypesList!=null && walletController.transferTypesList.length>0) ?
              Column(
                children: [
                  Text('Type'.tr,
                      style: robotoMedium.copyWith(fontSize:
                      Dimensions.fontSizeLarge)),
                  SizedBox(height: Dimensions.PADDING_SIZE_SMALL),
                ],
              )
                  : SizedBox(),
              (walletController.transferTypesList!=null && walletController.transferTypesList.length>0) ? Container(
                height: 30, alignment: Alignment.center,
                child: ListView.builder(
                  itemCount: walletController.transferTypesList.length,
                  shrinkWrap: true,
                  scrollDirection: Axis.horizontal,
                  itemBuilder: (context, index) {
                    return CustomCheckBox(
                      title:  walletController.transferTypesList[index].name,
                      value: (walletController.transferTypeDropDownValue!=null && walletController.transferTypeDropDownValue.name==walletController.transferTypesList[index].name),
                      onClick: () {
                        if(walletController.transferTypeDropDownValue!=null && walletController.transferTypeDropDownValue.name==walletController.transferTypesList[index].name){
                          walletController.updateTransferTypeDropdown(null);
                        }else{
                          walletController.updateTransferTypeDropdown(walletController.transferTypesList[index]);
                        }
                      },
                    );
                  },
                ),
              )
                  : SizedBox(),
              SizedBox(height:(walletController.transferTypesList!=null && walletController.transferTypesList.length>0) ? 30 : 0.0),

              CustomButton(
                buttonText: 'apply_filters'.tr,
                onPressed: () {
                  walletController.setFilterApplied();
                  walletController.getWalletStatement();
                  Get.back();
                },
              ),

            ]),
          );
        }),
      ),
    );
  }
}

class WalletShimmer extends StatelessWidget {
  final WalletController walletController;
  WalletShimmer({@required this.walletController});

  @override
  Widget build(BuildContext context) {
    return GridView.builder(
      key: UniqueKey(),
      gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
        crossAxisSpacing: 50,
        mainAxisSpacing: ResponsiveHelper.isDesktop(context) ? Dimensions.PADDING_SIZE_LARGE : 0.1,
        childAspectRatio: ResponsiveHelper.isDesktop(context) ? 5 : 2.45,
        crossAxisCount: ResponsiveHelper.isMobile(context) ? 1 : 2,
      ),
      physics:  NeverScrollableScrollPhysics(),
      shrinkWrap:  true,
      itemCount: 10,
      padding: EdgeInsets.only(top: ResponsiveHelper.isDesktop(context) ? 28 : 25),
      itemBuilder: (context, index) {
        return Padding(
          padding: EdgeInsets.symmetric(vertical: Dimensions.PADDING_SIZE_SMALL),
          child: Shimmer(
            duration: Duration(seconds: 2),
            enabled: walletController.walletStatementData == null,
            child: Column(children: [
              Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Column(crossAxisAlignment: CrossAxisAlignment.start, children: [
                    Container(height: 10, width: 50, decoration: BoxDecoration(color: Colors.grey[300], borderRadius: BorderRadius.circular(2))),
                    SizedBox(height: 10),
                    Container(height: 10, width: 70, decoration: BoxDecoration(color: Colors.grey[300], borderRadius: BorderRadius.circular(2))),
                  ]),
                  Column(crossAxisAlignment: CrossAxisAlignment.end, children: [
                    Container(height: 10, width: 50, decoration: BoxDecoration(color: Colors.grey[300], borderRadius: BorderRadius.circular(2))),
                    SizedBox(height: 10),
                    Container(height: 10, width: 70, decoration: BoxDecoration(color: Colors.grey[300], borderRadius: BorderRadius.circular(2))),
                  ]),
                ],
              ),
              Padding(padding: const EdgeInsets.only(top: Dimensions.PADDING_SIZE_LARGE), child: Divider(color: Theme.of(context).disabledColor)),
            ],
            ),
          ),
        );
      },
    );
  }
}