import 'dart:io';

import 'package:country_code_picker/country_code.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:dotted_border/dotted_border.dart';
import 'package:phone_number/phone_number.dart';
import 'package:share_plus/share_plus.dart';
import 'package:sixam_mart/controller/auth_controller.dart';
import 'package:sixam_mart/controller/splash_controller.dart';
import 'package:sixam_mart/controller/user_controller.dart';
import 'package:sixam_mart/helper/price_converter.dart';
import 'package:sixam_mart/helper/responsive_helper.dart';
import 'package:sixam_mart/util/app_constants.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/images.dart';
import 'package:sixam_mart/util/styles.dart';
import 'package:sixam_mart/view/base/custom_app_bar.dart';
import 'package:sixam_mart/view/base/custom_button.dart';
import 'package:sixam_mart/view/base/custom_snackbar.dart';
import 'package:sixam_mart/view/base/footer_view.dart';
import 'package:sixam_mart/view/screens/menu/web_menu_drawer.dart';
import 'package:sixam_mart/view/base/not_logged_in_screen.dart';
import 'package:sixam_mart/view/screens/wallet/widget/wallet_bottom_sheet.dart';

import '../../../controller/wallet_controller.dart';
import '../../../helper/route_helper.dart';
import '../../base/custom_image.dart';
import '../../base/custom_text_field.dart';
import '../profile/widget/profile_card.dart';
import '../search/widget/custom_check_box.dart';
class WalletTransferScreen extends StatefulWidget {
  final bool fromWallet;
  WalletTransferScreen({Key key, @required this.fromWallet}) : super(key: key);

  @override
  State<WalletTransferScreen> createState() => _WalletTransferScreenState();
}

class _WalletTransferScreenState extends State<WalletTransferScreen> {
  bool _isLoggedIn;
  final FocusNode _remarkFocus = FocusNode();
  final FocusNode _amtFocus = FocusNode();
  final TextEditingController _mobileController = TextEditingController();
  final TextEditingController _amtController = TextEditingController();
  final TextEditingController _remarkController = TextEditingController();
  final TextEditingController _loanDeductionPercent = TextEditingController();
  String _countryDialCode;
  @override
  void initState() {
    super.initState();
    _countryDialCode = CountryCode.fromCountryCode(Get.find<SplashController>().configModel.country).dialCode;

    _isLoggedIn = Get.find<AuthController>().isLoggedIn();

    if(_isLoggedIn && Get.find<UserController>().userInfoModel == null) {
      Get.find<UserController>().getUserInfo();
    }
    Get.find<WalletController>().setCanTransferWalletAmt(false);
    Get.find<WalletController>().resetStatementFilter();
    Get.find<WalletController>().setActionType('receipt'.tr);
  }


  @override
  Widget build(BuildContext context) {
    bool _desktop = ResponsiveHelper.isDesktop(context);
    bool _isTab = ResponsiveHelper.isTab(context);
    bool _isWeb = ResponsiveHelper.isWeb();
    bool _isMobile = ResponsiveHelper.isMobile(context);
    double screenWidth = MediaQuery.of(context).size.width;

    print("screenWidthTest  $screenWidth");
    return Scaffold(
      endDrawer: WebMenuDrawer(),
      appBar: CustomAppBar(title: 'wallet_transfer'.tr,onBackPressed: (){
        Get.offAllNamed(RouteHelper.getInitialRoute());
      },),
      body: Center(
        child: _isLoggedIn ? SingleChildScrollView(
          child: FooterView(
            child: SizedBox(
              width: Dimensions.WEB_MAX_WIDTH,
              child: Padding(
                padding: const EdgeInsets.symmetric(horizontal: Dimensions.PADDING_SIZE_LARGE),
                child: GetBuilder<UserController>(builder: (userController) {
                  return GetBuilder<WalletController>(builder: (walletController) {
                    return Column( children: [
                      Stack(
                        children: [
                          Container(
                            padding: widget.fromWallet ? EdgeInsets.all(Dimensions.PADDING_SIZE_EXTRA_LARGE)
                                : EdgeInsets.only(top: 40, left: Dimensions.PADDING_SIZE_EXTRA_LARGE, right: Dimensions.PADDING_SIZE_EXTRA_LARGE),
                            decoration: BoxDecoration(
                              borderRadius: BorderRadius.circular(Dimensions.RADIUS_DEFAULT),
                              color: widget.fromWallet ? Theme.of(context).primaryColor : Theme.of(context).cardColor,
                            ),
                            child:  Row(mainAxisAlignment: widget.fromWallet ? MainAxisAlignment.start : MainAxisAlignment.center, children: [

                              Image.asset( widget.fromWallet ? Images.wallet : Images.loyal , height: 60, width: 60, color: widget.fromWallet ? Theme.of(context).cardColor : null),
                              SizedBox(width: Dimensions.PADDING_SIZE_EXTRA_LARGE),

                              widget.fromWallet ? Column(crossAxisAlignment: CrossAxisAlignment.start, mainAxisSize: MainAxisSize.min,
                                  children: [
                                    Text('wallet_amount'.tr,style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall, color: Theme.of(context).cardColor)),
                                    SizedBox(height: Dimensions.PADDING_SIZE_SMALL),

                                    Text(
                                      PriceConverter.convertPrice(userController.userInfoModel.walletBalance),
                                      style: robotoBold.copyWith(fontSize: Dimensions.fontSizeOverLarge, color: Theme.of(context).cardColor),
                                    ),
                                  ])
                                  : Column(crossAxisAlignment: CrossAxisAlignment.center, mainAxisAlignment: MainAxisAlignment.end, children: [

                                Text(
                                  userController.userInfoModel.loyaltyPoint == null ? '0' : userController.userInfoModel.loyaltyPoint.toString(),
                                  style: robotoBold.copyWith(fontSize: Dimensions.fontSizeOverLarge, color: Theme.of(context).textTheme.bodyText1.color),
                                ),
                                Text(
                                  'history'.tr + ' !',
                                  style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall, color: Theme.of(context).textTheme.bodyText1.color),
                                ),
                                SizedBox(height: Dimensions.PADDING_SIZE_SMALL),
                              ])
                            ]),
                          ),

                          Positioned(
                            top: 10,right: 10,
                            child: InkWell(
                              onTap: (){
                                  Get.toNamed(RouteHelper.getWalletTransferHistoryRoute());
                              },
                              child: Row(
                                children: [
                                  Text(
                                    'history'.tr , style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeLarge,
                                      color: widget.fromWallet ? Theme.of(context).cardColor : Theme.of(context).textTheme.bodyText1.color),
                                  ),
                                  Icon(Icons.keyboard_arrow_down_outlined,size: 16, color: widget.fromWallet ? Theme.of(context).cardColor
                                      : Theme.of(context).textTheme.bodyText1.color)
                                ],
                              ),
                            ),
                          )
                        ],
                      ) ,

                      ( walletController.userIdentityModel!=null && walletController.userIdentityModel.data!=null)?
                      Column(
                        children: [
                          SizedBox(height: Dimensions.PADDING_SIZE_LARGE),
                          Container(
                            decoration: BoxDecoration(
                              borderRadius: BorderRadius.circular(Dimensions.RADIUS_DEFAULT),
                              color:  Theme.of(context).primaryColor,
                              boxShadow: [BoxShadow(color: Colors.grey[Get.isDarkMode ? 800 : 200], spreadRadius: 1, blurRadius: 5)],
                            ),
                            child: Row(
                              mainAxisAlignment: MainAxisAlignment.spaceAround,
                              crossAxisAlignment: CrossAxisAlignment.start,
                              children: [
                                Column(
                                  crossAxisAlignment: CrossAxisAlignment.start,
                                  mainAxisAlignment: MainAxisAlignment.start,
                                  children: [

                                    SizedBox(height: 5,),
                                    Text('${
                                        walletController.userIdentityModel.data.fName == null ? "NA"
                                            :'${walletController.userIdentityModel.data.fName } '
                                            '${walletController.userIdentityModel.data.lName==null? ""
                                            : walletController.userIdentityModel.data.lName}'
                                    }', style:TextStyle(fontSize: 15, color: Colors.white)),

                                    SizedBox(height: 10,),
                                    Text(' ${walletController.userIdentityModel.data.phone}',
                                        style:TextStyle(fontSize: 15, color: Colors.white)),
                                    SizedBox(height: 10,),

                                    Text(' ${walletController.userIdentityModel.data.email}',
                                        style:TextStyle(fontSize: 15, color: Colors.white)),
                                  ]
                                  ,),
                                Padding(
                                  padding: const EdgeInsets.all(5.0),
                                  child: Column(
                                    children: [
                                      CustomImage(
                                        image: '${Get.find<SplashController>().configModel.baseUrls.customerImageUrl}'
                                            '/${walletController.userIdentityModel.data.image != null  ? walletController.userIdentityModel.data.image : ''}',
                                        height: 120, width: 100, fit: BoxFit.cover,isProfile: false,
                                      ),

                                      SizedBox(height: 10,),
                                      Container(
                                        color: Theme.of(context).cardColor,
                                        padding: const EdgeInsets.all(5.0),
                                        child: InkWell(child: Text('change'.tr,
                                            style:TextStyle(fontSize: 15,
                                                color: Theme.of(context).primaryColor)),onTap: (){
                                          walletController.removeUserIdentity();

                                        },),
                                      ),
                                      SizedBox(height: 5,),
                                    ],
                                  ),
                                ),

                              ],
                            ),
                          ),
                          SizedBox(height: Dimensions.PADDING_SIZE_LARGE),
                          CustomTextField(
                            hintText: 'enter_amount'.tr,
                            controller: _amtController,
                            showTitle: true,
                            showBorderStyle: true,
                            nextFocus: _remarkFocus,
                            focusNode: _amtFocus,
                            isNumber: false,
                            inputType: TextInputType.number,
                            divider: false,
                            // onChanged: (text) {
                            //
                            //   if(_amtController.text.isNotEmpty
                            //       && userController.userInfoModel.walletBalance!=null
                            //       && userController.userInfoModel.walletBalance>0
                            //       && (double.parse(_amtController.text.trim().toString()))<=userController.userInfoModel.walletBalance
                            //   ){
                            //     _walletTransferStatus.text="You Can Transfer";
                            //     walletController.setCanTransferWalletAmt(true);
                            //   }else{
                            //     _walletTransferStatus.text='insufficient_fund'.tr;
                            //     walletController.setCanTransferWalletAmt(false);
                            //   }
                            // },
                          ),
                          SizedBox(height: Get.find<UserController>().userInfoModel.isCompany=="true" ? Dimensions.PADDING_SIZE_LARGE : 0.0),
                          Get.find<UserController>().userInfoModel.isCompany=="true" ?  Row(crossAxisAlignment: CrossAxisAlignment.start,mainAxisAlignment: MainAxisAlignment.start,children: [
                            CustomCheckBox(
                              title:  'receipt'.tr,
                              value: walletController.actionType=='receipt'.tr,
                              onClick: () {
                                if(walletController.actionType=='receipt'.tr){
                                  walletController.setActionType("");
                                }else{
                                  walletController.setActionType('receipt'.tr);
                                }

                              },
                            ),
                            CustomCheckBox(
                              title:  'loan'.tr,
                              value: walletController.actionType=='loan'.tr,
                              onClick: () {
                                if(walletController.actionType=='loan'.tr){
                                  walletController.setActionType("");
                                }else{
                                  walletController.setActionType('loan'.tr);
                                }

                              },
                            ),

                          ],)
                          : SizedBox(),

                          SizedBox(height: walletController.actionType=='loan'.tr ?  Dimensions.PADDING_SIZE_LARGE : 0.0),
                          walletController.actionType=='loan'.tr ?

                          CustomTextField(
                            hintText: 'loan_deduction_percent'.tr,
                            controller: _loanDeductionPercent,
                            isNumber: false,
                            showBorderStyle: true,
                            showTitle: true,
                            inputType: TextInputType.number,
                            divider: false,

                          )
                          : SizedBox(),
                          SizedBox(height: Dimensions.PADDING_SIZE_LARGE),
                          CustomTextField(
                            hintText: 'remark'.tr,
                            controller: _remarkController,
                            showTitle: true,
                            showBorderStyle: true,
                            focusNode: _remarkFocus,
                            isNumber: false,
                            inputType: TextInputType.text,
                            divider: false,
                            // onChanged: (text) {
                            //
                            //   if(_amtController.text.isNotEmpty
                            //       && userController.userInfoModel.walletBalance!=null
                            //       && userController.userInfoModel.walletBalance>0
                            //       && (double.parse(_amtController.text.trim().toString()))<=userController.userInfoModel.walletBalance
                            //   ){
                            //     _walletTransferStatus.text="You Can Transfer";
                            //     walletController.setCanTransferWalletAmt(true);
                            //   }else{
                            //     _walletTransferStatus.text='insufficient_fund'.tr;
                            //     walletController.setCanTransferWalletAmt(false);
                            //   }
                            // },
                          ),

                          // (walletController.canTransferWalletAmt==null)?SizedBox()
                          //     :   Padding(
                          //   padding:  EdgeInsets.only(left: 5,top: 2,right: 5),
                          //   child:  Container(
                          //       padding:  EdgeInsets.all(5),
                          //       width: context.width,
                          //       color: walletController.canTransferWalletAmt? Colors.green.withOpacity(0.2) : Colors.transparent,
                          //       child: Text(_walletTransferStatus.text.toString(),
                          //           style: robotoMedium.copyWith(fontSize: 14,  color: walletController.canTransferWalletAmt? Colors.green : Colors.red))),
                          // ),

                          SizedBox(height: Dimensions.PADDING_SIZE_LARGE),
                          !walletController.isAmtTransferLoading ? CustomButton(buttonText: 'transfer'.tr, onPressed: ()
                          async {

                            var amt = _amtController.text.toString();
                            var remark = _remarkController.text.toString();
                            var loanDeductionPercent = _loanDeductionPercent.text.toString();


                            if (amt.isEmpty) {
                              showCustomSnackBar('please_enter_amount'.tr,isError: true);
                            }
                            else if (walletController.actionType=='loan'.tr && loanDeductionPercent.isEmpty) {
                              showCustomSnackBar('enter_loan_deduction'.tr,isError: true);
                            }


                            else{

                              if (walletController.actionType=='receipt'.tr) {
                                loanDeductionPercent="";
                              }

                              walletController.walletAmtTransfer(loanDeductionPercent,remark,amt, walletController.userIdentityModel.data.id.toString()).then((status) async {

                                if(status.isSuccess){
                                 // Get.find<UserController>().getUserInfo();
                                  Get.offNamed(RouteHelper.getWalletTransferSuccessRoute());
                                }else{
                                  showCustomSnackBar(status.message,isError: true);
                                }
                              });
                            }



                          })
                              : Center(child: CircularProgressIndicator(),)
                        ],
                      )
                          : Column(children: [
                        SizedBox(height: Dimensions.PADDING_SIZE_EXTRA_LARGE),
                        DottedBorder(
                          color: Theme.of(context).primaryColor,
                          strokeWidth: 1,
                          strokeCap: StrokeCap.butt,
                          dashPattern: [8, 5],
                          padding: EdgeInsets.all(0),
                          borderType: BorderType.RRect,
                          radius: Radius.circular(Dimensions.RADIUS_SMALL),
                          child: CustomTextField(
                            hintText: 'mobile'.tr,
                            controller: _mobileController,
                            nextFocus: _amtFocus,
                            isNumber: true,
                            inputType: TextInputType.number,
                            divider: false,
                          ),
                        ),

                        SizedBox(height: Dimensions.PADDING_SIZE_LARGE),


                        !walletController.isLoading ?
                        CustomButton(buttonText: 'verify'.tr, onPressed: ()
                        async {

                          var mobile = _mobileController.text.toString();
                          if(mobile.isEmpty){
                            showCustomSnackBar('please_enter_mobile_2'.tr,isError: true);
                          }
                          else if(mobile.length!=10){
                            showCustomSnackBar('invalid_mobile'.tr,isError: true);
                          }

                          else{
                            walletController.customerIdentity(mobile).then((status) async {
                              if (!status.isSuccess) {
                                showCustomSnackBar(status.message);
                              }
                            });
                          }

                        }):
                        Center(child: CircularProgressIndicator(),),

                        SizedBox(height: Dimensions.PADDING_SIZE_LARGE),
                      ],),

                      SizedBox(height: ( walletController.userIdentityModel!=null && walletController.userIdentityModel.data!=null)? Dimensions.PADDING_SIZE_LARGE:0.0),

                    ]);
                  }
                  );
                }
                ),
              ),
            ),
          ),
        ) : NotLoggedInScreen(),
      ),
    );
  }
}
