import 'dart:async';
import 'package:sixam_mart/controller/localization_controller.dart';
import 'package:sixam_mart/controller/wallet_controller.dart';
import 'package:sixam_mart/helper/responsive_helper.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/styles.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import '../../../../util/app_constants.dart';
import '../../../controller/change_client_controller.dart';
import '../../../data/model/response/WallerTransferHistoryResponseModel.dart';
import '../../../data/model/response/wallet_withdrawal_requests_history_model.dart';
import '../../../helper/date_converter.dart';
import '../../../util/images.dart';
import '../../base/custom_app_bar.dart';
import '../../base/footer_view.dart';
import '../../base/web_constrained_box.dart';
import '../menu/web_menu_drawer.dart';

class WalletWithdrawalScreen extends StatefulWidget {

  @override
  _WalletWithdrawalScreenState createState() => _WalletWithdrawalScreenState();
}

class _WalletWithdrawalScreenState extends State<WalletWithdrawalScreen> with TickerProviderStateMixin {
  final bool _ltr = Get.find<LocalizationController>().isLtr;
  var addOnOffset = 10;
  final TextEditingController _searchController = TextEditingController();
  Timer timeHandle;
  final ScrollController scrollController = ScrollController();
  String parentChild=AppConstants.CHILD;

  @override
  void initState() {
    super.initState();
    Get.find<WalletController>().walletWithdrawalRequestHistory();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: CustomAppBar(title: 'withdrawal_requests'.tr),
      endDrawer: WebMenuDrawer(),
      body: GetBuilder<WalletController>(
        builder: (walletController) {
          List<WithdrawalRequests> _items=walletController.walletWithdrawalRequestsHistoryModel?.withdrawalRequests;

          print("WallerTransferHistoryResponseData ${_items?.length}");
          return  ( _items!=null && _items.length > 0) ? SingleChildScrollView(
            child: Scrollbar(
              child: SingleChildScrollView(
                padding: ResponsiveHelper.isDesktop(context) ? EdgeInsets.only(
                  top: Dimensions.PADDING_SIZE_SMALL,
                ) : EdgeInsets.all(Dimensions.PADDING_SIZE_SMALL),
                physics: BouncingScrollPhysics(),
                child: FooterView(
                  child: SizedBox(
                    width: Dimensions.WEB_MAX_WIDTH,
                    child: ListView.builder(
                      physics: NeverScrollableScrollPhysics(),
                      shrinkWrap: true,
                      itemCount: _items.length,
                      itemBuilder: (context, index) {

                        return  Padding(
                          padding: const EdgeInsets.all(8.0),
                          child: Container(
                            padding: const EdgeInsets.only(left: 10,right: 10,top: 5,bottom: 5),
                            decoration: BoxDecoration(
                              border: Border.all(color: Colors.blueGrey),
                            ),
                            child: Column(
                              children: [
                                Row(
                                  children: [
                                    Text(
                                      'Account no:',
                                      style: robotoMedium.copyWith(fontSize: 12,),
                                      textAlign: TextAlign.center,
                                    ),
                                    SizedBox(width: 5,),
                                    Text(
                                      '${_items[index].bankAccountNo}',
                                      style: robotoMedium.copyWith(fontSize: 12, color: Colors.black54),
                                      textAlign: TextAlign.center,
                                    ),
                                  ],
                                ),

                                SizedBox(height: 10,),

                                Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,children: [

                                  Row(
                                    children: [
                                      Text(
                                        'Amount:',
                                        style: robotoMedium.copyWith(fontSize: 12,),
                                        textAlign: TextAlign.center,
                                      ),
                                      SizedBox(width: 5,),
                                      Text(
                                        '${_items[index].withdrawalAmount}',
                                        style: robotoMedium.copyWith(fontSize: 12, color: Theme.of(context).primaryColor),
                                        textAlign: TextAlign.center,
                                      ),
                                    ],
                                  ),

                                  SizedBox(width: 10,),
                                  Row(
                                    children: [
                                      Text(
                                        'Date:',
                                        style: robotoMedium.copyWith(fontSize: 12,),
                                        textAlign: TextAlign.center,
                                      ),
                                      SizedBox(width: 5,),
                                      Text(
                                      //  '${_items[index].createdAt}',
                                        DateConverter.dateToDateAndTimeAm(_items[index].createdAt),
                                        style: robotoMedium.copyWith(fontSize: 12,),
                                        textAlign: TextAlign.center,
                                      ),
                                    ],
                                  ),

                                ],),
                                SizedBox(height: 10,),

                                Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,children: [

                                  Row(
                                    children: [

                                      Text(
                                        'Status:',
                                        style: robotoMedium.copyWith(fontSize: 12),
                                        textAlign: TextAlign.center,
                                      ),
                                      SizedBox(width: 5,),

                                      Text(
                                        '${_items[index].status}',
                                        style: robotoMedium.copyWith(fontSize: 12,color:
                                        (_items[index].status!=null && _items[index].status.toLowerCase()=="pending") ? Colors.orange :
                                        (_items[index].status!=null && _items[index].status.toLowerCase()=="rejected")
                                            ? Colors.red : Colors.green)  ,
                                        textAlign: TextAlign.center,
                                      ),
                                    ],
                                  ),


                                ],),

                                Row(
                                  mainAxisAlignment: MainAxisAlignment.start,
                                  children: [
                                    Text(
                                      'Description:',
                                      style: robotoMedium.copyWith(fontSize: 12),
                                      textAlign: TextAlign.center,
                                    ),
                                    SizedBox(width: 5,),

                                    Expanded(child: Container(
                                      padding:  EdgeInsets.all(_items[index].description==null ? 0.0 : 1.0),
                                      decoration: BoxDecoration(
                                        border: Border.all(color: (_items[index].description!=null && _items[index].status.toLowerCase()=="pending") ? Colors.orange :
                                        (_items[index].description!=null && _items[index].status.toLowerCase()=="rejected")
                                            ? Colors.red : Colors.transparent),
                                      ),
                                      child: Text(
                                        '${_items[index].description}',
                                        style: robotoMedium.copyWith(fontSize: 12, color: Colors.black54),
                                        textAlign: TextAlign.center,
                                      ),
                                    )),
                                  ],
                                ),
                              ],
                            ),),
                        );
                        // return CartItemWidget(cart: cartController.cartList[index], cartIndex: index, addOns: cartController.addOnsList[index], isAvailable: cartController.availableList[index]);

                      },
                    ),
                  ),
                ),
              ),
            ),
          ) :
          walletController.isHistoryLoading? Center(child: CircularProgressIndicator(),) :
          SingleChildScrollView(
            child: FooterView(
              visibility: true,
              child: Column(mainAxisAlignment: MainAxisAlignment.center, crossAxisAlignment: CrossAxisAlignment.stretch, children: [

                Image.asset(
                  Images.no_data_found,
                  width: MediaQuery.of(context).size.height*0.15, height: MediaQuery.of(context).size.height*0.15,
                ),
                SizedBox(height: MediaQuery.of(context).size.height*0.03),

                Text(
                  'withdrawal_history_not_available'.tr ,
                  style: robotoMedium.copyWith(fontSize: MediaQuery.of(context).size.height*0.0175, color: Theme.of(context).disabledColor),
                  textAlign: TextAlign.center,
                ),

              ]),
            ),
          );
        },
      ),
    );
  }

}

