
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:sixam_mart/data/model/response/wallet_model.dart';
import 'package:sixam_mart/helper/date_converter.dart';
import 'package:sixam_mart/helper/price_converter.dart';
import 'package:sixam_mart/util/dimensions.dart';
import 'package:sixam_mart/util/styles.dart';
import 'package:universal_html/js_util.dart';
import 'package:url_launcher/url_launcher_string.dart';

import '../../../../controller/wallet_controller.dart';
import '../../../../data/model/response/closing_response.dart';
import '../../../../data/model/response/wallet_statement_response.dart';
import '../../../../helper/route_helper.dart';
import '../../../../util/images.dart';
import '../../../base/custom_snackbar.dart';
class WalletHistoryItem extends StatelessWidget {
  final int index;
  final bool fromWallet;
  // final List<Transaction> data;
  final WalletStatementData data;
  const WalletHistoryItem({Key key, @required this.index, @required this.fromWallet, @required this.data}) : super(key: key);


  String incomeType(String key){
    String name="";
    for(Types item in Get.find<WalletController>().transferTypesList){
      if(item.value==key){
        name=item.name;
        break;
      }
    }
    return name;
  }
  @override
  Widget build(BuildContext context) {
    return Column(crossAxisAlignment: CrossAxisAlignment.start,
        children: [

      Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,children: [
        Row(
          children: [
            Text('Type: ',
              style: robotoMedium.copyWith(color: Colors.black54,fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
            ),
            Text('${incomeType(data.incomeType.toString())} ${data.transferType==null?"":' | ${data.transferType}'}',
              style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
            )
          ],
        ) ,

        Text(data.transactionDate
            ,style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall,color: Theme.of(context).disabledColor),
            maxLines: 1, overflow: TextOverflow.ellipsis),
      ],),

      SizedBox(height: 5.0,),

      Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,children: [
        Row(
          children: [
            (data.debit==null && data.credit!=null)?
            Row(
              children: [
                //128.43
                Text(
                  '${'credit'.tr}:',
                  style: robotoMedium.copyWith(color: Colors.black54,fontSize: 12,),
                  textAlign: TextAlign.center,
                ),
                SizedBox(width: 5,),
                Text(
                  '${PriceConverter.convertPrice(double.parse(data.credit))}',
                  style: robotoMedium.copyWith(fontSize: 12,color: Colors.green),
                  textAlign: TextAlign.center,
                ),
              ],
            ) :
            (data.credit==null && data.debit!=null) ?
            Row(
              children: [
                Text(
                  '${'debit'.tr}:',
                  style: robotoMedium.copyWith(fontSize: 12,),
                  textAlign: TextAlign.center,
                ),
                SizedBox(width: 5,),
                Text(
                  '${PriceConverter.convertPrice(double.parse(data.debit))}',
                  style: robotoMedium.copyWith(fontSize: 12,color: Colors.red),
                  textAlign: TextAlign.center,
                ),
              ],
            )
                : SizedBox(),

          ],
        ) ,

        Row(
          children: [
            Text(
              '${'balance'.tr}:',
              style: robotoMedium.copyWith(fontSize: 12),
              textAlign: TextAlign.center,
            ),
            SizedBox(width: 5,),

            Text(
              '${data.balance}',
              style: robotoMedium.copyWith(fontSize: 12),
              textAlign: TextAlign.center,
            ),
          ],
        ),
      ],),
      SizedBox(height: 5.0,),



      Row(mainAxisAlignment : MainAxisAlignment.spaceBetween,children: [
        Row(
          children: [
            Text('Party: ',
              style: robotoMedium.copyWith(color: Colors.black54,fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
            ),
            Text('${data.party.toString()}',
              style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
            )
          ],
        ) ,

        //DateConverter.dateToDateAndTimeAm(data.createdAt)
        // Text(data.transactionDate
        //     ,style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall,color: Theme.of(context).disabledColor),
        //     maxLines: 1, overflow: TextOverflow.ellipsis),
      ],),

      SizedBox(height: 5.0,),
          data.particulars!=null? Text('${data.particulars.toString()}',
        style: robotoRegular.copyWith(color: Colors.black26,fontSize: Dimensions.fontSizeDefault), maxLines: 2, overflow: TextOverflow.ellipsis,
      ): SizedBox(),


          SizedBox(height:(data.remarks==null || data.remarks.isEmpty)?0: 5.0,),

          (data.remarks==null || data.remarks.isEmpty)?SizedBox():  Row(
            children: [
              Text('${'remark'.tr}: ',
                style: robotoMedium.copyWith(color: Colors.black54,fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
              ),
              Text('${data.remarks.toString()}',
                style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeDefault,color: Colors.black38), maxLines: 1, overflow: TextOverflow.ellipsis,
              )
            ],
          ) ,

      // Padding(
      //   padding: const EdgeInsets.only(top: Dimensions.PADDING_SIZE_DEFAULT),
      //   child: Divider(color: Theme.of(context).disabledColor),
      // ),
    ]);
  }
}


class LoanHistoryItem extends StatelessWidget {
  final int index;
  final bool fromWallet;
  final String preFilter;
  // final List<Transaction> data;
  final WalletStatementData data;
  const LoanHistoryItem({Key key, @required this.index, @required this.fromWallet, @required this.data, @required this.preFilter}) : super(key: key);


  String incomeType(String key){
    String name="";
    for(Types item in Get.find<WalletController>().transferTypesList){
      if(item.value==key){
        name=item.name;
        break;
      }
    }
    return name;
  }
  double remainingLoanAmt(double loanAmt , num receivedAmt){
    print("remainingLoanAmt loanAmt = $loanAmt receivedAmt $receivedAmt");
     double remainingLoanAmt=0.0;
      try{
        remainingLoanAmt = loanAmt - double.parse('${receivedAmt.toString()}') ;
      }catch(e){
        remainingLoanAmt=-1;
      }
     
   
    return remainingLoanAmt;
  }
  @override
  Widget build(BuildContext context) {
    return Column(crossAxisAlignment: CrossAxisAlignment.start,
        children: [




          Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,children: [
            Row(
              children: [
                Text('Type: ',
                  style: robotoMedium.copyWith(color: Colors.black54,fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
                ),
                Text('${incomeType(data.incomeType.toString())} ${data.transferType==null?"":' | ${data.transferType}'}',
                  style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
                )
              ],
            ) ,

            Text(data.transactionDate
                ,style: robotoRegular.copyWith(fontSize: Dimensions.fontSizeSmall,),
                maxLines: 1, overflow: TextOverflow.ellipsis),
          ],),



          SizedBox(height: 5.0,),



          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,children: [
            Row(
              children: [
                Text('Transfer To: ',
                  style: robotoMedium.copyWith(color: Colors.black54,fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
                ),
                 Text(data.transferToName == null ? 'NA' :' ${data.transferToName.toString()}',
                  style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
                )
              ],
            ) ,

            // Row(
            //   children: [
            //     Text(
            //       '${'balance'.tr}:',
            //       style: robotoMedium.copyWith(fontSize: 12),
            //       textAlign: TextAlign.center,
            //     ),
            //     SizedBox(width: 5,),
            //
            //     Text(
            //       '${data.balance}',
            //       style: robotoMedium.copyWith(fontSize: 12),
            //       textAlign: TextAlign.center,
            //     ),
            //   ],
            // ),
          ],),

          SizedBox(height: 5.0,),


          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              Row(children: [Text( data.transferToPrimeAccountNo==null? 'Customer ID: ' :  'Prime ID: ',
                style: robotoMedium.copyWith(color: Colors.black54,fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
              ),
                Text(data.transferToPrimeAccountNo==null? '${data.partyId==null?'NA':data.partyId.toString()}' : '${data.transferToPrimeAccountNo.toString()}',
                  style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
                )],),

              Row(
                children: [
                  (data.debit==null && data.credit!=null)?
                  Row(
                    children: [
                      //128.43
                      Text(
                        //'${'credit'.tr}:',
                        '',
                        style: robotoMedium.copyWith(color: Colors.black54,fontSize: 12,),
                        textAlign: TextAlign.center,
                      ),
                      SizedBox(width: 5,),
                      Text(
                        '${PriceConverter.convertPrice(double.parse(data.credit))}',
                        style: robotoMedium.copyWith(fontSize: 12,color:
                        data.transferType.toString().toLowerCase()=="loan"? Colors.red: Colors.green
                        ),
                        textAlign: TextAlign.center,
                      ),
                    ],
                  ) :
                  (data.credit==null && data.debit!=null) ?
                  Row(
                    children: [
                      Text(
                        //'${'debit'.tr}:',
                        '',
                        style: robotoMedium.copyWith(fontSize: 12,),
                        textAlign: TextAlign.center,
                      ),
                      SizedBox(width: 5,),
                      Text(
                        '${PriceConverter.convertPrice(double.parse(data.debit))}',
                        style: robotoMedium.copyWith(fontSize: 12,color: data.transferType.toString().toLowerCase()=="loan"? Colors.red: Colors.green),
                        textAlign: TextAlign.center,
                      ),
                    ],
                  )
                      : SizedBox(),

                ],
              )
            ],
          ),


          SizedBox(height: data.transferToPhone==null ? 0 : 5.0,),

          data.transferToPhone==null ? SizedBox() : Row(
            children: [
              Text('phone'.tr,
                style: robotoMedium.copyWith(color: Colors.black54,fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
              ),
              SizedBox(width: 5.0,),

              Text(data.transferToPhone.toString(),
                style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
              ),
              SizedBox(width: 10,),
              InkWell(child: Container(
                height: 25, width: 25,
                decoration: BoxDecoration(
                  shape: BoxShape.circle,
                  color: Colors.blue.withOpacity(0.2),
                ),
                child: Icon(Icons.call, color: Colors.blue, size: 20),
              ),
                  onTap: () async {
                    if(await canLaunchUrlString('tel:${data.transferToPhone.toString()}')) {
                      launchUrlString('tel:${data.transferToPhone.toString()}');
                    }else {
                      showCustomSnackBar('${'can_not_launch'.tr} ${data.transferToPhone.toString()}');
                    }
                  })
              ,SizedBox(width: 10,),

              InkWell(child: Container(
                height: 25, width: 25,
                decoration: BoxDecoration(
                  shape: BoxShape.circle,
                  color: Colors.red.withOpacity(0.2),
                ),
                child: Image.asset(Images.whatsapp, width: 30,
                  height: 30,fit: BoxFit.fill,),
              ), onTap: ()
              async {
                var whatsappUrl =
                    "whatsapp://send?phone=${data.transferToPhone.toString()}" ;
                //  + "&text=${Uri.encodeComponent("hi")}";

                if(await canLaunchUrlString(whatsappUrl)) {
                  launchUrlString(whatsappUrl);
                }else {
                  showCustomSnackBar('${'can_not_launch'.tr} ${data.transferToPhone.toString()}');
                }
              }),
            ],
          ) ,

          SizedBox(height: data.transferToEmail==null ? 0 : 5.0,),
          data.transferToEmail==null ? SizedBox()
              :  Row(
            children: [
              Text('email'.tr,
                style: robotoMedium.copyWith(color: Colors.black54,fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
              ),
              SizedBox(width: 5.0,),

              Expanded(child: Text(data.transferToEmail.toString(),
                style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
              )),
              SizedBox(width: 10,),
              InkWell(child: Container(
                height: 25, width: 25,
                decoration: BoxDecoration(
                  shape: BoxShape.circle,
                  color: Colors.red.withOpacity(0.2),
                ),
                child: Icon(Icons.mail_outline, color: Colors.red, size: 20),
              ), onTap: ()
              async {
                final Uri emailLaunchUri = Uri(
                  scheme: 'mailto',
                  path: data.transferToEmail.toString(),
                );
                launchUrlString(emailLaunchUri.toString());
              }),
            ],
          ) ,


          SizedBox(height: (data.primeName==null && data.primeName==null) ? 0 : 5.0,),

          Row(mainAxisAlignment: MainAxisAlignment.start,children: [

            data.primeName==null ? SizedBox() : Row(
              children: [
                Text('Transfer By: ',
                  style: robotoMedium.copyWith(color: Colors.black54,fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
                ),
                Text(
                  '${data.primeName.toString()}',
                  style: robotoMedium.copyWith(fontSize: 12,color: Colors.blueGrey),
                  textAlign: TextAlign.center,
                ),
              ],
            ),
            SizedBox(width: 5,),

            data.primeAccountNo==null ? SizedBox() :   Text(
              '(${data.primeAccountNo.toString()})',
              style: robotoMedium.copyWith(fontSize: 12,color: Colors.blueGrey),
              textAlign: TextAlign.center,
            )
          ],),

          SizedBox(height: data.primePhone==null ? 0 : 5.0,),
          data.primePhone==null ? SizedBox() : Row(
            children: [

              Text('phone'.tr,
                style: robotoMedium.copyWith(color: Colors.black54,fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
              ),
              SizedBox(width: 5.0,),

              Text('${data.primePhone.toString()}',
                style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeDefault,color: Colors.blueGrey), maxLines: 1, overflow: TextOverflow.ellipsis,
              ),
              SizedBox(width: 10,),

              InkWell(child: Container(
                height: 25, width: 25,
                decoration: BoxDecoration(
                  shape: BoxShape.circle,
                  color: Colors.blue.withOpacity(0.2),
                ),
                child: Icon(Icons.call, color: Colors.blue, size: 20),
              ),
              onTap: () async {
                    if(await canLaunchUrlString('tel:${data.primePhone}')) {
                      launchUrlString('tel:${data.primePhone}');
                    }else {
                      showCustomSnackBar('${'can_not_launch'.tr} ${data.primePhone}');
                    }
                  }),

              SizedBox(width: 10,),
              InkWell(child: Container(
                height: 25, width: 25,
                decoration: BoxDecoration(
                  shape: BoxShape.circle,
                  color: Colors.red.withOpacity(0.2),
                ),
                child: Image.asset(Images.whatsapp, width: 30,
                  height: 30,fit: BoxFit.fill,),
              ), onTap: ()
              async {
                var whatsappUrl =
                    "whatsapp://send?phone=${data.primePhone}" ;
                //  + "&text=${Uri.encodeComponent("hi")}";

                if(await canLaunchUrlString(whatsappUrl)) {
                  launchUrlString(whatsappUrl);
                }else {
                  showCustomSnackBar('${'can_not_launch'.tr} ${data.primePhone}');
                }
              }),

            ],
          ) ,
          SizedBox(height:preFilter=='loan'.tr ? 5.0: 0.0,),

          preFilter=='loan'.tr ?
          Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,children: [

            Row(
              children: [
                Text(

                  'loan_recovery'.tr,
                  style: robotoMedium.copyWith(fontSize: 12,),
                  textAlign: TextAlign.center,
                ),
                SizedBox(width: 5,),
                Text(
                  '${PriceConverter.convertPrice(double.parse(data.loanReceived.toString()))}',
                  style: robotoMedium.copyWith(fontSize: 12,color: Colors.green),
                  textAlign: TextAlign.center,
                ),
              ],
            ),

            Row(
              children: [
                Text(
                  'balance'.tr,
                  style: robotoMedium.copyWith(fontSize: 12,),
                  textAlign: TextAlign.center,
                ),
                SizedBox(width: 5,),
                Text(
                  remainingLoanAmt(double.parse(data.debit==null ? data.credit : data.debit), data.loanReceived)==-1? 'Invalid data found' : '${PriceConverter.convertPrice(remainingLoanAmt(double.parse(data.debit==null ? data.credit : data.debit), data.loanReceived))}',
                  style: robotoMedium.copyWith(fontSize: 12,color: data.transferType.toString().toLowerCase()=="loan"? Colors.red: Colors.green),
                  textAlign: TextAlign.center,
                ),
              ],
            )
          ],)
          : SizedBox(),


          SizedBox(height: data.loanDeductionPercentage==null ? 0 : 5.0,),
          data.loanDeductionPercentage==null ? SizedBox() : Row(
            children: [

              Text('Deduction %: '.tr,
                style: robotoMedium.copyWith(color: Colors.black54,fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
              ),
              SizedBox(width: 5.0,),

              Text('${data.loanDeductionPercentage.toString()}',
                style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeDefault,color: Colors.blueGrey), maxLines: 1, overflow: TextOverflow.ellipsis,
              ),

            ],
          ) ,


          SizedBox(height: data.remarks==null ? 0 : 5.0,),
          data.remarks==null ? SizedBox() : Row(
            children: [

              Text('remark'.tr,
                style: robotoMedium.copyWith(color: Colors.black54,fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
              ),
              SizedBox(width: 5.0,),

              Text('${data.remarks.toString()}',
                style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeDefault,color: Colors.grey), maxLines: 1, overflow: TextOverflow.ellipsis,
              ),

            ],
          ) ,

        ]);
  }
}

class ClosingDetailsItem extends StatelessWidget {
  final int index;
  final bool fromWallet;
  final String preFilter;
  // final List<Transaction> data;
  final WalletStatementData data;
  const ClosingDetailsItem({Key key, @required this.index, @required this.fromWallet, @required this.data, @required this.preFilter}) : super(key: key);


  @override
  Widget build(BuildContext context) {
    return Column(crossAxisAlignment: CrossAxisAlignment.start,
        children: [

          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              Row(children: [Text( 'Prime ID: ',
                style: robotoMedium.copyWith(color: Colors.black54,fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
              ),
                Text(data.primeAccountNo==null? 'NA' : '${data.primeAccountNo.toString()}',
                  style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
                )],),

              Row(
                children: [
                  data.credit!=null ?
                  Row(
                    children: [
                      //128.43
                      Text(
                        //'${'credit'.tr}:',
                        '',
                        style: robotoMedium.copyWith(color: Colors.black54,fontSize: 12,),
                        textAlign: TextAlign.center,
                      ),
                      SizedBox(width: 5,),
                      Text(
                        '${PriceConverter.convertPrice(double.parse(data.credit))}',
                        style: robotoMedium.copyWith(fontSize: 12,color:
                        data.transferType.toString().toLowerCase()=="loan"? Colors.red: Colors.green
                        ),
                        textAlign: TextAlign.center,
                      ),
                    ],
                  )
                      : SizedBox(),

                ],
              )
            ],
          ),
          SizedBox(height: 5.0,),
          Text('${data.primeName.toString()}',
            style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
          ),

          SizedBox(height: 5.0,),

          Row(
            children: [
              Text('phone'.tr,
                style: robotoMedium.copyWith(color: Colors.black54,fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
              ),
              SizedBox(width: 5.0,),

              Text(data.primePhone.toString(),
                style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
              ),
              SizedBox(width: 10,),
              InkWell(child: Container(
                height: 25, width: 25,
                decoration: BoxDecoration(
                  shape: BoxShape.circle,
                  color: Colors.blue.withOpacity(0.2),
                ),
                child: Icon(Icons.call, color: Colors.blue, size: 20),
              ),
                  onTap: () async {
                    if(await canLaunchUrlString('tel:${data.transferToPhone.toString()}')) {
                      launchUrlString('tel:${data.transferToPhone.toString()}');
                    }else {
                      showCustomSnackBar('${'can_not_launch'.tr} ${data.transferToPhone.toString()}');
                    }
                  })
              ,SizedBox(width: 10,),

              InkWell(child: Container(
                height: 25, width: 25,
                decoration: BoxDecoration(
                  shape: BoxShape.circle,
                  color: Colors.red.withOpacity(0.2),
                ),
                child: Image.asset(Images.whatsapp, width: 30,
                  height: 30,fit: BoxFit.fill,),
              ), onTap: ()
              async {
                var whatsappUrl =
                    "whatsapp://send?phone=${data.transferToPhone.toString()}" ;
                //  + "&text=${Uri.encodeComponent("hi")}";

                if(await canLaunchUrlString(whatsappUrl)) {
                  launchUrlString(whatsappUrl);
                }else {
                  showCustomSnackBar('${'can_not_launch'.tr} ${data.transferToPhone.toString()}');
                }
              }),
            ],
          ) ,

          SizedBox(height: 5.0,),

           Row(
            children:[
              Text('Sponsor ID: ',
                style: robotoMedium.copyWith(color: Colors.black54,fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
              ),
              SizedBox(width: 5.0,),

              Text(data.sponsorPrimeAccountNo.toString(),
                style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
              ),
            ],
          ) ,
          SizedBox(height: 5.0,),
          Text(data.sponsorName.toString(),
            style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
          ),


        ]);
  }
}

class ClosingItem extends StatelessWidget {
  final int index;
  final bool fromWallet;
  final String preFilter;
  final ClosingResponseData data;
   const ClosingItem({Key key, @required this.index, @required this.fromWallet, @required this.data, @required this.preFilter}) : super(key: key);


  String incomeType(String key){
    String name="";
    for(Types item in Get.find<WalletController>().transferTypesList){
      if(item.value==key){
        name=item.name;
        break;
      }
    }
    return name;
  }
  @override
  Widget build(BuildContext context) {
    return Column(crossAxisAlignment: CrossAxisAlignment.start,
        children: [

          Row(mainAxisAlignment: MainAxisAlignment.spaceBetween,children: [
            Row(
              children: [
                Text('date'.tr,
                  style: robotoMedium.copyWith(color: Colors.black54,fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
                ),
                SizedBox(width: 10,),

                Text(data.endate,
                  style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
                )
              ],
            ) ,

            Row(
              children: [
                Text('amount'.tr,
                  style: robotoMedium.copyWith(color: Colors.black54,fontSize: Dimensions.fontSizeDefault), maxLines: 1, overflow: TextOverflow.ellipsis,
                ),
                SizedBox(width: 10,),
                Text( data.payment==null? '0.0' : PriceConverter.convertPrice(double.parse(data.payment)),
                  style: robotoMedium.copyWith(fontSize: Dimensions.fontSizeDefault,color: Colors.green), maxLines: 1, overflow: TextOverflow.ellipsis,
                )
              ],
            ) ,
          ],),

          SizedBox(height: 5.0,),

          Padding(
            padding: const EdgeInsets.only(top: Dimensions.PADDING_SIZE_DEFAULT),
            child: Divider(color: Theme.of(context).disabledColor),
          ),
        ]);
  }
}